@@ -100,7 +100,7 @@ execute_clean_acls() {
 clean_up() {
   case $1 in
   --cleanZk)
-    execute_zk_command "rmr ${zparent}";
+    execute_zk_command "deleteall ${zparent}";
     ;;
   --cleanHdfs)
     execute_hdfs_command "-rm -R ${hrootdir}"
@@ -109,7 +109,7 @@ clean_up() {
     fi
     ;;
   --cleanAll)
-    execute_zk_command "rmr ${zparent}";
+    execute_zk_command "deleteall ${zparent}";
     execute_hdfs_command "-rm -R ${hrootdir}"
     if [ "${hbasewaldir}" != "null" ]; then
       execute_hdfs_command "-rm -R ${hbasewaldir}"
