@@ -30,7 +30,6 @@ export CLOVER_HOME=/home/jenkins/tools/clover/latest
 export MAVEN_HOME=/home/jenkins/tools/maven/latest
 
 export PATH=$PATH:$JAVA_HOME/bin:$ANT_HOME/bin:
-export MAVEN_OPTS="${MAVEN_OPTS:-"-Xmx3100M -XX:-UsePerfData -XX:MaxPermSize=256m"}"
+export MAVEN_OPTS="${MAVEN_OPTS:-"-Xmx3100M -XX:-UsePerfData"}"
 
 ulimit -n
-
