@@ -101,11 +101,7 @@ public class AsyncMetaTableAccessor {
     return future;
   }
 
-  /**
-   * Returns the HRegionLocation from meta for the given region
-   * @param regionName region we're looking for
-   * @return HRegionLocation for the given region
-   */
+  /** Returns the HRegionLocation from meta for the given region */
   public static CompletableFuture<Optional<HRegionLocation>>
     getRegionLocation(AsyncTable<?> metaTable, byte[] regionName) {
     CompletableFuture<Optional<HRegionLocation>> future = new CompletableFuture<>();
@@ -127,11 +123,7 @@ public class AsyncMetaTableAccessor {
     return future;
   }
 
-  /**
-   * Returns the HRegionLocation from meta for the given encoded region name
-   * @param encodedRegionName region we're looking for
-   * @return HRegionLocation for the given region
-   */
+  /** Returns the HRegionLocation from meta for the given encoded region name */
   public static CompletableFuture<Optional<HRegionLocation>>
     getRegionLocationWithEncodedName(AsyncTable<?> metaTable, byte[] encodedRegionName) {
     CompletableFuture<Optional<HRegionLocation>> future = new CompletableFuture<>();
@@ -176,7 +168,8 @@ public class AsyncMetaTableAccessor {
   }
 
   /**
-   * Used to get all region locations for the specific table.
+   * Used to get all region locations for the specific table
+   * @param metaTable scanner over meta table
    * @param tableName table we're looking for, can be null for getting all regions
    * @return the list of region locations. The return value will be wrapped by a
    *         {@link CompletableFuture}.
@@ -201,6 +194,7 @@ public class AsyncMetaTableAccessor {
 
   /**
    * Used to get table regions' info and server.
+   * @param metaTable                   scanner over meta table
    * @param tableName                   table we're looking for, can be null for getting all regions
    * @param excludeOfflinedSplitParents don't return split parents
    * @return the list of regioninfos and server. The return value will be wrapped by a
@@ -260,7 +254,8 @@ public class AsyncMetaTableAccessor {
 
   /**
    * Performs a scan of META table for given table.
-   * @param tableName table withing we scan
+   * @param metaTable scanner over meta table
+   * @param tableName table within we scan
    * @param type      scanned part of meta
    * @param visitor   Visitor invoked against each row
    */
@@ -272,11 +267,12 @@ public class AsyncMetaTableAccessor {
 
   /**
    * Performs a scan of META table for given table.
-   * @param startRow Where to start the scan
-   * @param stopRow  Where to stop the scan
-   * @param type     scanned part of meta
-   * @param maxRows  maximum rows to return
-   * @param visitor  Visitor invoked against each row
+   * @param metaTable scanner over meta table
+   * @param startRow  Where to start the scan
+   * @param stopRow   Where to stop the scan
+   * @param type      scanned part of meta
+   * @param maxRows   maximum rows to return
+   * @param visitor   Visitor invoked against each row
    */
   private static CompletableFuture<Void> scanMeta(AsyncTable<AdvancedScanResultConsumer> metaTable,
     byte[] startRow, byte[] stopRow, QueryType type, int maxRows, final Visitor visitor) {
@@ -412,9 +408,13 @@ public class AsyncMetaTableAccessor {
    *         can't deserialize the result.
    */
   private static Optional<RegionLocations> getRegionLocations(final Result r) {
-    if (r == null) return Optional.empty();
+    if (r == null) {
+      return Optional.empty();
+    }
     Optional<RegionInfo> regionInfo = getHRegionInfo(r, getRegionInfoColumn());
-    if (!regionInfo.isPresent()) return Optional.empty();
+    if (!regionInfo.isPresent()) {
+      return Optional.empty();
+    }
 
     List<HRegionLocation> locations = new ArrayList<HRegionLocation>(1);
     NavigableMap<byte[], NavigableMap<byte[], byte[]>> familyMap = r.getNoVersionMap();
@@ -422,15 +422,18 @@ public class AsyncMetaTableAccessor {
     locations.add(getRegionLocation(r, regionInfo.get(), 0));
 
     NavigableMap<byte[], byte[]> infoMap = familyMap.get(getCatalogFamily());
-    if (infoMap == null) return Optional.of(new RegionLocations(locations));
+    if (infoMap == null) {
+      return Optional.of(new RegionLocations(locations));
+    }
 
     // iterate until all serverName columns are seen
     int replicaId = 0;
     byte[] serverColumn = getServerColumn(replicaId);
-    SortedMap<byte[], byte[]> serverMap = null;
-    serverMap = infoMap.tailMap(serverColumn, false);
+    SortedMap<byte[], byte[]> serverMap = infoMap.tailMap(serverColumn, false);
 
-    if (serverMap.isEmpty()) return Optional.of(new RegionLocations(locations));
+    if (serverMap.isEmpty()) {
+      return Optional.of(new RegionLocations(locations));
+    }
 
     for (Map.Entry<byte[], byte[]> entry : serverMap.entrySet()) {
       replicaId = parseReplicaIdFromServerColumn(entry.getKey());
