@@ -35,6 +35,7 @@ import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder.ModifyableTableDescriptor;
 import org.apache.hadoop.hbase.exceptions.DeserializationException;
+import org.apache.hadoop.hbase.exceptions.HBaseException;
 import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.yetus.audience.InterfaceAudience;
@@ -56,8 +57,6 @@ public class HTableDescriptor implements TableDescriptor, Comparable<HTableDescr
   public static final Bytes OWNER_KEY = TableDescriptorBuilder.OWNER_KEY;
   public static final String READONLY = TableDescriptorBuilder.READONLY;
   public static final String COMPACTION_ENABLED = TableDescriptorBuilder.COMPACTION_ENABLED;
-  public static final boolean DEFAULT_NORMALIZATION_ENABLED =
-    TableDescriptorBuilder.DEFAULT_NORMALIZATION_ENABLED;
   public static final String SPLIT_ENABLED = TableDescriptorBuilder.SPLIT_ENABLED;
   public static final String MERGE_ENABLED = TableDescriptorBuilder.MERGE_ENABLED;
   public static final String MEMSTORE_FLUSHSIZE = TableDescriptorBuilder.MEMSTORE_FLUSHSIZE;
@@ -69,10 +68,14 @@ public class HTableDescriptor implements TableDescriptor, Comparable<HTableDescr
   public static final String REGION_MEMSTORE_REPLICATION =
     TableDescriptorBuilder.REGION_MEMSTORE_REPLICATION;
   public static final String NORMALIZATION_ENABLED = TableDescriptorBuilder.NORMALIZATION_ENABLED;
+  public static final boolean DEFAULT_NORMALIZATION_ENABLED =
+    TableDescriptorBuilder.DEFAULT_NORMALIZATION_ENABLED;
   public static final String NORMALIZER_TARGET_REGION_COUNT =
     TableDescriptorBuilder.NORMALIZER_TARGET_REGION_COUNT;
   public static final String NORMALIZER_TARGET_REGION_SIZE =
     TableDescriptorBuilder.NORMALIZER_TARGET_REGION_SIZE;
+  public static final String NORMALIZER_TARGET_REGION_SIZE_MB =
+    TableDescriptorBuilder.NORMALIZER_TARGET_REGION_SIZE_MB;
   public static final String PRIORITY = TableDescriptorBuilder.PRIORITY;
   public static final boolean DEFAULT_READONLY = TableDescriptorBuilder.DEFAULT_READONLY;
   public static final boolean DEFAULT_COMPACTION_ENABLED =
@@ -420,6 +423,11 @@ public class HTableDescriptor implements TableDescriptor, Comparable<HTableDescr
     return this;
   }
 
+  public HTableDescriptor setMaxFileSize(String maxFileSize) throws HBaseException {
+    getDelegateeForModification().setMaxFileSize(maxFileSize);
+    return this;
+  }
+
   /**
    * Returns the size of the memstore after which a flush to filesystem is triggered.
    * @return memory cache flush size for each hregion, -1 if not set.
@@ -440,6 +448,11 @@ public class HTableDescriptor implements TableDescriptor, Comparable<HTableDescr
     return this;
   }
 
+  public HTableDescriptor setMemStoreFlushSize(String memStoreFlushSize) throws HBaseException {
+    getDelegateeForModification().setMemStoreFlushSize(memStoreFlushSize);
+    return this;
+  }
+
   /**
    * This sets the class associated with the flush policy which determines determines the stores
    * need to be flushed when flushing a region. The class used by default is defined in
@@ -788,6 +801,7 @@ public class HTableDescriptor implements TableDescriptor, Comparable<HTableDescr
     new HTableDescriptor(TableDescriptorBuilder.NAMESPACE_TABLEDESC);
 
   /**
+   * Set the table owner.
    * @deprecated since 0.94.1
    * @see <a href="https://issues.apache.org/jira/browse/HBASE-6188">HBASE-6188</a>
    */
@@ -798,6 +812,7 @@ public class HTableDescriptor implements TableDescriptor, Comparable<HTableDescr
   }
 
   /**
+   * Set the table owner.
    * @deprecated since 0.94.1
    * @see <a href="https://issues.apache.org/jira/browse/HBASE-6188">HBASE-6188</a>
    */
@@ -809,6 +824,7 @@ public class HTableDescriptor implements TableDescriptor, Comparable<HTableDescr
   }
 
   /**
+   * Get the table owner.
    * @deprecated since 0.94.1
    * @see <a href="https://issues.apache.org/jira/browse/HBASE-6188">HBASE-6188</a>
    */
@@ -819,14 +835,14 @@ public class HTableDescriptor implements TableDescriptor, Comparable<HTableDescr
   }
 
   /**
-   * @return This instance serialized with pb with pb magic prefix
-   * @see #parseFrom(byte[])
+   * Returns This instance serialized with pb with pb magic prefix
    */
   public byte[] toByteArray() {
     return TableDescriptorBuilder.toByteArray(delegatee);
   }
 
   /**
+   * Parse the serialized representation of a {@link HTableDescriptor}
    * @param bytes A pb serialized {@link HTableDescriptor} instance with pb magic prefix
    * @return An instance of {@link HTableDescriptor} made from <code>bytes</code>
    * @see #toByteArray()
