@@ -61,6 +61,7 @@ import org.apache.hbase.thirdparty.com.google.common.collect.ImmutableList;
 public interface AsyncAdmin {
 
   /**
+   * Check if a table exists.
    * @param tableName Table to check.
    * @return True if table exists already. The return value will be wrapped by a
    *         {@link CompletableFuture}.
@@ -176,7 +177,27 @@ public interface AsyncAdmin {
    * Modify an existing table, more IRB friendly version.
    * @param desc modified description of the table
    */
-  CompletableFuture<Void> modifyTable(TableDescriptor desc);
+  default CompletableFuture<Void> modifyTable(TableDescriptor desc) {
+    return modifyTable(desc, true);
+  }
+
+  /**
+   * Modify an existing table, more IRB friendly version.
+   * @param desc          description of the table
+   * @param reopenRegions By default, 'modifyTable' reopens all regions, potentially causing a RIT
+   *                      (Region In Transition) storm in large tables. If set to 'false', regions
+   *                      will remain unaware of the modification until they are individually
+   *                      reopened. Please note that this may temporarily result in configuration
+   *                      inconsistencies among regions.
+   */
+  CompletableFuture<Void> modifyTable(TableDescriptor desc, boolean reopenRegions);
+
+  /**
+   * Change the store file tracker of the given table.
+   * @param tableName the table you want to change
+   * @param dstSFT    the destination store file tracker
+   */
+  CompletableFuture<Void> modifyTableStoreFileTracker(TableName tableName, String dstSFT);
 
   /**
    * Deletes a table.
@@ -203,6 +224,7 @@ public interface AsyncAdmin {
   CompletableFuture<Void> disableTable(TableName tableName);
 
   /**
+   * Check if a table is enabled.
    * @param tableName name of table to check
    * @return true if table is on-line. The return value will be wrapped by a
    *         {@link CompletableFuture}.
@@ -210,6 +232,7 @@ public interface AsyncAdmin {
   CompletableFuture<Boolean> isTableEnabled(TableName tableName);
 
   /**
+   * Check if a table is disabled.
    * @param tableName name of table to check
    * @return true if table is off-line. The return value will be wrapped by a
    *         {@link CompletableFuture}.
@@ -217,6 +240,7 @@ public interface AsyncAdmin {
   CompletableFuture<Boolean> isTableDisabled(TableName tableName);
 
   /**
+   * Check if a table is available.
    * @param tableName name of table to check
    * @return true if all regions of the table are available. The return value will be wrapped by a
    *         {@link CompletableFuture}.
@@ -257,6 +281,15 @@ public interface AsyncAdmin {
   CompletableFuture<Void> modifyColumnFamily(TableName tableName,
     ColumnFamilyDescriptor columnFamily);
 
+  /**
+   * Change the store file tracker of the given table's given family.
+   * @param tableName the table you want to change
+   * @param family    the family you want to change
+   * @param dstSFT    the destination store file tracker
+   */
+  CompletableFuture<Void> modifyColumnFamilyStoreFileTracker(TableName tableName, byte[] family,
+    String dstSFT);
+
   /**
    * Create a new namespace.
    * @param descriptor descriptor which describes the new namespace
@@ -582,11 +615,15 @@ public interface AsyncAdmin {
   CompletableFuture<Void> splitRegion(byte[] regionName, byte[] splitPoint);
 
   /**
+   * Assign an individual region.
    * @param regionName Encoded or full name of region to assign.
    */
   CompletableFuture<Void> assign(byte[] regionName);
 
   /**
+   * Unassign a region from current hosting regionserver. Region will then be assigned to a
+   * regionserver chosen at random. Region could be reassigned back to the same server. Use
+   * {@link #move(byte[], ServerName)} if you want to control the region movement.
    * @param regionName Encoded or full name of region to unassign.
    */
   CompletableFuture<Void> unassign(byte[] regionName);
@@ -866,8 +903,20 @@ public interface AsyncAdmin {
    * @param tableName    name of the table where the snapshot will be restored
    * @param restoreAcl   <code>true</code> to restore acl of snapshot
    */
+  default CompletableFuture<Void> cloneSnapshot(String snapshotName, TableName tableName,
+    boolean restoreAcl) {
+    return cloneSnapshot(snapshotName, tableName, restoreAcl, null);
+  }
+
+  /**
+   * Create a new table by cloning the snapshot content.
+   * @param snapshotName name of the snapshot to be cloned
+   * @param tableName    name of the table where the snapshot will be restored
+   * @param restoreAcl   <code>true</code> to restore acl of snapshot
+   * @param customSFT    specify the StroreFileTracker used for the table
+   */
   CompletableFuture<Void> cloneSnapshot(String snapshotName, TableName tableName,
-    boolean restoreAcl);
+    boolean restoreAcl, String customSFT);
 
   /**
    * List completed snapshots.
@@ -1127,18 +1176,19 @@ public interface AsyncAdmin {
 
   /**
    * Clear compacting queues on a region server.
-   * @param queues the set of queue name
+   * @param serverName The servername of the region server.
+   * @param queues     the set of queue name
    */
   CompletableFuture<Void> clearCompactionQueues(ServerName serverName, Set<String> queues);
 
   /**
-   * Get a list of {@link RegionMetrics} of all regions hosted on a region seerver.
-   * @return a list of {@link RegionMetrics} wrapped by {@link CompletableFuture}
+   * Get a list of {@link RegionMetrics} of all regions hosted on a region server.
+   * @return list of {@link RegionMetrics} wrapped by {@link CompletableFuture}
    */
   CompletableFuture<List<RegionMetrics>> getRegionMetrics(ServerName serverName);
 
   /**
-   * Get a list of {@link RegionMetrics} of all regions hosted on a region seerver for a table.
+   * Get a list of {@link RegionMetrics} of all regions hosted on a region server for a table.
    * @return a list of {@link RegionMetrics} wrapped by {@link CompletableFuture}
    */
   CompletableFuture<List<RegionMetrics>> getRegionMetrics(ServerName serverName,
@@ -1200,8 +1250,8 @@ public interface AsyncAdmin {
   CompletableFuture<Optional<Long>> getLastMajorCompactionTimestampForRegion(byte[] regionName);
 
   /**
-   * @return the list of supported security capabilities. The return value will be wrapped by a
-   *         {@link CompletableFuture}.
+   * Returns the list of supported security capabilities. The return value will be wrapped by a
+   * {@link CompletableFuture}.
    */
   CompletableFuture<List<SecurityCapability>> getSecurityCapabilities();
 
@@ -1234,7 +1284,7 @@ public interface AsyncAdmin {
    *         {@link CompletableFuture}.
    */
   default CompletableFuture<Boolean> balance() {
-    return balance(false);
+    return balance(BalanceRequest.defaultInstance()).thenApply(BalanceResponse::isBalancerRan);
   }
 
   /**
@@ -1244,8 +1294,22 @@ public interface AsyncAdmin {
    * @param forcible whether we should force balance even if there is region in transition.
    * @return True if balancer ran, false otherwise. The return value will be wrapped by a
    *         {@link CompletableFuture}.
+   * @deprecated Since 2.5.0. Will be removed in 4.0.0. Use {@link #balance(BalanceRequest)}
+   *             instead.
    */
-  CompletableFuture<Boolean> balance(boolean forcible);
+  @Deprecated
+  default CompletableFuture<Boolean> balance(boolean forcible) {
+    return balance(BalanceRequest.newBuilder().setIgnoreRegionsInTransition(forcible).build())
+      .thenApply(BalanceResponse::isBalancerRan);
+  }
+
+  /**
+   * Invoke the balancer with the given balance request. The BalanceRequest defines how the balancer
+   * will run. See {@link BalanceRequest} for more details.
+   * @param request defines how the balancer should run
+   * @return {@link BalanceResponse} with details about the results of the invocation.
+   */
+  CompletableFuture<BalanceResponse> balance(BalanceRequest request);
 
   /**
    * Query the current state of the balancer.
@@ -1332,9 +1396,7 @@ public interface AsyncAdmin {
    * one line lambda expression, like:
    *
    * <pre>
-   * <code>
-   * channel -> xxxService.newStub(channel)
-   * </code>
+   * channel -&gt; xxxService.newStub(channel)
    * </pre>
    *
    * @param stubMaker a delegation to the actual {@code newStub} call.
@@ -1355,9 +1417,7 @@ public interface AsyncAdmin {
    * one line lambda expression, like:
    *
    * <pre>
-   * <code>
-   * channel -> xxxService.newStub(channel)
-   * </code>
+   * channel -&gt; xxxService.newStub(channel)
    * </pre>
    *
    * @param stubMaker  a delegation to the actual {@code newStub} call.
@@ -1380,6 +1440,14 @@ public interface AsyncAdmin {
       .thenApply(ClusterMetrics::getDeadServerNames);
   }
 
+  /**
+   * List all the unknown region servers.
+   */
+  default CompletableFuture<List<ServerName>> listUnknownServers() {
+    return this.getClusterMetrics(EnumSet.of(Option.UNKNOWN_SERVERS))
+      .thenApply(ClusterMetrics::getUnknownServerNames);
+  }
+
   /**
    * Clear dead region servers from master.
    * @param servers list of dead region servers.
@@ -1573,8 +1641,12 @@ public interface AsyncAdmin {
    * @param serverType   enum for server type: HMaster or RegionServer
    * @param limit        put a limit to list of records that server should send in response
    * @param filterParams additional filter params
-   * @return Log entries representing online records from servers
    */
   CompletableFuture<List<LogEntry>> getLogEntries(Set<ServerName> serverNames, String logType,
     ServerType serverType, int limit, Map<String, Object> filterParams);
+
+  /**
+   * Flush master local region
+   */
+  CompletableFuture<Void> flushMasterStore();
 }
