@@ -58,7 +58,7 @@ class AsyncRpcRetryingCallerFactory {
 
     protected long pauseNs = conn.connConf.getPauseNs();
 
-    protected long pauseForCQTBENs = conn.connConf.getPauseForCQTBENs();
+    protected long pauseNsForServerOverloaded = conn.connConf.getPauseNsForServerOverloaded();
 
     protected int maxAttempts = retries2Attempts(conn.connConf.getMaxRetries());
 
@@ -119,8 +119,8 @@ class AsyncRpcRetryingCallerFactory {
       return this;
     }
 
-    public SingleRequestCallerBuilder<T> pauseForCQTBE(long pause, TimeUnit unit) {
-      this.pauseForCQTBENs = unit.toNanos(pause);
+    public SingleRequestCallerBuilder<T> pauseForServerOverloaded(long pause, TimeUnit unit) {
+      this.pauseNsForServerOverloaded = unit.toNanos(pause);
       return this;
     }
 
@@ -156,8 +156,8 @@ class AsyncRpcRetryingCallerFactory {
     public AsyncSingleRequestRpcRetryingCaller<T> build() {
       preCheck();
       return new AsyncSingleRequestRpcRetryingCaller<>(retryTimer, conn, tableName, row, replicaId,
-        locateType, callable, priority, pauseNs, pauseForCQTBENs, maxAttempts, operationTimeoutNs,
-        rpcTimeoutNs, startLogErrorsCnt);
+        locateType, callable, priority, pauseNs, pauseNsForServerOverloaded, maxAttempts,
+        operationTimeoutNs, rpcTimeoutNs, startLogErrorsCnt);
     }
 
     /**
@@ -263,8 +263,8 @@ class AsyncRpcRetryingCallerFactory {
       return this;
     }
 
-    public ScanSingleRegionCallerBuilder pauseForCQTBE(long pause, TimeUnit unit) {
-      this.pauseForCQTBENs = unit.toNanos(pause);
+    public ScanSingleRegionCallerBuilder pauseForServerOverloaded(long pause, TimeUnit unit) {
+      this.pauseNsForServerOverloaded = unit.toNanos(pause);
       return this;
     }
 
@@ -292,8 +292,8 @@ class AsyncRpcRetryingCallerFactory {
       preCheck();
       return new AsyncScanSingleRegionRpcRetryingCaller(retryTimer, conn, scan, scanMetrics,
         scannerId, resultCache, consumer, stub, loc, isRegionServerRemote, priority,
-        scannerLeaseTimeoutPeriodNs, pauseNs, pauseForCQTBENs, maxAttempts, scanTimeoutNs,
-        rpcTimeoutNs, startLogErrorsCnt);
+        scannerLeaseTimeoutPeriodNs, pauseNs, pauseNsForServerOverloaded, maxAttempts,
+        scanTimeoutNs, rpcTimeoutNs, startLogErrorsCnt);
     }
 
     /**
@@ -347,8 +347,8 @@ class AsyncRpcRetryingCallerFactory {
       return this;
     }
 
-    public BatchCallerBuilder pauseForCQTBE(long pause, TimeUnit unit) {
-      this.pauseForCQTBENs = unit.toNanos(pause);
+    public BatchCallerBuilder pauseForServerOverloaded(long pause, TimeUnit unit) {
+      this.pauseNsForServerOverloaded = unit.toNanos(pause);
       return this;
     }
 
@@ -364,7 +364,8 @@ class AsyncRpcRetryingCallerFactory {
 
     public <T> AsyncBatchRpcRetryingCaller<T> build() {
       return new AsyncBatchRpcRetryingCaller<>(retryTimer, conn, tableName, actions, pauseNs,
-        pauseForCQTBENs, maxAttempts, operationTimeoutNs, rpcTimeoutNs, startLogErrorsCnt);
+        pauseNsForServerOverloaded, maxAttempts, operationTimeoutNs, rpcTimeoutNs,
+        startLogErrorsCnt);
     }
 
     public <T> List<CompletableFuture<T>> call() {
@@ -406,8 +407,8 @@ class AsyncRpcRetryingCallerFactory {
       return this;
     }
 
-    public MasterRequestCallerBuilder<T> pauseForCQTBE(long pause, TimeUnit unit) {
-      this.pauseForCQTBENs = unit.toNanos(pause);
+    public MasterRequestCallerBuilder<T> pauseForServerOverloaded(long pause, TimeUnit unit) {
+      this.pauseNsForServerOverloaded = unit.toNanos(pause);
       return this;
     }
 
@@ -438,7 +439,8 @@ class AsyncRpcRetryingCallerFactory {
     public AsyncMasterRequestRpcRetryingCaller<T> build() {
       preCheck();
       return new AsyncMasterRequestRpcRetryingCaller<T>(retryTimer, conn, callable, priority,
-        pauseNs, pauseForCQTBENs, maxAttempts, operationTimeoutNs, rpcTimeoutNs, startLogErrorsCnt);
+        pauseNs, pauseNsForServerOverloaded, maxAttempts, operationTimeoutNs, rpcTimeoutNs,
+        startLogErrorsCnt);
     }
 
     /**
@@ -487,8 +489,8 @@ class AsyncRpcRetryingCallerFactory {
       return this;
     }
 
-    public AdminRequestCallerBuilder<T> pauseForCQTBE(long pause, TimeUnit unit) {
-      this.pauseForCQTBENs = unit.toNanos(pause);
+    public AdminRequestCallerBuilder<T> pauseForServerOverloaded(long pause, TimeUnit unit) {
+      this.pauseNsForServerOverloaded = unit.toNanos(pause);
       return this;
     }
 
@@ -514,8 +516,9 @@ class AsyncRpcRetryingCallerFactory {
 
     public AsyncAdminRequestRetryingCaller<T> build() {
       return new AsyncAdminRequestRetryingCaller<T>(retryTimer, conn, priority, pauseNs,
-        pauseForCQTBENs, maxAttempts, operationTimeoutNs, rpcTimeoutNs, startLogErrorsCnt,
-        checkNotNull(serverName, "serverName is null"), checkNotNull(callable, "action is null"));
+        pauseNsForServerOverloaded, maxAttempts, operationTimeoutNs, rpcTimeoutNs,
+        startLogErrorsCnt, checkNotNull(serverName, "serverName is null"),
+        checkNotNull(callable, "action is null"));
     }
 
     public CompletableFuture<T> call() {
@@ -558,8 +561,8 @@ class AsyncRpcRetryingCallerFactory {
       return this;
     }
 
-    public ServerRequestCallerBuilder<T> pauseForCQTBE(long pause, TimeUnit unit) {
-      this.pauseForCQTBENs = unit.toNanos(pause);
+    public ServerRequestCallerBuilder<T> pauseForServerOverloaded(long pause, TimeUnit unit) {
+      this.pauseNsForServerOverloaded = unit.toNanos(pause);
       return this;
     }
 
@@ -579,9 +582,10 @@ class AsyncRpcRetryingCallerFactory {
     }
 
     public AsyncServerRequestRpcRetryingCaller<T> build() {
-      return new AsyncServerRequestRpcRetryingCaller<T>(retryTimer, conn, pauseNs, pauseForCQTBENs,
-        maxAttempts, operationTimeoutNs, rpcTimeoutNs, startLogErrorsCnt,
-        checkNotNull(serverName, "serverName is null"), checkNotNull(callable, "action is null"));
+      return new AsyncServerRequestRpcRetryingCaller<T>(retryTimer, conn, pauseNs,
+        pauseNsForServerOverloaded, maxAttempts, operationTimeoutNs, rpcTimeoutNs,
+        startLogErrorsCnt, checkNotNull(serverName, "serverName is null"),
+        checkNotNull(callable, "action is null"));
     }
 
     public CompletableFuture<T> call() {
