@@ -37,6 +37,7 @@ import java.util.concurrent.atomic.AtomicLong;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.ipc.RpcControllerFactory;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.apache.yetus.audience.InterfaceStability;
 import org.slf4j.Logger;
@@ -85,6 +86,7 @@ public class BufferedMutatorImpl implements BufferedMutator {
   private Timer writeBufferPeriodicFlushTimer = null;
 
   private final int maxKeyValueSize;
+  private final int maxMutations;
   private final ExecutorService pool;
   private final AtomicInteger rpcTimeout;
   private final AtomicInteger operationTimeout;
@@ -127,6 +129,10 @@ public class BufferedMutatorImpl implements BufferedMutator {
       ? params.getMaxKeyValueSize()
       : tableConf.getMaxKeyValueSize();
 
+    this.maxMutations = params.getMaxMutations() != UNSET
+      ? params.getMaxMutations()
+      : conn.getConnectionConfiguration().getBufferedMutatorMaxMutations();
+
     this.rpcTimeout = new AtomicInteger(params.getRpcTimeout() != UNSET
       ? params.getRpcTimeout()
       : conn.getConnectionConfiguration().getWriteRpcTimeout());
@@ -190,7 +196,7 @@ public class BufferedMutatorImpl implements BufferedMutator {
     }
 
     if (currentWriteBufferSize.get() == 0) {
-      firstRecordInBufferTimestamp.set(System.currentTimeMillis());
+      firstRecordInBufferTimestamp.set(EnvironmentEdgeManager.currentTime());
     }
     currentWriteBufferSize.addAndGet(toAddSize);
     writeAsyncBuffer.addAll(ms);
@@ -209,7 +215,7 @@ public class BufferedMutatorImpl implements BufferedMutator {
     if (currentWriteBufferSize.get() == 0) {
       return; // Nothing to flush
     }
-    long now = System.currentTimeMillis();
+    long now = EnvironmentEdgeManager.currentTime();
     if (firstRecordInBufferTimestamp.get() + writeBufferPeriodicFlushTimeoutMs.get() > now) {
       return; // No need to flush yet
     }
@@ -279,8 +285,11 @@ public class BufferedMutatorImpl implements BufferedMutator {
     throws InterruptedIOException, RetriesExhaustedWithDetailsException {
     List<RetriesExhaustedWithDetailsException> errors = new ArrayList<>();
     while (true) {
-      if (!flushAll && currentWriteBufferSize.get() <= writeBufferSize) {
-        // There is the room to accept more mutations.
+      if (
+        !flushAll && (currentWriteBufferSize.get() <= writeBufferSize)
+          && (maxMutations == UNSET || size() < maxMutations)
+      ) {
+        // There is room to accept more mutations.
         break;
       }
       AsyncRequestFuture asf;
