@@ -21,6 +21,9 @@ import static org.apache.hadoop.hbase.client.ConnectionUtils.calcEstimatedSize;
 import static org.apache.hadoop.hbase.client.ConnectionUtils.createScanResultCache;
 import static org.apache.hadoop.hbase.client.ConnectionUtils.incRegionCountMetrics;
 
+import io.opentelemetry.api.trace.Span;
+import io.opentelemetry.api.trace.StatusCode;
+import io.opentelemetry.context.Scope;
 import java.io.IOException;
 import java.io.InterruptedIOException;
 import java.util.ArrayDeque;
@@ -31,16 +34,19 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HRegionInfo;
+import org.apache.hadoop.hbase.HRegionLocation;
 import org.apache.hadoop.hbase.NotServingRegionException;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.UnknownScannerException;
 import org.apache.hadoop.hbase.client.ScannerCallable.MoreResults;
+import org.apache.hadoop.hbase.client.metrics.ScanMetrics;
 import org.apache.hadoop.hbase.exceptions.OutOfOrderScannerNextException;
 import org.apache.hadoop.hbase.exceptions.ScannerResetException;
 import org.apache.hadoop.hbase.ipc.RpcControllerFactory;
 import org.apache.hadoop.hbase.regionserver.LeaseException;
 import org.apache.hadoop.hbase.regionserver.RegionServerStoppedException;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -71,11 +77,13 @@ public abstract class ClientScanner extends AbstractClientScanner {
   protected final long maxScannerResultSize;
   private final ClusterConnection connection;
   protected final TableName tableName;
+  protected final int readRpcTimeout;
   protected final int scannerTimeout;
   protected boolean scanMetricsPublished = false;
   protected RpcRetryingCaller<Result[]> caller;
   protected RpcControllerFactory rpcControllerFactory;
   protected Configuration conf;
+  protected final Span span;
   // The timeout on the primary. Applicable if there are multiple replicas for a region
   // In that case, we will only wait for this much timeout on the primary before going
   // to the replicas and trying the same scan. Note that the retries will still happen
@@ -95,15 +103,15 @@ public abstract class ClientScanner extends AbstractClientScanner {
    */
   public ClientScanner(final Configuration conf, final Scan scan, final TableName tableName,
     ClusterConnection connection, RpcRetryingCallerFactory rpcFactory,
-    RpcControllerFactory controllerFactory, ExecutorService pool, int primaryOperationTimeout)
-    throws IOException {
+    RpcControllerFactory controllerFactory, ExecutorService pool, int scanReadRpcTimeout,
+    int scannerTimeout, int primaryOperationTimeout) throws IOException {
     if (LOG.isTraceEnabled()) {
       LOG.trace(
         "Scan table=" + tableName + ", startRow=" + Bytes.toStringBinary(scan.getStartRow()));
     }
     this.scan = scan;
     this.tableName = tableName;
-    this.lastNext = System.currentTimeMillis();
+    this.lastNext = EnvironmentEdgeManager.currentTime();
     this.connection = connection;
     this.pool = pool;
     this.primaryOperationTimeout = primaryOperationTimeout;
@@ -115,9 +123,13 @@ public abstract class ClientScanner extends AbstractClientScanner {
       this.maxScannerResultSize = conf.getLong(HConstants.HBASE_CLIENT_SCANNER_MAX_RESULT_SIZE_KEY,
         HConstants.DEFAULT_HBASE_CLIENT_SCANNER_MAX_RESULT_SIZE);
     }
-    this.scannerTimeout = conf.getInt(HConstants.HBASE_CLIENT_SCANNER_TIMEOUT_PERIOD,
-      HConstants.DEFAULT_HBASE_CLIENT_SCANNER_TIMEOUT_PERIOD);
+    this.readRpcTimeout = scanReadRpcTimeout;
+    this.scannerTimeout = scannerTimeout;
 
+    if (scan.isScanMetricsByRegionEnabled() && scan.getConsistency() == Consistency.TIMELINE) {
+      scan.setEnableScanMetricsByRegion(false);
+      LOG.warn("Scan metrics by region is not supported for timeline consistency in HBase 2");
+    }
     // check if application wants to collect scan metrics
     initScanMetrics(scan);
 
@@ -133,15 +145,14 @@ public abstract class ClientScanner extends AbstractClientScanner {
     this.rpcControllerFactory = controllerFactory;
 
     this.conf = conf;
+    this.span = Span.current();
 
     this.scanResultCache = createScanResultCache(scan);
     initCache();
   }
 
   protected final int getScanReplicaId() {
-    return scan.getReplicaId() >= RegionReplicaUtil.DEFAULT_REPLICA_ID
-      ? scan.getReplicaId()
-      : RegionReplicaUtil.DEFAULT_REPLICA_ID;
+    return Math.max(scan.getReplicaId(), RegionReplicaUtil.DEFAULT_REPLICA_ID);
   }
 
   protected ClusterConnection getConnection() {
@@ -244,9 +255,12 @@ public abstract class ClientScanner extends AbstractClientScanner {
     // clear the current region, we will set a new value to it after the first call of the new
     // callable.
     this.currentRegion = null;
-    this.callable =
-      new ScannerCallableWithReplicas(getTable(), getConnection(), createScannerCallable(), pool,
-        primaryOperationTimeout, scan, getRetries(), scannerTimeout, caching, conf, caller);
+    if (isScanMetricsByRegionEnabled()) {
+      scanMetrics.moveToNextRegion();
+    }
+    this.callable = new ScannerCallableWithReplicas(getTable(), getConnection(),
+      createScannerCallable(), pool, primaryOperationTimeout, scan, getRetries(), readRpcTimeout,
+      scannerTimeout, caching, conf, caller);
     this.callable.setCaching(this.caching);
     incRegionCountMetrics(scanMetrics);
     return true;
@@ -266,6 +280,7 @@ public abstract class ClientScanner extends AbstractClientScanner {
     Result[] rrs = caller.callWithoutRetries(callable, scannerTimeout);
     if (currentRegion == null && updateCurrentRegion) {
       currentRegion = callable.getHRegionInfo();
+      initScanMetricsRegionInfo();
     }
     return rrs;
   }
@@ -322,7 +337,7 @@ public abstract class ClientScanner extends AbstractClientScanner {
     return cache != null ? cache.size() : 0;
   }
 
-  private boolean scanExhausted(Result[] values) {
+  private boolean scanExhausted() {
     return callable.moreResultsForScan() == MoreResults.NO;
   }
 
@@ -452,9 +467,10 @@ public abstract class ClientScanner extends AbstractClientScanner {
         }
         continue;
       }
-      long currentTime = System.currentTimeMillis();
+      long currentTime = EnvironmentEdgeManager.currentTime();
       if (this.scanMetrics != null) {
-        this.scanMetrics.sumOfMillisSecBetweenNexts.addAndGet(currentTime - lastNext);
+        this.scanMetrics.addToCounter(ScanMetrics.MILLIS_BETWEEN_NEXTS_METRIC_NAME,
+          currentTime - lastNext);
       }
       lastNext = currentTime;
       // Groom the array of Results that we received back from the server before adding that
@@ -479,7 +495,7 @@ public abstract class ClientScanner extends AbstractClientScanner {
         assert newLimit >= 0;
         scan.setLimit(newLimit);
       }
-      if (scan.getLimit() == 0 || scanExhausted(values)) {
+      if (scan.getLimit() == 0 || scanExhausted()) {
         closeScanner();
         closed = true;
         break;
@@ -548,40 +564,52 @@ public abstract class ClientScanner extends AbstractClientScanner {
 
   @Override
   public void close() {
-    if (!scanMetricsPublished) writeScanMetrics();
-    if (callable != null) {
-      callable.setClose();
-      try {
-        call(callable, caller, scannerTimeout, false);
-      } catch (UnknownScannerException e) {
-        // We used to catch this error, interpret, and rethrow. However, we
-        // have since decided that it's not nice for a scanner's close to
-        // throw exceptions. Chances are it was just due to lease time out.
-        LOG.debug("scanner failed to close", e);
-      } catch (IOException e) {
-        /* An exception other than UnknownScanner is unexpected. */
-        LOG.warn("scanner failed to close.", e);
+    try (Scope ignored = span.makeCurrent()) {
+      if (!scanMetricsPublished) {
+        writeScanMetrics();
       }
-      callable = null;
+      if (callable != null) {
+        callable.setClose();
+        try {
+          call(callable, caller, scannerTimeout, false);
+        } catch (UnknownScannerException e) {
+          // We used to catch this error, interpret, and rethrow. However, we
+          // have since decided that it's not nice for a scanner's close to
+          // throw exceptions. Chances are it was just due to lease time out.
+          LOG.debug("scanner failed to close", e);
+        } catch (IOException e) {
+          /* An exception other than UnknownScanner is unexpected. */
+          LOG.warn("scanner failed to close.", e);
+          span.recordException(e);
+          span.setStatus(StatusCode.ERROR);
+        }
+        callable = null;
+      }
+      closed = true;
+      span.setStatus(StatusCode.OK);
+    } finally {
+      span.end();
     }
-    closed = true;
   }
 
   @Override
   public boolean renewLease() {
-    if (callable == null) {
-      return false;
-    }
-    // do not return any rows, do not advance the scanner
-    callable.setRenew(true);
-    try {
-      this.caller.callWithoutRetries(callable, this.scannerTimeout);
-      return true;
-    } catch (Exception e) {
-      LOG.debug("scanner failed to renew lease", e);
-      return false;
-    } finally {
-      callable.setRenew(false);
+    try (Scope ignored = span.makeCurrent()) {
+      if (callable == null) {
+        return false;
+      }
+      // do not return any rows, do not advance the scanner
+      callable.setRenew(true);
+      try {
+        this.caller.callWithoutRetries(callable, this.scannerTimeout);
+        return true;
+      } catch (Exception e) {
+        LOG.debug("scanner failed to renew lease", e);
+        span.recordException(e);
+        return false;
+      } finally {
+        callable.setRenew(false);
+      }
     }
   }
 
@@ -591,6 +619,16 @@ public abstract class ClientScanner extends AbstractClientScanner {
 
   @Override
   public Result next() throws IOException {
-    return nextWithSyncCache();
+    try (Scope ignored = span.makeCurrent()) {
+      return nextWithSyncCache();
+    }
+  }
+
+  private void initScanMetricsRegionInfo() {
+    if (isScanMetricsByRegionEnabled()) {
+      HRegionLocation location = callable.getLocation();
+      String encodedRegionName = location.getRegion().getEncodedName();
+      scanMetrics.initScanMetricsRegionInfo(encodedRegionName, location.getServerName());
+    }
   }
 }
