@@ -56,8 +56,8 @@ public interface ClusterConnection extends Connection {
   /**
    * Use this api to check if the table has been created with the specified number of splitkeys
    * which was used while creating the given table. Note : If this api is used after a table's
-   * region gets splitted, the api may return false. n * tableName n * splitKeys used while creating
-   * table n * if a remote or network exception occurs
+   * region gets splitted, the api may return false. tableName splitKeys used while creating table
+   * if a remote or network exception occurs
    */
   boolean isTableAvailable(TableName tableName, byte[][] splitKeys) throws IOException;
 
@@ -111,12 +111,6 @@ public interface ClusterConnection extends Connection {
    */
   void clearRegionCache(final TableName tableName);
 
-  /**
-   * Deletes cached locations for the specific region.
-   * @param location The location object for the region, to be purged from cache.
-   */
-  void deleteCachedRegionLocation(final HRegionLocation location);
-
   /**
    * Find the location of the region of <i>tableName</i> that <i>row</i> lives in, ignoring any
    * value that might be in the cache.
@@ -260,7 +254,7 @@ public interface ClusterConnection extends Connection {
    * Returns a new RpcRetryingCallerFactory from the given {@link Configuration}. This
    * RpcRetryingCallerFactory lets the users create {@link RpcRetryingCaller}s which can be
    * intercepted with the configured {@link RetryingCallerInterceptor}
-   * @param conf configuration n
+   * @param conf configuration
    */
   RpcRetryingCallerFactory getNewRpcRetryingCallerFactory(Configuration conf);
 
