@@ -31,6 +31,7 @@ import org.apache.hadoop.hbase.exceptions.DeserializationException;
 import org.apache.hadoop.hbase.exceptions.HBaseException;
 import org.apache.hadoop.hbase.io.compress.Compression;
 import org.apache.hadoop.hbase.io.encoding.DataBlockEncoding;
+import org.apache.hadoop.hbase.io.encoding.IndexBlockEncoding;
 import org.apache.hadoop.hbase.regionserver.BloomType;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.PrettyPrinter;
@@ -42,9 +43,6 @@ import org.apache.hbase.thirdparty.com.google.common.base.Preconditions;
 import org.apache.hadoop.hbase.shaded.protobuf.ProtobufUtil;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.HBaseProtos.ColumnFamilySchema;
 
-/**
- * @since 2.0.0
- */
 @InterfaceAudience.Public
 public class ColumnFamilyDescriptorBuilder {
   // For future backward compatibility
@@ -77,10 +75,20 @@ public class ColumnFamilyDescriptorBuilder {
   public static final String COMPRESSION_COMPACT = "COMPRESSION_COMPACT";
   private static final Bytes COMPRESSION_COMPACT_BYTES =
     new Bytes(Bytes.toBytes(COMPRESSION_COMPACT));
+  public static final String COMPRESSION_COMPACT_MAJOR = "COMPRESSION_COMPACT_MAJOR";
+  private static final Bytes COMPRESSION_COMPACT_MAJOR_BYTES =
+    new Bytes(Bytes.toBytes(COMPRESSION_COMPACT_MAJOR));
+  public static final String COMPRESSION_COMPACT_MINOR = "COMPRESSION_COMPACT_MINOR";
+  private static final Bytes COMPRESSION_COMPACT_MINOR_BYTES =
+    new Bytes(Bytes.toBytes(COMPRESSION_COMPACT_MINOR));
   @InterfaceAudience.Private
   public static final String DATA_BLOCK_ENCODING = "DATA_BLOCK_ENCODING";
   private static final Bytes DATA_BLOCK_ENCODING_BYTES =
     new Bytes(Bytes.toBytes(DATA_BLOCK_ENCODING));
+  @InterfaceAudience.Private
+  public static final String INDEX_BLOCK_ENCODING = "INDEX_BLOCK_ENCODING";
+  private static final Bytes INDEX_BLOCK_ENCODING_BYTES =
+    new Bytes(Bytes.toBytes(INDEX_BLOCK_ENCODING));
   /**
    * Key for the BLOCKCACHE attribute. A more exact name would be CACHE_DATA_ON_READ because this
    * flag sets whether or not we cache DATA blocks. We always cache INDEX and BLOOM blocks; caching
@@ -196,6 +204,11 @@ public class ColumnFamilyDescriptorBuilder {
    */
   public static final DataBlockEncoding DEFAULT_DATA_BLOCK_ENCODING = DataBlockEncoding.NONE;
 
+  /**
+   * Default index block encoding algorithm.
+   */
+  public static final IndexBlockEncoding DEFAULT_INDEX_BLOCK_ENCODING = IndexBlockEncoding.NONE;
+
   /**
    * Default number of versions of a record to keep.
    */
@@ -298,6 +311,7 @@ public class ColumnFamilyDescriptorBuilder {
     DEFAULT_VALUES.put(BLOCKCACHE, String.valueOf(DEFAULT_BLOCKCACHE));
     DEFAULT_VALUES.put(KEEP_DELETED_CELLS, String.valueOf(DEFAULT_KEEP_DELETED));
     DEFAULT_VALUES.put(DATA_BLOCK_ENCODING, String.valueOf(DEFAULT_DATA_BLOCK_ENCODING));
+    DEFAULT_VALUES.put(INDEX_BLOCK_ENCODING, String.valueOf(DEFAULT_INDEX_BLOCK_ENCODING));
     // Do NOT add this key/value by default. NEW_VERSION_BEHAVIOR is NOT defined in hbase1 so
     // it is not possible to make an hbase1 HCD the same as an hbase2 HCD and so the replication
     // compare of schemas will fail. It is OK not adding the below to the initial map because of
@@ -316,12 +330,15 @@ public class ColumnFamilyDescriptorBuilder {
     switch (key) {
       case TTL:
         return Unit.TIME_INTERVAL;
+      case BLOCKSIZE:
+        return Unit.BYTE;
       default:
         return Unit.NONE;
     }
   }
 
   /**
+   * Check if the column family name is legal.
    * @param b Family name.
    * @return <code>b</code>
    * @throws IllegalArgumentException If not null and not a legitimate family name: i.e. 'printable'
@@ -390,6 +407,7 @@ public class ColumnFamilyDescriptorBuilder {
   }
 
   /**
+   * Serialize the table descriptor to a byte array.
    * @param desc The table descriptor to serialize
    * @return This instance serialized with pb with pb magic prefix
    */
@@ -423,6 +441,11 @@ public class ColumnFamilyDescriptorBuilder {
     return this;
   }
 
+  public ColumnFamilyDescriptorBuilder setBlocksize(String value) throws HBaseException {
+    desc.setBlocksize(value);
+    return this;
+  }
+
   public ColumnFamilyDescriptorBuilder setBloomFilterType(final BloomType value) {
     desc.setBloomFilterType(value);
     return this;
@@ -448,6 +471,18 @@ public class ColumnFamilyDescriptorBuilder {
     return this;
   }
 
+  public ColumnFamilyDescriptorBuilder
+    setMajorCompactionCompressionType(Compression.Algorithm value) {
+    desc.setMajorCompactionCompressionType(value);
+    return this;
+  }
+
+  public ColumnFamilyDescriptorBuilder
+    setMinorCompactionCompressionType(Compression.Algorithm value) {
+    desc.setMinorCompactionCompressionType(value);
+    return this;
+  }
+
   public ColumnFamilyDescriptorBuilder setCompressTags(boolean value) {
     desc.setCompressTags(value);
     return this;
@@ -477,6 +512,11 @@ public class ColumnFamilyDescriptorBuilder {
     return this;
   }
 
+  public ColumnFamilyDescriptorBuilder setIndexBlockEncoding(IndexBlockEncoding value) {
+    desc.setIndexBlockEncoding(value);
+    return this;
+  }
+
   public ColumnFamilyDescriptorBuilder setEncryptionKey(final byte[] value) {
     desc.setEncryptionKey(value);
     return this;
@@ -655,16 +695,17 @@ public class ColumnFamilyDescriptorBuilder {
       return value == null ? null : value.get();
     }
 
+    @Override
+    public String getValue(String key) {
+      Bytes rval = values.get(new Bytes(Bytes.toBytes(key)));
+      return rval == null ? null : Bytes.toString(rval.get(), rval.getOffset(), rval.getLength());
+    }
+
     @Override
     public Map<Bytes, Bytes> getValues() {
       return Collections.unmodifiableMap(values);
     }
 
-    /**
-     * @param key   The key.
-     * @param value The value.
-     * @return this (for chained invocation)
-     */
     public ModifyableColumnFamilyDescriptor setValue(byte[] key, byte[] value) {
       return setValue(toBytesOrNull(key, Function.identity()),
         toBytesOrNull(value, Function.identity()));
@@ -678,11 +719,6 @@ public class ColumnFamilyDescriptorBuilder {
       return setValue(key, toBytesOrNull(value, Bytes::toBytes));
     }
 
-    /**
-     * @param key   The key.
-     * @param value The value.
-     * @return this (for chained invocation)
-     */
     private ModifyableColumnFamilyDescriptor setValue(Bytes key, Bytes value) {
       if (value == null || value.getLength() == 0) {
         values.remove(key);
@@ -692,10 +728,6 @@ public class ColumnFamilyDescriptorBuilder {
       return this;
     }
 
-    /**
-     * @param key Key whose key and value we're to remove from HCD parameters.
-     * @return this (for chained invocation)
-     */
     public ModifyableColumnFamilyDescriptor removeValue(final Bytes key) {
       return setValue(key, (Bytes) null);
     }
@@ -727,6 +759,7 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
+     * Set the maximum number of versions to retain.
      * @param maxVersions maximum number of versions
      * @return this (for chained invocation)
      */
@@ -746,7 +779,7 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
-     * Set minimum and maximum versions to keep
+     * Set minimum and maximum versions to keep.
      * @param minVersions minimal number of versions
      * @param maxVersions maximum number of versions
      * @return this (for chained invocation)
@@ -773,14 +806,15 @@ public class ColumnFamilyDescriptorBuilder {
       return getStringOrDefault(BLOCKSIZE_BYTES, Integer::valueOf, DEFAULT_BLOCKSIZE);
     }
 
-    /**
-     * @param s Blocksize to use when writing out storefiles/hfiles on this column family.
-     * @return this (for chained invocation)
-     */
     public ModifyableColumnFamilyDescriptor setBlocksize(int s) {
       return setValue(BLOCKSIZE_BYTES, Integer.toString(s));
     }
 
+    public ModifyableColumnFamilyDescriptor setBlocksize(String blocksize) throws HBaseException {
+      return setBlocksize(
+        Integer.parseInt(PrettyPrinter.valueOf(blocksize, PrettyPrinter.Unit.BYTE)));
+    }
+
     @Override
     public Compression.Algorithm getCompressionType() {
       return getStringOrDefault(COMPRESSION_BYTES,
@@ -814,6 +848,22 @@ public class ColumnFamilyDescriptorBuilder {
         type == null ? DataBlockEncoding.NONE.name() : type.name());
     }
 
+    @Override
+    public IndexBlockEncoding getIndexBlockEncoding() {
+      return getStringOrDefault(INDEX_BLOCK_ENCODING_BYTES,
+        n -> IndexBlockEncoding.valueOf(n.toUpperCase()), IndexBlockEncoding.NONE);
+    }
+
+    /**
+     * Set index block encoding algorithm used in block cache.
+     * @param type What kind of index block encoding will be used.
+     * @return this (for chained invocation)
+     */
+    public ModifyableColumnFamilyDescriptor setIndexBlockEncoding(IndexBlockEncoding type) {
+      return setValue(INDEX_BLOCK_ENCODING_BYTES,
+        type == null ? IndexBlockEncoding.NONE.name() : type.name());
+    }
+
     /**
      * Set whether the tags should be compressed along with DataBlockEncoding. When no
      * DataBlockEncoding is been used, this is having no effect.
@@ -834,6 +884,18 @@ public class ColumnFamilyDescriptorBuilder {
         n -> Compression.Algorithm.valueOf(n.toUpperCase()), getCompressionType());
     }
 
+    @Override
+    public Compression.Algorithm getMajorCompactionCompressionType() {
+      return getStringOrDefault(COMPRESSION_COMPACT_MAJOR_BYTES,
+        n -> Compression.Algorithm.valueOf(n.toUpperCase()), getCompactionCompressionType());
+    }
+
+    @Override
+    public Compression.Algorithm getMinorCompactionCompressionType() {
+      return getStringOrDefault(COMPRESSION_COMPACT_MINOR_BYTES,
+        n -> Compression.Algorithm.valueOf(n.toUpperCase()), getCompactionCompressionType());
+    }
+
     /**
      * Compression types supported in hbase. LZO is not bundled as part of the hbase distribution.
      * See <a href="http://wiki.apache.org/hadoop/UsingLzoCompression">LZO Compression</a> for how
@@ -846,12 +908,23 @@ public class ColumnFamilyDescriptorBuilder {
       return setValue(COMPRESSION_COMPACT_BYTES, type.name());
     }
 
+    public ModifyableColumnFamilyDescriptor
+      setMajorCompactionCompressionType(Compression.Algorithm type) {
+      return setValue(COMPRESSION_COMPACT_MAJOR_BYTES, type.name());
+    }
+
+    public ModifyableColumnFamilyDescriptor
+      setMinorCompactionCompressionType(Compression.Algorithm type) {
+      return setValue(COMPRESSION_COMPACT_MINOR_BYTES, type.name());
+    }
+
     @Override
     public boolean isInMemory() {
       return getStringOrDefault(IN_MEMORY_BYTES, Boolean::valueOf, DEFAULT_IN_MEMORY);
     }
 
     /**
+     * Set the inMemory flag
      * @param inMemory True if we are to favor keeping all values for this column family in the
      *                 HRegionServer cache
      * @return this (for chained invocation)
@@ -866,10 +939,6 @@ public class ColumnFamilyDescriptorBuilder {
         n -> MemoryCompactionPolicy.valueOf(n.toUpperCase()), null);
     }
 
-    /**
-     * @param inMemoryCompaction the prefered in-memory compaction policy for this column family
-     * @return this (for chained invocation)
-     */
     public ModifyableColumnFamilyDescriptor
       setInMemoryCompaction(MemoryCompactionPolicy inMemoryCompaction) {
       return setValue(IN_MEMORY_COMPACTION_BYTES, inMemoryCompaction.name());
@@ -881,10 +950,6 @@ public class ColumnFamilyDescriptorBuilder {
         DEFAULT_KEEP_DELETED);
     }
 
-    /**
-     * @param keepDeletedCells True if deleted rows should not be collected immediately.
-     * @return this (for chained invocation)
-     */
     public ModifyableColumnFamilyDescriptor setKeepDeletedCells(KeepDeletedCells keepDeletedCells) {
       return setValue(KEEP_DELETED_CELLS_BYTES, keepDeletedCells.name());
     }
@@ -910,6 +975,7 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
+     * Set the time to live
      * @param timeToLive Time-to-live of cell contents, in seconds.
      * @return this (for chained invocation)
      */
@@ -918,9 +984,10 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
+     * Set the time to live
      * @param timeToLive Time-to-live of cell contents, in seconds.
      * @return this (for chained invocation)
-     * @throws org.apache.hadoop.hbase.exceptions.HBaseException
+     * @throws org.apache.hadoop.hbase.exceptions.HBaseException exception
      */
     public ModifyableColumnFamilyDescriptor setTimeToLive(String timeToLive) throws HBaseException {
       return setTimeToLive(Integer.parseInt(PrettyPrinter.valueOf(timeToLive, Unit.TIME_INTERVAL)));
@@ -932,6 +999,7 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
+     * Set minimum versions to retain.
      * @param minVersions The minimum number of versions to keep. (used when timeToLive is set)
      * @return this (for chained invocation)
      */
@@ -961,6 +1029,7 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
+     * Set the blockCacheEnabled flag
      * @param blockCacheEnabled True if hfile DATA type blocks should be cached (We always cache
      *                          INDEX and BLOOM blocks; you cannot turn this off).
      * @return this (for chained invocation)
@@ -985,10 +1054,6 @@ public class ColumnFamilyDescriptorBuilder {
         DEFAULT_REPLICATION_SCOPE);
     }
 
-    /**
-     * @param scope the scope tag
-     * @return this (for chained invocation)
-     */
     public ModifyableColumnFamilyDescriptor setScope(int scope) {
       return setValue(REPLICATION_SCOPE_BYTES, Integer.toString(scope));
     }
@@ -1000,6 +1065,7 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
+     * Set the setCacheDataOnWrite flag
      * @param value true if we should cache data blocks on write
      * @return this (for chained invocation)
      */
@@ -1014,6 +1080,7 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
+     * Set the setCacheIndexesOnWrite flag
      * @param value true if we should cache index blocks on write
      * @return this (for chained invocation)
      */
@@ -1028,6 +1095,7 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
+     * Set the setCacheBloomsOnWrite flag.
      * @param value true if we should cache bloomfilter blocks on write
      * @return this (for chained invocation)
      */
@@ -1042,6 +1110,7 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
+     * Set the setEvictBlocksOnClose flag.
      * @param value true if we should evict cached blocks from the blockcache on close
      * @return this (for chained invocation)
      */
@@ -1056,6 +1125,7 @@ public class ColumnFamilyDescriptorBuilder {
     }
 
     /**
+     * Set the setPrefetchBlocksOnOpen flag
      * @param value true if we should prefetch blocks into the blockcache on open
      * @return this (for chained invocation)
      */
@@ -1183,15 +1253,13 @@ public class ColumnFamilyDescriptorBuilder {
       return COMPARATOR.compare(this, other);
     }
 
-    /**
-     * @return This instance serialized with pb with pb magic prefix
-     * @see #parseFrom(byte[])
-     */
+    /** Returns This instance serialized with pb with pb magic prefix */
     private byte[] toByteArray() {
       return ProtobufUtil.prependPBMagic(ProtobufUtil.toColumnFamilySchema(this).toByteArray());
     }
 
     /**
+     * Parse the serialized representation of a {@link ModifyableColumnFamilyDescriptor}
      * @param bytes A pb serialized {@link ModifyableColumnFamilyDescriptor} instance with pb magic
      *              prefix
      * @return An instance of {@link ModifyableColumnFamilyDescriptor} made from <code>bytes</code>
