@@ -27,6 +27,7 @@ import java.util.NavigableSet;
 import java.util.Set;
 import java.util.TreeMap;
 import java.util.TreeSet;
+import java.util.stream.Collectors;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.filter.Filter;
 import org.apache.hadoop.hbase.io.TimeRange;
@@ -247,7 +248,8 @@ public class Get extends Query implements Row {
 
   @Override
   public Get setColumnFamilyTimeRange(byte[] cf, long minStamp, long maxStamp) {
-    return (Get) super.setColumnFamilyTimeRange(cf, minStamp, maxStamp);
+    super.setColumnFamilyTimeRange(cf, minStamp, maxStamp);
+    return this;
   }
 
   /**
@@ -299,7 +301,8 @@ public class Get extends Query implements Row {
 
   @Override
   public Get setLoadColumnFamiliesOnDemand(boolean value) {
-    return (Get) super.setLoadColumnFamiliesOnDemand(value);
+    super.setLoadColumnFamiliesOnDemand(value);
+    return this;
   }
 
   /**
@@ -488,6 +491,26 @@ public class Get extends Query implements Row {
     if (getId() != null) {
       map.put("id", getId());
     }
+    map.put("storeLimit", this.storeLimit);
+    map.put("storeOffset", this.storeOffset);
+    map.put("checkExistenceOnly", this.checkExistenceOnly);
+
+    map.put("targetReplicaId", this.targetReplicaId);
+    map.put("consistency", this.consistency);
+    map.put("loadColumnFamiliesOnDemand", this.loadColumnFamiliesOnDemand);
+    if (!colFamTimeRangeMap.isEmpty()) {
+      Map<String, List<Long>> colFamTimeRangeMapStr = colFamTimeRangeMap.entrySet().stream()
+        .collect(Collectors.toMap((e) -> Bytes.toStringBinary(e.getKey()), e -> {
+          TimeRange value = e.getValue();
+          List<Long> rangeList = new ArrayList<>();
+          rangeList.add(value.getMin());
+          rangeList.add(value.getMax());
+          return rangeList;
+        }));
+
+      map.put("colFamTimeRangeMap", colFamTimeRangeMapStr);
+    }
+    map.put("priority", getPriority());
     return map;
   }
 
@@ -520,46 +543,55 @@ public class Get extends Query implements Row {
 
   @Override
   public Get setAttribute(String name, byte[] value) {
-    return (Get) super.setAttribute(name, value);
+    super.setAttribute(name, value);
+    return this;
   }
 
   @Override
   public Get setId(String id) {
-    return (Get) super.setId(id);
+    super.setId(id);
+    return this;
   }
 
   @Override
   public Get setAuthorizations(Authorizations authorizations) {
-    return (Get) super.setAuthorizations(authorizations);
+    super.setAuthorizations(authorizations);
+    return this;
   }
 
   @Override
   public Get setACL(Map<String, Permission> perms) {
-    return (Get) super.setACL(perms);
+    super.setACL(perms);
+    return this;
   }
 
   @Override
   public Get setACL(String user, Permission perms) {
-    return (Get) super.setACL(user, perms);
+    super.setACL(user, perms);
+    return this;
   }
 
   @Override
   public Get setConsistency(Consistency consistency) {
-    return (Get) super.setConsistency(consistency);
+    super.setConsistency(consistency);
+    return this;
   }
 
   @Override
   public Get setReplicaId(int Id) {
-    return (Get) super.setReplicaId(Id);
+    super.setReplicaId(Id);
+    return this;
   }
 
   @Override
   public Get setIsolationLevel(IsolationLevel level) {
-    return (Get) super.setIsolationLevel(level);
+    super.setIsolationLevel(level);
+    return this;
   }
 
   @Override
   public Get setPriority(int priority) {
-    return (Get) super.setPriority(priority);
+    super.setPriority(priority);
+    return this;
   }
 }
