@@ -1306,7 +1306,8 @@ public class HTable implements Table {
       Object[] results = new Object[execs.size()];
 
       AsyncProcess asyncProcess = new AsyncProcess(connection, configuration,
-        RpcRetryingCallerFactory.instantiate(configuration, connection.getStatisticsTracker()),
+        RpcRetryingCallerFactory.instantiate(configuration, connConfiguration,
+          connection.getStatisticsTracker(), connection.getConnectionMetrics()),
         RpcControllerFactory.instantiate(configuration));
 
       Batch.Callback<ClientProtos.CoprocessorServiceResult> resultsCallback =
