@@ -1,5 +1,4 @@
 /*
- *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -16,15 +15,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.client;
 
-import org.apache.hadoop.hbase.classification.InterfaceAudience;
-import org.apache.hadoop.hbase.classification.InterfaceStability;
+import org.apache.yetus.audience.InterfaceAudience;
+import org.apache.yetus.audience.InterfaceStability;
 
 /**
- * Abstract response class representing online logs response from ring-buffer use-cases
- * e.g slow/large RPC logs, balancer decision logs
+ * Abstract response class representing online logs response from ring-buffer use-cases e.g
+ * slow/large RPC logs, balancer decision logs
  */
 @InterfaceAudience.Public
 @InterfaceStability.Evolving
