@@ -130,6 +130,8 @@ public class Scan extends Query {
   // define this attribute with the appropriate table name by calling
   // scan.setAttribute(Scan.SCAN_ATTRIBUTES_TABLE_NAME, Bytes.toBytes(tableName))
   static public final String SCAN_ATTRIBUTES_TABLE_NAME = "scan.attributes.table.name";
+  static private final String SCAN_ATTRIBUTES_METRICS_BY_REGION_ENABLE =
+    "scan.attributes.metrics.byregion.enable";
 
   /**
    * -1 means no caching specified and the value of {@link HConstants#HBASE_CLIENT_SCANNER_CACHING}
@@ -406,7 +408,8 @@ public class Scan extends Query {
 
   @Override
   public Scan setColumnFamilyTimeRange(byte[] cf, long minStamp, long maxStamp) {
-    return (Scan) super.setColumnFamilyTimeRange(cf, minStamp, maxStamp);
+    super.setColumnFamilyTimeRange(cf, minStamp, maxStamp);
+    return this;
   }
 
   /**
@@ -414,6 +417,11 @@ public class Scan extends Query {
    * <p>
    * If the specified row does not exist, the Scanner will start from the next closest row after the
    * specified row.
+   * <p>
+   * <b>Note:</b> <strong>Do NOT use this in combination with {@link #setRowPrefixFilter(byte[])} or
+   * {@link #setStartStopRowForPrefixScan(byte[])}.</strong> Doing so will make the scan result
+   * unexpected or even undefined.
+   * </p>
    * @param startRow row to start scanner at or after
    * @throws IllegalArgumentException if startRow does not meet criteria for a row key (when length
    *                                  exceeds {@link HConstants#MAX_ROW_LENGTH})
@@ -451,6 +459,11 @@ public class Scan extends Query {
    * <p>
    * If the specified row does not exist, or the {@code inclusive} is {@code false}, the Scanner
    * will start from the next closest row after the specified row.
+   * <p>
+   * <b>Note:</b> <strong>Do NOT use this in combination with {@link #setRowPrefixFilter(byte[])} or
+   * {@link #setStartStopRowForPrefixScan(byte[])}.</strong> Doing so will make the scan result
+   * unexpected or even undefined.
+   * </p>
    * @param startRow  row to start scanner at or after
    * @param inclusive whether we should include the start row when scan
    * @throws IllegalArgumentException if startRow does not meet criteria for a row key (when length
@@ -471,8 +484,9 @@ public class Scan extends Query {
    * <p>
    * The scan will include rows that are lexicographically less than the provided stopRow.
    * <p>
-   * <b>Note:</b> When doing a filter for a rowKey <u>Prefix</u> use
-   * {@link #setRowPrefixFilter(byte[])}. The 'trailing 0' will not yield the desired result.
+   * <b>Note:</b> <strong>Do NOT use this in combination with {@link #setRowPrefixFilter(byte[])} or
+   * {@link #setStartStopRowForPrefixScan(byte[])}.</strong> Doing so will make the scan result
+   * unexpected or even undefined.
    * </p>
    * @param stopRow row to end at (exclusive)
    * @throws IllegalArgumentException if stopRow does not meet criteria for a row key (when length
@@ -514,6 +528,11 @@ public class Scan extends Query {
    * <p>
    * The scan will include rows that are lexicographically less than (or equal to if
    * {@code inclusive} is {@code true}) the provided stopRow.
+   * <p>
+   * <b>Note:</b> <strong>Do NOT use this in combination with {@link #setRowPrefixFilter(byte[])} or
+   * {@link #setStartStopRowForPrefixScan(byte[])}.</strong> Doing so will make the scan result
+   * unexpected or even undefined.
+   * </p>
    * @param stopRow   row to end at
    * @param inclusive whether we should include the stop row when scan
    * @throws IllegalArgumentException if stopRow does not meet criteria for a row key (when length
@@ -542,12 +561,37 @@ public class Scan extends Query {
    * This can safely be used in combination with setFilter.
    * </p>
    * <p>
-   * <b>NOTE: Doing a {@link #setStartRow(byte[])} and/or {@link #setStopRow(byte[])} after this
-   * method will yield undefined results.</b>
+   * <strong>This CANNOT be used in combination with withStartRow and/or withStopRow.</strong> Such
+   * a combination will yield unexpected and even undefined results.
+   * </p>
+   * @param rowPrefix the prefix all rows must start with. (Set <i>null</i> to remove the filter.)
+   * @deprecated since 2.5.0, will be removed in 4.0.0. The name of this method is considered to be
+   *             confusing as it does not use a {@link Filter} but uses setting the startRow and
+   *             stopRow instead. Use {@link #setStartStopRowForPrefixScan(byte[])} instead.
+   */
+  public Scan setRowPrefixFilter(byte[] rowPrefix) {
+    return setStartStopRowForPrefixScan(rowPrefix);
+  }
+
+  /**
+   * <p>
+   * Set a filter (using stopRow and startRow) so the result set only contains rows where the rowKey
+   * starts with the specified prefix.
+   * </p>
+   * <p>
+   * This is a utility method that converts the desired rowPrefix into the appropriate values for
+   * the startRow and stopRow to achieve the desired result.
+   * </p>
+   * <p>
+   * This can safely be used in combination with setFilter.
+   * </p>
+   * <p>
+   * <strong>This CANNOT be used in combination with withStartRow and/or withStopRow.</strong> Such
+   * a combination will yield unexpected and even undefined results.
    * </p>
    * @param rowPrefix the prefix all rows must start with. (Set <i>null</i> to remove the filter.)
    */
-  public Scan setRowPrefixFilter(byte[] rowPrefix) {
+  public Scan setStartStopRowForPrefixScan(byte[] rowPrefix) {
     if (rowPrefix == null) {
       setStartRow(HConstants.EMPTY_START_ROW);
       setStopRow(HConstants.EMPTY_END_ROW);
@@ -823,9 +867,9 @@ public class Scan extends Query {
   }
 
   /**
-   * @return true when the constructor of this scan understands that the results they will see may
-   *         only represent a partial portion of a row. The entire row would be retrieved by
-   *         subsequent calls to {@link ResultScanner#next()}
+   * Returns true when the constructor of this scan understands that the results they will see may
+   * only represent a partial portion of a row. The entire row would be retrieved by subsequent
+   * calls to {@link ResultScanner#next()}
    */
   public boolean getAllowPartialResults() {
     return allowPartialResults;
@@ -833,7 +877,8 @@ public class Scan extends Query {
 
   @Override
   public Scan setLoadColumnFamiliesOnDemand(boolean value) {
-    return (Scan) super.setLoadColumnFamiliesOnDemand(value);
+    super.setLoadColumnFamiliesOnDemand(value);
+    return this;
   }
 
   /**
@@ -970,6 +1015,7 @@ public class Scan extends Query {
    * if setting it true, we would do openScanner,next,closeScanner in one RPC call. It means the
    * better performance for small scan. [HBASE-9488]. Generally, if the scan range is within one
    * data block(64KB), it could be considered as a small scan.
+   * @param small set if that should use read type of PREAD
    * @deprecated since 2.0.0 and will be removed in 3.0.0. Use {@link #setLimit(int)} and
    *             {@link #setReadType(ReadType)} instead. And for the one rpc optimization, now we
    *             will also fetch data when openScanner, and if the number of rows reaches the limit
@@ -1002,55 +1048,68 @@ public class Scan extends Query {
 
   @Override
   public Scan setAttribute(String name, byte[] value) {
-    return (Scan) super.setAttribute(name, value);
+    super.setAttribute(name, value);
+    return this;
   }
 
   @Override
   public Scan setId(String id) {
-    return (Scan) super.setId(id);
+    super.setId(id);
+    return this;
   }
 
   @Override
   public Scan setAuthorizations(Authorizations authorizations) {
-    return (Scan) super.setAuthorizations(authorizations);
+    super.setAuthorizations(authorizations);
+    return this;
   }
 
   @Override
   public Scan setACL(Map<String, Permission> perms) {
-    return (Scan) super.setACL(perms);
+    super.setACL(perms);
+    return this;
   }
 
   @Override
   public Scan setACL(String user, Permission perms) {
-    return (Scan) super.setACL(user, perms);
+    super.setACL(user, perms);
+    return this;
   }
 
   @Override
   public Scan setConsistency(Consistency consistency) {
-    return (Scan) super.setConsistency(consistency);
+    super.setConsistency(consistency);
+    return this;
   }
 
   @Override
   public Scan setReplicaId(int Id) {
-    return (Scan) super.setReplicaId(Id);
+    super.setReplicaId(Id);
+    return this;
   }
 
   @Override
   public Scan setIsolationLevel(IsolationLevel level) {
-    return (Scan) super.setIsolationLevel(level);
+    super.setIsolationLevel(level);
+    return this;
   }
 
   @Override
   public Scan setPriority(int priority) {
-    return (Scan) super.setPriority(priority);
+    super.setPriority(priority);
+    return this;
   }
 
   /**
-   * Enable collection of {@link ScanMetrics}. For advanced users.
+   * Enable collection of {@link ScanMetrics}. For advanced users. While disabling scan metrics,
+   * will also disable region level scan metrics.
    * @param enabled Set to true to enable accumulating scan metrics
    */
   public Scan setScanMetricsEnabled(final boolean enabled) {
     setAttribute(Scan.SCAN_ATTRIBUTES_METRICS_ENABLE, Bytes.toBytes(Boolean.valueOf(enabled)));
+    if (!enabled) {
+      setEnableScanMetricsByRegion(false);
+    }
     return this;
   }
 
@@ -1183,4 +1242,22 @@ public class Scan extends Query {
   public static Scan createScanFromCursor(Cursor cursor) {
     return new Scan().withStartRow(cursor.getRow());
   }
+
+  /**
+   * Enables region level scan metrics. If scan metrics are disabled then first enables scan metrics
+   * followed by region level scan metrics.
+   * @param enable Set to true to enable region level scan metrics.
+   */
+  public Scan setEnableScanMetricsByRegion(final boolean enable) {
+    if (enable) {
+      setScanMetricsEnabled(true);
+    }
+    setAttribute(Scan.SCAN_ATTRIBUTES_METRICS_BY_REGION_ENABLE, Bytes.toBytes(enable));
+    return this;
+  }
+
+  public boolean isScanMetricsByRegionEnabled() {
+    byte[] attr = getAttribute(Scan.SCAN_ATTRIBUTES_METRICS_BY_REGION_ENABLE);
+    return attr != null && Bytes.toBoolean(attr);
+  }
 }
