@@ -28,6 +28,7 @@ import java.io.InterruptedIOException;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.HBaseIOException;
+import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.HRegionLocation;
 import org.apache.hadoop.hbase.NotServingRegionException;
@@ -38,8 +39,10 @@ import org.apache.hadoop.hbase.TableNotEnabledException;
 import org.apache.hadoop.hbase.UnknownScannerException;
 import org.apache.hadoop.hbase.client.metrics.ScanMetrics;
 import org.apache.hadoop.hbase.exceptions.ScannerResetException;
+import org.apache.hadoop.hbase.ipc.HBaseRpcController;
 import org.apache.hadoop.hbase.ipc.RpcControllerFactory;
 import org.apache.hadoop.hbase.regionserver.RegionServerStoppedException;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -223,7 +226,7 @@ public class ScannerCallable extends ClientServiceCallable<Result[]> {
         // when what we need is to open scanner against new location.
         // Attach NSRE to signal client that it needs to re-setup scanner.
         if (this.scanMetrics != null) {
-          this.scanMetrics.countOfNSRE.incrementAndGet();
+          this.scanMetrics.addToCounter(ScanMetrics.NOT_SERVING_REGION_EXCEPTION_METRIC_NAME, 1);
         }
         throw new DoNotRetryIOException("Resetting the scanner -- see exception cause", ioe);
       } else if (ioe instanceof RegionServerStoppedException) {
@@ -257,7 +260,7 @@ public class ScannerCallable extends ClientServiceCallable<Result[]> {
     } else {
       response = next();
     }
-    long timestamp = System.currentTimeMillis();
+    long timestamp = EnvironmentEdgeManager.currentTime();
     boolean isHeartBeat = response.hasHeartbeatMessage() && response.getHeartbeatMessage();
     setHeartbeatMessage(isHeartBeat);
     if (isHeartBeat && scan.isNeedCursorResult() && response.hasCursor()) {
@@ -265,7 +268,7 @@ public class ScannerCallable extends ClientServiceCallable<Result[]> {
     }
     Result[] rrs = ResponseConverter.getResults(getRpcControllerCellScanner(), response);
     if (logScannerActivity) {
-      long now = System.currentTimeMillis();
+      long now = EnvironmentEdgeManager.currentTime();
       if (now - timestamp > logCutOffLatency) {
         int rows = rrs == null ? 0 : rrs.length;
         LOG.info(
@@ -324,8 +327,22 @@ public class ScannerCallable extends ClientServiceCallable<Result[]> {
       incRPCCallsMetrics(scanMetrics, isRegionServerRemote);
       ScanRequest request =
         RequestConverter.buildScanRequest(this.scannerId, 0, true, this.scanMetrics != null);
+      HBaseRpcController controller = rpcControllerFactory.newController();
+
+      // Set fields from the original controller onto the close-specific controller
+      // We set the timeout and the priority -- we will overwrite the priority to HIGH
+      // below, but the controller will take whichever is highest.
+      if (getRpcController() instanceof HBaseRpcController) {
+        HBaseRpcController original = (HBaseRpcController) getRpcController();
+        controller.setPriority(original.getPriority());
+        if (original.hasCallTimeout()) {
+          controller.setCallTimeout(original.getCallTimeout());
+        }
+      }
+      controller.setPriority(HConstants.HIGH_QOS);
+
       try {
-        getStub().scan(getRpcController(), request);
+        getStub().scan(controller, request);
       } catch (Exception e) {
         throw ProtobufUtil.handleRemoteException(e);
       }
