@@ -39,9 +39,11 @@ import org.apache.hadoop.hbase.Coprocessor;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.exceptions.DeserializationException;
+import org.apache.hadoop.hbase.exceptions.HBaseException;
 import org.apache.hadoop.hbase.rsgroup.RSGroupInfo;
 import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.PrettyPrinter;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -104,12 +106,6 @@ public class TableDescriptorBuilder {
   public static final String MERGE_ENABLED = "MERGE_ENABLED";
   private static final Bytes MERGE_ENABLED_KEY = new Bytes(Bytes.toBytes(MERGE_ENABLED));
 
-  /**
-   * Constant that denotes whether the table is normalized by default.
-   */
-  @InterfaceAudience.Private
-  public static final boolean DEFAULT_NORMALIZATION_ENABLED = false;
-
   /**
    * Used by HBase Shell interface to access this metadata attribute which represents the maximum
    * size of the memstore after which its contents are flushed onto the disk.
@@ -152,8 +148,6 @@ public class TableDescriptorBuilder {
   private static final Bytes REGION_MEMSTORE_REPLICATION_KEY =
     new Bytes(Bytes.toBytes(REGION_MEMSTORE_REPLICATION));
 
-  private static final Bytes REGION_REPLICA_WAIT_FOR_PRIMARY_FLUSH_CONF_KEY =
-    new Bytes(Bytes.toBytes(RegionReplicaUtil.REGION_REPLICA_WAIT_FOR_PRIMARY_FLUSH_CONF_KEY));
   /**
    * Used by shell/rest interface to access this metadata attribute which denotes if the table
    * should be treated by region normalizer.
@@ -162,6 +156,9 @@ public class TableDescriptorBuilder {
   public static final String NORMALIZATION_ENABLED = "NORMALIZATION_ENABLED";
   private static final Bytes NORMALIZATION_ENABLED_KEY =
     new Bytes(Bytes.toBytes(NORMALIZATION_ENABLED));
+  @InterfaceAudience.Private
+  @Deprecated
+  public static final boolean DEFAULT_NORMALIZATION_ENABLED = false;
 
   @InterfaceAudience.Private
   public static final String NORMALIZER_TARGET_REGION_COUNT = "NORMALIZER_TARGET_REGION_COUNT";
@@ -169,7 +166,14 @@ public class TableDescriptorBuilder {
     new Bytes(Bytes.toBytes(NORMALIZER_TARGET_REGION_COUNT));
 
   @InterfaceAudience.Private
+  public static final String NORMALIZER_TARGET_REGION_SIZE_MB = "NORMALIZER_TARGET_REGION_SIZE_MB";
+  private static final Bytes NORMALIZER_TARGET_REGION_SIZE_MB_KEY =
+    new Bytes(Bytes.toBytes(NORMALIZER_TARGET_REGION_SIZE_MB));
+  // TODO: Keeping backward compatability with HBASE-25651 change. Can be removed in later version
+  @InterfaceAudience.Private
+  @Deprecated
   public static final String NORMALIZER_TARGET_REGION_SIZE = "NORMALIZER_TARGET_REGION_SIZE";
+  @Deprecated
   private static final Bytes NORMALIZER_TARGET_REGION_SIZE_KEY =
     new Bytes(Bytes.toBytes(NORMALIZER_TARGET_REGION_SIZE));
 
@@ -235,6 +239,16 @@ public class TableDescriptorBuilder {
     RESERVED_KEYWORDS.add(IS_META_KEY);
   }
 
+  public static PrettyPrinter.Unit getUnit(String key) {
+    switch (key) {
+      case MAX_FILESIZE:
+      case MEMSTORE_FLUSHSIZE:
+        return PrettyPrinter.Unit.BYTE;
+      default:
+        return PrettyPrinter.Unit.NONE;
+    }
+  }
+
   @InterfaceAudience.Private
   public final static String NAMESPACE_FAMILY_INFO = "info";
   @InterfaceAudience.Private
@@ -278,10 +292,7 @@ public class TableDescriptorBuilder {
 
   private final ModifyableTableDescriptor desc;
 
-  /**
-   * @param desc The table descriptor to serialize
-   * @return This instance serialized with pb with pb magic prefix
-   */
+  /** Returns This instance serialized with pb with pb magic prefix */
   public static byte[] toByteArray(TableDescriptor desc) {
     if (desc instanceof ModifyableTableDescriptor) {
       return ((ModifyableTableDescriptor) desc).toByteArray();
@@ -293,7 +304,7 @@ public class TableDescriptorBuilder {
    * The input should be created by {@link #toByteArray}.
    * @param pbBytes A pb serialized TableDescriptor instance with pb magic prefix
    * @return This instance serialized with pb with pb magic prefix
-   * @throws org.apache.hadoop.hbase.exceptions.DeserializationException
+   * @throws org.apache.hadoop.hbase.exceptions.DeserializationException if an error occurred
    */
   public static TableDescriptor parseFrom(byte[] pbBytes) throws DeserializationException {
     return ModifyableTableDescriptor.parseFrom(pbBytes);
@@ -403,6 +414,11 @@ public class TableDescriptorBuilder {
     return this;
   }
 
+  public TableDescriptorBuilder removeValue(final String key) {
+    desc.removeValue(key);
+    return this;
+  }
+
   public TableDescriptorBuilder removeValue(Bytes key) {
     desc.removeValue(key);
     return this;
@@ -453,11 +469,22 @@ public class TableDescriptorBuilder {
     return this;
   }
 
+  public TableDescriptorBuilder setMaxFileSize(String maxFileSize) throws HBaseException {
+    desc.setMaxFileSize(maxFileSize);
+    return this;
+  }
+
   public TableDescriptorBuilder setMemStoreFlushSize(long memstoreFlushSize) {
     desc.setMemStoreFlushSize(memstoreFlushSize);
     return this;
   }
 
+  public TableDescriptorBuilder setMemStoreFlushSize(String memStoreFlushSize)
+    throws HBaseException {
+    desc.setMemStoreFlushSize(memStoreFlushSize);
+    return this;
+  }
+
   public TableDescriptorBuilder setNormalizerTargetRegionCount(final int regionCount) {
     desc.setNormalizerTargetRegionCount(regionCount);
     return this;
@@ -474,6 +501,7 @@ public class TableDescriptorBuilder {
   }
 
   /**
+   * Set the table owner
    * @deprecated since 2.0.0 and will be removed in 3.0.0.
    * @see <a href="https://issues.apache.org/jira/browse/HBASE-15583">HBASE-15583</a>
    */
@@ -484,6 +512,7 @@ public class TableDescriptorBuilder {
   }
 
   /**
+   * Set the table owner
    * @deprecated since 2.0.0 and will be removed in 3.0.0.
    * @see <a href="https://issues.apache.org/jira/browse/HBASE-15583">HBASE-15583</a>
    */
@@ -533,6 +562,10 @@ public class TableDescriptorBuilder {
     return this;
   }
 
+  public String getValue(String key) {
+    return desc.getValue(key);
+  }
+
   /**
    * Sets replication scope all & only the columns already in the builder. Columns added later won't
    * be backfilled with replication scope.
@@ -726,8 +759,8 @@ public class TableDescriptorBuilder {
      * @param key Key whose key and value we're to remove from TableDescriptor parameters.
      * @return the modifyable TD
      */
-    public ModifyableTableDescriptor removeValue(Bytes key) {
-      return setValue(key, (Bytes) null);
+    public ModifyableTableDescriptor removeValue(final String key) {
+      return setValue(key, (String) null);
     }
 
     /**
@@ -735,6 +768,15 @@ public class TableDescriptorBuilder {
      * @param key Key whose key and value we're to remove from TableDescriptor parameters.
      * @return the modifyable TD
      */
+    public ModifyableTableDescriptor removeValue(Bytes key) {
+      return setValue(key, (Bytes) null);
+    }
+
+    /**
+     * Remove metadata represented by the key from the {@link #values} map
+     * @param key Key whose key and value we're to remove from TableDescriptor parameters
+     * @return the modifiable TD
+     */
     public ModifyableTableDescriptor removeValue(final byte[] key) {
       return removeValue(new Bytes(key));
     }
@@ -824,8 +866,7 @@ public class TableDescriptorBuilder {
      **/
     @Override
     public boolean isNormalizationEnabled() {
-      return getOrDefault(NORMALIZATION_ENABLED_KEY, Boolean::valueOf,
-        DEFAULT_NORMALIZATION_ENABLED);
+      return getOrDefault(NORMALIZATION_ENABLED_KEY, Boolean::valueOf, false);
     }
 
     /**
@@ -846,7 +887,11 @@ public class TableDescriptorBuilder {
      */
     @Override
     public long getNormalizerTargetRegionSize() {
-      return getOrDefault(NORMALIZER_TARGET_REGION_SIZE_KEY, Long::valueOf, Long.valueOf(-1));
+      long target_region_size =
+        getOrDefault(NORMALIZER_TARGET_REGION_SIZE_MB_KEY, Long::valueOf, Long.valueOf(-1));
+      return target_region_size == Long.valueOf(-1)
+        ? getOrDefault(NORMALIZER_TARGET_REGION_SIZE_KEY, Long::valueOf, Long.valueOf(-1))
+        : target_region_size;
     }
 
     /**
@@ -873,7 +918,7 @@ public class TableDescriptorBuilder {
      * @return the modifyable TD
      */
     public ModifyableTableDescriptor setNormalizerTargetRegionSize(final long regionSize) {
-      return setValue(NORMALIZER_TARGET_REGION_SIZE_KEY, Long.toString(regionSize));
+      return setValue(NORMALIZER_TARGET_REGION_SIZE_MB_KEY, Long.toString(regionSize));
     }
 
     /**
@@ -955,6 +1000,11 @@ public class TableDescriptorBuilder {
       return setValue(MAX_FILESIZE_KEY, Long.toString(maxFileSize));
     }
 
+    public ModifyableTableDescriptor setMaxFileSize(String maxFileSize) throws HBaseException {
+      return setMaxFileSize(
+        Long.parseLong(PrettyPrinter.valueOf(maxFileSize, PrettyPrinter.Unit.BYTE)));
+    }
+
     /**
      * Returns the size of the memstore after which a flush to filesystem is triggered.
      * @return memory cache flush size for each hregion, -1 if not set.
@@ -975,6 +1025,12 @@ public class TableDescriptorBuilder {
       return setValue(MEMSTORE_FLUSHSIZE_KEY, Long.toString(memstoreFlushSize));
     }
 
+    public ModifyableTableDescriptor setMemStoreFlushSize(String memStoreFlushSize)
+      throws HBaseException {
+      return setMemStoreFlushSize(
+        Long.parseLong(PrettyPrinter.valueOf(memStoreFlushSize, PrettyPrinter.Unit.BYTE)));
+    }
+
     /**
      * This sets the class associated with the flush policy which determines determines the stores
      * need to be flushed when flushing a region. The class used by default is defined in
@@ -1133,7 +1189,7 @@ public class TableDescriptorBuilder {
           printCommaForAttr = true;
           s.append(key);
           s.append(" => ");
-          s.append('\'').append(value).append('\'');
+          s.append('\'').append(PrettyPrinter.format(value, getUnit(key))).append('\'');
         }
 
         if (!userKeys.isEmpty()) {
@@ -1153,7 +1209,7 @@ public class TableDescriptorBuilder {
             printCommaForCfg = true;
             s.append('\'').append(key).append('\'');
             s.append(" => ");
-            s.append('\'').append(value).append('\'');
+            s.append('\'').append(PrettyPrinter.format(value, getUnit(key))).append('\'');
           }
           s.append("}");
         }
@@ -1447,10 +1503,13 @@ public class TableDescriptorBuilder {
       // if we found a match, remove it
       if (match != null) {
         ModifyableTableDescriptor.this.removeValue(match);
+      } else {
+        LOG.warn("coprocessor with class name {} was not found in the table attribute", className);
       }
     }
 
     /**
+     * Set the table owner
      * @deprecated since 2.0.0 and will be removed in 3.0.0.
      * @see <a href="https://issues.apache.org/jira/browse/HBASE-15583">HBASE-15583</a>
      */
@@ -1460,6 +1519,7 @@ public class TableDescriptorBuilder {
     }
 
     /**
+     * Set the table owner.
      * @deprecated since 2.0.0 and will be removed in 3.0.0.
      * @see <a href="https://issues.apache.org/jira/browse/HBASE-15583">HBASE-15583</a>
      */
@@ -1470,6 +1530,7 @@ public class TableDescriptorBuilder {
     }
 
     /**
+     * Set the table owner.
      * @deprecated since 2.0.0 and will be removed in 3.0.0.
      * @see <a href="https://issues.apache.org/jira/browse/HBASE-15583">HBASE-15583</a>
      */
@@ -1488,6 +1549,7 @@ public class TableDescriptorBuilder {
     }
 
     /**
+     * Parse the serialized representation of a {@link ModifyableTableDescriptor}
      * @param bytes A pb serialized {@link ModifyableTableDescriptor} instance with pb magic prefix
      * @return An instance of {@link ModifyableTableDescriptor} made from <code>bytes</code>
      * @see #toByteArray()
