@@ -53,6 +53,8 @@ public class ServerSideScanMetrics {
     currentRegionScanMetricsData.createCounter(BYTES_READ_FROM_BLOCK_CACHE_METRIC_NAME);
     currentRegionScanMetricsData.createCounter(BYTES_READ_FROM_MEMSTORE_METRIC_NAME);
     currentRegionScanMetricsData.createCounter(BLOCK_READ_OPS_COUNT_METRIC_NAME);
+    currentRegionScanMetricsData.createCounter(RPC_SCAN_PROCESSING_TIME_METRIC_NAME);
+    currentRegionScanMetricsData.createCounter(RPC_SCAN_QUEUE_WAIT_TIME_METRIC_NAME);
   }
 
   /**
@@ -71,6 +73,8 @@ public class ServerSideScanMetrics {
     "BYTES_READ_FROM_BLOCK_CACHE";
   public static final String BYTES_READ_FROM_MEMSTORE_METRIC_NAME = "BYTES_READ_FROM_MEMSTORE";
   public static final String BLOCK_READ_OPS_COUNT_METRIC_NAME = "BLOCK_READ_OPS_COUNT";
+  public static final String RPC_SCAN_PROCESSING_TIME_METRIC_NAME = "RPC_SCAN_PROCESSING_TIME";
+  public static final String RPC_SCAN_QUEUE_WAIT_TIME_METRIC_NAME = "RPC_SCAN_QUEUE_WAIT_TIME";
 
   /**
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0
@@ -110,6 +114,12 @@ public class ServerSideScanMetrics {
 
   public final AtomicLong blockReadOpsCount = createCounter(BLOCK_READ_OPS_COUNT_METRIC_NAME);
 
+  public final AtomicLong rpcScanProcessingTime =
+    createCounter(RPC_SCAN_PROCESSING_TIME_METRIC_NAME);
+
+  public final AtomicLong rpcScanQueueWaitTime =
+    createCounter(RPC_SCAN_QUEUE_WAIT_TIME_METRIC_NAME);
+
   /**
    * Sets counter with counterName to passed in value, does nothing if counter does not exist. If
    * region level scan metrics are enabled then sets the value of counter for the current region
