@@ -17,6 +17,7 @@
  */
 package org.apache.hadoop.hbase.exceptions;
 
+import com.google.errorprone.annotations.RestrictedApi;
 import java.io.EOFException;
 import java.io.IOException;
 import java.io.SyncFailedException;
@@ -120,6 +121,10 @@ public final class ClientExceptionsUtil {
    * For test only. Usually you should use the {@link #isConnectionException(Throwable)} method
    * below.
    */
+  @RestrictedApi(explanation = "Should only be called in tests", link = "",
+      allowedOnPath = ".*/src/test/.*")
+  @edu.umd.cs.findbugs.annotations.SuppressWarnings(value = "MS_EXPOSE_REP",
+      justification = "test only")
   public static Set<Class<? extends Throwable>> getConnectionExceptionTypes() {
     return CONNECTION_EXCEPTION_TYPES;
   }
@@ -145,7 +150,7 @@ public final class ClientExceptionsUtil {
   /**
    * Translates exception for preemptive fast fail checks.
    * @param t exception to check
-   * @return translated exception n
+   * @return translated exception
    */
   public static Throwable translatePFFE(Throwable t) throws IOException {
     if (t instanceof NoSuchMethodError) {
