@@ -50,7 +50,7 @@ import org.apache.hadoop.hbase.shaded.protobuf.generated.FilterProtos;
  * fast-forwarding during scan. Thus, the scan will be quite efficient.
  */
 @InterfaceAudience.Public
-public class MultiRowRangeFilter extends FilterBase {
+public class MultiRowRangeFilter extends FilterBase implements HintingFilter {
 
   private static final int ROW_BEFORE_FIRST_RANGE = -1;
 
@@ -203,9 +203,11 @@ public class MultiRowRangeFilter extends FilterBase {
   }
 
   /**
+   * Parse a serialized representation of {@link MultiRowRangeFilter}
    * @param pbBytes A pb serialized instance
-   * @return An instance of MultiRowRangeFilter
-   * @throws org.apache.hadoop.hbase.exceptions.DeserializationException
+   * @return An instance of {@link MultiRowRangeFilter}
+   * @throws DeserializationException if an error occurred
+   * @see #toByteArray
    */
   public static MultiRowRangeFilter parseFrom(final byte[] pbBytes)
     throws DeserializationException {
@@ -230,15 +232,17 @@ public class MultiRowRangeFilter extends FilterBase {
   }
 
   /**
-   * @param o the filter to compare
-   * @return true if and only if the fields of the filter that are serialized are equal to the
-   *         corresponding fields in other. Used for testing.
+   * Returns true if and only if the fields of the filter that are serialized are equal to the
+   * corresponding fields in other. Used for testing.
    */
   @Override
   boolean areSerializedFieldsEqual(Filter o) {
-    if (o == this) return true;
-    if (!(o instanceof MultiRowRangeFilter)) return false;
-
+    if (o == this) {
+      return true;
+    }
+    if (!(o instanceof MultiRowRangeFilter)) {
+      return false;
+    }
     MultiRowRangeFilter other = (MultiRowRangeFilter) o;
     if (this.rangeList.size() != other.rangeList.size()) return false;
     for (int i = 0; i < rangeList.size(); ++i) {
@@ -725,7 +729,7 @@ public class MultiRowRangeFilter extends FilterBase {
     /**
      * Gets the RowRange at the given offset.
      */
-    @SuppressWarnings("unchecked")
+    @SuppressWarnings({ "unchecked", "TypeParameterUnusedInFormals" })
     public <T extends BasicRowRange> T get(int i) {
       return (T) ranges.get(i);
     }
