@@ -242,6 +242,12 @@ public final class ParseConstants {
   public static final byte[] regexStringType =
     new byte[] { 'r', 'e', 'g', 'e', 'x', 's', 't', 'r', 'i', 'n', 'g' };
 
+  /**
+   * RegexStringNoCaseType byte array
+   */
+  public static final byte[] regexStringNoCaseType = new byte[] { 'r', 'e', 'g', 'e', 'x', 's', 't',
+    'r', 'i', 'n', 'g', 'n', 'o', 'c', 'a', 's', 'e' };
+
   /**
    * SubstringType byte array
    */
