@@ -296,7 +296,10 @@ class NettyRpcConnection extends RpcConnection {
         public void operationComplete(ChannelFuture future) throws Exception {
           Channel ch = future.channel();
           if (!future.isSuccess()) {
-            failInit(ch, toIOE(future.cause()));
+            IOException ex = toIOE(future.cause());
+            LOG.warn(
+              "Exception encountered while connecting to the server " + remoteId.getAddress(), ex);
+            failInit(ch, ex);
             rpcClient.failedServers.addToFailedServers(remoteId.getAddress(), future.cause());
             return;
           }
@@ -315,7 +318,7 @@ class NettyRpcConnection extends RpcConnection {
   private void sendRequest0(Call call, HBaseRpcController hrc) throws IOException {
     assert eventLoop.inEventLoop();
     if (reloginInProgress) {
-      throw new IOException("Can not send request because relogin is in progress.");
+      throw new IOException(RpcConnectionConstants.RELOGIN_IS_IN_PROGRESS);
     }
     hrc.notifyOnCancel(new RpcCallback<Object>() {
 
