@@ -17,7 +17,10 @@
  */
 package org.apache.hadoop.hbase.security;
 
+import java.io.IOException;
+import java.util.Arrays;
 import java.util.Base64;
+import java.util.List;
 import java.util.Map;
 import java.util.TreeMap;
 import javax.security.sasl.Sasl;
@@ -29,6 +32,8 @@ import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.hbase.thirdparty.com.google.common.base.Splitter;
+
 @InterfaceAudience.Private
 public class SaslUtil {
   private static final Logger LOG = LoggerFactory.getLogger(SaslUtil.class);
@@ -62,7 +67,7 @@ public class SaslUtil {
 
   /** Splitting fully qualified Kerberos name into parts */
   public static String[] splitKerberosName(String fullName) {
-    return fullName.split("[/@]");
+    return Splitter.onPattern("[/@]").splitToStream(fullName).toArray(String[]::new);
   }
 
   public static String encodeIdentifier(byte[] identifier) {
@@ -93,6 +98,7 @@ public class SaslUtil {
   }
 
   /**
+   * Initialize SASL properties for a given RPC protection level.
    * @param rpcProtection Value of 'hbase.rpc.protection' configuration.
    * @return Map with values for SASL properties.
    */
@@ -101,10 +107,9 @@ public class SaslUtil {
     if (rpcProtection.isEmpty()) {
       saslQop = QualityOfProtection.AUTHENTICATION.getSaslQop();
     } else {
-      String[] qops = rpcProtection.split(",");
       StringBuilder saslQopBuilder = new StringBuilder();
-      for (int i = 0; i < qops.length; ++i) {
-        QualityOfProtection qop = getQop(qops[i]);
+      for (String s : Splitter.on(',').split(rpcProtection)) {
+        QualityOfProtection qop = getQop(s);
         saslQopBuilder.append(",").append(qop.getSaslQop());
       }
       saslQop = saslQopBuilder.substring(1); // remove first ','
@@ -130,4 +135,23 @@ public class SaslUtil {
       LOG.error("Error disposing of SASL server", e);
     }
   }
+
+  public static void verifyNegotiatedQop(String requestedQopString, String negotiatedQop)
+    throws IOException {
+    // We use the SASL QOP names here, not the HBase names
+    if (requestedQopString == null || requestedQopString.isEmpty()) {
+      // None requested, nothing to check
+      return;
+    }
+    List<String> requestedQops = Arrays.asList(requestedQopString.toLowerCase().split(","));
+    if (negotiatedQop == null) {
+      // Null negotiated QOP is equivalent to "auth" (for mechanisms without QOP support)
+      negotiatedQop = QualityOfProtection.AUTHENTICATION.getSaslQop();
+    }
+    if (requestedQops.contains(negotiatedQop.toLowerCase())) {
+      return;
+    }
+    throw new IOException("Could not negotiate requested SASL QOP. Requested:" + requestedQopString
+      + " , negotiated:" + negotiatedQop);
+  }
 }
