@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -17,28 +17,31 @@
  */
 package org.apache.hadoop.hbase.shaded.protobuf;
 
+import edu.umd.cs.findbugs.annotations.Nullable;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellScanner;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.ServerName;
+import org.apache.hadoop.hbase.client.CheckAndMutateResult;
 import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.SingleResponse;
 import org.apache.hadoop.hbase.ipc.ServerRpcController;
 import org.apache.hadoop.hbase.protobuf.generated.AccessControlProtos.HasPermissionResponse;
-import org.apache.hadoop.hbase.shaded.protobuf.generated.AdminProtos;
 import org.apache.hadoop.util.StringUtils;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+
 import org.apache.hbase.thirdparty.com.google.protobuf.ByteString;
 import org.apache.hbase.thirdparty.com.google.protobuf.RpcController;
+
+import org.apache.hadoop.hbase.shaded.protobuf.generated.AdminProtos;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.AdminProtos.CloseRegionResponse;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.AdminProtos.GetOnlineRegionResponse;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.AdminProtos.GetServerInfoResponse;
@@ -60,11 +63,9 @@ import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.RunCatalog
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.RunCleanerChoreResponse;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.RegionServerStatusProtos.GetLastFlushedSequenceIdResponse;
 
-import edu.umd.cs.findbugs.annotations.Nullable;
-
 /**
- * Helper utility to build protocol buffer responses,
- * or retrieve data from protocol buffer responses.
+ * Helper utility to build protocol buffer responses, or retrieve data from protocol buffer
+ * responses.
  */
 @InterfaceAudience.Private
 public final class ResponseConverter {
@@ -75,9 +76,7 @@ public final class ResponseConverter {
 
   // Start utilities for Client
   public static SingleResponse getResult(final ClientProtos.MutateRequest request,
-      final ClientProtos.MutateResponse response,
-      final CellScanner cells)
-          throws IOException {
+    final ClientProtos.MutateResponse response, final CellScanner cells) throws IOException {
     SingleResponse singleResponse = new SingleResponse();
     SingleResponse.Entry entry = new SingleResponse.Entry();
     entry.setResult(ProtobufUtil.toResult(response.getResult(), cells));
@@ -88,37 +87,32 @@ public final class ResponseConverter {
 
   /**
    * Get the results from a protocol buffer MultiResponse
-   *
-   * @param request the original protocol buffer MultiRequest
+   * @param request  the original protocol buffer MultiRequest
    * @param response the protocol buffer MultiResponse to convert
-   * @param cells Cells to go with the passed in <code>proto</code>.  Can be null.
+   * @param cells    Cells to go with the passed in <code>proto</code>. Can be null.
    * @return the results that were in the MultiResponse (a Result or an Exception).
-   * @throws IOException
    */
   public static org.apache.hadoop.hbase.client.MultiResponse getResults(final MultiRequest request,
-      final MultiResponse response, final CellScanner cells)
-  throws IOException {
+    final MultiResponse response, final CellScanner cells) throws IOException {
     return getResults(request, null, response, cells);
   }
 
   /**
    * Get the results from a protocol buffer MultiResponse
-   *
-   * @param request the original protocol buffer MultiRequest
-   * @param rowMutationsIndexMap Used to support RowMutations in batch
+   * @param request  the original protocol buffer MultiRequest
+   * @param indexMap Used to support RowMutations/CheckAndMutate in batch
    * @param response the protocol buffer MultiResponse to convert
-   * @param cells Cells to go with the passed in <code>proto</code>.  Can be null.
+   * @param cells    Cells to go with the passed in <code>proto</code>. Can be null.
    * @return the results that were in the MultiResponse (a Result or an Exception).
-   * @throws IOException
    */
   public static org.apache.hadoop.hbase.client.MultiResponse getResults(final MultiRequest request,
-      final Map<Integer, Integer> rowMutationsIndexMap, final MultiResponse response,
-      final CellScanner cells) throws IOException {
+    final Map<Integer, Integer> indexMap, final MultiResponse response, final CellScanner cells)
+    throws IOException {
     int requestRegionActionCount = request.getRegionActionCount();
     int responseRegionActionResultCount = response.getRegionActionResultCount();
     if (requestRegionActionCount != responseRegionActionResultCount) {
-      throw new IllegalStateException("Request mutation count=" + requestRegionActionCount +
-          " does not match response mutation result count=" + responseRegionActionResultCount);
+      throw new IllegalStateException("Request mutation count=" + requestRegionActionCount
+        + " does not match response mutation result count=" + responseRegionActionResultCount);
     }
 
     org.apache.hadoop.hbase.client.MultiResponse results =
@@ -128,58 +122,80 @@ public final class ResponseConverter {
       RegionAction actions = request.getRegionAction(i);
       RegionActionResult actionResult = response.getRegionActionResult(i);
       HBaseProtos.RegionSpecifier rs = actions.getRegion();
-      if (rs.hasType() &&
-          (rs.getType() != HBaseProtos.RegionSpecifier.RegionSpecifierType.REGION_NAME)){
+      if (
+        rs.hasType()
+          && (rs.getType() != HBaseProtos.RegionSpecifier.RegionSpecifierType.REGION_NAME)
+      ) {
         throw new IllegalArgumentException(
-            "We support only encoded types for protobuf multi response.");
+          "We support only encoded types for protobuf multi response.");
       }
       byte[] regionName = rs.getValue().toByteArray();
 
       if (actionResult.hasException()) {
-        Throwable regionException =  ProtobufUtil.toException(actionResult.getException());
+        Throwable regionException = ProtobufUtil.toException(actionResult.getException());
         results.addException(regionName, regionException);
         continue;
       }
 
       if (actions.getActionCount() != actionResult.getResultOrExceptionCount()) {
-        throw new IllegalStateException("actions.getActionCount=" + actions.getActionCount() +
-            ", actionResult.getResultOrExceptionCount=" +
-            actionResult.getResultOrExceptionCount() + " for region " + actions.getRegion());
+        throw new IllegalStateException("actions.getActionCount=" + actions.getActionCount()
+          + ", actionResult.getResultOrExceptionCount=" + actionResult.getResultOrExceptionCount()
+          + " for region " + actions.getRegion());
       }
 
-      Object responseValue;
-
-      // For RowMutations action, if there is an exception, the exception is set
+      // For RowMutations/CheckAndMutate action, if there is an exception, the exception is set
       // at the RegionActionResult level and the ResultOrException is null at the original index
-      Integer rowMutationsIndex =
-          (rowMutationsIndexMap == null ? null : rowMutationsIndexMap.get(i));
-      if (rowMutationsIndex != null) {
-        // This RegionAction is from a RowMutations in a batch.
+      Integer index = (indexMap == null ? null : indexMap.get(i));
+      if (index != null) {
+        // This RegionAction is from a RowMutations/CheckAndMutate in a batch.
         // If there is an exception from the server, the exception is set at
         // the RegionActionResult level, which has been handled above.
-        responseValue = response.getProcessed() ?
-            ProtobufUtil.EMPTY_RESULT_EXISTS_TRUE :
-            ProtobufUtil.EMPTY_RESULT_EXISTS_FALSE;
-        results.add(regionName, rowMutationsIndex, responseValue);
+        if (actions.hasCondition()) {
+          results.add(regionName, index, getCheckAndMutateResult(actionResult, cells));
+        } else {
+          results.add(regionName, index, getMutateRowResult(actionResult, cells));
+        }
         continue;
       }
 
-      for (ResultOrException roe : actionResult.getResultOrExceptionList()) {
-        if (roe.hasException()) {
-          responseValue = ProtobufUtil.toException(roe.getException());
-        } else if (roe.hasResult()) {
-          responseValue = ProtobufUtil.toResult(roe.getResult(), cells);
-        } else if (roe.hasServiceResult()) {
-          responseValue = roe.getServiceResult();
-        } else{
-          // Sometimes, the response is just "it was processed". Generally, this occurs for things
-          // like mutateRows where either we get back 'processed' (or not) and optionally some
-          // statistics about the regions we touched.
-          responseValue = response.getProcessed() ?
-                          ProtobufUtil.EMPTY_RESULT_EXISTS_TRUE :
-                          ProtobufUtil.EMPTY_RESULT_EXISTS_FALSE;
+      if (actions.hasCondition()) {
+        for (ResultOrException roe : actionResult.getResultOrExceptionList()) {
+          Result result = null;
+          Result r = ProtobufUtil.toResult(roe.getResult(), cells);
+          if (!r.isEmpty()) {
+            result = r;
+          }
+          results.add(regionName, roe.getIndex(),
+            new CheckAndMutateResult(actionResult.getProcessed(), result));
+        }
+      } else {
+        if (actionResult.hasProcessed()) {
+          for (ResultOrException roe : actionResult.getResultOrExceptionList()) {
+            Result result = actionResult.getProcessed()
+              ? ProtobufUtil.EMPTY_RESULT_EXISTS_TRUE
+              : ProtobufUtil.EMPTY_RESULT_EXISTS_FALSE;
+            Result r = ProtobufUtil.toResult(roe.getResult(), cells);
+            if (!r.isEmpty()) {
+              r.setExists(true);
+              result = r;
+            }
+            results.add(regionName, roe.getIndex(), result);
+          }
+          continue;
+        }
+        for (ResultOrException roe : actionResult.getResultOrExceptionList()) {
+          Object responseValue;
+          if (roe.hasException()) {
+            responseValue = ProtobufUtil.toException(roe.getException());
+          } else if (roe.hasResult()) {
+            responseValue = ProtobufUtil.toResult(roe.getResult(), cells);
+          } else if (roe.hasServiceResult()) {
+            responseValue = roe.getServiceResult();
+          } else {
+            responseValue = ProtobufUtil.EMPTY_RESULT_EXISTS_TRUE;
+          }
+          results.add(regionName, roe.getIndex(), responseValue);
         }
-        results.add(regionName, roe.getIndex(), responseValue);
       }
     }
 
@@ -193,10 +209,63 @@ public final class ResponseConverter {
     return results;
   }
 
+  private static CheckAndMutateResult getCheckAndMutateResult(RegionActionResult actionResult,
+    CellScanner cells) throws IOException {
+    Result result = null;
+    if (actionResult.getResultOrExceptionCount() > 0) {
+      // Get the result of the Increment/Append operations from the first element of the
+      // ResultOrException list
+      ResultOrException roe = actionResult.getResultOrException(0);
+      if (roe.hasResult()) {
+        Result r = ProtobufUtil.toResult(roe.getResult(), cells);
+        if (!r.isEmpty()) {
+          result = r;
+        }
+      }
+    }
+    return new CheckAndMutateResult(actionResult.getProcessed(), result);
+  }
+
+  private static Result getMutateRowResult(RegionActionResult actionResult, CellScanner cells)
+    throws IOException {
+    if (actionResult.getProcessed()) {
+      Result result = null;
+      if (actionResult.getResultOrExceptionCount() > 0) {
+        // Get the result of the Increment/Append operations from the first element of the
+        // ResultOrException list
+        ResultOrException roe = actionResult.getResultOrException(0);
+        Result r = ProtobufUtil.toResult(roe.getResult(), cells);
+        if (!r.isEmpty()) {
+          r.setExists(true);
+          result = r;
+        }
+      }
+      if (result != null) {
+        return result;
+      } else {
+        return ProtobufUtil.EMPTY_RESULT_EXISTS_TRUE;
+      }
+    } else {
+      return ProtobufUtil.EMPTY_RESULT_EXISTS_FALSE;
+    }
+  }
+
+  /**
+   * Create a CheckAndMutateResult object from a protocol buffer MutateResponse
+   * @return a CheckAndMutateResult object
+   */
+  public static CheckAndMutateResult getCheckAndMutateResult(
+    ClientProtos.MutateResponse mutateResponse, CellScanner cells) throws IOException {
+    boolean success = mutateResponse.getProcessed();
+    Result result = null;
+    if (mutateResponse.hasResult()) {
+      result = ProtobufUtil.toResult(mutateResponse.getResult(), cells);
+    }
+    return new CheckAndMutateResult(success, result);
+  }
+
   /**
    * Wrap a throwable to an action result.
-   *
-   * @param t
    * @return an action result builder
    */
   public static ResultOrException.Builder buildActionResult(final Throwable t) {
@@ -207,8 +276,6 @@ public final class ResponseConverter {
 
   /**
    * Wrap a throwable to an action result.
-   *
-   * @param r
    * @return an action result builder
    */
   public static ResultOrException.Builder buildActionResult(final ClientProtos.Result r) {
@@ -217,15 +284,11 @@ public final class ResponseConverter {
     return builder;
   }
 
-  /**
-   * @param t
-   * @return NameValuePair of the exception name to stringified version os exception.
-   */
+  /** Returns NameValuePair of the exception name to stringified version os exception. */
   public static NameBytesPair buildException(final Throwable t) {
     NameBytesPair.Builder parameterBuilder = NameBytesPair.newBuilder();
     parameterBuilder.setName(t.getClass().getName());
-    parameterBuilder.setValue(
-      ByteString.copyFromUtf8(StringUtils.stringifyException(t)));
+    parameterBuilder.setValue(ByteString.copyFromUtf8(StringUtils.stringifyException(t)));
     return parameterBuilder.build();
   }
 
@@ -238,12 +301,11 @@ public final class ResponseConverter {
     return builder.build();
   }
 
-// End utilities for Client
-// Start utilities for Admin
+  // End utilities for Client
+  // Start utilities for Admin
 
   /**
    * Get the list of region info from a GetOnlineRegionResponse
-   *
    * @param proto the GetOnlineRegionResponse
    * @return the list of region info
    */
@@ -254,25 +316,20 @@ public final class ResponseConverter {
 
   /**
    * Check if the region is closed from a CloseRegionResponse
-   *
    * @param proto the CloseRegionResponse
    * @return the region close state
    */
-  public static boolean isClosed
-      (final CloseRegionResponse proto) {
+  public static boolean isClosed(final CloseRegionResponse proto) {
     if (proto == null || !proto.hasClosed()) return false;
     return proto.getClosed();
   }
 
   /**
    * A utility to build a GetServerInfoResponse.
-   *
-   * @param serverName
-   * @param webuiPort
    * @return the response
    */
-  public static GetServerInfoResponse buildGetServerInfoResponse(
-      final ServerName serverName, final int webuiPort) {
+  public static GetServerInfoResponse buildGetServerInfoResponse(final ServerName serverName,
+    final int webuiPort) {
     GetServerInfoResponse.Builder builder = GetServerInfoResponse.newBuilder();
     ServerInfo.Builder serverInfoBuilder = ServerInfo.newBuilder();
     serverInfoBuilder.setServerName(ProtobufUtil.toServerName(serverName));
@@ -285,14 +342,12 @@ public final class ResponseConverter {
 
   /**
    * A utility to build a GetOnlineRegionResponse.
-   *
-   * @param regions
    * @return the response
    */
-  public static GetOnlineRegionResponse buildGetOnlineRegionResponse(
-      final List<RegionInfo> regions) {
+  public static GetOnlineRegionResponse
+    buildGetOnlineRegionResponse(final List<RegionInfo> regions) {
     GetOnlineRegionResponse.Builder builder = GetOnlineRegionResponse.newBuilder();
-    for (RegionInfo region: regions) {
+    for (RegionInfo region : regions) {
       builder.addRegionInfo(ProtobufUtil.toRegionInfo(region));
     }
     return builder.build();
@@ -322,30 +377,30 @@ public final class ResponseConverter {
     return RunCleanerChoreResponse.newBuilder().setCleanerChoreRan(ran).build();
   }
 
-// End utilities for Admin
+  // End utilities for Admin
 
   /**
    * Creates a response for the last flushed sequence Id request
    * @return A GetLastFlushedSequenceIdResponse
    */
-  public static GetLastFlushedSequenceIdResponse buildGetLastFlushedSequenceIdResponse(
-      RegionStoreSequenceIds ids) {
+  public static GetLastFlushedSequenceIdResponse
+    buildGetLastFlushedSequenceIdResponse(RegionStoreSequenceIds ids) {
     return GetLastFlushedSequenceIdResponse.newBuilder()
-        .setLastFlushedSequenceId(ids.getLastFlushedSequenceId())
-        .addAllStoreLastFlushedSequenceId(ids.getStoreSequenceIdList()).build();
+      .setLastFlushedSequenceId(ids.getLastFlushedSequenceId())
+      .addAllStoreLastFlushedSequenceId(ids.getStoreSequenceIdList()).build();
   }
 
   /**
-   * Stores an exception encountered during RPC invocation so it can be passed back
-   * through to the client.
+   * Stores an exception encountered during RPC invocation so it can be passed back through to the
+   * client.
    * @param controller the controller instance provided by the client when calling the service
-   * @param ioe the exception encountered
+   * @param ioe        the exception encountered
    */
   public static void setControllerException(com.google.protobuf.RpcController controller,
-      IOException ioe) {
+    IOException ioe) {
     if (controller != null) {
       if (controller instanceof ServerRpcController) {
-        ((ServerRpcController)controller).setFailedOn(ioe);
+        ((ServerRpcController) controller).setFailedOn(ioe);
       } else {
         controller.setFailed(StringUtils.stringifyException(ioe));
       }
@@ -356,13 +411,13 @@ public final class ResponseConverter {
    * Retreivies exception stored during RPC invocation.
    * @param controller the controller instance provided by the client when calling the service
    * @return exception if any, or null; Will return DoNotRetryIOException for string represented
-   * failure causes in controller.
+   *         failure causes in controller.
    */
   @Nullable
   public static IOException getControllerException(RpcController controller) throws IOException {
     if (controller != null && controller.failed()) {
       if (controller instanceof ServerRpcController) {
-        return ((ServerRpcController)controller).getFailedOn();
+        return ((ServerRpcController) controller).getFailedOn();
       } else {
         return new DoNotRetryIOException(controller.errorText());
       }
@@ -370,35 +425,31 @@ public final class ResponseConverter {
     return null;
   }
 
-
   /**
    * Create Results from the cells using the cells meta data.
-   * @param cellScanner
-   * @param response
-   * @return results
    */
   public static Result[] getResults(CellScanner cellScanner, ScanResponse response)
-      throws IOException {
+    throws IOException {
     if (response == null) return null;
     // If cellscanner, then the number of Results to return is the count of elements in the
-    // cellsPerResult list.  Otherwise, it is how many results are embedded inside the response.
-    int noOfResults = cellScanner != null?
-      response.getCellsPerResultCount(): response.getResultsCount();
+    // cellsPerResult list. Otherwise, it is how many results are embedded inside the response.
+    int noOfResults =
+      cellScanner != null ? response.getCellsPerResultCount() : response.getResultsCount();
     Result[] results = new Result[noOfResults];
     for (int i = 0; i < noOfResults; i++) {
       if (cellScanner != null) {
-        // Cells are out in cellblocks.  Group them up again as Results.  How many to read at a
+        // Cells are out in cellblocks. Group them up again as Results. How many to read at a
         // time will be found in getCellsLength -- length here is how many Cells in the i'th Result
         int noOfCells = response.getCellsPerResult(i);
         boolean isPartial =
-            response.getPartialFlagPerResultCount() > i ?
-                response.getPartialFlagPerResult(i) : false;
+          response.getPartialFlagPerResultCount() > i ? response.getPartialFlagPerResult(i) : false;
         List<Cell> cells = new ArrayList<>(noOfCells);
         for (int j = 0; j < noOfCells; j++) {
           try {
             if (cellScanner.advance() == false) {
               // We are not able to retrieve the exact number of cells which ResultCellMeta says us.
-              // We have to scan for the same results again. Throwing DNRIOE as a client retry on the
+              // We have to scan for the same results again. Throwing DNRIOE as a client retry on
+              // the
               // same scanner will result in OutOfOrderScannerNextException
               String msg = "Results sent from server=" + noOfResults + ". But only got " + i
                 + " results completely at client. Resetting the scanner to scan again.";
@@ -409,8 +460,9 @@ public final class ResponseConverter {
             // We are getting IOE while retrieving the cells for Results.
             // We have to scan for the same results again. Throwing DNRIOE as a client retry on the
             // same scanner will result in OutOfOrderScannerNextException
-            LOG.error("Exception while reading cells from result."
-              + "Resetting the scanner to scan again.", ioe);
+            LOG.error(
+              "Exception while reading cells from result." + "Resetting the scanner to scan again.",
+              ioe);
             throw new DoNotRetryIOException("Resetting the scanner.", ioe);
           }
           cells.add(cellScanner.current());
@@ -448,11 +500,11 @@ public final class ResponseConverter {
 
   /**
    * Creates a protocol buffer ClearRegionBlockCacheResponse
-   *
    * @return a ClearRegionBlockCacheResponse
    */
-  public static AdminProtos.ClearRegionBlockCacheResponse buildClearRegionBlockCacheResponse(final HBaseProtos.CacheEvictionStats
-                                                                                   cacheEvictionStats) {
-    return AdminProtos.ClearRegionBlockCacheResponse.newBuilder().setStats(cacheEvictionStats).build();
+  public static AdminProtos.ClearRegionBlockCacheResponse
+    buildClearRegionBlockCacheResponse(final HBaseProtos.CacheEvictionStats cacheEvictionStats) {
+    return AdminProtos.ClearRegionBlockCacheResponse.newBuilder().setStats(cacheEvictionStats)
+      .build();
   }
 }
