@@ -27,6 +27,7 @@ import org.apache.hadoop.hbase.master.RegionState;
 import org.apache.hadoop.hbase.testclassification.MasterTests;
 import org.apache.hadoop.hbase.testclassification.SmallTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.junit.Assert;
 import org.junit.ClassRule;
 import org.junit.Rule;
@@ -55,8 +56,8 @@ public class TestRegionInfoDisplay {
     checkEquality(ri, conf);
     // check HRIs with non-default replicaId
     ri = RegionInfoBuilder.newBuilder(TableName.valueOf(name.getMethodName())).setStartKey(startKey)
-      .setEndKey(endKey).setSplit(false).setRegionId(System.currentTimeMillis()).setReplicaId(1)
-      .build();
+      .setEndKey(endKey).setSplit(false).setRegionId(EnvironmentEdgeManager.currentTime())
+      .setReplicaId(1).build();
     checkEquality(ri, conf);
     Assert.assertArrayEquals(RegionInfoDisplay.HIDDEN_END_KEY,
       RegionInfoDisplay.getEndKeyForDisplay(ri, conf));
@@ -87,8 +88,8 @@ public class TestRegionInfoDisplay {
     String firstPartOrig = origDesc.substring(0, origDesc.indexOf(Bytes.toStringBinary(startKey)));
     String secondPartOrig = origDesc.substring(
       origDesc.indexOf(Bytes.toStringBinary(startKey)) + Bytes.toStringBinary(startKey).length());
-    assert (firstPart.equals(firstPartOrig));
-    assert (secondPart.equals(secondPartOrig));
+    Assert.assertTrue(firstPart.equals(firstPartOrig));
+    Assert.assertTrue(secondPart.equals(secondPartOrig));
   }
 
   private void checkEquality(RegionInfo ri, Configuration conf) throws IOException {
