@@ -34,7 +34,6 @@ import java.util.Map.Entry;
 import java.util.NavigableMap;
 import java.util.Optional;
 import java.util.function.Function;
-import org.apache.hadoop.hbase.KeyValue.Type;
 import org.apache.hadoop.hbase.io.HeapSize;
 import org.apache.hadoop.hbase.util.ByteBufferUtils;
 import org.apache.hadoop.hbase.util.ByteRange;
@@ -431,7 +430,7 @@ public final class CellUtil {
   }
 
   /**
-   * @return cell's qualifier wrapped into a ByteBuffer.
+   * Return cell's qualifier wrapped into a ByteBuffer.
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0.
    */
   @Deprecated
@@ -443,6 +442,7 @@ public final class CellUtil {
   }
 
   /**
+   * Create a cell
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0. Use {@link CellBuilder}
    *             instead
    */
@@ -508,7 +508,7 @@ public final class CellUtil {
   @InterfaceAudience.Private
   @Deprecated
   public static Cell createCell(final byte[] row, final byte[] family, final byte[] qualifier,
-    final long timestamp, Type type, final byte[] value, byte[] tags) {
+    final long timestamp, KeyValue.Type type, final byte[] value, byte[] tags) {
     return createCell(row, family, qualifier, timestamp, type.getCode(), value, tags, 0);
   }
 
@@ -696,7 +696,7 @@ public final class CellUtil {
   }
 
   /**
-   * @return True if the rows in <code>left</code> and <code>right</code> Cells match
+   * Return true if the rows in <code>left</code> and <code>right</code> Cells match
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0. Instead use
    *             {@link #matchingRows(Cell, Cell)}
    */
@@ -706,6 +706,7 @@ public final class CellUtil {
   }
 
   /**
+   * Return true if the row is matching
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0. Instead use
    *             {@link #matchingRows(Cell, byte[])}
    */
@@ -722,9 +723,9 @@ public final class CellUtil {
   }
 
   /**
+   * Return true if the row is matching
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0. Instead use
    *             {@link #matchingRows(Cell, Cell)}
-   * @return true if the row is matching
    */
   @Deprecated
   public static boolean matchingRow(final Cell left, final byte[] buf, final int offset,
@@ -773,6 +774,7 @@ public final class CellUtil {
   }
 
   /**
+   * Return true if the family is matching
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0.
    */
   @Deprecated
@@ -816,8 +818,7 @@ public final class CellUtil {
   }
 
   /**
-   * Finds if the qualifier part of the cell and the KV serialized byte[] are equal
-   * @param buf the serialized keyvalue format byte[]
+   * Finds if the qualifier part of the cell and the KV serialized byte[] are equal.
    * @return true if the qualifier matches, false otherwise
    */
   public static boolean matchingQualifier(final Cell left, final byte[] buf) {
@@ -861,6 +862,7 @@ public final class CellUtil {
   }
 
   /**
+   * Return true if the column is matching
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0.
    */
   @Deprecated
@@ -903,8 +905,8 @@ public final class CellUtil {
   }
 
   /**
-   * @return True if a delete type, a {@link KeyValue.Type#Delete} or a {KeyValue.Type#DeleteFamily}
-   *         or a {@link KeyValue.Type#DeleteColumn} KeyValue type.
+   * Return true if a delete type, a {@link KeyValue.Type#Delete} or a {KeyValue.Type#DeleteFamily}
+   * or a {@link KeyValue.Type#DeleteColumn} KeyValue type.
    */
   @SuppressWarnings("deprecation")
   public static boolean isDelete(final Cell cell) {
@@ -912,70 +914,74 @@ public final class CellUtil {
   }
 
   /**
-   * @return True if a delete type, a {@link KeyValue.Type#Delete} or a {KeyValue.Type#DeleteFamily}
-   *         or a {@link KeyValue.Type#DeleteColumn} KeyValue type.
+   * Return true if a delete type, a {@link KeyValue.Type#Delete} or a {KeyValue.Type#DeleteFamily}
+   * or a {@link KeyValue.Type#DeleteColumn} KeyValue type.
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0.
    */
   @Deprecated
   public static boolean isDelete(final byte type) {
-    return Type.Delete.getCode() <= type && type <= Type.DeleteFamily.getCode();
+    return KeyValue.Type.Delete.getCode() <= type && type <= KeyValue.Type.DeleteFamily.getCode();
   }
 
   /**
-   * @return True if this cell is a {@link KeyValue.Type#Delete} type.
+   * Return true if this cell is a {@link KeyValue.Type#Delete} type.
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0.
    */
   @Deprecated
   public static boolean isDeleteType(Cell cell) {
-    return cell.getTypeByte() == Type.Delete.getCode();
+    return cell.getTypeByte() == KeyValue.Type.Delete.getCode();
   }
 
   /**
+   * Check whether the given cell is a delete family
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0.
    */
   @Deprecated
   public static boolean isDeleteFamily(final Cell cell) {
-    return cell.getTypeByte() == Type.DeleteFamily.getCode();
+    return cell.getTypeByte() == KeyValue.Type.DeleteFamily.getCode();
   }
 
   /**
+   * Check whether the given cell is a delete family version
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0.
    */
   @Deprecated
   public static boolean isDeleteFamilyVersion(final Cell cell) {
-    return cell.getTypeByte() == Type.DeleteFamilyVersion.getCode();
+    return cell.getTypeByte() == KeyValue.Type.DeleteFamilyVersion.getCode();
   }
 
   /**
+   * Check whether the given cell is a delete columns
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0.
    */
   @Deprecated
   public static boolean isDeleteColumns(final Cell cell) {
-    return cell.getTypeByte() == Type.DeleteColumn.getCode();
+    return cell.getTypeByte() == KeyValue.Type.DeleteColumn.getCode();
   }
 
   /**
+   * Check whether the given cell is a delete column version
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0.
    */
   @Deprecated
   public static boolean isDeleteColumnVersion(final Cell cell) {
-    return cell.getTypeByte() == Type.Delete.getCode();
+    return cell.getTypeByte() == KeyValue.Type.Delete.getCode();
   }
 
   /**
-   * @return True if this cell is a delete family or column type.
+   * Return true if this cell is a delete family or column type.
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0.
    */
   @Deprecated
   public static boolean isDeleteColumnOrFamily(Cell cell) {
     int t = cell.getTypeByte();
-    return t == Type.DeleteColumn.getCode() || t == Type.DeleteFamily.getCode();
+    return t == KeyValue.Type.DeleteColumn.getCode() || t == KeyValue.Type.DeleteFamily.getCode();
   }
 
   /** Returns True if this cell is a Put. */
   @SuppressWarnings("deprecation")
   public static boolean isPut(Cell cell) {
-    return cell.getTypeByte() == Type.Put.getCode();
+    return cell.getTypeByte() == KeyValue.Type.Put.getCode();
   }
 
   /**
@@ -1001,15 +1007,14 @@ public final class CellUtil {
   }
 
   /**
-   * Returns Sum of the lengths of all the elements in a Cell; does not count in any infrastructure
+   * Return sum of the lengths of all the elements in a Cell; does not count in any infrastructure
    */
   private static int getSumOfCellElementLengths(final Cell cell) {
     return getSumOfCellKeyElementLengths(cell) + cell.getValueLength() + cell.getTagsLength();
   }
 
   /**
-   * @return Sum of all elements that make up a key; does not include infrastructure, tags or
-   *         values.
+   * Return sum of all elements that make up a key; does not include infrastructure, tags or values.
    */
   private static int getSumOfCellKeyElementLengths(final Cell cell) {
     return cell.getRowLength() + cell.getFamilyLength() + cell.getQualifierLength()
@@ -1080,8 +1085,7 @@ public final class CellUtil {
   }
 
   /**
-   * @param cell The Cell
-   * @return Tags in the given Cell as a List
+   * Return tags in the given Cell as a List
    * @deprecated As of 2.0.0 and will be removed in 3.0.0
    */
   @Deprecated
@@ -1135,7 +1139,8 @@ public final class CellUtil {
   }
 
   /**
-   * Sets the given timestamp to the cell.
+   * Sets the given timestamp to the cell. Note that this method is a LimitedPrivate API and may
+   * change between minor releases.
    * @throws IOException when the passed cell is not of type {@link ExtendedCell}
    * @deprecated As of HBase-2.0. Will be a LimitedPrivate API in HBase-3.0.
    */
@@ -1145,9 +1150,8 @@ public final class CellUtil {
   }
 
   /**
-   * Sets the given timestamp to the cell.
-   * @param ts       buffer containing the timestamp value
-   * @param tsOffset offset to the new timestamp
+   * Sets the given timestamp to the cell. Note that this method is a LimitedPrivate API and may
+   * change between minor releases.
    * @throws IOException when the passed cell is not of type {@link ExtendedCell}
    * @deprecated As of HBase-2.0. Will be a LimitedPrivate API in HBase-3.0.
    */
@@ -1237,13 +1241,16 @@ public final class CellUtil {
     }
   }
 
-  /** Returns The Key portion of the passed <code>cell</code> as a String. */
+  /**
+   * Return the key portion of the passed <code>cell</code> as a String.
+   */
   public static String getCellKeyAsString(Cell cell) {
     return getCellKeyAsString(cell,
       c -> Bytes.toStringBinary(c.getRowArray(), c.getRowOffset(), c.getRowLength()));
   }
 
   /**
+   * Return the Key portion of the passed <code>cell</code> as a String.
    * @param cell         the cell to convert
    * @param rowConverter used to convert the row of the cell to a string
    * @return The Key portion of the passed <code>cell</code> as a String.
@@ -1264,7 +1271,7 @@ public final class CellUtil {
     sb.append('/');
     sb.append(KeyValue.humanReadableTimestamp(cell.getTimestamp()));
     sb.append('/');
-    sb.append(Type.codeToType(cell.getTypeByte()));
+    sb.append(KeyValue.Type.codeToType(cell.getTypeByte()));
     if (!(cell instanceof KeyValue.KeyOnlyKeyValue)) {
       sb.append("/vlen=");
       sb.append(cell.getValueLength());
@@ -1488,6 +1495,7 @@ public final class CellUtil {
   }
 
   /**
+   * Check whether the type of these two cells are the same
    * @deprecated As of HBase-2.0. Will be removed in HBase-3.0
    */
   @Deprecated
@@ -1495,16 +1503,14 @@ public final class CellUtil {
     return a.getTypeByte() == b.getTypeByte();
   }
 
-  /**
-   * Compares the row of two keyvalues for equality
-   * @return True if rows match.
-   */
+  /** Compares the row of two keyvalues for equality */
   public static boolean matchingRows(final Cell left, final Cell right) {
     short lrowlength = left.getRowLength();
     short rrowlength = right.getRowLength();
     return matchingRows(left, lrowlength, right, rrowlength);
   }
 
+  /** Compares the row of two keyvalues for equality */
   public static boolean matchingRows(final Cell left, final short lrowlength, final Cell right,
     final short rrowlength) {
     if (lrowlength != rrowlength) return false;
@@ -1528,10 +1534,7 @@ public final class CellUtil {
       right.getRowOffset(), rrowlength);
   }
 
-  /**
-   * Compares the row and column of two keyvalues for equality
-   * @return True if same row and column.
-   */
+  /** Compares the row and column of two keyvalues for equality */
   public static boolean matchingRowColumn(final Cell left, final Cell right) {
     short lrowlength = left.getRowLength();
     short rrowlength = right.getRowLength();
@@ -1558,6 +1561,7 @@ public final class CellUtil {
     return matchingColumn(left, lfamlength, lqlength, right, rfamlength, rqlength);
   }
 
+  /** Compares the row and column of two keyvalues for equality */
   public static boolean matchingRowColumnBytes(final Cell left, final Cell right) {
     int lrowlength = left.getRowLength();
     int rrowlength = right.getRowLength();
