@@ -26,6 +26,7 @@ import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.ScheduledThreadPoolExecutor;
 import java.util.concurrent.ThreadFactory;
 import java.util.concurrent.atomic.AtomicInteger;
+import org.apache.hadoop.hbase.trace.TraceUtil;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -139,6 +140,7 @@ public class ChoreService {
   }
 
   /**
+   * Schedule a chore.
    * @param chore Chore to be scheduled. If the chore is already scheduled with another ChoreService
    *              instance, that schedule will be cancelled (i.e. a Chore can only ever be scheduled
    *              with a single ChoreService instance).
@@ -169,8 +171,9 @@ public class ChoreService {
             chore.getChoreService().cancelChore(chore);
           }
           chore.setChoreService(this);
-          ScheduledFuture<?> future = scheduler.scheduleAtFixedRate(chore, chore.getInitialDelay(),
-            chore.getPeriod(), chore.getTimeUnit());
+          ScheduledFuture<?> future =
+            scheduler.scheduleAtFixedRate(TraceUtil.tracedRunnable(chore, chore.getName()),
+              chore.getInitialDelay(), chore.getPeriod(), chore.getTimeUnit());
           scheduledChores.put(chore, future);
           return true;
         } catch (Exception e) {
@@ -256,8 +259,8 @@ public class ChoreService {
   }
 
   /**
-   * @return number of chores that this service currently has scheduled that are missing their
-   *         scheduled start time
+   * Return number of chores that this service currently has scheduled that are missing their
+   * scheduled start time
    */
   int getNumberOfChoresMissingStartTime() {
     return choresMissingStartTime.size();
@@ -277,9 +280,6 @@ public class ChoreService {
     private final static String THREAD_NAME_SUFFIX = ".Chore.";
     private AtomicInteger threadNumber = new AtomicInteger(1);
 
-    /**
-     * @param threadPrefix The prefix given to all threads created by this factory
-     */
     public ChoreServiceThreadFactory(final String threadPrefix) {
       this.threadPrefix = threadPrefix;
     }
@@ -354,9 +354,9 @@ public class ChoreService {
   }
 
   /**
-   * shutdown the service. Any chores that are scheduled for execution will be cancelled. Any chores
-   * in the middle of execution will be interrupted and shutdown. This service will be unusable
-   * after this method has been called (i.e. future scheduling attempts will fail).
+   * Shut down the service. Any chores that are scheduled for execution will be cancelled. Any
+   * chores in the middle of execution will be interrupted and shutdown. This service will be
+   * unusable after this method has been called (i.e. future scheduling attempts will fail).
    * <p/>
    * Notice that, this will only clean the chore from this ChoreService but you could still schedule
    * the chore with other ChoreService.
@@ -394,9 +394,7 @@ public class ChoreService {
     }
   }
 
-  /**
-   * Prints a summary of important details about the chore. Used for debugging purposes
-   */
+  /** Prints a summary of important details about the chore. Used for debugging purposes */
   private void printChoreDetails(final String header, ScheduledChore chore) {
     if (!LOG.isTraceEnabled()) {
       return;
@@ -412,9 +410,7 @@ public class ChoreService {
     }
   }
 
-  /**
-   * Prints a summary of important details about the service. Used for debugging purposes
-   */
+  /** Prints a summary of important details about the service. Used for debugging purposes */
   private void printChoreServiceDetails(final String header) {
     if (!LOG.isTraceEnabled()) {
       return;
