@@ -73,8 +73,6 @@ import org.slf4j.LoggerFactory;
  */
 @InterfaceAudience.Private
 public class KeyValue implements ExtendedCell, Cloneable {
-  private static final ArrayList<Tag> EMPTY_ARRAY_LIST = new ArrayList<>();
-
   private static final Logger LOG = LoggerFactory.getLogger(KeyValue.class);
 
   public static final int FIXED_OVERHEAD = ClassSize.OBJECT + // the KeyValue object itself
@@ -248,6 +246,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
     /**
      * Cannot rely on enum ordinals . They change if item is removed or moved. Do our own codes.
+     * @param b the kv serialized byte[] to process
      * @return Type associated with passed code.
      */
     public static Type codeToType(final byte b) {
@@ -335,6 +334,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param bytes  byte array
    * @param offset offset to start of the KeyValue
    * @param length length of the KeyValue
+   * @param ts     timestamp
    */
   public KeyValue(final byte[] bytes, final int offset, final int length, long ts) {
     this(bytes, offset, length, null, 0, 0, null, 0, 0, ts, Type.Maximum, null, 0, 0, null);
@@ -345,7 +345,8 @@ public class KeyValue implements ExtendedCell, Cloneable {
   /**
    * Constructs KeyValue structure filled with null value. Sets type to
    * {@link KeyValue.Type#Maximum}
-   * @param row - row key (arbitrary byte array)
+   * @param row       - row key (arbitrary byte array)
+   * @param timestamp version timestamp
    */
   public KeyValue(final byte[] row, final long timestamp) {
     this(row, null, null, timestamp, Type.Maximum, null);
@@ -353,7 +354,8 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
   /**
    * Constructs KeyValue structure filled with null value.
-   * @param row - row key (arbitrary byte array)
+   * @param row       - row key (arbitrary byte array)
+   * @param timestamp version timestamp
    */
   public KeyValue(final byte[] row, final long timestamp, Type type) {
     this(row, null, null, timestamp, type, null);
@@ -388,6 +390,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param qualifier column qualifier
    * @param timestamp version timestamp
    * @param type      key type
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final byte[] row, final byte[] family, final byte[] qualifier,
     final long timestamp, Type type) {
@@ -401,6 +404,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param qualifier column qualifier
    * @param timestamp version timestamp
    * @param value     column value
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final byte[] row, final byte[] family, final byte[] qualifier,
     final long timestamp, final byte[] value) {
@@ -415,6 +419,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param timestamp version timestamp
    * @param value     column value
    * @param tags      tags
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final byte[] row, final byte[] family, final byte[] qualifier,
     final long timestamp, final byte[] value, final Tag[] tags) {
@@ -429,6 +434,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param timestamp version timestamp
    * @param value     column value
    * @param tags      tags non-empty list of tags or null
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final byte[] row, final byte[] family, final byte[] qualifier,
     final long timestamp, final byte[] value, final List<Tag> tags) {
@@ -445,6 +451,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param timestamp version timestamp
    * @param type      key type
    * @param value     column value
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final byte[] row, final byte[] family, final byte[] qualifier,
     final long timestamp, Type type, final byte[] value) {
@@ -462,6 +469,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param timestamp version timestamp
    * @param type      key type
    * @param value     column value
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final byte[] row, final byte[] family, final byte[] qualifier,
     final long timestamp, Type type, final byte[] value, final List<Tag> tags) {
@@ -477,6 +485,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param timestamp version timestamp
    * @param type      key type
    * @param value     column value
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final byte[] row, final byte[] family, final byte[] qualifier,
     final long timestamp, Type type, final byte[] value, final byte[] tags) {
@@ -496,6 +505,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param value     column value
    * @param voffset   value offset
    * @param vlength   value length
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(byte[] row, byte[] family, byte[] qualifier, int qoffset, int qlength,
     long timestamp, Type type, byte[] value, int voffset, int vlength, List<Tag> tags) {
@@ -504,7 +514,18 @@ public class KeyValue implements ExtendedCell, Cloneable {
   }
 
   /**
-   *   */
+   * @param row       row key
+   * @param family    family name
+   * @param qualifier qualifier name
+   * @param qoffset   qualifier offset
+   * @param qlength   qualifier length
+   * @param timestamp version timestamp
+   * @param type      key type
+   * @param value     column value
+   * @param voffset   value offset
+   * @param vlength   value length
+   * @param tags      tags
+   */
   public KeyValue(byte[] row, byte[] family, byte[] qualifier, int qoffset, int qlength,
     long timestamp, Type type, byte[] value, int voffset, int vlength, byte[] tags) {
     this(row, 0, row == null ? 0 : row.length, family, 0, family == null ? 0 : family.length,
@@ -517,6 +538,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * <p>
    * Column is split into two fields, family and qualifier.
    * @param row row key
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final byte[] row, final int roffset, final int rlength, final byte[] family,
     final int foffset, final int flength, final byte[] qualifier, final int qoffset,
@@ -580,6 +602,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param voffset   value offset
    * @param vlength   value length
    * @param tags      tags
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final byte[] row, final int roffset, final int rlength, final byte[] family,
     final int foffset, final int flength, final byte[] qualifier, final int qoffset,
@@ -592,7 +615,22 @@ public class KeyValue implements ExtendedCell, Cloneable {
   }
 
   /**
-   *   */
+   * @param row       row key
+   * @param roffset   row offset
+   * @param rlength   row length
+   * @param family    family name
+   * @param foffset   fammily offset
+   * @param flength   family length
+   * @param qualifier column qualifier
+   * @param qoffset   qualifier offset
+   * @param qlength   qualifier length
+   * @param timestamp version timestamp
+   * @param type      key type
+   * @param value     column value
+   * @param voffset   value offset
+   * @param vlength   value length
+   * @param tags      input tags
+   */
   public KeyValue(final byte[] row, final int roffset, final int rlength, final byte[] family,
     final int foffset, final int flength, final byte[] qualifier, final int qoffset,
     final int qlength, final long timestamp, final Type type, final byte[] value, final int voffset,
@@ -614,6 +652,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @param timestamp version timestamp
    * @param type      key type
    * @param vlength   value length
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final int rlength, final int flength, final int qlength, final long timestamp,
     final Type type, final int vlength) {
@@ -625,12 +664,14 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * fill up KeyValues.
    * <p>
    * Column is split into two fields, family and qualifier.
-   * @param rlength   row length
-   * @param flength   family length
-   * @param qlength   qualifier length
-   * @param timestamp version timestamp
-   * @param type      key type
-   * @param vlength   value length
+   * @param rlength    row length
+   * @param flength    family length
+   * @param qlength    qualifier length
+   * @param timestamp  version timestamp
+   * @param type       key type
+   * @param vlength    value length
+   * @param tagsLength length of the tags
+   * @throws IllegalArgumentException an illegal value was passed
    */
   public KeyValue(final int rlength, final int flength, final int qlength, final long timestamp,
     final Type type, final int vlength, final int tagsLength) {
@@ -661,6 +702,12 @@ public class KeyValue implements ExtendedCell, Cloneable {
   /**
    * Create an empty byte[] representing a KeyValue All lengths are preset and can be filled in
    * later.
+   * @param rlength   row length
+   * @param flength   family length
+   * @param qlength   qualifier length
+   * @param timestamp version timestamp
+   * @param type      key type
+   * @param vlength   value length
    * @return The newly created byte array.
    */
   private static byte[] createEmptyByteArray(final int rlength, int flength, int qlength,
@@ -987,6 +1034,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
   /**
    * Clones a KeyValue. This creates a copy, re-allocating the buffer.
    * @return Fully copied clone of this KeyValue
+   * @throws CloneNotSupportedException if cloning of keyValue is not supported
    */
   @Override
   public KeyValue clone() throws CloneNotSupportedException {
@@ -1027,10 +1075,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
       + getValueLength() + "/seqid=" + seqId;
   }
 
-  /**
-   * @param k Key portion of a KeyValue.
-   * @return Key as a String, empty string if k is null.
-   */
+  /** Return key as a String, empty string if k is null. */
   public static String keyToString(final byte[] k) {
     if (k == null) {
       return "";
@@ -1072,7 +1117,9 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * @return Key as a String.
    */
   public static String keyToString(final byte[] b, final int o, final int l) {
-    if (b == null) return "";
+    if (b == null) {
+      return "";
+    }
     int rowlength = Bytes.toShort(b, o);
     String row = Bytes.toStringBinary(b, o + Bytes.SIZEOF_SHORT, rowlength);
     int columnoffset = o + Bytes.SIZEOF_SHORT + 1 + rowlength;
@@ -1278,10 +1325,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
     return getTimestampOffset(getKeyLength());
   }
 
-  /**
-   * @param keylength Pass if you have it to save on a int creation.
-   * @return Timestamp offset
-   */
+  /** Return the timestamp offset */
   private int getTimestampOffset(final int keylength) {
     return getKeyOffset() + keylength - TIMESTAMP_TYPE_SIZE;
   }
@@ -1293,6 +1337,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
   }
 
   /**
+   * Update the timestamp.
    * @param now Time to set into <code>this</code> IFF timestamp ==
    *            {@link HConstants#LATEST_TIMESTAMP} (else, its a noop).
    * @return True is we modified this.
@@ -1336,16 +1381,13 @@ public class KeyValue implements ExtendedCell, Cloneable {
     return key;
   }
 
-  /**
-   *   */
+  /** Return the timestamp. */
   @Override
   public long getTimestamp() {
     return getTimestamp(getKeyLength());
   }
 
-  /**
-   * @param keylength Pass if you have it to save on a int creation.
-   */
+  /** Return the timestamp. */
   long getTimestamp(final int keylength) {
     int tsOffset = getTimestampOffset(keylength);
     return Bytes.toLong(this.bytes, tsOffset);
@@ -1357,13 +1399,12 @@ public class KeyValue implements ExtendedCell, Cloneable {
     return getTypeByte(getKeyLength());
   }
 
+  /** Return the KeyValue.TYPE byte representation */
   byte getTypeByte(int keyLength) {
     return this.bytes[this.offset + keyLength - 1 + ROW_OFFSET];
   }
 
-  /**
-   * This returns the offset where the tag actually starts.
-   */
+  /** Return the offset where the tag data starts. */
   @Override
   public int getTagsOffset() {
     int tagsLen = getTagsLength();
@@ -1373,9 +1414,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
     return this.offset + this.length - tagsLen;
   }
 
-  /**
-   * This returns the total length of the tag bytes
-   */
+  /** Return the total length of the tag bytes */
   @Override
   public int getTagsLength() {
     int tagsLen = this.length - (getKeyLength() + getValueLength() + KEYVALUE_INFRASTRUCTURE_SIZE);
@@ -1414,7 +1453,12 @@ public class KeyValue implements ExtendedCell, Cloneable {
     return new KeyValue(newBuffer);
   }
 
-  /** Returns Index of delimiter having started from start of <code>b</code> moving rightward. */
+  /**
+   * Find index of passed delimiter walking from start of buffer forwards.
+   * @param b         the kv serialized byte[] to process
+   * @param delimiter input delimeter to fetch index from start
+   * @return Index of delimiter having started from start of <code>b</code> moving rightward.
+   */
   public static int getDelimiter(final byte[] b, int offset, final int length,
     final int delimiter) {
     if (b == null) {
@@ -1432,6 +1476,10 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
   /**
    * Find index of passed delimiter walking from end of buffer backwards.
+   * @param b         the kv serialized byte[] to process
+   * @param offset    the offset in the byte[]
+   * @param length    the length in the byte[]
+   * @param delimiter input delimeter to fetch index from end
    * @return Index of delimiter
    */
   public static int getDelimiterInReverse(final byte[] b, final int offset, final int length,
@@ -1583,6 +1631,8 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
     /**
      * Compares the only the user specified portion of a Key. This is overridden by MetaComparator.
+     * @param left  left cell to compare row key
+     * @param right right cell to compare row key
      * @return 0 if equal, &lt;0 if left smaller, &gt;0 if right smaller
      */
     protected int compareRowKey(final Cell left, final Cell right) {
@@ -1592,6 +1642,12 @@ public class KeyValue implements ExtendedCell, Cloneable {
     /**
      * Compares left to right assuming that left,loffset,llength and right,roffset,rlength are full
      * KVs laid out in a flat byte[]s.
+     * @param left    the left kv serialized byte[] to be compared with
+     * @param loffset the offset in the left byte[]
+     * @param llength the length in the left byte[]
+     * @param right   the right kv serialized byte[] to be compared with
+     * @param roffset the offset in the right byte[]
+     * @param rlength the length in the right byte[]
      * @return 0 if equal, &lt;0 if left smaller, &gt;0 if right smaller
      */
     public int compareFlatKey(byte[] left, int loffset, int llength, byte[] right, int roffset,
@@ -1681,7 +1737,12 @@ public class KeyValue implements ExtendedCell, Cloneable {
       return CellComparatorImpl.COMPARATOR.compareTimestamps(left, right);
     }
 
-    /** Returns Result comparing rows. */
+    /**
+     * Compares the rows of a cell
+     * @param left  left cell to compare rows for
+     * @param right right cell to compare rows for
+     * @return Result comparing rows.
+     */
     public int compareRows(final Cell left, final Cell right) {
       return compareRows(left.getRowArray(), left.getRowOffset(), left.getRowLength(),
         right.getRowArray(), right.getRowOffset(), right.getRowLength());
@@ -1689,6 +1750,12 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
     /**
      * Get the b[],o,l for left and right rowkey portions and compare.
+     * @param left    the left kv serialized byte[] to be compared with
+     * @param loffset the offset in the left byte[]
+     * @param llength the length in the left byte[]
+     * @param right   the right kv serialized byte[] to be compared with
+     * @param roffset the offset in the right byte[]
+     * @param rlength the length in the right byte[]
      * @return 0 if equal, &lt;0 if left smaller, &gt;0 if right smaller
      */
     public int compareRows(byte[] left, int loffset, int llength, byte[] right, int roffset,
@@ -1728,6 +1795,13 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
     /**
      * Overridden
+     * @param commonPrefix location of expected common prefix
+     * @param left         the left kv serialized byte[] to be compared with
+     * @param loffset      the offset in the left byte[]
+     * @param llength      the length in the left byte[]
+     * @param right        the right kv serialized byte[] to be compared with
+     * @param roffset      the offset in the byte[]
+     * @param rlength      the length in the right byte[]
      * @return 0 if equal, &lt;0 if left smaller, &gt;0 if right smaller
      */
     @Override // SamePrefixComparator
@@ -1862,6 +1936,8 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
     /**
      * Compares the row and column of two keyvalues for equality
+     * @param left  left cell to compare row and column
+     * @param right right cell to compare row and column
      * @return True if same row and column.
      */
     public boolean matchingRowColumn(final Cell left, final Cell right) {
@@ -1899,6 +1975,8 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
     /**
      * Compares the row of two keyvalues for equality
+     * @param left  left cell to compare row
+     * @param right right cell to compare row
      * @return True if rows match.
      */
     public boolean matchingRows(final Cell left, final Cell right) {
@@ -1907,7 +1985,14 @@ public class KeyValue implements ExtendedCell, Cloneable {
       return matchingRows(left, lrowlength, right, rrowlength);
     }
 
-    /** Returns True if rows match. */
+    /**
+     * Compares the row of two keyvalues for equality
+     * @param left       left cell to compare row
+     * @param lrowlength left row length
+     * @param right      right cell to compare row
+     * @param rrowlength right row length
+     * @return True if rows match.
+     */
     private boolean matchingRows(final Cell left, final short lrowlength, final Cell right,
       final short rrowlength) {
       return lrowlength == rrowlength && matchingRows(left.getRowArray(), left.getRowOffset(),
@@ -1947,6 +2032,8 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
     /**
      * This is a HFile block index key optimization.
+     * @param leftKey  byte array for left Key
+     * @param rightKey byte array for right Key
      * @return 0 if equal, &lt;0 if left smaller, &gt;0 if right smaller
      * @deprecated Since 0.99.2;
      */
@@ -2028,10 +2115,12 @@ public class KeyValue implements ExtendedCell, Cloneable {
   }
 
   /**
+   * Create a KeyValue reading from <code>in</code>
    * @param in Where to read bytes from. Creates a byte array to hold the KeyValue backing bytes
    *           copied from the steam.
    * @return KeyValue created by deserializing from <code>in</code> OR if we find a length of zero,
    *         we will return null which can be useful marking a stream as done.
+   * @throws IOException if any IO error happen
    */
   public static KeyValue create(final DataInput in) throws IOException {
     return create(in.readInt(), in);
@@ -2039,13 +2128,18 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
   /**
    * Create a KeyValue reading <code>length</code> from <code>in</code>
+   * @param length length of the Key
+   * @param in     Input to read from
    * @return Created KeyValue OR if we find a length of zero, we will return null which can be
    *         useful marking a stream as done.
+   * @throws IOException if any IO error happen
    */
   public static KeyValue create(int length, final DataInput in) throws IOException {
 
     if (length <= 0) {
-      if (length == 0) return null;
+      if (length == 0) {
+        return null;
+      }
       throw new IOException("Failed read " + length + " bytes, stream corrupt?");
     }
 
@@ -2057,7 +2151,10 @@ public class KeyValue implements ExtendedCell, Cloneable {
 
   /**
    * Write out a KeyValue in the manner in which we used to when KeyValue was a Writable.
+   * @param kv  the KeyValue on which write is being requested
+   * @param out OutputStream to write keyValue to
    * @return Length written on stream
+   * @throws IOException if any IO error happen
    * @see #create(DataInput) for the inverse function
    */
   public static long write(final KeyValue kv, final DataOutput out) throws IOException {
@@ -2073,7 +2170,11 @@ public class KeyValue implements ExtendedCell, Cloneable {
    * Write out a KeyValue in the manner in which we used to when KeyValue was a Writable but do not
    * require a {@link DataOutput}, just take plain {@link OutputStream} Named <code>oswrite</code>
    * so does not clash with {@link #write(KeyValue, DataOutput)}
+   * @param kv       the KeyValue on which write is being requested
+   * @param out      OutputStream to write keyValue to
+   * @param withTags boolean value indicating write is with Tags or not
    * @return Length written on stream
+   * @throws IOException if any IO error happen
    * @see #create(DataInput) for the inverse function
    * @see #write(KeyValue, DataOutput)
    * @see KeyValueUtil#oswrite(Cell, OutputStream, boolean)
@@ -2141,7 +2242,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
       return fixed + ClassSize.sizeOfByteArray(length);
     } else {
       // only count the number of bytes
-      return fixed + length;
+      return (long) fixed + length;
     }
   }
 
@@ -2191,6 +2292,9 @@ public class KeyValue implements ExtendedCell, Cloneable {
     /**
      * A setter that helps to avoid object creation every time and whenever there is a need to
      * create new KeyOnlyKeyValue.
+     * @param key    Key to set
+     * @param offset Offset of the Key
+     * @param length length of the Key
      */
     public void setKey(byte[] key, int offset, int length) {
       this.bytes = key;
@@ -2227,6 +2331,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
       return this.bytes[getFamilyOffset() - 1];
     }
 
+    @Override
     int getFamilyLengthPosition(int rowLength) {
       return this.offset + Bytes.SIZEOF_SHORT + rowLength;
     }
@@ -2266,6 +2371,7 @@ public class KeyValue implements ExtendedCell, Cloneable {
       return getTypeByte(getKeyLength());
     }
 
+    @Override
     byte getTypeByte(int keyLength) {
       return this.bytes[this.offset + keyLength - 1];
     }
