@@ -22,9 +22,12 @@ import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
 import java.util.Set;
 import java.util.concurrent.CopyOnWriteArraySet;
+import org.apache.commons.lang3.ArrayUtils;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.yetus.audience.InterfaceAudience;
 
+import org.apache.hbase.thirdparty.com.google.common.base.Preconditions;
+
 /**
  * Immutable POJO class for representing a table name. Which is of the form: &lt;table
  * namespace&gt;:&lt;table qualifier&gt; Two special namespaces: 1. hbase - system namespace, used
@@ -157,15 +160,13 @@ public final class TableName implements Comparable<TableName> {
       throw new IllegalArgumentException(
         isSnapshot ? "Snapshot" : "Table" + " qualifier must not be empty");
     }
+    String qualifierString = Bytes.toString(qualifierName, start, end - start);
     if (qualifierName[start] == '.' || qualifierName[start] == '-') {
       throw new IllegalArgumentException("Illegal first character <" + qualifierName[start]
         + "> at 0. " + (isSnapshot ? "Snapshot" : "User-space table")
         + " qualifiers can only start with 'alphanumeric " + "characters' from any language: "
-        + Bytes.toString(qualifierName, start, end));
+        + qualifierString);
     }
-    // Treat the bytes as UTF-8
-    String qualifierString =
-      new String(qualifierName, start, (end - start), StandardCharsets.UTF_8);
     if (qualifierString.equals(DISALLOWED_TABLE_NAME)) {
       // Per https://zookeeper.apache.org/doc/r3.4.10/zookeeperProgrammers.html#ch_zkDataModel
       // A znode named "zookeeper" is disallowed by zookeeper.
@@ -268,9 +269,6 @@ public final class TableName implements Comparable<TableName> {
     return nameAsString;
   }
 
-  /**
-   * @throws IllegalArgumentException See {@link #valueOf(byte[])}
-   */
   private TableName(ByteBuffer namespace, ByteBuffer qualifier) throws IllegalArgumentException {
     this.qualifier = new byte[qualifier.remaining()];
     qualifier.duplicate().get(this.qualifier);
@@ -314,9 +312,7 @@ public final class TableName implements Comparable<TableName> {
     isLegalTableQualifierName(this.qualifier);
   }
 
-  /**
-   * This is only for the old and meta tables.
-   */
+  /** This is only for the old and meta tables. */
   private TableName(String qualifier) {
     this.qualifier = Bytes.toBytes(qualifier);
     this.qualifierAsString = qualifier;
@@ -388,32 +384,77 @@ public final class TableName implements Comparable<TableName> {
   }
 
   /**
+   * Construct a TableName
+   * @param fullName will use the entire byte array
    * @throws IllegalArgumentException if fullName equals old root or old meta. Some code depends on
    *                                  this. The test is buried in the table creation to save on
    *                                  array comparison when we're creating a standard table object
    *                                  that will be in the cache.
    */
   public static TableName valueOf(byte[] fullName) throws IllegalArgumentException {
+    return valueOf(fullName, 0, fullName.length);
+  }
+
+  /**
+   * Construct a TableName
+   * @param fullName byte array to look into
+   * @param offset   within said array
+   * @param length   within said array
+   * @throws IllegalArgumentException if fullName equals old root or old meta.
+   */
+  public static TableName valueOf(byte[] fullName, int offset, int length)
+    throws IllegalArgumentException {
+    Preconditions.checkArgument(offset >= 0, "offset must be non-negative but was %s", offset);
+    Preconditions.checkArgument(offset < fullName.length, "offset (%s) must be < array length (%s)",
+      offset, fullName.length);
+    Preconditions.checkArgument(length <= fullName.length,
+      "length (%s) must be <= array length (%s)", length, fullName.length);
     for (TableName tn : tableCache) {
-      if (Arrays.equals(tn.getName(), fullName)) {
+      final byte[] tnName = tn.getName();
+      if (Bytes.equals(tnName, 0, tnName.length, fullName, offset, length)) {
         return tn;
       }
     }
 
-    int namespaceDelimIndex = org.apache.hbase.thirdparty.com.google.common.primitives.Bytes
-      .lastIndexOf(fullName, (byte) NAMESPACE_DELIM);
+    int namespaceDelimIndex = ArrayUtils.lastIndexOf(fullName, (byte) NAMESPACE_DELIM);
 
-    if (namespaceDelimIndex < 0) {
+    if (namespaceDelimIndex < offset) {
       return createTableNameIfNecessary(ByteBuffer.wrap(NamespaceDescriptor.DEFAULT_NAMESPACE_NAME),
-        ByteBuffer.wrap(fullName));
+        ByteBuffer.wrap(fullName, offset, length));
     } else {
-      return createTableNameIfNecessary(ByteBuffer.wrap(fullName, 0, namespaceDelimIndex),
-        ByteBuffer.wrap(fullName, namespaceDelimIndex + 1,
-          fullName.length - (namespaceDelimIndex + 1)));
+      return createTableNameIfNecessary(ByteBuffer.wrap(fullName, offset, namespaceDelimIndex),
+        ByteBuffer.wrap(fullName, namespaceDelimIndex + 1, length - (namespaceDelimIndex + 1)));
     }
   }
 
   /**
+   * Construct a TableName
+   * @param fullname of a table, possibly with a leading namespace and ':' as delimiter.
+   * @throws IllegalArgumentException if fullName equals old root or old meta.
+   */
+  public static TableName valueOf(ByteBuffer fullname) {
+    fullname = fullname.duplicate();
+    fullname.mark();
+    boolean miss = true;
+    while (fullname.hasRemaining() && miss) {
+      miss = ((byte) NAMESPACE_DELIM) != fullname.get();
+    }
+    if (miss) {
+      fullname.reset();
+      return valueOf(null, fullname);
+    } else {
+      ByteBuffer qualifier = fullname.slice();
+      int delimiterIndex = fullname.position() - 1;
+      fullname.reset();
+      // changing variable name for clarity
+      ByteBuffer namespace = fullname.duplicate();
+      namespace.limit(delimiterIndex);
+      return valueOf(namespace, qualifier);
+    }
+  }
+
+  /**
+   * Construct a TableName
    * @throws IllegalArgumentException if fullName equals old root or old meta. Some code depends on
    *                                  this.
    */
@@ -478,12 +519,12 @@ public final class TableName implements Comparable<TableName> {
     return hashCode;
   }
 
-  /**
-   * For performance reasons, the ordering is not lexicographic.
-   */
   @Override
   public int compareTo(TableName tableName) {
-    if (this == tableName) return 0;
+    // For performance reasons, the ordering is not lexicographic.
+    if (this == tableName) {
+      return 0;
+    }
     if (this.hashCode < tableName.hashCode()) {
       return -1;
     }
