@@ -50,10 +50,12 @@ public abstract class ByteArrayComparable implements Comparable<byte[]> {
   public abstract byte[] toByteArray();
 
   /**
+   * Parse a serialized representation of {@link ByteArrayComparable}
    * @param pbBytes A pb serialized {@link ByteArrayComparable} instance
    * @return An instance of {@link ByteArrayComparable} made from <code>bytes</code>
    * @see #toByteArray
    */
+  @SuppressWarnings("DoNotCallSuggester")
   public static ByteArrayComparable parseFrom(final byte[] pbBytes)
     throws DeserializationException {
     throw new DeserializationException(
@@ -61,12 +63,13 @@ public abstract class ByteArrayComparable implements Comparable<byte[]> {
   }
 
   /**
-   * @return true if and only if the fields of the comparator that are serialized are equal to the
-   *         corresponding fields in other. Used for testing.
+   * Return true if and only if the fields of the comparator that are serialized are equal to the
+   * corresponding fields in other.
    */
   boolean areSerializedFieldsEqual(ByteArrayComparable other) {
-    if (other == this) return true;
-
+    if (other == this) {
+      return true;
+    }
     return Bytes.equals(this.getValue(), other.getValue());
   }
 
