@@ -102,20 +102,6 @@ public class ByteBuffAllocator {
   @Deprecated
   static final String DEPRECATED_BUFFER_SIZE_KEY = "hbase.ipc.server.reservoir.initial.buffer.size";
 
-  /**
-   * The hbase.ipc.server.reservoir.initial.max and hbase.ipc.server.reservoir.initial.buffer.size
-   * were introduced in HBase2.0.0, while in HBase3.0.0 the two config keys will be replaced by
-   * {@link ByteBuffAllocator#MAX_BUFFER_COUNT_KEY} and {@link ByteBuffAllocator#BUFFER_SIZE_KEY}.
-   * Also the hbase.ipc.server.reservoir.enabled will be replaced by
-   * hbase.server.allocator.pool.enabled. Keep the three old config keys here for HBase2.x
-   * compatibility.
-   */
-  static {
-    Configuration.addDeprecation(DEPRECATED_ALLOCATOR_POOL_ENABLED_KEY, ALLOCATOR_POOL_ENABLED_KEY);
-    Configuration.addDeprecation(DEPRECATED_MAX_BUFFER_COUNT_KEY, MAX_BUFFER_COUNT_KEY);
-    Configuration.addDeprecation(DEPRECATED_BUFFER_SIZE_KEY, BUFFER_SIZE_KEY);
-  }
-
   /**
    * There're some reasons why better to choose 65KB(rather than 64KB) as the default buffer size:
    * <p>
@@ -174,16 +160,6 @@ public class ByteBuffAllocator {
    * @return ByteBuffAllocator to manage the byte buffers.
    */
   public static ByteBuffAllocator create(Configuration conf, boolean reservoirEnabled) {
-    if (
-      conf.get(DEPRECATED_BUFFER_SIZE_KEY) != null
-        || conf.get(DEPRECATED_MAX_BUFFER_COUNT_KEY) != null
-    ) {
-      LOG.warn(
-        "The config keys {} and {} are deprecated now, instead please use {} and {}. In "
-          + "future release we will remove the two deprecated configs.",
-        DEPRECATED_BUFFER_SIZE_KEY, DEPRECATED_MAX_BUFFER_COUNT_KEY, BUFFER_SIZE_KEY,
-        MAX_BUFFER_COUNT_KEY);
-    }
     int poolBufSize = conf.getInt(BUFFER_SIZE_KEY, DEFAULT_BUFFER_SIZE);
     if (reservoirEnabled) {
       // The max number of buffers to be pooled in the ByteBufferPool. The default value been
