@@ -471,38 +471,75 @@ public final class ByteBufferUtils {
     }
   }
 
-  private interface ByteVisitor {
-    byte get();
-  }
-
-  private static long readVLong(ByteVisitor visitor) {
-    byte firstByte = visitor.get();
+  /**
+   * Similar to {@link WritableUtils#readVLong(java.io.DataInput)} but reads from a
+   * {@link ByteBuff}.
+   */
+  public static long readVLong(ByteBuff buf) {
+    byte firstByte = buf.get();
     int len = WritableUtils.decodeVIntSize(firstByte);
     if (len == 1) {
       return firstByte;
+    } else {
+      int remaining = len - 1;
+      long i = 0;
+      int offsetFromPos = 0;
+      if (remaining >= Bytes.SIZEOF_INT) {
+        // The int read has to be converted to unsigned long so the & op
+        i = (buf.getIntAfterPosition(offsetFromPos) & 0x00000000ffffffffL);
+        remaining -= Bytes.SIZEOF_INT;
+        offsetFromPos += Bytes.SIZEOF_INT;
+      }
+      if (remaining >= Bytes.SIZEOF_SHORT) {
+        short s = buf.getShortAfterPosition(offsetFromPos);
+        i = i << 16;
+        i = i | (s & 0xFFFF);
+        remaining -= Bytes.SIZEOF_SHORT;
+        offsetFromPos += Bytes.SIZEOF_SHORT;
+      }
+      for (int idx = 0; idx < remaining; idx++) {
+        byte b = buf.getByteAfterPosition(offsetFromPos + idx);
+        i = i << 8;
+        i = i | (b & 0xFF);
+      }
+      buf.skip(len - 1);
+      return WritableUtils.isNegativeVInt(firstByte) ? ~i : i;
     }
-    long i = 0;
-    for (int idx = 0; idx < len - 1; idx++) {
-      byte b = visitor.get();
-      i = i << 8;
-      i = i | (b & 0xFF);
-    }
-    return (WritableUtils.isNegativeVInt(firstByte) ? (i ^ -1L) : i);
   }
 
   /**
    * Similar to {@link WritableUtils#readVLong(DataInput)} but reads from a {@link ByteBuffer}.
    */
-  public static long readVLong(ByteBuffer in) {
-    return readVLong(in::get);
-  }
-
-  /**
-   * Similar to {@link WritableUtils#readVLong(java.io.DataInput)} but reads from a
-   * {@link ByteBuff}.
-   */
-  public static long readVLong(ByteBuff in) {
-    return readVLong(in::get);
+  public static long readVLong(ByteBuffer buf) {
+    byte firstByte = buf.get();
+    int len = WritableUtils.decodeVIntSize(firstByte);
+    if (len == 1) {
+      return firstByte;
+    } else {
+      int remaining = len - 1;
+      long i = 0;
+      int offsetFromPos = 0;
+      if (remaining >= Bytes.SIZEOF_INT) {
+        // The int read has to be converted to unsigned long so the & op
+        i = (buf.getInt(buf.position() + offsetFromPos) & 0x00000000ffffffffL);
+        remaining -= Bytes.SIZEOF_INT;
+        offsetFromPos += Bytes.SIZEOF_INT;
+      }
+      if (remaining >= Bytes.SIZEOF_SHORT) {
+        short s = buf.getShort(buf.position() + offsetFromPos);
+        i = i << 16;
+        i = i | (s & 0xFFFF);
+        remaining -= Bytes.SIZEOF_SHORT;
+        offsetFromPos += Bytes.SIZEOF_SHORT;
+      }
+      for (int idx = 0; idx < remaining; idx++) {
+        byte b = buf.get(buf.position() + offsetFromPos + idx);
+        i = i << 8;
+        i = i | (b & 0xFF);
+      }
+      buf.position(buf.position() + len - 1);
+      return WritableUtils.isNegativeVInt(firstByte) ? ~i : i;
+    }
   }
 
   /**
@@ -687,6 +724,7 @@ public final class ByteBufferUtils {
   /**
    * Read integer from stream coded in 7 bits and increment position.
    * @return the integer that has been read
+   * @throws IOException on stream error
    */
   public static int readCompressedInt(InputStream input) throws IOException {
     int result = 0;
@@ -720,6 +758,7 @@ public final class ByteBufferUtils {
    * Read long which was written to fitInBytes bytes and increment position.
    * @param fitInBytes In how many bytes given long is stored.
    * @return The value of parsed long.
+   * @throws IOException on stream error
    */
   public static long readLong(InputStream in, final int fitInBytes) throws IOException {
     long tmpLong = 0;
@@ -798,6 +837,11 @@ public final class ByteBufferUtils {
   /**
    * Copy from one buffer to another from given offset. This will be absolute positional copying and
    * won't affect the position of any of the buffers.
+   * @param in                input bytebuffer
+   * @param out               destination bytebuffer
+   * @param sourceOffset      offset of source buffer
+   * @param destinationOffset offset of destination buffer
+   * @param length            the number of bytes to copy
    */
   public static void copyFromBufferToBuffer(ByteBuffer in, ByteBuffer out, int sourceOffset,
     int destinationOffset, int length) {
@@ -967,6 +1011,9 @@ public final class ByteBufferUtils {
 
   /**
    * Copy the given number of bytes from specified offset into a new byte[]
+   * @param buffer input bytebuffer to read
+   * @param offset input offset where Bytes are
+   * @param length the number of bytes to read
    * @return a new byte[] containing the bytes in the specified range
    */
   public static byte[] toBytes(ByteBuffer buffer, int offset, int length) {
@@ -985,7 +1032,9 @@ public final class ByteBufferUtils {
     // Since we're often comparing adjacent sorted data,
     // it's usual to have equal arrays except for the very last byte
     // so check that first
-    if (toByte(buf1, o1 + l1 - 1) != toByte(buf2, o2 + l2 - 1)) return false;
+    if (toByte(buf1, o1 + l1 - 1) != toByte(buf2, o2 + l2 - 1)) {
+      return false;
+    }
     return compareTo(buf1, o1, l1, buf2, o2, l2) == 0;
   }
 
@@ -1012,7 +1061,9 @@ public final class ByteBufferUtils {
     // Since we're often comparing adjacent sorted data,
     // it's usual to have equal arrays except for the very last byte
     // so check that first
-    if (toByte(buf1, o1 + l1 - 1) != buf2[o2 + l2 - 1]) return false;
+    if (toByte(buf1, o1 + l1 - 1) != buf2[o2 + l2 - 1]) {
+      return false;
+    }
     return compareTo(buf1, o1, l1, buf2, o2, l2) == 0;
   }
 
@@ -1110,6 +1161,8 @@ public final class ByteBufferUtils {
 
   /**
    * Reads a short value at the given buffer's offset.
+   * @param buffer input byte buffer to read
+   * @param offset input offset where short is
    * @return short value at offset
    */
   public static short toShort(ByteBuffer buffer, int offset) {
@@ -1125,6 +1178,8 @@ public final class ByteBufferUtils {
 
   /**
    * Reads an int value at the given buffer's offset.
+   * @param buffer input byte buffer to read
+   * @param offset input offset where int is
    * @return int value at offset
    */
   public static int toInt(ByteBuffer buffer, int offset) {
@@ -1153,6 +1208,8 @@ public final class ByteBufferUtils {
 
   /**
    * Reads a long value at the given buffer's offset.
+   * @param buffer input byte buffer to read
+   * @param offset input offset where Long is
    * @return long value at offset
    */
   public static long toLong(ByteBuffer buffer, int offset) {
@@ -1175,6 +1232,7 @@ public final class ByteBufferUtils {
 
   /**
    * Reads a double value at the given buffer's offset.
+   * @param buffer input byte buffer to read
    * @param offset offset where double is
    * @return double value at offset
    */
@@ -1184,6 +1242,8 @@ public final class ByteBufferUtils {
 
   /**
    * Reads a BigDecimal value at the given buffer's offset.
+   * @param buffer input bytebuffer to read
+   * @param offset input offset
    * @return BigDecimal value at offset
    */
   public static BigDecimal toBigDecimal(ByteBuffer buffer, int offset, int length) {
@@ -1235,6 +1295,10 @@ public final class ByteBufferUtils {
   /**
    * Copies the bytes from given array's offset to length part into the given buffer. Puts the bytes
    * to buffer's current position. This also advances the position in the 'out' buffer by 'length'
+   * @param out      output bytebuffer to copy to
+   * @param in       input array to copy from
+   * @param inOffset input offset to copy from
+   * @param length   the number of bytes to copy
    */
   public static void copyFromArrayToBuffer(ByteBuffer out, byte[] in, int inOffset, int length) {
     if (out.hasArray()) {
@@ -1252,7 +1316,12 @@ public final class ByteBufferUtils {
 
   /**
    * Copies bytes from given array's offset to length part into the given buffer. Puts the bytes to
-   * buffer's given position. This doesn't affact the position of buffer.
+   * buffer's given position. This doesn't affect the position of buffer.
+   * @param out       output bytebuffer to copy to
+   * @param outOffset output buffer offset
+   * @param in        input array to copy from
+   * @param inOffset  input offset to copy from
+   * @param length    the number of bytes to copy
    */
   public static void copyFromArrayToBuffer(ByteBuffer out, int outOffset, byte[] in, int inOffset,
     int length) {
@@ -1269,7 +1338,12 @@ public final class ByteBufferUtils {
 
   /**
    * Copies specified number of bytes from given offset of 'in' ByteBuffer to the array. This
-   * doesn't affact the position of buffer.
+   * doesn't affect the position of buffer.
+   * @param out               output array to copy input bytebuffer to
+   * @param in                input bytebuffer to copy from
+   * @param sourceOffset      offset of source bytebuffer
+   * @param destinationOffset offset of destination array
+   * @param length            the number of bytes to copy
    */
   public static void copyFromBufferToArray(byte[] out, ByteBuffer in, int sourceOffset,
     int destinationOffset, int length) {
@@ -1293,7 +1367,9 @@ public final class ByteBufferUtils {
    */
   public static byte[] copyOfRange(ByteBuffer original, int from, int to) {
     int newLength = to - from;
-    if (newLength < 0) throw new IllegalArgumentException(from + " > " + to);
+    if (newLength < 0) {
+      throw new IllegalArgumentException(from + " > " + to);
+    }
     byte[] copy = new byte[newLength];
     ByteBufferUtils.copyFromBufferToArray(copy, original, from, 0, newLength);
     return copy;
@@ -1303,8 +1379,12 @@ public final class ByteBufferUtils {
   public static String toStringBinary(final ByteBuffer b, int off, int len) {
     StringBuilder result = new StringBuilder();
     // Just in case we are passed a 'len' that is > buffer length...
-    if (off >= b.capacity()) return result.toString();
-    if (off + len > b.capacity()) len = b.capacity() - off;
+    if (off >= b.capacity()) {
+      return result.toString();
+    }
+    if (off + len > b.capacity()) {
+      len = b.capacity() - off;
+    }
     for (int i = off; i < off + len; ++i) {
       int ch = b.get(i) & 0xFF;
       if (
