@@ -33,14 +33,19 @@ import org.apache.hbase.thirdparty.com.google.common.base.Splitter;
  * Utility methods for reading, and building the ZooKeeper configuration. The order and priority for
  * reading the config are as follows:
  * <ol>
- * <li>Property with "hbase.zookeeper.property." prefix from HBase XML.</li>
+ * <li>Property with "hbase.zookeeper.property." prefix from HBase XML is added with "zookeeper."
+ * prefix</li>
  * <li>other zookeeper related properties in HBASE XML</li>
  * </ol>
  */
+/**
+ *
+ */
 @InterfaceAudience.Private
 public final class ZKConfig {
 
   private static final String VARIABLE_START = "${";
+  private static final String ZOOKEEPER_JAVA_PROPERTY_PREFIX = "zookeeper.";
 
   private ZKConfig() {
   }
@@ -55,11 +60,26 @@ public final class ZKConfig {
     return makeZKPropsFromHbaseConfig(conf);
   }
 
+  private static Properties extractZKClientPropsFromHBaseConfig(final Configuration conf) {
+    return extractZKPropsFromHBaseConfig(conf, ZOOKEEPER_JAVA_PROPERTY_PREFIX);
+  }
+
+  // This is only used for the in-process ZK Quorums used mainly for testing, not for
+  // deployments with an external Zookeeper.
+  private static Properties extractZKServerPropsFromHBaseConfig(final Configuration conf) {
+    return extractZKPropsFromHBaseConfig(conf, "");
+  }
+
   /**
-   * Directly map all the hbase.zookeeper.property.KEY properties. Synchronize on conf so no loading
-   * of configs while we iterate
+   * Map all hbase.zookeeper.property.KEY properties to targetPrefix.KEY. Synchronize on conf so no
+   * loading of configs while we iterate This is rather messy, as we use the same prefix for both
+   * ZKClientConfig and for the HQuorum properties. ZKClientConfig props all have the zookeeper.
+   * prefix, while the HQuorum server props don't, and ZK automagically sets a system property
+   * adding a zookeeper. prefix to the non HQuorum properties, so we need to add the "zookeeper."
+   * prefix for ZKClientConfig but not for the HQuorum props.
    */
-  private static Properties extractZKPropsFromHBaseConfig(final Configuration conf) {
+  private static Properties extractZKPropsFromHBaseConfig(final Configuration conf,
+    final String targetPrefix) {
     Properties zkProperties = new Properties();
 
     synchronized (conf) {
@@ -72,7 +92,7 @@ public final class ZKConfig {
           if (value.contains(VARIABLE_START)) {
             value = conf.get(key);
           }
-          zkProperties.setProperty(zkKey, value);
+          zkProperties.setProperty(targetPrefix + zkKey, value);
         }
       }
     }
@@ -87,7 +107,7 @@ public final class ZKConfig {
    * @return Properties holding mappings representing ZooKeeper config file.
    */
   private static Properties makeZKPropsFromHbaseConfig(Configuration conf) {
-    Properties zkProperties = extractZKPropsFromHBaseConfig(conf);
+    Properties zkProperties = extractZKServerPropsFromHBaseConfig(conf);
 
     // If clientPort is not set, assign the default.
     if (zkProperties.getProperty(HConstants.CLIENT_PORT_STR) == null) {
@@ -302,7 +322,7 @@ public final class ZKConfig {
   }
 
   public static ZKClientConfig getZKClientConfig(Configuration conf) {
-    Properties zkProperties = extractZKPropsFromHBaseConfig(conf);
+    Properties zkProperties = extractZKClientPropsFromHBaseConfig(conf);
     ZKClientConfig zkClientConfig = new ZKClientConfig();
     zkProperties.forEach((k, v) -> zkClientConfig.setProperty(k.toString(), v.toString()));
     return zkClientConfig;
