@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -31,22 +31,20 @@ import org.junit.ClassRule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 
-@Category({MiscTests.class, SmallTests.class})
+@Category({ MiscTests.class, SmallTests.class })
 public class TestRawString {
 
   @ClassRule
   public static final HBaseClassTestRule CLASS_RULE =
-      HBaseClassTestRule.forClass(TestRawString.class);
+    HBaseClassTestRule.forClass(TestRawString.class);
 
-  static final String[] VALUES = new String[] {
-    "", "1", "22", "333", "4444", "55555", "666666", "7777777", "88888888", "999999999",
-  };
+  static final String[] VALUES = new String[] { "", "1", "22", "333", "4444", "55555", "666666",
+    "7777777", "88888888", "999999999", };
 
   @Test
   public void testReadWrite() {
     for (Order ord : new Order[] { Order.ASCENDING, Order.DESCENDING }) {
-      RawString type =
-          Order.ASCENDING == ord ? RawString.ASCENDING : RawString.DESCENDING;
+      RawString type = Order.ASCENDING == ord ? RawString.ASCENDING : RawString.DESCENDING;
       for (String val : VALUES) {
         PositionedByteRange buff = new SimplePositionedMutableByteRange(Bytes.toBytes(val).length);
         assertEquals(buff.getLength(), type.encode(buff, val));
