@@ -130,15 +130,15 @@ public class DemoClient {
     System.out.println("scanning tables...");
 
     for (ByteBuffer name : client.getTableNames()) {
-      System.out.println("  found: " + ClientUtils.utf8(name.array()));
+      System.out.println("  found: " + ClientUtils.utf8(name));
 
       if (name.equals(demoTable) || name.equals(disabledTable)) {
         if (client.isTableEnabled(name)) {
-          System.out.println("    disabling table: " + ClientUtils.utf8(name.array()));
+          System.out.println("    disabling table: " + ClientUtils.utf8(name));
           client.disableTable(name);
         }
 
-        System.out.println("    deleting table: " + ClientUtils.utf8(name.array()));
+        System.out.println("    deleting table: " + ClientUtils.utf8(name));
         client.deleteTable(name);
       }
     }
@@ -326,7 +326,7 @@ public class DemoClient {
     columnNames.clear();
 
     for (ColumnDescriptor col2 : client.getColumnDescriptors(demoTable).values()) {
-      System.out.println("column with name: " + new String(col2.name.array()));
+      System.out.println("column with name: " + ClientUtils.utf8(col2.name));
       System.out.println(col2.toString());
 
       columnNames.add(col2.name);
@@ -358,7 +358,7 @@ public class DemoClient {
       rowStr.append("; ");
     }
 
-    System.out.println("row: " + ClientUtils.utf8(row.array()) + ", values: " + rowStr);
+    System.out.println("row: " + ClientUtils.utf8(row) + ", values: " + rowStr);
   }
 
   private void printRow(TRowResult rowResult) {
