@@ -17,6 +17,8 @@
  */
 package org.apache.hadoop.hbase.io.hfile;
 
+import io.opentelemetry.api.trace.Span;
+import io.opentelemetry.context.Scope;
 import java.io.IOException;
 import java.net.InetSocketAddress;
 import java.nio.ByteBuffer;
@@ -25,29 +27,37 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.NoSuchElementException;
 import java.util.concurrent.ExecutionException;
+import java.util.concurrent.Executors;
+import java.util.concurrent.ScheduledExecutorService;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicLong;
 import net.spy.memcached.CachedData;
+import net.spy.memcached.ConnectionFactory;
 import net.spy.memcached.ConnectionFactoryBuilder;
 import net.spy.memcached.FailureMode;
 import net.spy.memcached.MemcachedClient;
+import net.spy.memcached.OperationTimeoutException;
 import net.spy.memcached.transcoders.Transcoder;
 import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.io.ByteBuffAllocator;
 import org.apache.hadoop.hbase.nio.ByteBuff;
 import org.apache.hadoop.hbase.nio.SingleByteBuff;
 import org.apache.hadoop.hbase.trace.TraceUtil;
 import org.apache.hadoop.hbase.util.Addressing;
-import org.apache.htrace.core.TraceScope;
+import org.apache.hadoop.util.StringUtils;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.hbase.thirdparty.com.google.common.util.concurrent.ThreadFactoryBuilder;
+
 /**
  * Class to store blocks into memcached. This should only be used on a cluster of Memcached daemons
  * that are tuned well and have a good network connection to the HBase regionservers. Any other use
  * will likely slow down HBase greatly.
  */
 @InterfaceAudience.Private
+@SuppressWarnings("FutureReturnValueIgnored")
 public class MemcachedBlockCache implements BlockCache {
   private static final Logger LOG = LoggerFactory.getLogger(MemcachedBlockCache.class.getName());
 
@@ -55,6 +65,10 @@ public class MemcachedBlockCache implements BlockCache {
   // that just in case this client is used with those versions.
   public static final int MAX_SIZE = 1020 * 1024;
 
+  // Start memcached with -I <MAX_SIZE> to ensure it has the ability to store blocks of this size
+  public static final int MAX_TIME = 60 * 60 * 24 * 30; // 30 days, max allowed per the memcached
+                                                        // spec
+
   // Config key for what memcached servers to use.
   // They should be specified in a comma sperated list with ports.
   // like:
@@ -66,10 +80,20 @@ public class MemcachedBlockCache implements BlockCache {
   public static final String MEMCACHED_OPTIMIZE_KEY = "hbase.cache.memcached.spy.optimze";
   public static final long MEMCACHED_DEFAULT_TIMEOUT = 500;
   public static final boolean MEMCACHED_OPTIMIZE_DEFAULT = false;
+  public static final int STAT_THREAD_PERIOD = 60 * 5;
 
   private final MemcachedClient client;
   private final HFileBlockTranscoder tc = new HFileBlockTranscoder();
   private final CacheStats cacheStats = new CacheStats("MemcachedBlockCache");
+  private final AtomicLong cachedCount = new AtomicLong();
+  private final AtomicLong notCachedCount = new AtomicLong();
+  private final AtomicLong cacheErrorCount = new AtomicLong();
+  private final AtomicLong timeoutCount = new AtomicLong();
+
+  /** Statistics thread schedule pool (for heavy debugging, could remove) */
+  private transient final ScheduledExecutorService scheduleThreadPool =
+    Executors.newScheduledThreadPool(1, new ThreadFactoryBuilder()
+      .setNameFormat("MemcachedBlockCacheStatsExecutor").setDaemon(true).build());
 
   public MemcachedBlockCache(Configuration c) throws IOException {
     LOG.info("Creating MemcachedBlockCache");
@@ -79,31 +103,15 @@ public class MemcachedBlockCache implements BlockCache {
     boolean optimize = c.getBoolean(MEMCACHED_OPTIMIZE_KEY, MEMCACHED_OPTIMIZE_DEFAULT);
 
     ConnectionFactoryBuilder builder =
-      new ConnectionFactoryBuilder().setOpTimeout(opTimeout).setOpQueueMaxBlockTime(queueTimeout) // Cap
-                                                                                                  // the
-                                                                                                  // max
-                                                                                                  // time
-                                                                                                  // before
-                                                                                                  // anything
-                                                                                                  // times
-                                                                                                  // out
-        .setFailureMode(FailureMode.Redistribute).setShouldOptimize(optimize).setDaemon(true) // Don't
-                                                                                              // keep
-                                                                                              // threads
-                                                                                              // around
-                                                                                              // past
-                                                                                              // the
-                                                                                              // end
-                                                                                              // of
-                                                                                              // days.
-        .setUseNagleAlgorithm(false) // Ain't nobody got time for that
-        .setReadBufferSize(HConstants.DEFAULT_BLOCKSIZE * 4 * 1024); // Much larger just in case
+      new ConnectionFactoryBuilder().setOpTimeout(opTimeout).setOpQueueMaxBlockTime(queueTimeout)
+        .setFailureMode(FailureMode.Redistribute).setShouldOptimize(optimize).setDaemon(true)
+        .setUseNagleAlgorithm(false).setReadBufferSize(MAX_SIZE);
 
-    // Assume only the localhost is serving memecached.
+    // Assume only the localhost is serving memcached.
     // A la mcrouter or co-locating memcached with split regionservers.
     //
-    // If this config is a pool of memecached servers they will all be used according to the
-    // default hashing scheme defined by the memcache client. Spy Memecache client in this
+    // If this config is a pool of memcached servers they will all be used according to the
+    // default hashing scheme defined by the memcached client. Spy Memecache client in this
     // case.
     String serverListString = c.get(MEMCACHED_CONFIG_KEY, "localhost:11211");
     String[] servers = serverListString.split(",");
@@ -115,7 +123,14 @@ public class MemcachedBlockCache implements BlockCache {
       serverAddresses.add(Addressing.createInetSocketAddressFromHostAndPortStr(s));
     }
 
-    client = new MemcachedClient(builder.build(), serverAddresses);
+    client = createMemcachedClient(builder.build(), serverAddresses);
+    this.scheduleThreadPool.scheduleAtFixedRate(new StatisticsThread(this), STAT_THREAD_PERIOD,
+      STAT_THREAD_PERIOD, TimeUnit.SECONDS);
+  }
+
+  protected MemcachedClient createMemcachedClient(ConnectionFactory factory,
+    List<InetSocketAddress> serverAddresses) throws IOException {
+    return new MemcachedClient(factory, serverAddresses);
   }
 
   @Override
@@ -126,12 +141,24 @@ public class MemcachedBlockCache implements BlockCache {
   @Override
   public void cacheBlock(BlockCacheKey cacheKey, Cacheable buf) {
     if (buf instanceof HFileBlock) {
-      client.add(cacheKey.toString(), MAX_SIZE, (HFileBlock) buf, tc);
-    } else {
-      if (LOG.isDebugEnabled()) {
-        LOG.debug(
-          "MemcachedBlockCache can not cache Cacheable's of type " + buf.getClass().toString());
+      if (buf.getSerializedLength() > MAX_SIZE) {
+        LOG.debug("Block of type {} with key {} is too large, size={}, max={}, will not cache",
+          buf.getClass(), cacheKey, buf.getSerializedLength(), MAX_SIZE);
+        notCachedCount.incrementAndGet();
+        return;
       }
+      client.set(cacheKey.toString(), MAX_TIME, (HFileBlock) buf, tc).addListener(f -> {
+        try {
+          f.get();
+          cachedCount.incrementAndGet();
+        } catch (Exception e) {
+          LOG.warn("Failed to cache block with key " + cacheKey, e);
+          cacheErrorCount.incrementAndGet();
+        }
+      });
+    } else {
+      LOG.debug("Can not cache Cacheables of type {} with key {}", buf.getClass(), cacheKey);
+      notCachedCount.incrementAndGet();
     }
   }
 
@@ -140,20 +167,29 @@ public class MemcachedBlockCache implements BlockCache {
     boolean updateCacheMetrics) {
     // Assume that nothing is the block cache
     HFileBlock result = null;
-
-    try (TraceScope traceScope = TraceUtil.createTrace("MemcachedBlockCache.getBlock")) {
+    Span span = TraceUtil.getGlobalTracer().spanBuilder("MemcachedBlockCache.getBlock").startSpan();
+    try (Scope traceScope = span.makeCurrent()) {
       result = client.get(cacheKey.toString(), tc);
     } catch (Exception e) {
-      // Catch a pretty broad set of exceptions to limit any changes in the memecache client
+      // Catch a pretty broad set of exceptions to limit any changes in the memcache client
       // and how it handles failures from leaking into the read path.
-      if (LOG.isDebugEnabled()) {
-        LOG.debug(
-          "Exception pulling from memcached [ " + cacheKey.toString() + " ]. Treating as a miss.",
-          e);
+      if (
+        (e instanceof OperationTimeoutException) || ((e instanceof RuntimeException)
+          && (e.getCause() instanceof OperationTimeoutException))
+      ) {
+        timeoutCount.incrementAndGet();
+        if (LOG.isDebugEnabled()) {
+          LOG.debug("Timeout getting key " + cacheKey.toString(), e);
+        }
+      } else {
+        cacheErrorCount.incrementAndGet();
+        if (LOG.isDebugEnabled()) {
+          LOG.debug("Exception getting key " + cacheKey.toString(), e);
+        }
       }
       result = null;
     } finally {
-      // Update stats if this request doesn't have it turned off 100% of the time
+      span.end();
       if (updateCacheMetrics) {
         if (result == null) {
           cacheStats.miss(caching, cacheKey.isPrimary(), cacheKey.getBlockType());
@@ -162,7 +198,6 @@ public class MemcachedBlockCache implements BlockCache {
         }
       }
     }
-
     return result;
   }
 
@@ -198,6 +233,22 @@ public class MemcachedBlockCache implements BlockCache {
   @Override
   public void shutdown() {
     client.shutdown();
+    this.scheduleThreadPool.shutdown();
+    for (int i = 0; i < 10; i++) {
+      if (!this.scheduleThreadPool.isShutdown()) {
+        try {
+          Thread.sleep(10);
+        } catch (InterruptedException e) {
+          LOG.warn("Interrupted while sleeping");
+          Thread.currentThread().interrupt();
+          break;
+        }
+      }
+    }
+    if (!this.scheduleThreadPool.isShutdown()) {
+      List<Runnable> runnables = this.scheduleThreadPool.shutdownNow();
+      LOG.debug("Still running " + runnables);
+    }
   }
 
   @Override
@@ -293,4 +344,38 @@ public class MemcachedBlockCache implements BlockCache {
       return MAX_SIZE;
     }
   }
+
+  private static class StatisticsThread extends Thread {
+
+    private final MemcachedBlockCache c;
+
+    public StatisticsThread(MemcachedBlockCache c) {
+      super("MemcachedBlockCacheStats");
+      setDaemon(true);
+      this.c = c;
+    }
+
+    @Override
+    public void run() {
+      c.logStats();
+    }
+
+  }
+
+  public void logStats() {
+    LOG.info("cached=" + cachedCount.get() + ", notCached=" + notCachedCount.get()
+      + ", cacheErrors=" + cacheErrorCount.get() + ", timeouts=" + timeoutCount.get() + ", reads="
+      + cacheStats.getRequestCount() + ", " + "hits=" + cacheStats.getHitCount() + ", hitRatio="
+      + (cacheStats.getHitCount() == 0
+        ? "0"
+        : (StringUtils.formatPercent(cacheStats.getHitRatio(), 2) + ", "))
+      + "cachingAccesses=" + cacheStats.getRequestCachingCount() + ", " + "cachingHits="
+      + cacheStats.getHitCachingCount() + ", " + "cachingHitsRatio="
+      + (cacheStats.getHitCachingCount() == 0
+        ? "0,"
+        : (StringUtils.formatPercent(cacheStats.getHitCachingRatio(), 2) + ", "))
+      + "evictions=" + cacheStats.getEvictionCount() + ", " + "evicted="
+      + cacheStats.getEvictedCount() + ", " + "evictedPerRun=" + cacheStats.evictedPerEviction());
+  }
+
 }
