@@ -17,6 +17,7 @@
  */
 package org.apache.hadoop.hbase.regionserver;
 
+import java.util.List;
 import org.apache.yetus.audience.InterfaceAudience;
 
 /**
@@ -75,6 +76,11 @@ public interface MetricsRegionServerWrapper {
    */
   long getWALFileSize();
 
+  /**
+   * Get the excluded datanodes in the cache of this region server.
+   */
+  List<String> getWALExcludeDNs();
+
   /**
    * Get the number of WAL files with slow appends for this region server.
    */
@@ -95,6 +101,16 @@ public interface MetricsRegionServerWrapper {
    */
   long getMemStoreSize();
 
+  /**
+   * Get the size of the on heap memstore on this region server.
+   */
+  long getOnHeapMemStoreSize();
+
+  /**
+   * Get the size of the off heap memstore on this region server.
+   */
+  long getOffHeapMemStoreSize();
+
   /**
    * Get the total size of the store files this region server is serving from.
    */
@@ -172,6 +188,21 @@ public interface MetricsRegionServerWrapper {
    */
   long getTotalStaticBloomSize();
 
+  /**
+   * Count of bloom filter requests.
+   */
+  long getBloomFilterRequestsCount();
+
+  /**
+   * Count of bloom filter requests which return a negative result.
+   */
+  long getBloomFilterNegativeResultsCount();
+
+  /**
+   * Count of requests which could have used bloom filters, but they weren't configured or loaded.
+   */
+  long getBloomFilterEligibleRequestsCount();
+
   /**
    * Number of mutations received with WAL explicitly turned off.
    */
@@ -212,8 +243,22 @@ public interface MetricsRegionServerWrapper {
    */
   int getFlushQueueSize();
 
+  /**
+   * Get the limit size of the off heap memstore (if enabled), otherwise get the limit size of the
+   * on heap memstore.
+   */
   long getMemStoreLimit();
 
+  /**
+   * Get the limit size of the on heap memstore.
+   */
+  long getOnHeapMemStoreLimit();
+
+  /**
+   * Get the limit size of the off heap memstore.
+   */
+  long getOffHeapMemStoreLimit();
+
   /**
    * Get the size (in bytes) of the block cache that is free.
    */
@@ -586,4 +631,6 @@ public interface MetricsRegionServerWrapper {
   long getByteBuffAllocatorTotalBufferCount();
 
   long getByteBuffAllocatorUsedBufferCount();
+
+  int getActiveScanners();
 }
