@@ -17,12 +17,13 @@
  */
 package org.apache.hadoop.hbase.replication.regionserver;
 
-import org.apache.hadoop.hbase.metrics.MetricRegistryInfo;
 import org.apache.hadoop.metrics2.lib.MutableFastCounter;
 import org.apache.hadoop.metrics2.lib.MutableGaugeInt;
 import org.apache.hadoop.metrics2.lib.MutableGaugeLong;
 import org.apache.hadoop.metrics2.lib.MutableHistogram;
+import org.apache.yetus.audience.InterfaceAudience;
 
+@InterfaceAudience.Private
 public class MetricsReplicationSourceSourceImpl implements MetricsReplicationSourceSource {
 
   private final MetricsReplicationSourceImpl rms;
@@ -33,8 +34,12 @@ public class MetricsReplicationSourceSourceImpl implements MetricsReplicationSou
   private final String logEditsFilteredKey;
   private final String shippedBatchesKey;
   private final String shippedOpsKey;
+  private final String failedBatchesKey;
   private String keyPrefix;
 
+  /**
+   * @deprecated since 1.3.0. Use {@link #shippedBytesKey} instead.
+   */
   @Deprecated
   private final String shippedKBsKey;
   private final String shippedBytesKey;
@@ -47,8 +52,9 @@ public class MetricsReplicationSourceSourceImpl implements MetricsReplicationSou
   private final MutableHistogram ageOfLastShippedOpHist;
   private final MutableGaugeLong sizeOfLogQueueGauge;
   private final MutableFastCounter logReadInEditsCounter;
-  private final MutableFastCounter logEditsFilteredCounter;
+  private final MutableFastCounter walEditsFilteredCounter;
   private final MutableFastCounter shippedBatchesCounter;
+  private final MutableFastCounter failedBatchesCounter;
   private final MutableFastCounter shippedOpsCounter;
   private final MutableFastCounter shippedKBsCounter;
   private final MutableFastCounter shippedBytesCounter;
@@ -87,6 +93,9 @@ public class MetricsReplicationSourceSourceImpl implements MetricsReplicationSou
     shippedBatchesKey = this.keyPrefix + "shippedBatches";
     shippedBatchesCounter = rms.getMetricsRegistry().getCounter(shippedBatchesKey, 0L);
 
+    failedBatchesKey = this.keyPrefix + "failedBatches";
+    failedBatchesCounter = rms.getMetricsRegistry().getCounter(failedBatchesKey, 0L);
+
     shippedOpsKey = this.keyPrefix + "shippedOps";
     shippedOpsCounter = rms.getMetricsRegistry().getCounter(shippedOpsKey, 0L);
 
@@ -103,7 +112,7 @@ public class MetricsReplicationSourceSourceImpl implements MetricsReplicationSou
     logReadInEditsCounter = rms.getMetricsRegistry().getCounter(logReadInEditsKey, 0L);
 
     logEditsFilteredKey = this.keyPrefix + "logEditsFiltered";
-    logEditsFilteredCounter = rms.getMetricsRegistry().getCounter(logEditsFilteredKey, 0L);
+    walEditsFilteredCounter = rms.getMetricsRegistry().getCounter(logEditsFilteredKey, 0L);
 
     shippedHFilesKey = this.keyPrefix + "shippedHFiles";
     shippedHFilesCounter = rms.getMetricsRegistry().getCounter(shippedHFilesKey, 0L);
@@ -139,50 +148,66 @@ public class MetricsReplicationSourceSourceImpl implements MetricsReplicationSou
     sourceInitializing = rms.getMetricsRegistry().getGaugeInt(sourceInitializingKey, 0);
   }
 
-  @Override public void setLastShippedAge(long age) {
+  @Override
+  public void setLastShippedAge(long age) {
     ageOfLastShippedOpHist.add(age);
   }
 
-  @Override public void incrSizeOfLogQueue(int size) {
+  @Override
+  public void incrSizeOfLogQueue(int size) {
     sizeOfLogQueueGauge.incr(size);
   }
 
-  @Override public void decrSizeOfLogQueue(int size) {
+  @Override
+  public void decrSizeOfLogQueue(int size) {
     sizeOfLogQueueGauge.decr(size);
   }
 
-  @Override public void incrLogReadInEdits(long size) {
+  @Override
+  public void incrLogReadInEdits(long size) {
     logReadInEditsCounter.incr(size);
   }
 
-  @Override public void incrLogEditsFiltered(long size) {
-    logEditsFilteredCounter.incr(size);
+  @Override
+  public void incrLogEditsFiltered(long size) {
+    walEditsFilteredCounter.incr(size);
   }
 
-  @Override public void incrBatchesShipped(int batches) {
+  @Override
+  public void incrBatchesShipped(int batches) {
     shippedBatchesCounter.incr(batches);
   }
 
-  @Override public void incrOpsShipped(long ops) {
+  @Override
+  public void incrFailedBatches() {
+    failedBatchesCounter.incr();
+  }
+
+  @Override
+  public void incrOpsShipped(long ops) {
     shippedOpsCounter.incr(ops);
   }
 
-  @Override public void incrShippedBytes(long size) {
+  @Override
+  public void incrShippedBytes(long size) {
     shippedBytesCounter.incr(size);
-    MetricsReplicationGlobalSourceSource
-      .incrementKBsCounter(shippedBytesCounter, shippedKBsCounter);
+    MetricsReplicationGlobalSourceSourceImpl.incrementKBsCounter(shippedBytesCounter,
+      shippedKBsCounter);
   }
 
-  @Override public void incrLogReadInBytes(long size) {
+  @Override
+  public void incrLogReadInBytes(long size) {
     logReadInBytesCounter.incr(size);
   }
 
-  @Override public void clear() {
+  @Override
+  public void clear() {
     rms.removeMetric(ageOfLastShippedOpKey);
 
     rms.removeMetric(sizeOfLogQueueKey);
 
     rms.removeMetric(shippedBatchesKey);
+    rms.removeMetric(failedBatchesKey);
     rms.removeMetric(shippedOpsKey);
     rms.removeMetric(shippedKBsKey);
     rms.removeMetric(shippedBytesKey);
@@ -228,7 +253,7 @@ public class MetricsReplicationSourceSourceImpl implements MetricsReplicationSou
 
   @Override
   public int getSizeOfLogQueue() {
-    return (int)sizeOfLogQueueGauge.value();
+    return (int) sizeOfLogQueueGauge.value();
   }
 
   @Override
@@ -272,13 +297,16 @@ public class MetricsReplicationSourceSourceImpl implements MetricsReplicationSou
   }
 
   @Override
-  public void incrFailedRecoveryQueue() {/*no op*/}
+  public void incrFailedRecoveryQueue() {
+    /* no op */}
 
-  @Override public void setOldestWalAge(long age) {
+  @Override
+  public void setOldestWalAge(long age) {
     oldestWalAge.set(age);
   }
 
-  @Override public long getOldestWalAge() {
+  @Override
+  public long getOldestWalAge() {
     return oldestWalAge.value();
   }
 
@@ -292,7 +320,8 @@ public class MetricsReplicationSourceSourceImpl implements MetricsReplicationSou
     return sourceInitializing.value();
   }
 
-  @Override public void decrSourceInitializing() {
+  @Override
+  public void decrSourceInitializing() {
     sourceInitializing.decr(1);
   }
 
@@ -352,8 +381,17 @@ public class MetricsReplicationSourceSourceImpl implements MetricsReplicationSou
   }
 
   @Override
-  public MetricRegistryInfo getMetricRegistryInfo() {
-    return new MetricRegistryInfo(getMetricsName(), getMetricsDescription(),
-      getMetricsContext(), getMetricsJmxContext(), true);
+  public long getWALEditsRead() {
+    return this.logReadInEditsCounter.value();
+  }
+
+  @Override
+  public long getShippedOps() {
+    return this.shippedOpsCounter.value();
+  }
+
+  @Override
+  public long getEditsFiltered() {
+    return this.walEditsFilteredCounter.value();
   }
 }
