@@ -17,15 +17,15 @@
  */
 package org.apache.hadoop.hbase.replication.regionserver;
 
-import org.apache.hadoop.hbase.metrics.MetricRegistryInfo;
 import org.apache.hadoop.metrics2.lib.MutableFastCounter;
 import org.apache.hadoop.metrics2.lib.MutableHistogram;
+import org.apache.yetus.audience.InterfaceAudience;
 
 /**
- * This is the metric source for table level replication metrics.
- * We can easy monitor some useful table level replication metrics such as
- * ageOfLastShippedOp and shippedBytes
+ * This is the metric source for table level replication metrics. We can easy monitor some useful
+ * table level replication metrics such as ageOfLastShippedOp and shippedBytes
  */
+@InterfaceAudience.Private
 public class MetricsReplicationTableSourceImpl implements MetricsReplicationTableSource {
 
   private final MetricsReplicationSourceImpl rms;
@@ -130,9 +130,4 @@ public class MetricsReplicationTableSourceImpl implements MetricsReplicationTabl
   public String getMetricsName() {
     return rms.getMetricsName();
   }
-
-  @Override
-  public MetricRegistryInfo getMetricRegistryInfo() {
-    return rms.getMetricRegistryInfo();
-  }
 }
