@@ -22,7 +22,6 @@ import static org.junit.Assert.assertNotEquals;
 
 import java.util.HashMap;
 import java.util.Map;
-
 import org.apache.hadoop.hbase.CompatibilitySingletonFactory;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
 import org.apache.hadoop.hbase.testclassification.MetricsTests;
@@ -31,17 +30,17 @@ import org.junit.ClassRule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 
-@Category({MetricsTests.class, SmallTests.class})
+@Category({ MetricsTests.class, SmallTests.class })
 public class TestMetricsRegionSourceImpl {
   @ClassRule
   public static final HBaseClassTestRule CLASS_RULE =
-      HBaseClassTestRule.forClass(TestMetricsRegionSourceImpl.class);
+    HBaseClassTestRule.forClass(TestMetricsRegionSourceImpl.class);
 
   @SuppressWarnings("SelfComparison")
   @Test
   public void testCompareToHashCodeEquals() {
-    MetricsRegionServerSourceFactory fact = CompatibilitySingletonFactory.getInstance(
-            MetricsRegionServerSourceFactory.class);
+    MetricsRegionServerSourceFactory fact =
+      CompatibilitySingletonFactory.getInstance(MetricsRegionServerSourceFactory.class);
 
     MetricsRegionSource one = fact.createRegion(new RegionWrapperStub("TEST"));
     MetricsRegionSource oneClone = fact.createRegion(new RegionWrapperStub("TEST"));
