@@ -146,8 +146,8 @@ public class JMXJsonServlet extends HttpServlet {
   }
 
   /**
-   * Process a GET request for the specified resource. n * The servlet request we are processing n *
-   * The servlet response we are creating
+   * Process a GET request for the specified resource. The servlet request we are processing The
+   * servlet response we are creating
    */
   @Override
   public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException {
@@ -171,8 +171,7 @@ public class JMXJsonServlet extends HttpServlet {
         }
         beanWriter = this.jsonBeanWriter.open(writer);
         // Should we output description on each attribute and bean?
-        String tmpStr = request.getParameter(INCLUDE_DESCRIPTION);
-        boolean description = tmpStr != null && tmpStr.length() > 0;
+        boolean description = "true".equals(request.getParameter(INCLUDE_DESCRIPTION));
 
         // query per mbean attribute
         String getmethod = request.getParameter("get");
