@@ -45,7 +45,6 @@ import org.apache.hadoop.util.HttpExceptionUtils;
 import org.apache.hadoop.util.ServletUtil;
 import org.apache.hadoop.util.Tool;
 import org.apache.yetus.audience.InterfaceAudience;
-import org.apache.yetus.audience.InterfaceStability;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -86,7 +85,7 @@ public final class LogLevel {
   }
 
   public static boolean isValidProtocol(String protocol) {
-    return ((protocol.equals(PROTOCOL_HTTP) || protocol.equals(PROTOCOL_HTTPS)));
+    return protocol.equals(PROTOCOL_HTTP) || protocol.equals(PROTOCOL_HTTPS);
   }
 
   static class CLI extends Configured implements Tool {
@@ -290,8 +289,7 @@ public final class LogLevel {
   /**
    * A servlet implementation
    */
-  @InterfaceAudience.LimitedPrivate({ "HDFS", "MapReduce" })
-  @InterfaceStability.Unstable
+  @InterfaceAudience.Private
   public static class Servlet extends HttpServlet {
     private static final long serialVersionUID = 1L;
 
@@ -328,7 +326,7 @@ public final class LogLevel {
       String[] readOnlyLogLevels = conf.getStrings(READONLY_LOGGERS_CONF_KEY);
 
       if (logName != null) {
-        out.println("<p>Results:</p>");
+        out.println("<h2>Results</h2>");
         out.println(MARKER + "Submitted Log Name: <b>" + logName + "</b><br />");
 
         Logger log = LoggerFactory.getLogger(logName);
@@ -374,24 +372,29 @@ public final class LogLevel {
     }
 
     static final String FORMS = "<div class='container-fluid content'>\n"
-      + "<div class='row inner_header'>\n" + "<div class='page-header'>\n"
-      + "<h1>Get/Set Log Level</h1>\n" + "</div>\n" + "</div>\n" + "Actions:" + "<p>" + "<center>\n"
-      + "<table class='table' style='border: 0;' width='95%' >\n" + "<tr>\n" + "<form>\n"
-      + "<td class='centered'>\n"
-      + "<input style='font-size: 12pt; width: 10em' type='submit' value='Get Log Level'"
-      + " class='btn' />\n" + "</td>\n" + "<td style='text-align: center;'>\n"
-      + "<input type='text' name='log' size='50' required='required'"
-      + " placeholder='Log Name (required)' />\n" + "</td>\n" + "<td width=\"40%\">"
-      + "Get the current log level for the specified log name." + "</td>\n" + "</form>\n"
-      + "</tr>\n" + "<tr>\n" + "<form>\n" + "<td class='centered'>\n"
-      + "<input style='font-size: 12pt; width: 10em' type='submit'"
-      + " value='Set Log Level' class='btn' />\n" + "</td>\n" + "<td style='text-align: center;'>\n"
-      + "<input type='text' name='log' size='50' required='required'"
-      + " placeholder='Log Name (required)' />\n"
-      + "<input type='text' name='level' size='50' required='required'"
-      + " placeholder='Log Level (required)' />\n" + "</td>\n" + "<td width=\"40%\" style=\"\">"
-      + "Set the specified log level for the specified log name." + "</td>\n" + "</form>\n"
-      + "</tr>\n" + "</table>\n" + "</center>\n" + "</p>\n" + "<hr/>\n";
+      + "<div class='row inner_header top_header'>\n" + "<div class='page-header'>\n"
+      + "<h1>Get/Set Log Level</h1>\n" + "</div>\n" + "</div>\n" + "\n" + "<h2>Actions</h2>\n"
+      + "\n" + "<div class='row mb-4'>\n" + "<div class='col'>\n"
+      + "<form class='row g-3 align-items-center justify-content-center'>\n"
+      + "<div class='col-sm-auto'>\n"
+      + "<button type='submit' class='btn btn-primary'>Get Log Level</button>\n" + "</div>\n"
+      + "  <div class='col-sm-auto'>\n"
+      + "<input type='text' name='log' class='form-control' size='50'"
+      + " required='required' placeholder='Log Name (required)'>\n" + "</div>\n"
+      + "  <div class='col-sm-auto'>\n"
+      + "<span>Gets the current log level for the specified log name.</span>\n" + "</div>\n"
+      + "</form>\n" + "</div>\n" + "</div>\n" + "\n" + "<div class='row'>\n" + "<div class='col'>\n"
+      + "\n" + "<form class='row g-3 align-items-center justify-content-center'>\n"
+      + "<div class='col-sm-auto'>\n"
+      + "<button type='submit' class='btn btn-primary'>Set Log Level</button>\n" + "</div>\n"
+      + "<div class='col-sm-auto'>\n"
+      + "<input type='text' name='log' class='form-control mb-2' size='50'"
+      + " required='required' placeholder='Log Name (required)'>\n"
+      + "<input type='text' name='level' class='form-control' size='50'"
+      + " required='required' placeholder='Log Level (required)'>\n" + "</div>\n"
+      + "<div class='col-sm-auto'>\n"
+      + "<span>Sets the specified log level for the specified log name.</span>\n" + "</div>\n"
+      + "</form>\n" + "\n" + "</div>\n" + "</div>" + "<hr>\n";
 
     private static void process(Logger logger, String levelName, PrintWriter out) {
       if (levelName != null) {
