@@ -24,6 +24,7 @@ import java.util.Set;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.testclassification.IntegrationTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.HFileTestUtil;
 import org.apache.hadoop.hbase.util.LoadTestTool;
 import org.apache.hadoop.hbase.util.Threads;
@@ -35,6 +36,7 @@ import org.junit.experimental.categories.Category;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.hbase.thirdparty.com.google.common.base.Splitter;
 import org.apache.hbase.thirdparty.com.google.common.collect.Sets;
 
 /**
@@ -62,6 +64,7 @@ public class IntegrationTestIngest extends IntegrationTestBase {
 
   // Log is being used in IntegrationTestIngestWithEncryption, hence it is protected
   protected static final Logger LOG = LoggerFactory.getLogger(IntegrationTestIngest.class);
+
   protected IntegrationTestingUtility util;
   protected HBaseCluster cluster;
   protected LoadTestTool loadTool;
@@ -136,7 +139,7 @@ public class IntegrationTestIngest extends IntegrationTestBase {
         families.add(Bytes.toString(family));
       }
     } else {
-      for (String family : familiesString.split(",")) {
+      for (String family : Splitter.on(',').split(familiesString)) {
         families.add(family);
       }
     }
@@ -157,18 +160,17 @@ public class IntegrationTestIngest extends IntegrationTestBase {
     LOG.info("Cluster size:"
       + util.getHBaseClusterInterface().getClusterMetrics().getLiveServerMetrics().size());
 
-    long start = System.currentTimeMillis();
+    long start = EnvironmentEdgeManager.currentTime();
     String runtimeKey = String.format(RUN_TIME_KEY, this.getClass().getSimpleName());
     long runtime = util.getConfiguration().getLong(runtimeKey, defaultRunTime);
     long startKey = 0;
 
     long numKeys = getNumKeys(keysPerServerPerIter);
-    while (System.currentTimeMillis() - start < 0.9 * runtime) {
+    while (EnvironmentEdgeManager.currentTime() - start < 0.9 * runtime) {
       LOG.info("Intended run time: " + (runtime / 60000) + " min, left:"
-        + ((runtime - (System.currentTimeMillis() - start)) / 60000) + " min");
+        + ((runtime - (EnvironmentEdgeManager.currentTime() - start)) / 60000) + " min");
 
-      int ret = -1;
-      ret = loadTool.run(getArgsForLoadTestTool("-write",
+      int ret = loadTool.run(getArgsForLoadTestTool("-write",
         String.format("%d:%d:%d", colsPerKey, recordSize, writeThreads), startKey, numKeys));
       if (0 != ret) {
         String errorMsg = "Load failed with error code " + ret;
