@@ -18,7 +18,6 @@
 package org.apache.hadoop.hbase;
 
 import java.io.IOException;
-
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Waiter.Predicate;
 import org.apache.hadoop.hbase.client.Admin;
@@ -27,12 +26,12 @@ import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.io.crypto.KeyProviderForTesting;
 import org.apache.hadoop.hbase.io.hfile.HFile;
-import org.apache.hadoop.hbase.wal.WAL.Reader;
-import org.apache.hadoop.hbase.wal.WALProvider.Writer;
 import org.apache.hadoop.hbase.regionserver.wal.SecureProtobufLogReader;
 import org.apache.hadoop.hbase.regionserver.wal.SecureProtobufLogWriter;
 import org.apache.hadoop.hbase.testclassification.IntegrationTests;
 import org.apache.hadoop.hbase.util.EncryptionTest;
+import org.apache.hadoop.hbase.wal.WAL.Reader;
+import org.apache.hadoop.hbase.wal.WALProvider.Writer;
 import org.apache.hadoop.util.ToolRunner;
 import org.junit.Before;
 import org.junit.experimental.categories.Category;
@@ -42,7 +41,7 @@ import org.slf4j.LoggerFactory;
 @Category(IntegrationTests.class)
 public class IntegrationTestIngestWithEncryption extends IntegrationTestIngest {
   private final static Logger LOG =
-      LoggerFactory.getLogger(IntegrationTestIngestWithEncryption.class);
+    LoggerFactory.getLogger(IntegrationTestIngestWithEncryption.class);
 
   boolean initialized = false;
 
@@ -88,8 +87,8 @@ public class IntegrationTestIngestWithEncryption extends IntegrationTestIngest {
     final Admin admin = util.getAdmin();
     TableDescriptor tableDescriptor = admin.getDescriptor(getTablename());
     for (ColumnFamilyDescriptor columnDescriptor : tableDescriptor.getColumnFamilies()) {
-      ColumnFamilyDescriptor updatedColumn = ColumnFamilyDescriptorBuilder
-          .newBuilder(columnDescriptor).setEncryptionType("AES").build();
+      ColumnFamilyDescriptor updatedColumn =
+        ColumnFamilyDescriptorBuilder.newBuilder(columnDescriptor).setEncryptionType("AES").build();
       LOG.info(
         "Updating CF schema for " + getTablename() + "." + columnDescriptor.getNameAsString());
       admin.disableTable(getTablename());
