@@ -18,6 +18,7 @@
 package org.apache.hadoop.hbase;
 
 import java.io.IOException;
+import java.util.List;
 import java.util.Locale;
 import java.util.Set;
 import org.apache.commons.lang3.StringUtils;
@@ -29,6 +30,7 @@ import org.apache.hadoop.hbase.regionserver.StripeStoreConfig;
 import org.apache.hadoop.hbase.regionserver.StripeStoreEngine;
 import org.apache.hadoop.hbase.util.AbstractHBaseTool;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.LoadTestKVGenerator;
 import org.apache.hadoop.hbase.util.MultiThreadedAction;
 import org.apache.hadoop.hbase.util.MultiThreadedReader;
@@ -40,6 +42,8 @@ import org.junit.Assert;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.hbase.thirdparty.com.google.common.base.Splitter;
+import org.apache.hbase.thirdparty.com.google.common.collect.Iterables;
 import org.apache.hbase.thirdparty.org.apache.commons.cli.CommandLine;
 
 /**
@@ -105,10 +109,12 @@ public class StripeCompactionsPerformanceEvaluation extends AbstractHBaseTool {
     int minValueSize = 0, maxValueSize = 0;
     String valueSize = cmd.getOptionValue(VALUE_SIZE_KEY, VALUE_SIZE_DEFAULT);
     if (valueSize.contains(":")) {
-      String[] valueSizes = valueSize.split(":");
-      if (valueSize.length() != 2) throw new RuntimeException("Invalid value size: " + valueSize);
-      minValueSize = Integer.parseInt(valueSizes[0]);
-      maxValueSize = Integer.parseInt(valueSizes[1]);
+      List<String> valueSizes = Splitter.on(':').splitToList(valueSize);
+      if (valueSizes.size() != 2) {
+        throw new RuntimeException("Invalid value size: " + valueSize);
+      }
+      minValueSize = Integer.parseInt(Iterables.get(valueSizes, 0));
+      maxValueSize = Integer.parseInt(Iterables.get(valueSizes, 1));
     } else {
       minValueSize = maxValueSize = Integer.parseInt(valueSize);
     }
@@ -202,14 +208,14 @@ public class StripeCompactionsPerformanceEvaluation extends AbstractHBaseTool {
 
     if (preloadKeys > 0) {
       MultiThreadedWriter preloader = new MultiThreadedWriter(dataGen, conf, TABLE_NAME);
-      long time = System.currentTimeMillis();
+      long time = EnvironmentEdgeManager.currentTime();
       preloader.start(0, startKey, writeThreads);
       preloader.waitForFinish();
       if (preloader.getNumWriteFailures() > 0) {
         throw new IOException("Preload failed");
       }
       int waitTime = (int) Math.min(preloadKeys / 100, 30000); // arbitrary
-      status(description + " preload took " + (System.currentTimeMillis() - time) / 1000
+      status(description + " preload took " + (EnvironmentEdgeManager.currentTime() - time) / 1000
         + "sec; sleeping for " + waitTime / 1000 + "sec for store to stabilize");
       Thread.sleep(waitTime);
     }
@@ -219,7 +225,7 @@ public class StripeCompactionsPerformanceEvaluation extends AbstractHBaseTool {
     // reader.getMetrics().enable();
     reader.linkToWriter(writer);
 
-    long testStartTime = System.currentTimeMillis();
+    long testStartTime = EnvironmentEdgeManager.currentTime();
     writer.start(startKey, endKey, writeThreads);
     reader.start(startKey, endKey, readThreads);
     writer.waitForFinish();
@@ -249,8 +255,8 @@ public class StripeCompactionsPerformanceEvaluation extends AbstractHBaseTool {
      * pt.getThird(), pt.getSecond())); } } LOG.info("Performance data dump for " + description +
      * " test: \n" + perfDump.toString());
      */
-    status(
-      description + " test took " + (System.currentTimeMillis() - testStartTime) / 1000 + "sec");
+    status(description + " test took "
+      + (EnvironmentEdgeManager.currentTime() - testStartTime) / 1000 + "sec");
     Assert.assertTrue(success);
   }
 
