@@ -15,11 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.chaos.actions;
 
 import java.io.IOException;
-import java.util.Random;
+import java.util.concurrent.ThreadLocalRandom;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.io.encoding.DataBlockEncoding;
 import org.slf4j.Logger;
@@ -30,15 +29,14 @@ import org.slf4j.LoggerFactory;
  */
 public class ChangeEncodingAction extends Action {
   private final TableName tableName;
-  private final Random random;
   private static final Logger LOG = LoggerFactory.getLogger(ChangeEncodingAction.class);
 
   public ChangeEncodingAction(TableName tableName) {
     this.tableName = tableName;
-    this.random = new Random();
   }
 
-  @Override protected Logger getLogger() {
+  @Override
+  protected Logger getLogger() {
     return LOG;
   }
 
@@ -46,10 +44,9 @@ public class ChangeEncodingAction extends Action {
   public void perform() throws IOException {
     getLogger().debug("Performing action: Changing encodings on " + tableName);
     // possible DataBlockEncoding id's
-    final int[] possibleIds = {0, 2, 3, 4, 7};
-
+    final int[] possibleIds = { 0, 2, 3, 4, 7 };
     modifyAllTableColumns(tableName, (columnName, columnBuilder) -> {
-      short id = (short) possibleIds[random.nextInt(possibleIds.length)];
+      short id = (short) possibleIds[ThreadLocalRandom.current().nextInt(possibleIds.length)];
       DataBlockEncoding encoding = DataBlockEncoding.getEncodingById(id);
       columnBuilder.setDataBlockEncoding(encoding);
       getLogger().debug("Set encoding of column family " + columnName + " to: " + encoding);
