@@ -15,39 +15,34 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.chaos.actions;
 
 import java.io.IOException;
-import java.util.Random;
+import java.util.concurrent.ThreadLocalRandom;
 import org.apache.hadoop.hbase.TableName;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * Action that changes the number of versions on a column family from a list of tables.
- *
- * Always keeps at least 1 as the number of versions.
+ * Action that changes the number of versions on a column family from a list of tables. Always keeps
+ * at least 1 as the number of versions.
  */
 public class ChangeVersionsAction extends Action {
   private static final Logger LOG = LoggerFactory.getLogger(ChangeVersionsAction.class);
   private final TableName tableName;
 
-  private final Random random;
-
   public ChangeVersionsAction(TableName tableName) {
     this.tableName = tableName;
-    this.random = new Random();
   }
 
-  @Override protected Logger getLogger() {
+  @Override
+  protected Logger getLogger() {
     return LOG;
   }
 
   @Override
   public void perform() throws IOException {
-    final int versions =  random.nextInt(3) + 1;
-
+    final int versions = ThreadLocalRandom.current().nextInt(3) + 1;
     getLogger().debug("Performing action: Changing versions on " + tableName + " to " + versions);
     modifyAllTableColumns(tableName, columnBuilder -> {
       columnBuilder.setMinVersions(versions).setMaxVersions(versions);
