@@ -15,11 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.chaos.actions;
 
 import java.io.IOException;
-import java.util.Random;
+import java.util.concurrent.ThreadLocalRandom;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
@@ -35,16 +34,15 @@ public class DecreaseMaxHFileSizeAction extends Action {
 
   private final long sleepTime;
   private final TableName tableName;
-  private final Random random;
   private Admin admin;
 
   public DecreaseMaxHFileSizeAction(long sleepTime, TableName tableName) {
     this.sleepTime = sleepTime;
     this.tableName = tableName;
-    this.random = new Random();
   }
 
-  @Override protected Logger getLogger() {
+  @Override
+  protected Logger getLogger() {
     return LOG;
   }
 
@@ -65,9 +63,8 @@ public class DecreaseMaxHFileSizeAction extends Action {
     // If configs are really weird this might not work.
     // That's ok. We're trying to cause chaos.
     if (currentValue <= 0) {
-      currentValue =
-          context.getHBaseCluster().getConf().getLong(HConstants.HREGION_MAX_FILESIZE,
-              HConstants.DEFAULT_MAX_FILE_SIZE);
+      currentValue = context.getHBaseCluster().getConf().getLong(HConstants.HREGION_MAX_FILESIZE,
+        HConstants.DEFAULT_MAX_FILE_SIZE);
     }
 
     // Decrease by 10% at a time.
@@ -75,11 +72,11 @@ public class DecreaseMaxHFileSizeAction extends Action {
 
     // We don't want to go too far below 1gb.
     // So go to about 1gb +/- 512 on each side.
-    newValue = Math.max(minFileSize, newValue) - (512 - random.nextInt(1024));
+    newValue = Math.max(minFileSize, newValue) - (512 - ThreadLocalRandom.current().nextInt(1024));
 
     // Change the table descriptor.
     TableDescriptor modifiedTable =
-        TableDescriptorBuilder.newBuilder(td).setMaxFileSize(newValue).build();
+      TableDescriptorBuilder.newBuilder(td).setMaxFileSize(newValue).build();
 
     // Don't try the modify if we're stopping
     if (context.isStopping()) {
