@@ -15,7 +15,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.chaos.actions;
 
 import org.apache.hadoop.hbase.HBaseTestingUtility;
@@ -25,8 +24,8 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
-* Action that tries to flush a table.
-*/
+ * Action that tries to flush a table.
+ */
 public class FlushTableAction extends Action {
   private static final Logger LOG = LoggerFactory.getLogger(FlushTableAction.class);
   private final long sleepTime;
@@ -41,7 +40,8 @@ public class FlushTableAction extends Action {
     this.tableName = tableName;
   }
 
-  @Override protected Logger getLogger() {
+  @Override
+  protected Logger getLogger() {
     return LOG;
   }
 
