@@ -20,6 +20,8 @@ package org.apache.hadoop.hbase.mttr;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assume.assumeFalse;
 
+import io.opentelemetry.api.trace.Span;
+import io.opentelemetry.context.Scope;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.concurrent.Callable;
@@ -61,9 +63,6 @@ import org.apache.hadoop.hbase.testclassification.IntegrationTests;
 import org.apache.hadoop.hbase.trace.TraceUtil;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.LoadTestTool;
-import org.apache.htrace.core.AlwaysSampler;
-import org.apache.htrace.core.Span;
-import org.apache.htrace.core.TraceScope;
 import org.junit.AfterClass;
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -360,12 +359,9 @@ public class IntegrationTestMTTR {
      * @param span Span. To be kept if the time taken was over 1 second
      */
     public void addResult(long time, Span span) {
-      if (span == null) {
-        return;
-      }
       stats.addValue(TimeUnit.MILLISECONDS.convert(time, TimeUnit.NANOSECONDS));
       if (TimeUnit.SECONDS.convert(time, TimeUnit.NANOSECONDS) >= 1) {
-        traces.add(span.getTracerId());
+        traces.add(span.getSpanContext().getTraceId());
       }
     }
 
@@ -399,15 +395,11 @@ public class IntegrationTestMTTR {
       final int maxIterations = 10;
       int numAfterDone = 0;
       int resetCount = 0;
-      TraceUtil.addSampler(AlwaysSampler.INSTANCE);
       // Keep trying until the rs is back up and we've gotten a put through
       while (numAfterDone < maxIterations) {
         long start = System.nanoTime();
-        Span span = null;
-        try (TraceScope scope = TraceUtil.createTrace(getSpanName())) {
-          if (scope != null) {
-            span = scope.getSpan();
-          }
+        Span span = TraceUtil.getGlobalTracer().spanBuilder(getSpanName()).startSpan();
+        try (Scope scope = span.makeCurrent()) {
           boolean actionResult = doAction();
           if (actionResult && future.isDone()) {
             numAfterDone++;
@@ -438,7 +430,6 @@ public class IntegrationTestMTTR {
           throw e;
         } catch (RetriesExhaustedException e) {
           throw e;
-
           // Everything else is potentially recoverable on the application side. For instance, a CM
           // action kills the RS that hosted a scanner the client was using. Continued use of that
           // scanner should be terminated, but a new scanner can be created and the read attempted
@@ -454,6 +445,8 @@ public class IntegrationTestMTTR {
             LOG.info("Too many unexpected Exceptions. Aborting.", e);
             throw e;
           }
+        } finally {
+          span.end();
         }
         result.addResult(System.nanoTime() - start, span);
       }
