@@ -46,7 +46,6 @@ import org.apache.hadoop.mapreduce.JobContext;
 import org.apache.hadoop.mapreduce.RecordReader;
 import org.apache.hadoop.mapreduce.TaskAttemptContext;
 import org.apache.hadoop.net.DNS;
-import org.apache.hadoop.util.StringUtils;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -171,7 +170,7 @@ public abstract class TableInputFormatBase extends InputFormat<ImmutableBytesWri
       throw new IOException(INITIALIZATION_ERROR, exception);
     }
     TableSplit tSplit = (TableSplit) split;
-    LOG.info("Input split length: " + StringUtils.humanReadableInt(tSplit.getLength()) + " bytes.");
+    LOG.info("Input split length: " + Strings.humanReadableInt(tSplit.getLength()) + " bytes.");
     final TableRecordReader trr =
       this.tableRecordReader != null ? this.tableRecordReader : new TableRecordReader();
     Scan sc = new Scan(this.scan);
@@ -362,8 +361,7 @@ public abstract class TableInputFormatBase extends InputFormat<ImmutableBytesWri
    * @param split A TableSplit corresponding to a range of rowkeys
    * @param n     Number of ranges after splitting. Pass 1 means no split for the range Pass 2 if
    *              you want to split the range in two;
-   * @return A list of TableSplit, the size of the list is n
-   * @throws IllegalArgumentIOException throws IllegalArgumentIOException
+   * @return A list of TableSplit, the size of the list is {@code n}
    */
   protected List<InputSplit> createNInputSplitsUniform(InputSplit split, int n)
     throws IllegalArgumentIOException {
@@ -581,7 +579,7 @@ public abstract class TableInputFormatBase extends InputFormat<ImmutableBytesWri
   /**
    * Allows subclasses to initialize the table information.
    * @param connection The Connection to the HBase cluster. MUST be unmanaged. We will close.
-   * @param tableName  The {@link TableName} of the table to process. n
+   * @param tableName  The {@link TableName} of the table to process.
    */
   protected void initializeTable(Connection connection, TableName tableName) throws IOException {
     if (this.table != null || this.connection != null) {
@@ -642,7 +640,7 @@ public abstract class TableInputFormatBase extends InputFormat<ImmutableBytesWri
 
   /**
    * Close the Table and related objects that were initialized via
-   * {@link #initializeTable(Connection, TableName)}. n
+   * {@link #initializeTable(Connection, TableName)}.
    */
   protected void closeTable() throws IOException {
     close(admin, table, regionLocator, connection);
