@@ -58,6 +58,7 @@ import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.FSUtils;
 import org.apache.hadoop.hbase.util.HFileArchiveUtil;
 import org.apache.hadoop.hbase.util.Pair;
+import org.apache.hadoop.hbase.util.Strings;
 import org.apache.hadoop.io.BytesWritable;
 import org.apache.hadoop.io.IOUtils;
 import org.apache.hadoop.io.NullWritable;
@@ -80,6 +81,7 @@ import org.slf4j.LoggerFactory;
 import org.apache.hbase.thirdparty.org.apache.commons.cli.CommandLine;
 import org.apache.hbase.thirdparty.org.apache.commons.cli.Option;
 
+import org.apache.hadoop.hbase.shaded.protobuf.ProtobufUtil;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.SnapshotProtos.SnapshotDescription;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.SnapshotProtos.SnapshotFileInfo;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.SnapshotProtos.SnapshotRegionManifest;
@@ -138,9 +140,9 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
     static final Option NO_CHECKSUM_VERIFY = new Option(null, "no-checksum-verify", false,
       "Do not verify checksum, use name+length only.");
     static final Option NO_TARGET_VERIFY = new Option(null, "no-target-verify", false,
-      "Do not verify the integrity of the exported snapshot.");
-    static final Option NO_SOURCE_VERIFY =
-      new Option(null, "no-source-verify", false, "Do not verify the source of the snapshot.");
+      "Do not verify the exported snapshot's expiration status and integrity.");
+    static final Option NO_SOURCE_VERIFY = new Option(null, "no-source-verify", false,
+      "Do not verify the source snapshot's expiration status and integrity.");
     static final Option OVERWRITE =
       new Option(null, "overwrite", false, "Rewrite the snapshot manifest if already exists.");
     static final Option CHUSER =
@@ -234,7 +236,7 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
       // Use the default block size of the outputFs if bigger
       int defaultBlockSize = Math.max((int) outputFs.getDefaultBlockSize(outputRoot), BUFFER_SIZE);
       bufferSize = conf.getInt(CONF_BUFFER_SIZE, defaultBlockSize);
-      LOG.info("Using bufferSize=" + StringUtils.humanReadableInt(bufferSize));
+      LOG.info("Using bufferSize=" + Strings.humanReadableInt(bufferSize));
 
       for (Counter c : Counter.values()) {
         context.getCounter(c).increment(0);
@@ -341,10 +343,9 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
 
         long etime = EnvironmentEdgeManager.currentTime();
         LOG.info("copy completed for input=" + inputPath + " output=" + outputPath);
-        LOG
-          .info("size=" + totalBytesWritten + " (" + StringUtils.humanReadableInt(totalBytesWritten)
-            + ")" + " time=" + StringUtils.formatTimeDiff(etime, stime) + String
-              .format(" %.3fM/sec", (totalBytesWritten / ((etime - stime) / 1000.0)) / 1048576.0));
+        LOG.info("size=" + totalBytesWritten + " (" + Strings.humanReadableInt(totalBytesWritten)
+          + ")" + " time=" + StringUtils.formatTimeDiff(etime, stime) + String.format(" %.3fM/sec",
+            (totalBytesWritten / ((etime - stime) / 1000.0)) / 1048576.0));
         context.getCounter(Counter.FILES_COPIED).increment(1);
 
         // Try to Preserve attributes
@@ -436,7 +437,7 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
       final Path outputPath, final FSDataOutputStream out, final long inputFileSize)
       throws IOException {
       final String statusMessage =
-        "copied %s/" + StringUtils.humanReadableInt(inputFileSize) + " (%.1f%%)";
+        "copied %s/" + Strings.humanReadableInt(inputFileSize) + " (%.1f%%)";
 
       try {
         byte[] buffer = new byte[bufferSize];
@@ -451,8 +452,8 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
 
           if (reportBytes >= REPORT_SIZE) {
             context.getCounter(Counter.BYTES_COPIED).increment(reportBytes);
-            context.setStatus(
-              String.format(statusMessage, StringUtils.humanReadableInt(totalBytesWritten),
+            context
+              .setStatus(String.format(statusMessage, Strings.humanReadableInt(totalBytesWritten),
                 (totalBytesWritten / (float) inputFileSize) * 100.0f) + " from " + inputPath
                 + " to " + outputPath);
             reportBytes = 0;
@@ -460,10 +461,9 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
         }
 
         context.getCounter(Counter.BYTES_COPIED).increment(reportBytes);
-        context
-          .setStatus(String.format(statusMessage, StringUtils.humanReadableInt(totalBytesWritten),
-            (totalBytesWritten / (float) inputFileSize) * 100.0f) + " from " + inputPath + " to "
-            + outputPath);
+        context.setStatus(String.format(statusMessage, Strings.humanReadableInt(totalBytesWritten),
+          (totalBytesWritten / (float) inputFileSize) * 100.0f) + " from " + inputPath + " to "
+          + outputPath);
 
         return totalBytesWritten;
       } finally {
@@ -754,7 +754,7 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
 
     if (LOG.isDebugEnabled()) {
       for (int i = 0; i < sizeGroups.length; ++i) {
-        LOG.debug("export split=" + i + " size=" + StringUtils.humanReadableInt(sizeGroups[i]));
+        LOG.debug("export split=" + i + " size=" + Strings.humanReadableInt(sizeGroups[i]));
       }
     }
 
@@ -942,13 +942,17 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
     }
   }
 
-  private void verifySnapshot(final Configuration baseConf, final FileSystem fs, final Path rootDir,
-    final Path snapshotDir) throws IOException {
+  private void verifySnapshot(final SnapshotDescription snapshotDesc, final Configuration baseConf,
+    final FileSystem fs, final Path rootDir, final Path snapshotDir) throws IOException {
     // Update the conf with the current root dir, since may be a different cluster
     Configuration conf = new Configuration(baseConf);
     CommonFSUtils.setRootDir(conf, rootDir);
     CommonFSUtils.setFsDefault(conf, CommonFSUtils.getRootDir(conf));
-    SnapshotDescription snapshotDesc = SnapshotDescriptionUtils.readSnapshotInfo(fs, snapshotDir);
+    boolean isExpired = SnapshotDescriptionUtils.isExpiredSnapshot(snapshotDesc.getTtl(),
+      snapshotDesc.getCreationTime(), EnvironmentEdgeManager.currentTime());
+    if (isExpired) {
+      throw new SnapshotTTLExpiredException(ProtobufUtil.createSnapshotDesc(snapshotDesc));
+    }
     SnapshotReferenceUtil.verifySnapshot(conf, fs, snapshotDir, snapshotDesc);
   }
 
@@ -1050,14 +1054,14 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
     if (snapshotName == null) {
       System.err.println("Snapshot name not provided.");
       LOG.error("Use -h or --help for usage instructions.");
-      return 0;
+      return EXIT_FAILURE;
     }
 
     if (outputRoot == null) {
       System.err
         .println("Destination file-system (--" + Options.COPY_TO.getLongOpt() + ") not provided.");
       LOG.error("Use -h or --help for usage instructions.");
-      return 0;
+      return EXIT_FAILURE;
     }
 
     if (targetName == null) {
@@ -1087,11 +1091,14 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
     LOG.debug("outputFs={}, outputRoot={}, skipTmp={}, initialOutputSnapshotDir={}", outputFs,
       outputRoot.toString(), skipTmp, initialOutputSnapshotDir);
 
+    // throw CorruptedSnapshotException if we can't read the snapshot info.
+    SnapshotDescription sourceSnapshotDesc =
+      SnapshotDescriptionUtils.readSnapshotInfo(inputFs, snapshotDir);
+
     // Verify snapshot source before copying files
     if (verifySource) {
-      LOG.info("Verify snapshot source, inputFs={}, inputRoot={}, snapshotDir={}.",
-        inputFs.getUri(), inputRoot, snapshotDir);
-      verifySnapshot(srcConf, inputFs, inputRoot, snapshotDir);
+      LOG.info("Verify the source snapshot's expiration status and integrity.");
+      verifySnapshot(sourceSnapshotDesc, srcConf, inputFs, inputRoot, snapshotDir);
     }
 
     // Find the necessary directory which need to change owner and group
@@ -1112,12 +1119,12 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
       if (overwrite) {
         if (!outputFs.delete(outputSnapshotDir, true)) {
           System.err.println("Unable to remove existing snapshot directory: " + outputSnapshotDir);
-          return 1;
+          return EXIT_FAILURE;
         }
       } else {
         System.err.println("The snapshot '" + targetName + "' already exists in the destination: "
           + outputSnapshotDir);
-        return 1;
+        return EXIT_FAILURE;
       }
     }
 
@@ -1128,7 +1135,7 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
           if (!outputFs.delete(snapshotTmpDir, true)) {
             System.err
               .println("Unable to remove existing snapshot tmp directory: " + snapshotTmpDir);
-            return 1;
+            return EXIT_FAILURE;
           }
         } else {
           System.err
@@ -1137,7 +1144,7 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
             .println("Please check " + snapshotTmpDir + ". If the snapshot has completed, ");
           System.err
             .println("consider removing " + snapshotTmpDir + " by using the -overwrite option");
-          return 1;
+          return EXIT_FAILURE;
         }
       }
     }
@@ -1216,19 +1223,21 @@ public class ExportSnapshot extends AbstractHBaseTool implements Tool {
 
       // Step 4 - Verify snapshot integrity
       if (verifyTarget) {
-        LOG.info("Verify snapshot integrity");
-        verifySnapshot(destConf, outputFs, outputRoot, outputSnapshotDir);
+        LOG.info("Verify the exported snapshot's expiration status and integrity.");
+        SnapshotDescription targetSnapshotDesc =
+          SnapshotDescriptionUtils.readSnapshotInfo(outputFs, outputSnapshotDir);
+        verifySnapshot(targetSnapshotDesc, destConf, outputFs, outputRoot, outputSnapshotDir);
       }
 
       LOG.info("Export Completed: " + targetName);
-      return 0;
+      return EXIT_SUCCESS;
     } catch (Exception e) {
       LOG.error("Snapshot export failed", e);
       if (!skipTmp) {
         outputFs.delete(snapshotTmpDir, true);
       }
       outputFs.delete(outputSnapshotDir, true);
-      return 1;
+      return EXIT_FAILURE;
     } finally {
       IOUtils.closeStream(inputFs);
       IOUtils.closeStream(outputFs);
