@@ -20,7 +20,7 @@ package org.apache.hadoop.hbase.mapred;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.anyObject;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.doThrow;
@@ -207,7 +207,7 @@ public class TestTableInputFormat {
     };
 
     Table htable = spy(createTable(name));
-    doAnswer(a).when(htable).getScanner((Scan) anyObject());
+    doAnswer(a).when(htable).getScanner(any(Scan.class));
     return htable;
   }
 
@@ -240,7 +240,7 @@ public class TestTableInputFormat {
     };
 
     Table htable = spy(createTable(name));
-    doAnswer(a).when(htable).getScanner((Scan) anyObject());
+    doAnswer(a).when(htable).getScanner(any(Scan.class));
     return htable;
   }
 
