@@ -506,23 +506,19 @@ public class TestCellBasedHFileOutputFormat2 {
   }
 
   private byte[][] generateRandomStartKeys(int numKeys) {
-    Random random = new Random();
     byte[][] ret = new byte[numKeys][];
     // first region start key is always empty
     ret[0] = HConstants.EMPTY_BYTE_ARRAY;
     for (int i = 1; i < numKeys; i++) {
-      ret[i] =
-        PerformanceEvaluation.generateData(random, PerformanceEvaluation.DEFAULT_VALUE_LENGTH);
+      ret[i] = PerformanceEvaluation.generateData(PerformanceEvaluation.DEFAULT_VALUE_LENGTH);
     }
     return ret;
   }
 
   private byte[][] generateRandomSplitKeys(int numKeys) {
-    Random random = new Random();
     byte[][] ret = new byte[numKeys][];
     for (int i = 0; i < numKeys; i++) {
-      ret[i] =
-        PerformanceEvaluation.generateData(random, PerformanceEvaluation.DEFAULT_VALUE_LENGTH);
+      ret[i] = PerformanceEvaluation.generateData(PerformanceEvaluation.DEFAULT_VALUE_LENGTH);
     }
     return ret;
   }
@@ -776,7 +772,7 @@ public class TestCellBasedHFileOutputFormat2 {
   /**
    * Test for {@link HFileOutputFormat2#configureCompression(Configuration, HTableDescriptor)} and
    * {@link HFileOutputFormat2#createFamilyCompressionMap(Configuration)}. Tests that the
-   * compression map is correctly serialized into and deserialized from configuration n
+   * compression map is correctly serialized into and deserialized from configuration
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
@@ -839,7 +835,7 @@ public class TestCellBasedHFileOutputFormat2 {
   /**
    * Test for {@link HFileOutputFormat2#configureBloomType(HTableDescriptor, Configuration)} and
    * {@link HFileOutputFormat2#createFamilyBloomTypeMap(Configuration)}. Tests that the compression
-   * map is correctly serialized into and deserialized from configuration n
+   * map is correctly serialized into and deserialized from configuration
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
@@ -899,7 +895,7 @@ public class TestCellBasedHFileOutputFormat2 {
   /**
    * Test for {@link HFileOutputFormat2#configureBlockSize(HTableDescriptor, Configuration)} and
    * {@link HFileOutputFormat2#createFamilyBlockSizeMap(Configuration)}. Tests that the compression
-   * map is correctly serialized into and deserialized from configuration n
+   * map is correctly serialized into and deserialized from configuration
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
@@ -962,7 +958,7 @@ public class TestCellBasedHFileOutputFormat2 {
   /**
    * Test for {@link HFileOutputFormat2#configureDataBlockEncoding(HTableDescriptor, Configuration)}
    * and {@link HFileOutputFormat2#createFamilyDataBlockEncodingMap(Configuration)}. Tests that the
-   * compression map is correctly serialized into and deserialized from configuration n
+   * compression map is correctly serialized into and deserialized from configuration
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
