@@ -20,6 +20,8 @@ package org.apache.hadoop.hbase.snapshot;
 import static org.junit.Assert.assertTrue;
 
 import java.io.IOException;
+import java.util.HashSet;
+import java.util.Set;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.LocalFileSystem;
 import org.apache.hadoop.fs.Path;
@@ -28,11 +30,13 @@ import org.apache.hadoop.hbase.HBaseCommonTestingUtility;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.master.snapshot.SnapshotManager;
+import org.apache.hadoop.hbase.regionserver.StoreFileInfo;
 import org.apache.hadoop.hbase.snapshot.SnapshotTestingUtils.SnapshotMock;
 import org.apache.hadoop.hbase.testclassification.MapReduceTests;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
+import org.apache.hadoop.hbase.util.Pair;
 import org.junit.Before;
 import org.junit.ClassRule;
 import org.junit.Test;
@@ -104,12 +108,25 @@ public class TestExportSnapshotV1NoCluster {
     Path[] r1Files = builder.addRegion();
     Path[] r2Files = builder.addRegion();
     builder.commit();
-    int snapshotFilesCount = r1Files.length + r2Files.length;
+    // remove references, only keep data files
+    Set<String> dataFiles = new HashSet<>();
+    for (Path[] files : new Path[][] { r1Files, r2Files }) {
+      for (Path file : files) {
+        if (StoreFileInfo.isReference(file.getName())) {
+          Pair<String, String> referredToRegionAndFile =
+            StoreFileInfo.getReferredToRegionAndFile(file.getName());
+          dataFiles.add(referredToRegionAndFile.getSecond());
+        } else {
+          dataFiles.add(file.getName());
+        }
+      }
+    }
+    int snapshotFilesCount = dataFiles.size();
     byte[] snapshotName = Bytes.toBytes(builder.getSnapshotDescription().getName());
     TableName tableName = builder.getTableDescriptor().getTableName();
     TestExportSnapshot.testExportFileSystemState(testUtil.getConfiguration(), tableName,
       snapshotName, snapshotName, snapshotFilesCount, testDir,
-      getDestinationDir(fs, testUtil, testDir), false, false, null, true);
+      getDestinationDir(fs, testUtil, testDir), false, false, null, true, false);
   }
 
   static Path getDestinationDir(FileSystem fs, HBaseCommonTestingUtility hctu, Path testDir)
