@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -36,8 +36,8 @@ public class ProcedureWALPerformanceEvaluation
   // Command line options and defaults.
   public static int DEFAULT_NUM_WALS = 0;
   public static Option NUM_WALS_OPTION = new Option("wals", true,
-    "Number of WALs to write. If -ve or 0, uses " + WALProcedureStore.ROLL_THRESHOLD_CONF_KEY +
-      " conf to roll the logs. Default: " + DEFAULT_NUM_WALS);
+    "Number of WALs to write. If -ve or 0, uses " + WALProcedureStore.ROLL_THRESHOLD_CONF_KEY
+      + " conf to roll the logs. Default: " + DEFAULT_NUM_WALS);
 
   private long numProcsPerWal = Long.MAX_VALUE; // never roll wall based on this value.
   private int numWals;
