@@ -19,6 +19,8 @@ package org.apache.hadoop.hbase.replication;
 
 import static java.util.stream.Collectors.toList;
 import static java.util.stream.Collectors.toSet;
+import static org.hamcrest.CoreMatchers.instanceOf;
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -41,6 +43,7 @@ import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.replication.ReplicationPeerConfigUtil;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.testclassification.ReplicationTests;
+import org.apache.zookeeper.KeeperException;
 import org.junit.After;
 import org.junit.AfterClass;
 import org.junit.BeforeClass;
@@ -275,4 +278,22 @@ public class TestZKReplicationPeerStorage {
       .updateReplicationBasePeerConfigs(conf, existingReplicationPeerConfig);
     assertNull(updatedReplicationPeerConfig.getConfiguration().get(customPeerConfigKey));
   }
+
+  @Test
+  public void testPeerNameControl() throws Exception {
+    String clusterKey = "key";
+    STORAGE.addPeer("6", ReplicationPeerConfig.newBuilder().setClusterKey(clusterKey).build(),
+      true);
+
+    try {
+      STORAGE.addPeer("6", ReplicationPeerConfig.newBuilder().setClusterKey(clusterKey).build(),
+        true);
+      fail();
+    } catch (ReplicationException e) {
+      assertThat(e.getCause(), instanceOf(KeeperException.NodeExistsException.class));
+    } finally {
+      // clean up
+      STORAGE.removePeer("6");
+    }
+  }
 }
