@@ -59,6 +59,6 @@ public class ProtobufMessageBodyProducer implements MessageBodyWriter<ProtobufMe
   public void writeTo(ProtobufMessageHandler m, Class<?> type, Type genericType,
     Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, Object> httpHeaders,
     OutputStream entityStream) throws IOException, WebApplicationException {
-    entityStream.write(m.createProtobufOutput());
+    m.writeProtobufOutput(entityStream);
   }
 }
