@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -15,14 +15,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.rsgroup;
 
-
 import java.io.IOException;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
-
 import org.apache.hadoop.hbase.NamespaceDescriptor;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.net.Address;
@@ -30,9 +28,8 @@ import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.yetus.audience.InterfaceAudience;
 
 /**
- * Interface used to manage RSGroupInfo storage. An implementation
- * has the option to support offline mode.
- * See {@link RSGroupBasedLoadBalancer}
+ * Interface used to manage RSGroupInfo storage. An implementation has the option to support offline
+ * mode. See {@link RSGroupBasedLoadBalancer}
  */
 @InterfaceAudience.Private
 public interface RSGroupInfoManager {
@@ -40,13 +37,13 @@ public interface RSGroupInfoManager {
   String REASSIGN_WAIT_INTERVAL_KEY = "hbase.rsgroup.reassign.wait";
   long DEFAULT_REASSIGN_WAIT_INTERVAL = 30 * 1000L;
 
-  //Assigned before user tables
+  // Assigned before user tables
   TableName RSGROUP_TABLE_NAME =
-      TableName.valueOf(NamespaceDescriptor.SYSTEM_NAMESPACE_NAME_STR, "rsgroup");
+    TableName.valueOf(NamespaceDescriptor.SYSTEM_NAMESPACE_NAME_STR, "rsgroup");
   String rsGroupZNode = "rsgroup";
   byte[] META_FAMILY_BYTES = Bytes.toBytes("m");
   byte[] META_QUALIFIER_BYTES = Bytes.toBytes("i");
-  byte[] ROW_KEY = {0};
+  byte[] ROW_KEY = { 0 };
 
   void start();
 
@@ -62,13 +59,13 @@ public interface RSGroupInfoManager {
 
   /**
    * Move servers to a new group.
-   * @param servers list of servers, must be part of the same group
+   * @param servers  list of servers, must be part of the same group
    * @param srcGroup groupName being moved from
    * @param dstGroup groupName being moved to
    * @return Set of servers moved (May be a subset of {@code servers}).
    */
   Set<Address> moveServers(Set<Address> servers, String srcGroup, String dstGroup)
-      throws IOException;
+    throws IOException;
 
   /**
    * Gets the group info of server.
@@ -87,9 +84,8 @@ public interface RSGroupInfoManager {
 
   /**
    * Set the group membership of a set of tables
-   *
    * @param tableNames set of tables to move
-   * @param groupName name of group of tables to move to
+   * @param groupName  name of group of tables to move to
    */
   void moveTables(Set<TableName> tableNames, String groupName) throws IOException;
 
@@ -105,20 +101,19 @@ public interface RSGroupInfoManager {
 
   /**
    * Whether the manager is able to fully return group metadata
-   *
    * @return whether the manager is in online mode
    */
   boolean isOnline();
 
   /**
    * Move servers and tables to a new group.
-   * @param servers list of servers, must be part of the same group
-   * @param tables set of tables to move
+   * @param servers  list of servers, must be part of the same group
+   * @param tables   set of tables to move
    * @param srcGroup groupName being moved from
    * @param dstGroup groupName being moved to
    */
-  void moveServersAndTables(Set<Address> servers, Set<TableName> tables,
-      String srcGroup, String dstGroup) throws IOException;
+  void moveServersAndTables(Set<Address> servers, Set<TableName> tables, String srcGroup,
+    String dstGroup) throws IOException;
 
   /**
    * Remove decommissioned servers from rsgroup
@@ -139,4 +134,12 @@ public interface RSGroupInfoManager {
    * @return {@link RSGroupInfo} which table should belong to
    */
   RSGroupInfo determineRSGroupInfoForTable(TableName tableName) throws IOException;
+
+  /**
+   * Update RSGroup configuration
+   * @param groupName     the group name
+   * @param configuration new configuration of the group name to be set
+   * @throws IOException if a remote or network exception occurs
+   */
+  void updateRSGroupConfig(String groupName, Map<String, String> configuration) throws IOException;
 }
