@@ -17,6 +17,8 @@
  */
 package org.apache.hadoop.hbase.fs;
 
+import static org.apache.hadoop.hbase.util.LocatedBlockHelper.getLocatedBlockLocations;
+
 import edu.umd.cs.findbugs.annotations.Nullable;
 import java.io.Closeable;
 import java.io.IOException;
@@ -336,12 +338,17 @@ public class HFileSystem extends FilterFileSystem {
       nf.set(dfsc, cp1);
       LOG.info("Added intercepting call to namenode#getBlockLocations so can do block reordering"
         + " using class " + lrb.getClass().getName());
-    } catch (NoSuchFieldException e) {
-      LOG.warn("Can't modify the DFSClient#namenode field to add the location reorder.", e);
-      return false;
-    } catch (IllegalAccessException e) {
+    } catch (NoSuchFieldException | IllegalAccessException e) {
       LOG.warn("Can't modify the DFSClient#namenode field to add the location reorder.", e);
       return false;
+    } catch (Exception e) {
+      // InaccessibleObjectException was added in Java 9, need this for Java 8
+      if (e.getClass().getSimpleName().equals("InaccessibleObjectException")) {
+        LOG.warn("Can't modify the DFSClient#namenode field to add the location reorder.", e);
+        return false;
+      } else {
+        throw e;
+      }
     }
 
     return true;
@@ -425,7 +432,7 @@ public class HFileSystem extends FilterFileSystem {
 
       // Just check for all blocks
       for (LocatedBlock lb : lbs.getLocatedBlocks()) {
-        DatanodeInfo[] dnis = lb.getLocations();
+        DatanodeInfo[] dnis = getLocatedBlockLocations(lb);
         if (dnis != null && dnis.length > 1) {
           boolean found = false;
           for (int i = 0; i < dnis.length - 1 && !found; i++) {
@@ -451,13 +458,6 @@ public class HFileSystem extends FilterFileSystem {
     return new HFileSystem(conf, true);
   }
 
-  /**
-   * Wrap a LocalFileSystem within a HFileSystem.
-   */
-  static public FileSystem getLocalFs(Configuration conf) throws IOException {
-    return new HFileSystem(FileSystem.getLocal(conf));
-  }
-
   /**
    * The org.apache.hadoop.fs.FilterFileSystem does not yet support createNonRecursive. This is a
    * hadoop bug and when it is fixed in Hadoop, this definition will go away.
