@@ -37,7 +37,6 @@ import org.apache.hadoop.hbase.CellComparator;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.io.FSDataInputStreamWrapper;
 import org.apache.hadoop.hbase.io.MetricsIO;
-import org.apache.hadoop.hbase.io.MetricsIOWrapperImpl;
 import org.apache.hadoop.hbase.io.compress.Compression;
 import org.apache.hadoop.hbase.io.encoding.DataBlockEncoding;
 import org.apache.hadoop.hbase.io.hfile.ReaderContext.ReaderType;
@@ -168,9 +167,6 @@ public final class HFile {
   // For tests. Gets incremented when we read a block whether from HDFS or from Cache.
   public static final LongAdder DATABLOCK_READ_COUNT = new LongAdder();
 
-  /** Static instance for the metrics so that HFileReaders access the same instance */
-  static final MetricsIO metrics = new MetricsIO(new MetricsIOWrapperImpl());
-
   /**
    * Shutdown constructor.
    */
@@ -193,14 +189,14 @@ public final class HFile {
 
   public static final void updateReadLatency(long latencyMillis, boolean pread) {
     if (pread) {
-      metrics.updateFsPreadTime(latencyMillis);
+      MetricsIO.getInstance().updateFsPreadTime(latencyMillis);
     } else {
-      metrics.updateFsReadTime(latencyMillis);
+      MetricsIO.getInstance().updateFsReadTime(latencyMillis);
     }
   }
 
   public static final void updateWriteLatency(long latencyMillis) {
-    metrics.updateFsWriteTime(latencyMillis);
+    MetricsIO.getInstance().updateFsWriteTime(latencyMillis);
   }
 
   /** API required to write an {@link HFile} */
@@ -373,6 +369,10 @@ public final class HFile {
     HFileBlock readBlock(long offset, long onDiskBlockSize, boolean cacheBlock, final boolean pread,
       final boolean isCompaction, final boolean updateCacheMetrics, BlockType expectedBlockType,
       DataBlockEncoding expectedDataBlockEncoding) throws IOException;
+
+    HFileBlock readBlock(long offset, long onDiskBlockSize, boolean cacheBlock, final boolean pread,
+      final boolean isCompaction, final boolean updateCacheMetrics, BlockType expectedBlockType,
+      DataBlockEncoding expectedDataBlockEncoding, boolean cacheOnly) throws IOException;
   }
 
   /** An interface used by clients to open and iterate an {@link HFile}. */
@@ -452,6 +452,8 @@ public final class HFile {
 
     boolean prefetchComplete();
 
+    boolean prefetchStarted();
+
     /**
      * To close the stream's socket. Note: This can be concurrently called from multiple threads and
      * implementation should take care of thread safety.
