@@ -191,7 +191,7 @@ public class BucketCache implements BlockCache, HeapSize {
    */
   transient final IdReadWriteLock<Long> offsetLock = new IdReadWriteLock<>(ReferenceType.SOFT);
 
-  private final NavigableSet<BlockCacheKey> blocksByHFile = new ConcurrentSkipListSet<>((a, b) -> {
+  final NavigableSet<BlockCacheKey> blocksByHFile = new ConcurrentSkipListSet<>((a, b) -> {
     int nameComparison = a.getHfileName().compareTo(b.getHfileName());
     if (nameComparison != 0) {
       return nameComparison;
@@ -255,6 +255,8 @@ public class BucketCache implements BlockCache, HeapSize {
   public BucketCache(String ioEngineName, long capacity, int blockSize, int[] bucketSizes,
     int writerThreadNum, int writerQLen, String persistencePath, int ioErrorsTolerationDuration,
     Configuration conf) throws IOException {
+    Preconditions.checkArgument(blockSize > 0,
+      "BucketCache capacity is set to " + blockSize + ", can not be less than 0");
     this.algorithm = conf.get(FILE_VERIFY_ALGORITHM, DEFAULT_FILE_VERIFY_ALGORITHM);
     this.ioEngine = getIOEngineFromName(ioEngineName, capacity, persistencePath);
     this.writerThreads = new WriterThread[writerThreadNum];
@@ -1000,6 +1002,7 @@ public class BucketCache implements BlockCache, HeapSize {
    */
   protected void putIntoBackingMap(BlockCacheKey key, BucketEntry bucketEntry) {
     BucketEntry previousEntry = backingMap.put(key, bucketEntry);
+    blocksByHFile.add(key);
     if (previousEntry != null && previousEntry != bucketEntry) {
       previousEntry.withWriteLock(offsetLock, () -> {
         blockEvicted(key, previousEntry, false, false);
@@ -1025,13 +1028,19 @@ public class BucketCache implements BlockCache, HeapSize {
         final HFileContext fileContext = ((HFileBlock) re.getData()).getHFileContext();
         final String columnFamily = Bytes.toString(fileContext.getColumnFamily());
         final String tableName = Bytes.toString(fileContext.getTableName());
-        if (tableName != null && columnFamily != null) {
+        if (tableName != null) {
           sb.append(" Table: ");
           sb.append(tableName);
+        }
+        if (columnFamily != null) {
           sb.append(" CF: ");
           sb.append(columnFamily);
-          sb.append(" HFile: ");
+        }
+        sb.append(" HFile: ");
+        if (fileContext.getHFileName() != null) {
           sb.append(fileContext.getHFileName());
+        } else {
+          sb.append(re.getKey());
         }
       } else {
         sb.append(" HFile: ");
@@ -1074,10 +1083,6 @@ public class BucketCache implements BlockCache, HeapSize {
           index++;
           continue;
         }
-        BlockCacheKey cacheKey = re.getKey();
-        if (ramCache.containsKey(cacheKey)) {
-          blocksByHFile.add(cacheKey);
-        }
         // Reset the position for reuse.
         // It should be guaranteed that the data in the metaBuff has been transferred to the
         // ioEngine safely. Otherwise, this reuse is problematic. Fortunately, the data is already
@@ -1333,6 +1338,7 @@ public class BucketCache implements BlockCache, HeapSize {
     if (!ioEngine.isPersistent() || persistencePath == null) {
       // If persistent ioengine and a path, we will serialize out the backingMap.
       this.backingMap.clear();
+      this.blocksByHFile.clear();
     }
   }
 
