@@ -218,9 +218,7 @@ public class NettyRpcServer extends RpcServer {
 
   @Override
   public int getNumOpenConnections() {
-    int channelsCount = allChannels.size();
-    // allChannels also contains the server channel, so exclude that from the count.
-    return channelsCount > 0 ? channelsCount - 1 : channelsCount;
+    return allChannels.size();
   }
 
   @Override
