@@ -17,6 +17,9 @@
  */
 package org.apache.hadoop.hbase.master;
 
+import io.opentelemetry.api.trace.Span;
+import io.opentelemetry.api.trace.StatusCode;
+import io.opentelemetry.context.Scope;
 import java.io.File;
 import java.io.IOException;
 import java.util.List;
@@ -37,7 +40,6 @@ import org.apache.hadoop.hbase.zookeeper.MiniZooKeeperCluster;
 import org.apache.hadoop.hbase.zookeeper.ZKAuthentication;
 import org.apache.hadoop.metrics2.lib.DefaultMetricsSystem;
 import org.apache.yetus.audience.InterfaceAudience;
-import org.apache.zookeeper.KeeperException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -162,9 +164,8 @@ public class HMasterCommandLine extends ServerCommandLine {
 
   private int startMaster() {
     Configuration conf = getConf();
-    TraceUtil.initTracer(conf);
-
-    try {
+    final Span span = TraceUtil.createSpan("HMasterCommandLine.startMaster");
+    try (Scope ignored = span.makeCurrent()) {
       // If 'local', defer to LocalHBaseCluster instance. Starts master
       // and regionserver both in the one JVM.
       if (LocalHBaseCluster.isLocal(conf)) {
@@ -253,9 +254,13 @@ public class HMasterCommandLine extends ServerCommandLine {
         master.join();
         if (master.isAborted()) throw new RuntimeException("HMaster Aborted");
       }
+      span.setStatus(StatusCode.OK);
     } catch (Throwable t) {
+      TraceUtil.setError(span, t);
       LOG.error("Master exiting", t);
       return 1;
+    } finally {
+      span.end();
     }
     return 0;
   }
@@ -313,8 +318,7 @@ public class HMasterCommandLine extends ServerCommandLine {
   public static class LocalHMaster extends HMaster {
     private MiniZooKeeperCluster zkcluster = null;
 
-    public LocalHMaster(Configuration conf)
-      throws IOException, KeeperException, InterruptedException {
+    public LocalHMaster(Configuration conf) throws IOException {
       super(conf);
     }
 
