@@ -819,7 +819,7 @@ public class MasterCoprocessorHost
   /**
    * Invoked just before calling the split region procedure
    * @param tableName the table where the region belongs to
-   * @param splitRow  the split point n
+   * @param splitRow  the split point
    */
   public void preSplitRegion(final TableName tableName, final byte[] splitRow) throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
@@ -834,7 +834,7 @@ public class MasterCoprocessorHost
    * Invoked just before a split
    * @param tableName the table where the region belongs to
    * @param splitRow  the split point
-   * @param user      the user n
+   * @param user      the user
    */
   public void preSplitRegionAction(final TableName tableName, final byte[] splitRow,
     final User user) throws IOException {
@@ -850,7 +850,7 @@ public class MasterCoprocessorHost
    * Invoked just after a split
    * @param regionInfoA the new left-hand daughter region
    * @param regionInfoB the new right-hand daughter region
-   * @param user        the user n
+   * @param user        the user
    */
   public void postCompletedSplitRegionAction(final RegionInfo regionInfoA,
     final RegionInfo regionInfoB, final User user) throws IOException {
@@ -863,8 +863,8 @@ public class MasterCoprocessorHost
   }
 
   /**
-   * This will be called before update META step as part of split table region procedure. nn
-   * * @param user the user n
+   * This will be called before update META step as part of split table region procedure.
+   * @param user the user
    */
   public void preSplitBeforeMETAAction(final byte[] splitKey, final List<Mutation> metaEntries,
     final User user) throws IOException {
@@ -878,7 +878,7 @@ public class MasterCoprocessorHost
 
   /**
    * This will be called after update META step as part of split table region procedure.
-   * @param user the user n
+   * @param user the user
    */
   public void preSplitAfterMETAAction(final User user) throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation(user) {
@@ -891,7 +891,7 @@ public class MasterCoprocessorHost
 
   /**
    * Invoked just after the rollback of a failed split
-   * @param user the user n
+   * @param user the user
    */
   public void postRollBackSplitRegionAction(final User user) throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation(user) {
@@ -905,7 +905,7 @@ public class MasterCoprocessorHost
   /**
    * Invoked just before a merge
    * @param regionsToMerge the regions to merge
-   * @param user           the user n
+   * @param user           the user
    */
   public void preMergeRegionsAction(final RegionInfo[] regionsToMerge, final User user)
     throws IOException {
@@ -921,7 +921,7 @@ public class MasterCoprocessorHost
    * Invoked after completing merge regions operation
    * @param regionsToMerge the regions to merge
    * @param mergedRegion   the new merged region
-   * @param user           the user n
+   * @param user           the user
    */
   public void postCompletedMergeRegionsAction(final RegionInfo[] regionsToMerge,
     final RegionInfo mergedRegion, final User user) throws IOException {
@@ -937,7 +937,7 @@ public class MasterCoprocessorHost
    * Invoked before merge regions operation writes the new region to hbase:meta
    * @param regionsToMerge the regions to merge
    * @param metaEntries    the meta entry
-   * @param user           the user n
+   * @param user           the user
    */
   public void preMergeRegionsCommit(final RegionInfo[] regionsToMerge,
     final @MetaMutationAnnotation List<Mutation> metaEntries, final User user) throws IOException {
@@ -953,7 +953,7 @@ public class MasterCoprocessorHost
    * Invoked after merge regions operation writes the new region to hbase:meta
    * @param regionsToMerge the regions to merge
    * @param mergedRegion   the new merged region
-   * @param user           the user n
+   * @param user           the user
    */
   public void postMergeRegionsCommit(final RegionInfo[] regionsToMerge,
     final RegionInfo mergedRegion, final User user) throws IOException {
@@ -968,7 +968,7 @@ public class MasterCoprocessorHost
   /**
    * Invoked after rollback merge regions operation
    * @param regionsToMerge the regions to merge
-   * @param user           the user n
+   * @param user           the user
    */
   public void postRollBackMergeRegionsAction(final RegionInfo[] regionsToMerge, final User user)
     throws IOException {
@@ -1514,6 +1514,78 @@ public class MasterCoprocessorHost
     });
   }
 
+  public void preGetRSGroupInfo(final String groupName) throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.preGetRSGroupInfo(this, groupName);
+      }
+    });
+  }
+
+  public void postGetRSGroupInfo(final String groupName) throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.postGetRSGroupInfo(this, groupName);
+      }
+    });
+  }
+
+  public void preGetRSGroupInfoOfTable(final TableName tableName) throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.preGetRSGroupInfoOfTable(this, tableName);
+      }
+    });
+  }
+
+  public void postGetRSGroupInfoOfTable(final TableName tableName) throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.postGetRSGroupInfoOfTable(this, tableName);
+      }
+    });
+  }
+
+  public void preListRSGroups() throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.preListRSGroups(this);
+      }
+    });
+  }
+
+  public void postListRSGroups() throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.postListRSGroups(this);
+      }
+    });
+  }
+
+  public void preGetRSGroupInfoOfServer(final Address server) throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.preGetRSGroupInfoOfServer(this, server);
+      }
+    });
+  }
+
+  public void postGetRSGroupInfoOfServer(final Address server) throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.postGetRSGroupInfoOfServer(this, server);
+      }
+    });
+  }
+
   public void preUpdateRSGroupConfig(final String groupName,
     final Map<String, String> configuration) throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
