@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -19,73 +19,87 @@ package org.apache.hadoop.hbase.master.cleaner;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Comparator;
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hbase.Stoppable;
-import org.apache.hadoop.hbase.classification.InterfaceAudience;
 import org.apache.hadoop.hbase.conf.ConfigurationObserver;
 import org.apache.hadoop.hbase.io.HFileLink;
+import org.apache.hadoop.hbase.master.region.MasterRegionFactory;
 import org.apache.hadoop.hbase.regionserver.StoreFileInfo;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.StealJobQueue;
+import org.apache.yetus.audience.InterfaceAudience;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
- * This Chore, every time it runs, will clear the HFiles in the hfile archive
- * folder that are deletable for each HFile cleaner in the chain.
+ * This Chore, every time it runs, will clear the HFiles in the hfile archive folder that are
+ * deletable for each HFile cleaner in the chain.
  */
 @InterfaceAudience.Private
-public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> implements
-    ConfigurationObserver {
+public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate>
+  implements ConfigurationObserver {
 
   public static final String MASTER_HFILE_CLEANER_PLUGINS = "hbase.master.hfilecleaner.plugins";
 
   public HFileCleaner(final int period, final Stoppable stopper, Configuration conf, FileSystem fs,
-      Path directory, DirScanPool pool) {
+    Path directory, DirScanPool pool) {
     this(period, stopper, conf, fs, directory, pool, null);
   }
 
   // Configuration key for large/small throttle point
   public final static String HFILE_DELETE_THROTTLE_THRESHOLD =
-      "hbase.regionserver.thread.hfilecleaner.throttle";
+    "hbase.regionserver.thread.hfilecleaner.throttle";
   public final static int DEFAULT_HFILE_DELETE_THROTTLE_THRESHOLD = 64 * 1024 * 1024;// 64M
 
   // Configuration key for large queue initial size
   public final static String LARGE_HFILE_QUEUE_INIT_SIZE =
-      "hbase.regionserver.hfilecleaner.large.queue.size";
+    "hbase.regionserver.hfilecleaner.large.queue.size";
   public final static int DEFAULT_LARGE_HFILE_QUEUE_INIT_SIZE = 10240;
 
   // Configuration key for small queue initial size
   public final static String SMALL_HFILE_QUEUE_INIT_SIZE =
-      "hbase.regionserver.hfilecleaner.small.queue.size";
+    "hbase.regionserver.hfilecleaner.small.queue.size";
   public final static int DEFAULT_SMALL_HFILE_QUEUE_INIT_SIZE = 10240;
 
   // Configuration key for large file delete thread number
   public final static String LARGE_HFILE_DELETE_THREAD_NUMBER =
-      "hbase.regionserver.hfilecleaner.large.thread.count";
+    "hbase.regionserver.hfilecleaner.large.thread.count";
   public final static int DEFAULT_LARGE_HFILE_DELETE_THREAD_NUMBER = 1;
 
   // Configuration key for small file delete thread number
   public final static String SMALL_HFILE_DELETE_THREAD_NUMBER =
-      "hbase.regionserver.hfilecleaner.small.thread.count";
+    "hbase.regionserver.hfilecleaner.small.thread.count";
   public final static int DEFAULT_SMALL_HFILE_DELETE_THREAD_NUMBER = 1;
 
   public static final String HFILE_DELETE_THREAD_TIMEOUT_MSEC =
-      "hbase.regionserver.hfilecleaner.thread.timeout.msec";
+    "hbase.regionserver.hfilecleaner.thread.timeout.msec";
   static final long DEFAULT_HFILE_DELETE_THREAD_TIMEOUT_MSEC = 60 * 1000L;
 
   public static final String HFILE_DELETE_THREAD_CHECK_INTERVAL_MSEC =
-      "hbase.regionserver.hfilecleaner.thread.check.interval.msec";
+    "hbase.regionserver.hfilecleaner.thread.check.interval.msec";
   static final long DEFAULT_HFILE_DELETE_THREAD_CHECK_INTERVAL_MSEC = 1000L;
 
-  private static final Log LOG = LogFactory.getLog(HFileCleaner.class);
+  /**
+   * The custom paths for hfile cleaner, subdirectories of archive, e.g.
+   * data/default/testTable1,data/default/testTable2
+   */
+  public static final String HFILE_CLEANER_CUSTOM_PATHS = "hbase.master.hfile.cleaner.custom.paths";
+
+  /** Configure hfile cleaner classes for the custom paths */
+  public static final String HFILE_CLEANER_CUSTOM_PATHS_PLUGINS =
+    "hbase.master.hfilecleaner.custom.paths.plugins";
+  public static final String CUSTOM_POOL_SIZE = "hbase.cleaner.custom.hfiles.pool.size";
+
+  private static final Logger LOG = LoggerFactory.getLogger(HFileCleaner.class);
 
   StealJobQueue<HFileDeleteTask> largeFileQueue;
   BlockingQueue<HFileDeleteTask> smallFileQueue;
@@ -97,49 +111,72 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
   private long cleanerThreadTimeoutMsec;
   private long cleanerThreadCheckIntervalMsec;
   private List<Thread> threads = new ArrayList<Thread>();
-  private boolean running;
+  private volatile boolean running;
 
   private AtomicLong deletedLargeFiles = new AtomicLong();
   private AtomicLong deletedSmallFiles = new AtomicLong();
 
   /**
-   * @param period the period of time to sleep between each run
-   * @param stopper the stopper
-   * @param conf configuration to use
-   * @param fs handle to the FS
+   * @param period    the period of time to sleep between each run
+   * @param stopper   the stopper
+   * @param conf      configuration to use
+   * @param fs        handle to the FS
    * @param directory directory to be cleaned
-   * @param params params could be used in subclass of BaseHFileCleanerDelegate
+   * @param pool      the thread pool used to scan directories
+   * @param params    params could be used in subclass of BaseHFileCleanerDelegate
    */
   public HFileCleaner(final int period, final Stoppable stopper, Configuration conf, FileSystem fs,
-                      Path directory, DirScanPool pool, Map<String, Object> params) {
-    super("HFileCleaner", period, stopper, conf, fs,
-      directory, MASTER_HFILE_CLEANER_PLUGINS, pool, params);
+    Path directory, DirScanPool pool, Map<String, Object> params) {
+    this("HFileCleaner", period, stopper, conf, fs, directory, MASTER_HFILE_CLEANER_PLUGINS, pool,
+      params, null);
+  }
+
+  public HFileCleaner(final int period, final Stoppable stopper, Configuration conf, FileSystem fs,
+    Path directory, DirScanPool pool, Map<String, Object> params, List<Path> excludePaths) {
+    this("HFileCleaner", period, stopper, conf, fs, directory, MASTER_HFILE_CLEANER_PLUGINS, pool,
+      params, excludePaths);
+  }
+
+  /**
+   * For creating customized HFileCleaner.
+   * @param name      name of the chore being run
+   * @param period    the period of time to sleep between each run
+   * @param stopper   the stopper
+   * @param conf      configuration to use
+   * @param fs        handle to the FS
+   * @param directory directory to be cleaned
+   * @param confKey   configuration key for the classes to instantiate
+   * @param pool      the thread pool used to scan directories
+   * @param params    params could be used in subclass of BaseHFileCleanerDelegate
+   */
+  public HFileCleaner(String name, int period, Stoppable stopper, Configuration conf, FileSystem fs,
+    Path directory, String confKey, DirScanPool pool, Map<String, Object> params,
+    List<Path> excludePaths) {
+    super(name, period, stopper, conf, fs, directory, confKey, pool, params, excludePaths);
     throttlePoint =
-        conf.getInt(HFILE_DELETE_THROTTLE_THRESHOLD, DEFAULT_HFILE_DELETE_THROTTLE_THRESHOLD);
+      conf.getInt(HFILE_DELETE_THROTTLE_THRESHOLD, DEFAULT_HFILE_DELETE_THROTTLE_THRESHOLD);
     largeQueueInitSize =
-        conf.getInt(LARGE_HFILE_QUEUE_INIT_SIZE, DEFAULT_LARGE_HFILE_QUEUE_INIT_SIZE);
+      conf.getInt(LARGE_HFILE_QUEUE_INIT_SIZE, DEFAULT_LARGE_HFILE_QUEUE_INIT_SIZE);
     smallQueueInitSize =
-        conf.getInt(SMALL_HFILE_QUEUE_INIT_SIZE, DEFAULT_SMALL_HFILE_QUEUE_INIT_SIZE);
-    largeFileQueue = new StealJobQueue<>(largeQueueInitSize, smallQueueInitSize);
+      conf.getInt(SMALL_HFILE_QUEUE_INIT_SIZE, DEFAULT_SMALL_HFILE_QUEUE_INIT_SIZE);
+    largeFileQueue = new StealJobQueue<>(largeQueueInitSize, smallQueueInitSize, COMPARATOR);
     smallFileQueue = largeFileQueue.getStealFromQueue();
     largeFileDeleteThreadNumber =
-        conf.getInt(LARGE_HFILE_DELETE_THREAD_NUMBER, DEFAULT_LARGE_HFILE_DELETE_THREAD_NUMBER);
+      conf.getInt(LARGE_HFILE_DELETE_THREAD_NUMBER, DEFAULT_LARGE_HFILE_DELETE_THREAD_NUMBER);
     smallFileDeleteThreadNumber =
-        conf.getInt(SMALL_HFILE_DELETE_THREAD_NUMBER, DEFAULT_SMALL_HFILE_DELETE_THREAD_NUMBER);
+      conf.getInt(SMALL_HFILE_DELETE_THREAD_NUMBER, DEFAULT_SMALL_HFILE_DELETE_THREAD_NUMBER);
     cleanerThreadTimeoutMsec =
-        conf.getLong(HFILE_DELETE_THREAD_TIMEOUT_MSEC, DEFAULT_HFILE_DELETE_THREAD_TIMEOUT_MSEC);
-    cleanerThreadCheckIntervalMsec =
-        conf.getLong(HFILE_DELETE_THREAD_CHECK_INTERVAL_MSEC,
-            DEFAULT_HFILE_DELETE_THREAD_CHECK_INTERVAL_MSEC);
+      conf.getLong(HFILE_DELETE_THREAD_TIMEOUT_MSEC, DEFAULT_HFILE_DELETE_THREAD_TIMEOUT_MSEC);
+    cleanerThreadCheckIntervalMsec = conf.getLong(HFILE_DELETE_THREAD_CHECK_INTERVAL_MSEC,
+      DEFAULT_HFILE_DELETE_THREAD_CHECK_INTERVAL_MSEC);
     startHFileDeleteThreads();
   }
 
   @Override
   protected boolean validate(Path file) {
-    if (HFileLink.isBackReferencesDir(file) || HFileLink.isBackReferencesDir(file.getParent())) {
-      return true;
-    }
-    return StoreFileInfo.validateStoreFileName(file.getName());
+    return HFileLink.isBackReferencesDir(file) || HFileLink.isBackReferencesDir(file.getParent())
+      || StoreFileInfo.validateStoreFileName(file.getName())
+      || file.getName().endsWith(MasterRegionFactory.ARCHIVED_HFILE_SUFFIX);
   }
 
   /**
@@ -184,17 +221,13 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
     if (task.fileLength >= this.throttlePoint) {
       if (!this.largeFileQueue.offer(task)) {
         // should never arrive here as long as we use PriorityQueue
-        if (LOG.isTraceEnabled()) {
-          LOG.trace("Large file deletion queue is full");
-        }
+        LOG.trace("Large file deletion queue is full");
         return false;
       }
     } else {
       if (!this.smallFileQueue.offer(task)) {
         // should never arrive here as long as we use PriorityQueue
-        if (LOG.isTraceEnabled()) {
-          LOG.trace("Small file deletion queue is full");
-        }
+        LOG.trace("Small file deletion queue is full");
         return false;
       }
     }
@@ -202,7 +235,7 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
   }
 
   @Override
-  public void cleanup() {
+  public synchronized void cleanup() {
     super.cleanup();
     stopHFileDeleteThreads();
   }
@@ -222,9 +255,9 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
         }
       };
       large.setDaemon(true);
-      large.setName(n + "-HFileCleaner.large." + i + "-" + System.currentTimeMillis());
+      large.setName(n + "-HFileCleaner.large." + i + "-" + EnvironmentEdgeManager.currentTime());
       large.start();
-      LOG.debug("Starting hfile cleaner for large files: " + large.getName());
+      LOG.debug("Starting for large file={}", large);
       threads.add(large);
     }
 
@@ -237,9 +270,9 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
         }
       };
       small.setDaemon(true);
-      small.setName(n + "-HFileCleaner.small." + i + "-" + System.currentTimeMillis());
+      small.setName(n + "-HFileCleaner.small." + i + "-" + EnvironmentEdgeManager.currentTime());
       small.start();
-      LOG.debug("Starting hfile cleaner for small files: " + small.getName());
+      LOG.debug("Starting for small files={}", small);
       threads.add(small);
     }
   }
@@ -251,20 +284,16 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
         try {
           task = queue.take();
         } catch (InterruptedException e) {
-          if (LOG.isDebugEnabled()) {
-            LOG.debug("Interrupted while trying to take a task from queue", e);
-          }
+          LOG.trace("Interrupted while trying to take a task from queue", e);
           break;
         }
         if (task != null) {
-          if (LOG.isDebugEnabled()) {
-            LOG.debug("Removing: " + task.filePath + " from archive");
-          }
+          LOG.trace("Removing {}", task.filePath);
           boolean succeed;
           try {
             succeed = this.fs.delete(task.filePath, false);
           } catch (IOException e) {
-            LOG.warn("Failed to delete file " + task.filePath, e);
+            LOG.warn("Failed to delete {}", task.filePath, e);
             succeed = false;
           }
           task.setResult(succeed);
@@ -274,9 +303,7 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
         }
       }
     } finally {
-      if (LOG.isDebugEnabled()) {
-        LOG.debug("Exit thread: " + Thread.currentThread());
-      }
+      LOG.debug("Exit {}", Thread.currentThread());
     }
   }
 
@@ -284,16 +311,16 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
   private void countDeletedFiles(boolean isLargeFile, boolean fromLargeQueue) {
     if (isLargeFile) {
       if (deletedLargeFiles.get() == Long.MAX_VALUE) {
-        LOG.info("Deleted more than Long.MAX_VALUE large files, reset counter to 0");
+        LOG.debug("Deleted more than Long.MAX_VALUE large files, reset counter to 0");
         deletedLargeFiles.set(0L);
       }
       deletedLargeFiles.incrementAndGet();
     } else {
       if (deletedSmallFiles.get() == Long.MAX_VALUE) {
-        LOG.info("Deleted more than Long.MAX_VALUE small files, reset counter to 0");
+        LOG.debug("Deleted more than Long.MAX_VALUE small files, reset counter to 0");
         deletedSmallFiles.set(0L);
       }
-      if (fromLargeQueue && LOG.isTraceEnabled()) {
+      if (fromLargeQueue) {
         LOG.trace("Stolen a small file deletion task in large file thread");
       }
       deletedSmallFiles.incrementAndGet();
@@ -305,15 +332,27 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
    */
   private void stopHFileDeleteThreads() {
     running = false;
-    if (LOG.isDebugEnabled()) {
-      LOG.debug("Stopping file delete threads");
-    }
-    for(Thread thread: threads){
+    LOG.debug("Stopping file delete threads");
+    for (Thread thread : threads) {
       thread.interrupt();
     }
   }
 
-  static class HFileDeleteTask implements Comparable<HFileDeleteTask> {
+  private static final Comparator<HFileDeleteTask> COMPARATOR = new Comparator<HFileDeleteTask>() {
+
+    @Override
+    public int compare(HFileDeleteTask o1, HFileDeleteTask o2) {
+      // larger file first so reverse compare
+      int cmp = Long.compare(o2.fileLength, o1.fileLength);
+      if (cmp != 0) {
+        return cmp;
+      }
+      // just use hashCode to generate a stable result.
+      return System.identityHashCode(o1) - System.identityHashCode(o2);
+    }
+  };
+
+  private static final class HFileDeleteTask {
 
     boolean done = false;
     boolean result;
@@ -339,49 +378,25 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
         while (!done) {
           long startTimeNanos = System.nanoTime();
           wait(waitIfNotFinished);
-          waitTimeMsec += TimeUnit.MILLISECONDS.convert(System.nanoTime() - startTimeNanos,
-              TimeUnit.NANOSECONDS);
+          waitTimeMsec +=
+            TimeUnit.MILLISECONDS.convert(System.nanoTime() - startTimeNanos, TimeUnit.NANOSECONDS);
           if (done) {
             return this.result;
           }
           if (waitTimeMsec > timeoutMsec) {
-            LOG.warn("Wait more than " + timeoutMsec + " ms for deleting " + this.filePath
-                + ", exit...");
+            LOG.warn(
+              "Wait more than " + timeoutMsec + " ms for deleting " + this.filePath + ", exit...");
             return false;
           }
         }
       } catch (InterruptedException e) {
-        LOG.warn("Interrupted while waiting for result of deleting " + filePath
-            + ", will return false", e);
+        LOG.warn(
+          "Interrupted while waiting for result of deleting " + filePath + ", will return false",
+          e);
         return false;
       }
       return this.result;
     }
-
-    @Override
-    public int compareTo(HFileDeleteTask o) {
-      long sub = this.fileLength - o.fileLength;
-      // smaller value with higher priority in PriorityQueue, and we intent to delete the larger
-      // file first.
-      return (sub > 0) ? -1 : (sub < 0 ? 1 : 0);
-    }
-
-    @Override
-    public boolean equals(Object o) {
-      if (this == o) {
-        return true;
-      }
-      if (o == null || !(o instanceof HFileDeleteTask)) {
-        return false;
-      }
-      HFileDeleteTask otherTask = (HFileDeleteTask) o;
-      return this.filePath.equals(otherTask.filePath) && (this.fileLength == otherTask.fileLength);
-    }
-
-    @Override
-    public int hashCode() {
-      return filePath.hashCode();
-    }
   }
 
   public List<Thread> getCleanerThreads() {
@@ -425,14 +440,10 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
     stopHFileDeleteThreads();
     // record the left over tasks
     List<HFileDeleteTask> leftOverTasks =
-        new ArrayList<>(largeFileQueue.size() + smallFileQueue.size());
-    for (HFileDeleteTask task : largeFileQueue) {
-      leftOverTasks.add(task);
-    }
-    for (HFileDeleteTask task : smallFileQueue) {
-      leftOverTasks.add(task);
-    }
-    largeFileQueue = new StealJobQueue<>(largeQueueInitSize, smallQueueInitSize);
+      new ArrayList<>(largeFileQueue.size() + smallFileQueue.size());
+    leftOverTasks.addAll(largeFileQueue);
+    leftOverTasks.addAll(smallFileQueue);
+    largeFileQueue = new StealJobQueue<>(largeQueueInitSize, smallQueueInitSize, COMPARATOR);
     smallFileQueue = largeFileQueue.getStealFromQueue();
     threads.clear();
     startHFileDeleteThreads();
@@ -450,57 +461,64 @@ public class HFileCleaner extends CleanerChore<BaseHFileCleanerDelegate> impleme
   private boolean checkAndUpdateConfigurations(Configuration conf) {
     boolean updated = false;
     int throttlePoint =
-        conf.getInt(HFILE_DELETE_THROTTLE_THRESHOLD, DEFAULT_HFILE_DELETE_THROTTLE_THRESHOLD);
+      conf.getInt(HFILE_DELETE_THROTTLE_THRESHOLD, DEFAULT_HFILE_DELETE_THROTTLE_THRESHOLD);
     if (throttlePoint != this.throttlePoint) {
-      LOG.debug("Updating throttle point, from " + this.throttlePoint + " to " + throttlePoint);
+      LOG.debug("Updating throttle point, from {} to {}", this.throttlePoint, throttlePoint);
       this.throttlePoint = throttlePoint;
       updated = true;
     }
     int largeQueueInitSize =
-        conf.getInt(LARGE_HFILE_QUEUE_INIT_SIZE, DEFAULT_LARGE_HFILE_QUEUE_INIT_SIZE);
+      conf.getInt(LARGE_HFILE_QUEUE_INIT_SIZE, DEFAULT_LARGE_HFILE_QUEUE_INIT_SIZE);
     if (largeQueueInitSize != this.largeQueueInitSize) {
-      LOG.debug("Updating largeQueueInitSize, from " + this.largeQueueInitSize + " to "
-          + largeQueueInitSize);
+      LOG.debug("Updating largeQueueInitSize, from {} to {}", this.largeQueueInitSize,
+        largeQueueInitSize);
       this.largeQueueInitSize = largeQueueInitSize;
       updated = true;
     }
     int smallQueueInitSize =
-        conf.getInt(SMALL_HFILE_QUEUE_INIT_SIZE, DEFAULT_SMALL_HFILE_QUEUE_INIT_SIZE);
+      conf.getInt(SMALL_HFILE_QUEUE_INIT_SIZE, DEFAULT_SMALL_HFILE_QUEUE_INIT_SIZE);
     if (smallQueueInitSize != this.smallQueueInitSize) {
-      LOG.debug("Updating smallQueueInitSize, from " + this.smallQueueInitSize + " to "
-          + smallQueueInitSize);
+      LOG.debug("Updating smallQueueInitSize, from {} to {}", this.smallQueueInitSize,
+        smallQueueInitSize);
       this.smallQueueInitSize = smallQueueInitSize;
       updated = true;
     }
     int largeFileDeleteThreadNumber =
-        conf.getInt(LARGE_HFILE_DELETE_THREAD_NUMBER, DEFAULT_LARGE_HFILE_DELETE_THREAD_NUMBER);
+      conf.getInt(LARGE_HFILE_DELETE_THREAD_NUMBER, DEFAULT_LARGE_HFILE_DELETE_THREAD_NUMBER);
     if (largeFileDeleteThreadNumber != this.largeFileDeleteThreadNumber) {
-      LOG.debug("Updating largeFileDeleteThreadNumber, from " + this.largeFileDeleteThreadNumber
-          + " to " + largeFileDeleteThreadNumber);
+      LOG.debug("Updating largeFileDeleteThreadNumber, from {} to {}",
+        this.largeFileDeleteThreadNumber, largeFileDeleteThreadNumber);
       this.largeFileDeleteThreadNumber = largeFileDeleteThreadNumber;
       updated = true;
     }
     int smallFileDeleteThreadNumber =
-        conf.getInt(SMALL_HFILE_DELETE_THREAD_NUMBER, DEFAULT_SMALL_HFILE_DELETE_THREAD_NUMBER);
+      conf.getInt(SMALL_HFILE_DELETE_THREAD_NUMBER, DEFAULT_SMALL_HFILE_DELETE_THREAD_NUMBER);
     if (smallFileDeleteThreadNumber != this.smallFileDeleteThreadNumber) {
-      LOG.debug("Updating smallFileDeleteThreadNumber, from " + this.smallFileDeleteThreadNumber
-          + " to " + smallFileDeleteThreadNumber);
+      LOG.debug("Updating smallFileDeleteThreadNumber, from {} to {}",
+        this.smallFileDeleteThreadNumber, smallFileDeleteThreadNumber);
       this.smallFileDeleteThreadNumber = smallFileDeleteThreadNumber;
       updated = true;
     }
     long cleanerThreadTimeoutMsec =
-        conf.getLong(HFILE_DELETE_THREAD_TIMEOUT_MSEC, DEFAULT_HFILE_DELETE_THREAD_TIMEOUT_MSEC);
+      conf.getLong(HFILE_DELETE_THREAD_TIMEOUT_MSEC, DEFAULT_HFILE_DELETE_THREAD_TIMEOUT_MSEC);
     if (cleanerThreadTimeoutMsec != this.cleanerThreadTimeoutMsec) {
       this.cleanerThreadTimeoutMsec = cleanerThreadTimeoutMsec;
       updated = true;
     }
-    long cleanerThreadCheckIntervalMsec =
-        conf.getLong(HFILE_DELETE_THREAD_CHECK_INTERVAL_MSEC,
-            DEFAULT_HFILE_DELETE_THREAD_CHECK_INTERVAL_MSEC);
+    long cleanerThreadCheckIntervalMsec = conf.getLong(HFILE_DELETE_THREAD_CHECK_INTERVAL_MSEC,
+      DEFAULT_HFILE_DELETE_THREAD_CHECK_INTERVAL_MSEC);
     if (cleanerThreadCheckIntervalMsec != this.cleanerThreadCheckIntervalMsec) {
       this.cleanerThreadCheckIntervalMsec = cleanerThreadCheckIntervalMsec;
       updated = true;
     }
     return updated;
   }
+
+  @Override
+  public synchronized void cancel(boolean mayInterruptIfRunning) {
+    super.cancel(mayInterruptIfRunning);
+    for (Thread t : this.threads) {
+      t.interrupt();
+    }
+  }
 }
