@@ -52,7 +52,9 @@ import org.apache.hadoop.hbase.snapshot.RestoreSnapshotException;
 import org.apache.hadoop.hbase.snapshot.RestoreSnapshotHelper;
 import org.apache.hadoop.hbase.snapshot.SnapshotDescriptionUtils;
 import org.apache.hadoop.hbase.snapshot.SnapshotManifest;
+import org.apache.hadoop.hbase.snapshot.SnapshotTTLExpiredException;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.FSTableDescriptors;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.yetus.audience.InterfaceAudience;
@@ -380,12 +382,20 @@ public class CloneSnapshotProcedure extends AbstractStateMachineTableProcedure<C
       throw new TableExistsException(tableName);
     }
 
+    // check whether ttl has expired for this snapshot
+    if (
+      SnapshotDescriptionUtils.isExpiredSnapshot(snapshot.getTtl(), snapshot.getCreationTime(),
+        EnvironmentEdgeManager.currentTime())
+    ) {
+      throw new SnapshotTTLExpiredException(ProtobufUtil.createSnapshotDesc(snapshot));
+    }
+
     validateSFT();
   }
 
   /**
    * Action before cloning from snapshot.
-   * @param env MasterProcedureEnv nn
+   * @param env MasterProcedureEnv
    */
   private void preCloneSnapshot(final MasterProcedureEnv env)
     throws IOException, InterruptedException {
@@ -409,7 +419,7 @@ public class CloneSnapshotProcedure extends AbstractStateMachineTableProcedure<C
 
   /**
    * Action after cloning from snapshot.
-   * @param env MasterProcedureEnv nn
+   * @param env MasterProcedureEnv
    */
   private void postCloneSnapshot(final MasterProcedureEnv env)
     throws IOException, InterruptedException {
@@ -423,7 +433,7 @@ public class CloneSnapshotProcedure extends AbstractStateMachineTableProcedure<C
 
   /**
    * Create regions in file system.
-   * @param env MasterProcedureEnv n
+   * @param env MasterProcedureEnv
    */
   private List<RegionInfo> createFilesystemLayout(final MasterProcedureEnv env,
     final TableDescriptor tableDescriptor, final List<RegionInfo> newRegions) throws IOException {
@@ -461,6 +471,12 @@ public class CloneSnapshotProcedure extends AbstractStateMachineTableProcedure<C
           LOG.info(msg);
           monitorStatus.setStatus(msg + " Waiting for table to be enabled...");
 
+          // Extract the parent to children regions mapping so we can update meta later.
+          // If we don't update the split information, the parent region will be garbage-collected.
+          // And once the snapshot is deleted, HFiles of the parent region can be prematurely
+          // deleted, causing permanent data loss.
+          parentsToChildrenPairMap = metaChanges.getParentToChildrenPairMap();
+
           // 2. Let the next step to add the regions to meta
           return metaChanges.getRegionsToAdd();
         } catch (Exception e) {
@@ -480,7 +496,7 @@ public class CloneSnapshotProcedure extends AbstractStateMachineTableProcedure<C
 
   /**
    * Create region layout in file system.
-   * @param env MasterProcedureEnv n
+   * @param env MasterProcedureEnv
    */
   private List<RegionInfo> createFsLayout(final MasterProcedureEnv env,
     final TableDescriptor tableDescriptor, List<RegionInfo> newRegions,
@@ -509,13 +525,11 @@ public class CloneSnapshotProcedure extends AbstractStateMachineTableProcedure<C
 
   /**
    * Add regions to hbase:meta table.
-   * @param env MasterProcedureEnv n
+   * @param env MasterProcedureEnv
    */
   private void addRegionsToMeta(final MasterProcedureEnv env) throws IOException {
     newRegions = CreateTableProcedure.addTableToMeta(env, tableDescriptor, newRegions);
 
-    // TODO: parentsToChildrenPairMap is always empty, which makes updateMetaParentRegions()
-    // a no-op. This part seems unnecessary. Figure out. - Appy 12/21/17
     RestoreSnapshotHelper.RestoreMetaChanges metaChanges =
       new RestoreSnapshotHelper.RestoreMetaChanges(tableDescriptor, parentsToChildrenPairMap);
     metaChanges.updateMetaParentRegions(env.getMasterServices().getConnection(), newRegions);
