@@ -36,6 +36,7 @@ import org.apache.hadoop.hbase.master.SplitWALManager;
 import org.apache.hadoop.hbase.master.assignment.AssignmentManager;
 import org.apache.hadoop.hbase.master.assignment.RegionStateNode;
 import org.apache.hadoop.hbase.master.assignment.TransitRegionStateProcedure;
+import org.apache.hadoop.hbase.master.replication.ClaimReplicationQueuesProcedure;
 import org.apache.hadoop.hbase.monitoring.MonitoredTask;
 import org.apache.hadoop.hbase.monitoring.TaskMonitor;
 import org.apache.hadoop.hbase.procedure2.Procedure;
@@ -240,11 +241,15 @@ public class ServerCrashProcedure extends
             }
             assignRegions(env, regionsOnCrashedServer);
           }
-          setNextState(ServerCrashState.SERVER_CRASH_FINISH);
+          setNextState(ServerCrashState.SERVER_CRASH_CLAIM_REPLICATION_QUEUES);
           break;
         case SERVER_CRASH_HANDLE_RIT2:
           // Noop. Left in place because we used to call handleRIT here for a second time
           // but no longer necessary since HBASE-20634.
+          setNextState(ServerCrashState.SERVER_CRASH_CLAIM_REPLICATION_QUEUES);
+          break;
+        case SERVER_CRASH_CLAIM_REPLICATION_QUEUES:
+          addChildProcedure(new ClaimReplicationQueuesProcedure(serverName));
           setNextState(ServerCrashState.SERVER_CRASH_FINISH);
           break;
         case SERVER_CRASH_FINISH:
@@ -536,18 +541,6 @@ public class ServerCrashProcedure extends
             !retainAssignment);
           continue;
         }
-        if (
-          env.getMasterServices().getTableStateManager().isTableState(regionNode.getTable(),
-            TableState.State.DISABLING)
-        ) {
-          // We need to change the state here otherwise the TRSP scheduled by DTP will try to
-          // close the region from a dead server and will never succeed. Please see HBASE-23636
-          // for more details.
-          env.getAssignmentManager().regionClosedAbnormally(regionNode);
-          LOG.info("{} found table disabling for region {}, set it state to ABNORMALLY_CLOSED.",
-            this, regionNode);
-          continue;
-        }
         if (
           env.getMasterServices().getTableStateManager().isTableState(regionNode.getTable(),
             TableState.State.DISABLED)
