@@ -19,13 +19,10 @@ package org.apache.hadoop.hbase.master.snapshot;
 
 import java.io.IOException;
 import java.util.Collection;
-import java.util.HashMap;
-import java.util.HashSet;
 import java.util.List;
-import java.util.Map;
-import java.util.Set;
 import java.util.Timer;
 import java.util.TimerTask;
+import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.Lock;
 import org.apache.commons.lang3.ArrayUtils;
 import org.apache.hadoop.conf.Configuration;
@@ -41,6 +38,8 @@ import org.apache.yetus.audience.InterfaceStability;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.hbase.thirdparty.com.google.common.collect.ImmutableMap;
+import org.apache.hbase.thirdparty.com.google.common.collect.ImmutableSet;
 import org.apache.hbase.thirdparty.com.google.common.collect.Lists;
 
 /**
@@ -91,14 +90,16 @@ public class SnapshotFileCache implements Stoppable {
   private final FileSystem fs, workingFs;
   private final SnapshotFileInspector fileInspector;
   private final Path snapshotDir, workingSnapshotDir;
-  private final Set<String> cache = new HashSet<>();
+  private volatile ImmutableSet<String> cache = ImmutableSet.of();
   /**
    * This is a helper map of information about the snapshot directories so we don't need to rescan
    * them if they haven't changed since the last time we looked.
    */
-  private final Map<String, SnapshotDirectoryInfo> snapshots = new HashMap<>();
+  private ImmutableMap<String, SnapshotDirectoryInfo> snapshots = ImmutableMap.of();
   private final Timer refreshTimer;
 
+  private static final int LOCK_TIMEOUT_MS = 30000;
+
   /**
    * Create a snapshot file cache for all snapshots under the specified [root]/.snapshot on the
    * filesystem.
@@ -177,15 +178,11 @@ public class SnapshotFileCache implements Stoppable {
    * at that point, cache will still think the file system contains that file and return
    * <tt>true</tt>, even if it is no longer present (false positive). However, if the file never was
    * on the filesystem, we will never find it and always return <tt>false</tt>.
-   * @param files file to check, NOTE: Relies that files are loaded from hdfs before method is
-   *              called (NOT LAZY)
+   * @param files file to check
    * @return <tt>unReferencedFiles</tt> the collection of files that do not have snapshot references
    * @throws IOException if there is an unexpected error reaching the filesystem.
    */
-  // XXX this is inefficient to synchronize on the method, when what we really need to guard against
-  // is an illegal access to the cache. Really we could do a mutex-guarded pointer swap on the
-  // cache, but that seems overkill at the moment and isn't necessarily a bottleneck.
-  public synchronized Iterable<FileStatus> getUnreferencedFiles(Iterable<FileStatus> files,
+  public Iterable<FileStatus> getUnreferencedFiles(List<FileStatus> files,
     final SnapshotManager snapshotManager) throws IOException {
     List<FileStatus> unReferencedFiles = Lists.newArrayList();
     List<String> snapshotsInProgress = null;
@@ -194,35 +191,47 @@ public class SnapshotFileCache implements Stoppable {
     if (snapshotManager != null) {
       lock = snapshotManager.getTakingSnapshotLock().writeLock();
     }
-    if (lock == null || lock.tryLock()) {
-      try {
-        if (snapshotManager != null && snapshotManager.isTakingAnySnapshot()) {
-          LOG.warn("Not checking unreferenced files since snapshot is running, it will "
-            + "skip to clean the HFiles this time");
-          return unReferencedFiles;
-        }
-        for (FileStatus file : files) {
-          String fileName = file.getPath().getName();
-          if (!refreshed && !cache.contains(fileName)) {
-            refreshCache();
-            refreshed = true;
+    try {
+      if (lock == null || lock.tryLock(LOCK_TIMEOUT_MS, TimeUnit.MILLISECONDS)) {
+        try {
+          if (snapshotManager != null && snapshotManager.isTakingAnySnapshot()) {
+            LOG.warn("Not checking unreferenced files since snapshot is running, it will "
+              + "skip to clean the HFiles this time");
+            return unReferencedFiles;
           }
-          if (cache.contains(fileName)) {
-            continue;
+          ImmutableSet<String> currentCache = cache;
+          for (FileStatus file : files) {
+            String fileName = file.getPath().getName();
+            if (!refreshed && !currentCache.contains(fileName)) {
+              synchronized (this) {
+                refreshCache();
+                currentCache = cache;
+                refreshed = true;
+              }
+            }
+            if (currentCache.contains(fileName)) {
+              continue;
+            }
+            if (snapshotsInProgress == null) {
+              snapshotsInProgress = getSnapshotsInProgress();
+            }
+            if (snapshotsInProgress.contains(fileName)) {
+              continue;
+            }
+            unReferencedFiles.add(file);
           }
-          if (snapshotsInProgress == null) {
-            snapshotsInProgress = getSnapshotsInProgress();
+        } finally {
+          if (lock != null) {
+            lock.unlock();
           }
-          if (snapshotsInProgress.contains(fileName)) {
-            continue;
-          }
-          unReferencedFiles.add(file);
-        }
-      } finally {
-        if (lock != null) {
-          lock.unlock();
         }
+      } else {
+        LOG.warn("Failed to acquire write lock on taking snapshot after waiting {}ms",
+          LOCK_TIMEOUT_MS);
       }
+    } catch (InterruptedException e) {
+      LOG.warn("Interrupted while acquiring write lock on taking snapshot");
+      Thread.currentThread().interrupt(); // restore the interrupt flag
     }
     return unReferencedFiles;
   }
@@ -236,22 +245,23 @@ public class SnapshotFileCache implements Stoppable {
 
     // clear the cache, as in the below code, either we will also clear the snapshots, or we will
     // refill the file name cache again.
-    this.cache.clear();
     if (ArrayUtils.isEmpty(snapshotDirs)) {
       // remove all the remembered snapshots because we don't have any left
       if (LOG.isDebugEnabled() && this.snapshots.size() > 0) {
         LOG.debug("No snapshots on-disk, clear cache");
       }
-      this.snapshots.clear();
+      this.snapshots = ImmutableMap.of();
+      this.cache = ImmutableSet.of();
       return;
     }
 
+    ImmutableSet.Builder<String> cacheBuilder = ImmutableSet.builder();
+    ImmutableMap.Builder<String, SnapshotDirectoryInfo> snapshotsBuilder = ImmutableMap.builder();
     // iterate over all the cached snapshots and see if we need to update some, it is not an
     // expensive operation if we do not reload the manifest of snapshots.
-    Map<String, SnapshotDirectoryInfo> newSnapshots = new HashMap<>();
     for (FileStatus snapshotDir : snapshotDirs) {
       String name = snapshotDir.getPath().getName();
-      SnapshotDirectoryInfo files = this.snapshots.remove(name);
+      SnapshotDirectoryInfo files = snapshots.get(name);
       // if we don't know about the snapshot or its been modified, we need to update the
       // files the latter could occur where I create a snapshot, then delete it, and then make a
       // new snapshot with the same name. We will need to update the cache the information from
@@ -263,12 +273,12 @@ public class SnapshotFileCache implements Stoppable {
         files = new SnapshotDirectoryInfo(snapshotDir.getModificationTime(), storedFiles);
       }
       // add all the files to cache
-      this.cache.addAll(files.getFiles());
-      newSnapshots.put(name, files);
+      cacheBuilder.addAll(files.getFiles());
+      snapshotsBuilder.put(name, files);
     }
     // set the snapshots we are tracking
-    this.snapshots.clear();
-    this.snapshots.putAll(newSnapshots);
+    this.snapshots = snapshotsBuilder.build();
+    this.cache = cacheBuilder.build();
   }
 
   List<String> getSnapshotsInProgress() throws IOException {
@@ -303,11 +313,10 @@ public class SnapshotFileCache implements Stoppable {
         } catch (IOException e) {
           LOG.warn("Failed to refresh snapshot hfile cache!", e);
           // clear all the cached entries if we meet an error
-          cache.clear();
-          snapshots.clear();
+          cache = ImmutableSet.of();
+          snapshots = ImmutableMap.of();
         }
       }
-
     }
   }
 
@@ -317,7 +326,6 @@ public class SnapshotFileCache implements Stoppable {
       this.stop = true;
       this.refreshTimer.cancel();
     }
-
   }
 
   @Override
