@@ -280,6 +280,7 @@ public final class MobUtils {
     calendar.set(Calendar.HOUR_OF_DAY, 0);
     calendar.set(Calendar.MINUTE, 0);
     calendar.set(Calendar.SECOND, 0);
+    calendar.set(Calendar.MILLISECOND, 0);
 
     Date expireDate = calendar.getTime();
 
@@ -436,6 +437,7 @@ public final class MobUtils {
   /**
    * Gets the RegionInfo of the mob files. This is a dummy region. The mob files are not saved in a
    * region in HBase. It's internally used only.
+   * @return A dummy mob region info.
    */
   public static RegionInfo getMobRegionInfo(TableName tableName) {
     return RegionInfoBuilder.newBuilder(tableName).setStartKey(MobConstants.MOB_REGION_NAME_BYTES)
