@@ -22,6 +22,7 @@ import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.LinkedList;
 import java.util.List;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.yetus.audience.InterfaceAudience;
 
 import org.apache.hbase.thirdparty.com.google.common.base.Charsets;
@@ -49,7 +50,7 @@ public class MemoryBoundedLogMessageBuffer {
    * desired memory limit is achieved.
    */
   public synchronized void add(String messageText) {
-    LogMessage message = new LogMessage(messageText, System.currentTimeMillis());
+    LogMessage message = new LogMessage(messageText, EnvironmentEdgeManager.currentTime());
 
     usage += message.estimateHeapUsage();
     messages.add(message);
