@@ -18,6 +18,7 @@
 package org.apache.hadoop.hbase.regionserver;
 
 import java.io.IOException;
+import java.util.List;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.util.BloomFilterWriter;
 import org.apache.yetus.audience.InterfaceAudience;
@@ -34,4 +35,14 @@ public interface CellSink {
    * @param cell the cell to be added
    */
   void append(Cell cell) throws IOException;
+
+  /**
+   * Append the given (possibly partial) list of cells of a row
+   * @param cellList the cell list to be added
+   */
+  default void appendAll(List<Cell> cellList) throws IOException {
+    for (Cell cell : cellList) {
+      append(cell);
+    }
+  }
 }
