@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -15,14 +15,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.regionserver;
 
-import org.apache.hadoop.hbase.classification.InterfaceAudience;
+import org.apache.yetus.audience.InterfaceAudience;
 
 @InterfaceAudience.Private
 public interface MetricsUserAggregate {
 
+  /** Returns return a singleton instance of MetricsUserAggregateSource or null in case of NoOp */
+  MetricsUserAggregateSource getSource();
+
   void updatePut(long t);
 
   void updateDelete(long t);
@@ -36,4 +38,8 @@ public interface MetricsUserAggregate {
   void updateReplay(long t);
 
   void updateScanTime(long t);
+
+  void updateFilteredReadRequests();
+
+  void updateReadRequestCount();
 }
