@@ -17,6 +17,8 @@
  */
 package org.apache.hadoop.hbase.regionserver.compactions;
 
+import static org.apache.hadoop.hbase.regionserver.StoreFileWriter.shouldEnableHistoricalCompactionFiles;
+
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.client.RegionInfo;
@@ -141,6 +143,12 @@ public class CompactionConfiguration {
       conf.getLong(HBASE_HSTORE_COMPACTION_MIN_SIZE_KEY, storeConfigInfo.getMemStoreFlushSize());
     minFilesToCompact = Math.max(2, conf.getInt(HBASE_HSTORE_COMPACTION_MIN_KEY,
       /* old name */ conf.getInt("hbase.hstore.compactionThreshold", 3)));
+    if (shouldEnableHistoricalCompactionFiles(conf)) {
+      // If historical file writing is enabled, we bump up the min value by one as DualFileWriter
+      // compacts files into two files, live and historical, instead of one. This also eliminates
+      // infinite re-compaction when the min value is set to 2
+      minFilesToCompact += 1;
+    }
     maxFilesToCompact = conf.getInt(HBASE_HSTORE_COMPACTION_MAX_KEY, 10);
     compactionRatio = conf.getFloat(HBASE_HSTORE_COMPACTION_RATIO_KEY, 1.2F);
     offPeakCompactionRatio = conf.getFloat(HBASE_HSTORE_COMPACTION_RATIO_OFFPEAK_KEY, 5.0F);
