@@ -468,6 +468,11 @@ class SequenceIdAccounting {
           continue;
         }
         for (Map.Entry<ImmutableByteArray, Long> me : m.entrySet()) {
+          // FLUSH events produce an entry in the wal with a "fake" METAFAMILY CF. We need to ignore
+          // these entries here, as there is actual no such store.
+          if (me.getKey().toString().equals("METAFAMILY")) {
+            continue;
+          }
           if (me.getValue() <= e.getValue()) {
             if (toFlush == null) {
               toFlush = new TreeMap(Bytes.BYTES_COMPARATOR);
