@@ -390,8 +390,9 @@ public class RegionReplicaReplicationEndpoint extends HBaseReplicationEndpoint {
       this.sink = sink;
       this.connection = connection;
       this.operationTimeout = operationTimeout;
-      this.rpcRetryingCallerFactory = RpcRetryingCallerFactory
-        .instantiate(connection.getConfiguration(), connection.getConnectionMetrics());
+      this.rpcRetryingCallerFactory =
+        RpcRetryingCallerFactory.instantiate(connection.getConfiguration(),
+          connection.getConnectionConfiguration(), connection.getConnectionMetrics());
       this.rpcControllerFactory = RpcControllerFactory.instantiate(connection.getConfiguration());
       this.pool = pool;
       this.tableDescriptors = tableDescriptors;
