@@ -97,15 +97,11 @@ import org.apache.hbase.thirdparty.com.google.common.util.concurrent.ThreadFacto
  * case need synchronized is {@link #cleanOldLogs(NavigableSet, String, boolean, String)} and
  * {@link #preLogRoll(Path)}.</li>
  * <li>No need synchronized on {@link #walsByIdRecoveredQueues}. There are three methods which
- * modify it, {@link #removePeer(String)} , <<<<<<< HEAD
+ * modify it, {@link #removePeer(String)},
  * {@link #cleanOldLogs(NavigableSet, String, boolean, String)} and
- * {@link ReplicationSourceManager.NodeFailoverWorker#run()}.
- * {@link #cleanOldLogs(NavigableSet, String, boolean, String)} is called by =======
- * {@link #cleanOldLogs(String, boolean, ReplicationSourceInterface)} and
  * {@link ReplicationSourceManager#claimQueue(ServerName, String)}.
- * {@link #cleanOldLogs(String, boolean, ReplicationSourceInterface)} is called by >>>>>>>
- * 51893b9ba3... HBASE-26029 It is not reliable to use nodeDeleted event to track region server's
- * death (#3430) {@link ReplicationSourceInterface}. {@link #removePeer(String)} will terminate the
+ * {@link #cleanOldLogs(NavigableSet, String, boolean, String)} is called by
+ * {@link ReplicationSourceInterface}. {@link #removePeer(String)} will terminate the
  * {@link ReplicationSourceInterface} firstly, then remove the wals from
  * {@link #walsByIdRecoveredQueues}. And
  * {@link ReplicationSourceManager#claimQueue(ServerName, String)} will add the wals to
@@ -368,22 +364,19 @@ public class ReplicationSourceManager {
     String terminateMessage = "Peer " + peerId
       + " state or config changed. Will close the previous replication source and open a new one";
     ReplicationPeer peer = replicationPeers.getPeer(peerId);
-    ReplicationSourceInterface src = createSource(peerId, peer);
+    ReplicationSourceInterface src;
     // synchronized on latestPaths to avoid missing the new log
     synchronized (this.latestPaths) {
-      ReplicationSourceInterface toRemove = this.sources.put(peerId, src);
+      ReplicationSourceInterface toRemove = this.sources.remove(peerId);
       if (toRemove != null) {
         LOG.info("Terminate replication source for " + toRemove.getPeerId());
         // Do not clear metrics
         toRemove.terminate(terminateMessage, null, false);
       }
-      for (SortedSet<String> walsByGroup : walsById.get(peerId).values()) {
-        walsByGroup.forEach(wal -> {
-          Path walPath = new Path(this.logDir, wal);
-          src.enqueueLog(walPath);
-          LOG.trace("Enqueued {} to source {} during source creation.", walPath, src.getQueueId());
-        });
-
+      src = createSource(peerId, peer);
+      this.sources.put(peerId, src);
+      for (NavigableSet<String> walsByGroup : walsById.get(peerId).values()) {
+        walsByGroup.forEach(wal -> src.enqueueLog(new Path(this.logDir, wal)));
       }
     }
     LOG.info("Startup replication source for " + src.getPeerId());
@@ -721,8 +714,10 @@ public class ReplicationSourceManager {
     for (ReplicationSourceInterface source : this.sources.values()) {
       source.terminate("Region server is closing");
     }
-    for (ReplicationSourceInterface source : this.oldsources) {
-      source.terminate("Region server is closing");
+    synchronized (oldsources) {
+      for (ReplicationSourceInterface source : this.oldsources) {
+        source.terminate("Region server is closing");
+      }
     }
   }
 
