@@ -63,6 +63,7 @@ import org.apache.hadoop.hbase.security.access.ShadedAccessControlUtil;
 import org.apache.hadoop.hbase.security.access.TablePermission;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.FSUtils;
 import org.apache.hadoop.hbase.util.ModifyRegionUtils;
 import org.apache.hadoop.hbase.util.Pair;
@@ -410,7 +411,7 @@ public class RestoreSnapshotHelper {
     ModifyRegionUtils.editRegions(exec, regions, new ModifyRegionUtils.RegionEditTask() {
       @Override
       public void editRegion(final RegionInfo hri) throws IOException {
-        HFileArchiver.archiveRegion(conf, fs, hri);
+        HFileArchiver.archiveRegion(conf, fs, hri, rootDir, tableDir);
       }
     });
   }
@@ -649,7 +650,7 @@ public class RestoreSnapshotHelper {
    * Clone region directory content from the snapshot info. Each region is encoded with the table
    * name, so the cloned region will have a different region name. Instead of copying the hfiles a
    * HFileLink is created.
-   * @param regionDir {@link Path} cloned dir n
+   * @param regionDir {@link Path} cloned dir
    */
   private void cloneRegion(final RegionInfo newRegionInfo, final Path regionDir,
     final RegionInfo snapshotRegionInfo, final SnapshotRegionManifest manifest) throws IOException {
@@ -696,7 +697,7 @@ public class RestoreSnapshotHelper {
    * Clone region directory content from the snapshot info. Each region is encoded with the table
    * name, so the cloned region will have a different region name. Instead of copying the hfiles a
    * HFileLink is created.
-   * @param region {@link HRegion} cloned n
+   * @param region {@link HRegion} cloned
    */
   private void cloneRegion(final HRegion region, final RegionInfo snapshotRegionInfo,
     final SnapshotRegionManifest manifest) throws IOException {
@@ -861,7 +862,7 @@ public class RestoreSnapshotHelper {
   }
 
   /**
-   * Copy the snapshot files for a snapshot scanner, discards meta changes. nnnnnn
+   * Copy the snapshot files for a snapshot scanner, discards meta changes.
    */
   public static RestoreMetaChanges copySnapshotForScanner(Configuration conf, FileSystem fs,
     Path rootDir, Path restoreDir, String snapshotName) throws IOException {
@@ -877,6 +878,12 @@ public class RestoreSnapshotHelper {
 
     Path snapshotDir = SnapshotDescriptionUtils.getCompletedSnapshotDir(snapshotName, rootDir);
     SnapshotDescription snapshotDesc = SnapshotDescriptionUtils.readSnapshotInfo(fs, snapshotDir);
+    // check if the snapshot is expired.
+    boolean isExpired = SnapshotDescriptionUtils.isExpiredSnapshot(snapshotDesc.getTtl(),
+      snapshotDesc.getCreationTime(), EnvironmentEdgeManager.currentTime());
+    if (isExpired) {
+      throw new SnapshotTTLExpiredException(ProtobufUtil.createSnapshotDesc(snapshotDesc));
+    }
     SnapshotManifest manifest = SnapshotManifest.open(conf, fs, snapshotDir, snapshotDesc);
 
     MonitoredTask status = TaskMonitor.get()
