@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -15,11 +15,8 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.snapshot;
 
-import com.google.protobuf.CodedInputStream;
-import com.google.protobuf.InvalidProtocolBufferException;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InterruptedIOException;
@@ -28,47 +25,54 @@ import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.concurrent.Callable;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorCompletionService;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FSDataOutputStream;
+import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
-import org.apache.hadoop.hbase.HRegionInfo;
-import org.apache.hadoop.hbase.HTableDescriptor;
-import org.apache.hadoop.hbase.classification.InterfaceAudience;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
+import org.apache.hadoop.hbase.client.RegionInfo;
+import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.errorhandling.ForeignExceptionSnare;
+import org.apache.hadoop.hbase.mob.MobUtils;
 import org.apache.hadoop.hbase.monitoring.MonitoredTask;
-import org.apache.hadoop.hbase.protobuf.ProtobufUtil;
-import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescription;
-import org.apache.hadoop.hbase.protobuf.generated.SnapshotProtos.SnapshotDataManifest;
-import org.apache.hadoop.hbase.protobuf.generated.SnapshotProtos.SnapshotRegionManifest;
 import org.apache.hadoop.hbase.regionserver.HRegion;
 import org.apache.hadoop.hbase.regionserver.HRegionFileSystem;
-import org.apache.hadoop.hbase.regionserver.Store;
-import org.apache.hadoop.hbase.regionserver.StoreFile;
+import org.apache.hadoop.hbase.regionserver.HStore;
+import org.apache.hadoop.hbase.regionserver.HStoreFile;
 import org.apache.hadoop.hbase.regionserver.StoreFileInfo;
-import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.regionserver.storefiletracker.StoreFileTracker;
+import org.apache.hadoop.hbase.regionserver.storefiletracker.StoreFileTrackerFactory;
+import org.apache.hadoop.hbase.util.CommonFSUtils;
 import org.apache.hadoop.hbase.util.FSTableDescriptors;
-import org.apache.hadoop.hbase.util.FSUtils;
 import org.apache.hadoop.hbase.util.Threads;
+import org.apache.yetus.audience.InterfaceAudience;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import org.apache.hbase.thirdparty.com.google.common.util.concurrent.ThreadFactoryBuilder;
+import org.apache.hbase.thirdparty.com.google.protobuf.CodedInputStream;
+import org.apache.hbase.thirdparty.com.google.protobuf.InvalidProtocolBufferException;
+
+import org.apache.hadoop.hbase.shaded.protobuf.ProtobufUtil;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.SnapshotProtos.SnapshotDataManifest;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.SnapshotProtos.SnapshotDescription;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.SnapshotProtos.SnapshotRegionManifest;
 
 /**
- * Utility class to help read/write the Snapshot Manifest.
- *
- * The snapshot format is transparent for the users of this class,
- * once the snapshot is written, it will never be modified.
- * On open() the snapshot will be loaded to the current in-memory format.
+ * Utility class to help read/write the Snapshot Manifest. The snapshot format is transparent for
+ * the users of this class, once the snapshot is written, it will never be modified. On open() the
+ * snapshot will be loaded to the current in-memory format.
  */
 @InterfaceAudience.Private
 public final class SnapshotManifest {
-  private static final Log LOG = LogFactory.getLog(SnapshotManifest.class);
+  private static final Logger LOG = LoggerFactory.getLogger(SnapshotManifest.class);
 
   public static final String SNAPSHOT_MANIFEST_SIZE_LIMIT_CONF_KEY = "snapshot.manifest.size.limit";
 
@@ -76,7 +80,7 @@ public final class SnapshotManifest {
 
   private List<SnapshotRegionManifest> regionManifests;
   private SnapshotDescription desc;
-  private HTableDescriptor htd;
+  private TableDescriptor htd;
 
   private final ForeignExceptionSnare monitor;
   private final Configuration conf;
@@ -87,18 +91,17 @@ public final class SnapshotManifest {
   private final MonitoredTask statusTask;
 
   /**
-   *
-   * @param conf configuration file for HBase setup
-   * @param rootFs root filesystem containing HFiles
+   * @param conf       configuration file for HBase setup
+   * @param rootFs     root filesystem containing HFiles
    * @param workingDir file path of where the manifest should be located
-   * @param desc description of snapshot being taken
-   * @param monitor monitor of foreign exceptions
-   * @throws IOException if the working directory file system cannot be
-   *                     determined from the config file
+   * @param desc       description of snapshot being taken
+   * @param monitor    monitor of foreign exceptions
+   * @throws IOException if the working directory file system cannot be determined from the config
+   *                     file
    */
-  private SnapshotManifest(final Configuration conf, final FileSystem rootFs,
-      final Path workingDir, final SnapshotDescription desc,
-      final ForeignExceptionSnare monitor, final MonitoredTask statusTask) throws IOException {
+  private SnapshotManifest(final Configuration conf, final FileSystem rootFs, final Path workingDir,
+    final SnapshotDescription desc, final ForeignExceptionSnare monitor,
+    final MonitoredTask statusTask) throws IOException {
     this.monitor = monitor;
     this.desc = desc;
     this.workingDir = workingDir;
@@ -110,60 +113,54 @@ public final class SnapshotManifest {
   }
 
   /**
-   * Return a SnapshotManifest instance, used for writing a snapshot.
-   *
-   * There are two usage pattern:
-   *  - The Master will create a manifest, add the descriptor, offline regions
-   *    and consolidate the snapshot by writing all the pending stuff on-disk.
-   *      manifest = SnapshotManifest.create(...)
-   *      manifest.addRegion(tableDir, hri)
-   *      manifest.consolidate()
-   *  - The RegionServer will create a single region manifest
-   *      manifest = SnapshotManifest.create(...)
-   *      manifest.addRegion(region)
+   * Return a SnapshotManifest instance, used for writing a snapshot. There are two usage pattern: -
+   * The Master will create a manifest, add the descriptor, offline regions and consolidate the
+   * snapshot by writing all the pending stuff on-disk. manifest = SnapshotManifest.create(...)
+   * manifest.addRegion(tableDir, hri) manifest.consolidate() - The RegionServer will create a
+   * single region manifest manifest = SnapshotManifest.create(...) manifest.addRegion(region)
    */
   public static SnapshotManifest create(final Configuration conf, final FileSystem fs,
-      final Path workingDir, final SnapshotDescription desc,
-      final ForeignExceptionSnare monitor) throws IOException {
+    final Path workingDir, final SnapshotDescription desc, final ForeignExceptionSnare monitor)
+    throws IOException {
     return create(conf, fs, workingDir, desc, monitor, null);
 
   }
 
   public static SnapshotManifest create(final Configuration conf, final FileSystem fs,
-      final Path workingDir, final SnapshotDescription desc, final ForeignExceptionSnare monitor,
-      final MonitoredTask statusTask) throws IOException {
+    final Path workingDir, final SnapshotDescription desc, final ForeignExceptionSnare monitor,
+    final MonitoredTask statusTask) throws IOException {
     return new SnapshotManifest(conf, fs, workingDir, desc, monitor, statusTask);
+
   }
 
   /**
    * Return a SnapshotManifest instance with the information already loaded in-memory.
-   *    SnapshotManifest manifest = SnapshotManifest.open(...)
-   *    HTableDescriptor htd = manifest.getTableDescriptor()
-   *    for (SnapshotRegionManifest regionManifest: manifest.getRegionManifests())
-   *      hri = regionManifest.getRegionInfo()
-   *      for (regionManifest.getFamilyFiles())
-   *        ...
+   * SnapshotManifest manifest = SnapshotManifest.open(...) TableDescriptor htd =
+   * manifest.getTableDescriptor() for (SnapshotRegionManifest regionManifest:
+   * manifest.getRegionManifests()) hri = regionManifest.getRegionInfo() for
+   * (regionManifest.getFamilyFiles()) ...
    */
   public static SnapshotManifest open(final Configuration conf, final FileSystem fs,
-      final Path workingDir, final SnapshotDescription desc) throws IOException {
+    final Path workingDir, final SnapshotDescription desc) throws IOException {
     SnapshotManifest manifest = new SnapshotManifest(conf, fs, workingDir, desc, null, null);
     manifest.load();
     return manifest;
   }
 
-
   /**
    * Add the table descriptor to the snapshot manifest
    */
-  public void addTableDescriptor(final HTableDescriptor htd) throws IOException {
+  public void addTableDescriptor(final TableDescriptor htd) throws IOException {
     this.htd = htd;
   }
 
   interface RegionVisitor<TRegion, TFamily> {
-    TRegion regionOpen(final HRegionInfo regionInfo) throws IOException;
+    TRegion regionOpen(final RegionInfo regionInfo) throws IOException;
+
     void regionClose(final TRegion region) throws IOException;
 
     TFamily familyOpen(final TRegion region, final byte[] familyName) throws IOException;
+
     void familyClose(final TRegion region, final TFamily family) throws IOException;
 
     void storeFile(final TRegion region, final TFamily family, final StoreFileInfo storeFile)
@@ -177,10 +174,54 @@ public final class SnapshotManifest {
       case SnapshotManifestV2.DESCRIPTOR_VERSION:
         return new SnapshotManifestV2.ManifestBuilder(conf, rootFs, workingDir);
       default:
-        throw new CorruptedSnapshotException("Invalid Snapshot version: "+ desc.getVersion(), desc);
+        throw new CorruptedSnapshotException("Invalid Snapshot version: " + desc.getVersion(),
+          ProtobufUtil.createSnapshotDesc(desc));
     }
   }
 
+  public void addMobRegion(RegionInfo regionInfo) throws IOException {
+    // Get the ManifestBuilder/RegionVisitor
+    RegionVisitor visitor = createRegionVisitor(desc);
+
+    // Visit the region and add it to the manifest
+    addMobRegion(regionInfo, visitor);
+  }
+
+  protected void addMobRegion(RegionInfo regionInfo, RegionVisitor visitor) throws IOException {
+    // 1. dump region meta info into the snapshot directory
+    final String snapshotName = desc.getName();
+    LOG.debug("Storing mob region '" + regionInfo + "' region-info for snapshot=" + snapshotName);
+    Object regionData = visitor.regionOpen(regionInfo);
+    monitor.rethrowException();
+
+    // 2. iterate through all the stores in the region
+    LOG.debug("Creating references for mob files");
+
+    Path mobRegionPath = MobUtils.getMobRegionPath(conf, regionInfo.getTable());
+    for (ColumnFamilyDescriptor hcd : htd.getColumnFamilies()) {
+      // 2.1. build the snapshot reference for the store if it's a mob store
+      if (!hcd.isMobEnabled()) {
+        continue;
+      }
+      Object familyData = visitor.familyOpen(regionData, hcd.getName());
+      monitor.rethrowException();
+
+      Path storePath = MobUtils.getMobFamilyPath(mobRegionPath, hcd.getNameAsString());
+      List<StoreFileInfo> storeFiles = getStoreFiles(storePath);
+      if (storeFiles == null) {
+        if (LOG.isDebugEnabled()) {
+          LOG.debug("No mob files under family: " + hcd.getNameAsString());
+        }
+        continue;
+      }
+
+      addReferenceFiles(visitor, regionData, familyData, storeFiles, true);
+
+      visitor.familyClose(regionData, familyData);
+    }
+    visitor.regionClose(regionData);
+  }
+
   /**
    * Creates a 'manifest' for the specified region, by reading directly from the HRegion object.
    * This is used by the "online snapshot" when the table is enabled.
@@ -195,30 +236,33 @@ public final class SnapshotManifest {
 
   protected void addRegion(final HRegion region, RegionVisitor visitor) throws IOException {
     // 1. dump region meta info into the snapshot directory
-    LOG.debug("Storing '" + region + "' region-info for snapshot.");
+    final String snapshotName = desc.getName();
+    LOG.debug("Storing '" + region + "' region-info for snapshot=" + snapshotName);
     Object regionData = visitor.regionOpen(region.getRegionInfo());
     monitor.rethrowException();
 
     // 2. iterate through all the stores in the region
     LOG.debug("Creating references for hfiles");
 
-    for (Store store : region.getStores()) {
+    for (HStore store : region.getStores()) {
       // 2.1. build the snapshot reference for the store
-      Object familyData = visitor.familyOpen(regionData, store.getFamily().getName());
+      Object familyData =
+        visitor.familyOpen(regionData, store.getColumnFamilyDescriptor().getName());
       monitor.rethrowException();
 
-      List<StoreFile> storeFiles = new ArrayList<StoreFile>(store.getStorefiles());
+      List<HStoreFile> storeFiles = new ArrayList<>(store.getStorefiles());
       if (LOG.isDebugEnabled()) {
-        LOG.debug("Adding snapshot references for " + storeFiles  + " hfiles");
+        LOG.debug("Adding snapshot references for " + storeFiles + " hfiles");
       }
 
       // 2.2. iterate through all the store's files and create "references".
       for (int i = 0, sz = storeFiles.size(); i < sz; i++) {
-        StoreFile storeFile = storeFiles.get(i);
+        HStoreFile storeFile = storeFiles.get(i);
         monitor.rethrowException();
 
         // create "reference" to this store file.
-        LOG.debug("Adding reference for file (" + (i+1) + "/" + sz + "): " + storeFile.getPath());
+        LOG.debug("Adding reference for file (" + (i + 1) + "/" + sz + "): " + storeFile.getPath()
+          + " for snapshot=" + snapshotName);
         visitor.storeFile(regionData, familyData, storeFile.getFileInfo());
       }
       visitor.familyClose(regionData, familyData);
@@ -227,10 +271,10 @@ public final class SnapshotManifest {
   }
 
   /**
-   * Creates a 'manifest' for the specified region, by reading directly from the disk.
-   * This is used by the "offline snapshot" when the table is disabled.
+   * Creates a 'manifest' for the specified region, by reading directly from the disk. This is used
+   * by the "offline snapshot" when the table is disabled.
    */
-  public void addRegion(final Path tableDir, final HRegionInfo regionInfo) throws IOException {
+  public void addRegion(final Path tableDir, final RegionInfo regionInfo) throws IOException {
     // Get the ManifestBuilder/RegionVisitor
     RegionVisitor visitor = createRegionVisitor(desc);
 
@@ -238,66 +282,101 @@ public final class SnapshotManifest {
     addRegion(tableDir, regionInfo, visitor);
   }
 
-  protected void addRegion(final Path tableDir, final HRegionInfo regionInfo, RegionVisitor visitor)
-      throws IOException {
+  protected void addRegion(Path tableDir, RegionInfo regionInfo, RegionVisitor visitor)
+    throws IOException {
+    boolean isMobRegion = MobUtils.isMobRegionInfo(regionInfo);
+    try {
+      Path baseDir = tableDir;
+      // Open the RegionFS
+      if (isMobRegion) {
+        baseDir = CommonFSUtils.getTableDir(MobUtils.getMobHome(conf), regionInfo.getTable());
+      }
+      HRegionFileSystem regionFs =
+        HRegionFileSystem.openRegionFromFileSystem(conf, rootFs, baseDir, regionInfo, true);
+      monitor.rethrowException();
 
-    // Open the RegionFS
-    HRegionFileSystem regionFs = HRegionFileSystem.openRegionFromFileSystem(conf, rootFs,
-        tableDir, regionInfo, true);
-    monitor.rethrowException();
+      // 1. dump region meta info into the snapshot directory
+      LOG.debug("Storing region-info for snapshot.");
+      Object regionData = visitor.regionOpen(regionInfo);
+      monitor.rethrowException();
 
-    // 1. dump region meta info into the snapshot directory
-    LOG.debug("Storing region-info for snapshot.");
-    Object regionData = visitor.regionOpen(regionInfo);
-    monitor.rethrowException();
+      // 2. iterate through all the stores in the region
+      LOG.debug("Creating references for hfiles");
 
-    // 2. iterate through all the stores in the region
-    LOG.debug("Creating references for hfiles");
-
-    // This ensures that we have an atomic view of the directory as long as we have < ls limit
-    // (batch size of the files in a directory) on the namenode. Otherwise, we get back the files in
-    // batches and may miss files being added/deleted. This could be more robust (iteratively
-    // checking to see if we have all the files until we are sure), but the limit is currently 1000
-    // files/batch, far more than the number of store files under a single column family.
-    Collection<String> familyNames = regionFs.getFamilies();
-    if (familyNames != null) {
-      for (String familyName: familyNames) {
-        Object familyData = visitor.familyOpen(regionData, Bytes.toBytes(familyName));
+      // This ensures that we have an atomic view of the directory as long as we have < ls limit
+      // (batch size of the files in a directory) on the namenode. Otherwise, we get back the files
+      // in batches and may miss files being added/deleted. This could be more robust (iteratively
+      // checking to see if we have all the files until we are sure), but the limit is currently
+      // 1000 files/batch, far more than the number of store files under a single column family.
+      for (ColumnFamilyDescriptor cfd : htd.getColumnFamilies()) {
+        Object familyData = visitor.familyOpen(regionData, cfd.getName());
         monitor.rethrowException();
-
-        Collection<StoreFileInfo> storeFiles = regionFs.getStoreFiles(familyName);
-        if (storeFiles == null) {
-          LOG.debug("No files under family: " + familyName);
+        StoreFileTracker tracker = null;
+        if (isMobRegion) {
+          // MOB regions are always using the default SFT implementation
+          ColumnFamilyDescriptor defaultSFTCfd = ColumnFamilyDescriptorBuilder.newBuilder(cfd)
+            .setValue(StoreFileTrackerFactory.TRACKER_IMPL,
+              StoreFileTrackerFactory.Trackers.DEFAULT.name())
+            .build();
+          tracker = StoreFileTrackerFactory.create(conf, htd, defaultSFTCfd, regionFs);
+        } else {
+          tracker = StoreFileTrackerFactory.create(conf, htd, cfd, regionFs);
+        }
+        List<StoreFileInfo> storeFiles = tracker.load();
+        if (storeFiles.isEmpty()) {
+          LOG.debug("No files under family: {}", cfd.getNameAsString());
           continue;
         }
-
         // 2.1. build the snapshot reference for the store
-        if (LOG.isDebugEnabled()) {
-          LOG.debug("Adding snapshot references for " + storeFiles  + " hfiles");
-        }
-
-        // 2.2. iterate through all the store's files and create "references".
-        int i = 0;
-        int sz = storeFiles.size();
-        for (StoreFileInfo storeFile: storeFiles) {
-          monitor.rethrowException();
-
-          // create "reference" to this store file.
-          LOG.debug("Adding reference for file ("+ (++i) +"/" + sz + "): " + storeFile.getPath());
-          visitor.storeFile(regionData, familyData, storeFile);
-        }
+        // iterate through all the store's files and create "references".
+        addReferenceFiles(visitor, regionData, familyData, storeFiles, false);
         visitor.familyClose(regionData, familyData);
       }
+      visitor.regionClose(regionData);
+    } catch (IOException e) {
+      // the mob directory might not be created yet, so do nothing when it is a mob region
+      if (!isMobRegion) {
+        throw e;
+      }
+    }
+  }
+
+  private List<StoreFileInfo> getStoreFiles(Path storeDir) throws IOException {
+    FileStatus[] stats = CommonFSUtils.listStatus(rootFs, storeDir);
+    if (stats == null) return null;
+
+    ArrayList<StoreFileInfo> storeFiles = new ArrayList<>(stats.length);
+    for (int i = 0; i < stats.length; ++i) {
+      storeFiles.add(new StoreFileInfo(conf, rootFs, stats[i]));
+    }
+    return storeFiles;
+  }
+
+  private void addReferenceFiles(RegionVisitor visitor, Object regionData, Object familyData,
+    Collection<StoreFileInfo> storeFiles, boolean isMob) throws IOException {
+    final String fileType = isMob ? "mob file" : "hfile";
+
+    if (LOG.isDebugEnabled()) {
+      LOG.debug(String.format("Adding snapshot references for %s %ss", storeFiles, fileType));
+    }
+
+    int i = 0;
+    int sz = storeFiles.size();
+    for (StoreFileInfo storeFile : storeFiles) {
+      monitor.rethrowException();
+
+      LOG.debug(String.format("Adding reference for %s (%d/%d): %s", fileType, ++i, sz,
+        storeFile.getPath()));
+
+      // create "reference" to this store file.
+      visitor.storeFile(regionData, familyData, storeFile);
     }
-    visitor.regionClose(regionData);
   }
 
   /**
-   * Load the information in the SnapshotManifest. Called by SnapshotManifest.open()
-   *
-   * If the format is v2 and there is no data-manifest, means that we are loading an
-   * in-progress snapshot. Since we support rolling-upgrades, we loook for v1 and v2
-   * regions format.
+   * Load the information in the SnapshotManifest. Called by SnapshotManifest.open() If the format
+   * is v2 and there is no data-manifest, means that we are loading an in-progress snapshot. Since
+   * we support rolling-upgrades, we loook for v1 and v2 regions format.
    */
   private void load() throws IOException {
     switch (getSnapshotFormat(desc)) {
@@ -315,7 +394,7 @@ public final class SnapshotManifest {
       case SnapshotManifestV2.DESCRIPTOR_VERSION: {
         SnapshotDataManifest dataManifest = readDataManifest();
         if (dataManifest != null) {
-          htd = HTableDescriptor.convert(dataManifest.getTableSchema());
+          htd = ProtobufUtil.toTableDescriptor(dataManifest.getTableSchema());
           regionManifests = dataManifest.getRegionManifestsList();
         } else {
           // Compatibility, load the v1 regions
@@ -323,19 +402,18 @@ public final class SnapshotManifest {
           List<SnapshotRegionManifest> v1Regions, v2Regions;
           ThreadPoolExecutor tpool = createExecutor("SnapshotManifestLoader");
           try {
-            v1Regions = SnapshotManifestV1.loadRegionManifests(conf, tpool, rootFs,
-                workingDir, desc);
-            v2Regions = SnapshotManifestV2.loadRegionManifests(conf, tpool, rootFs,
-                workingDir, desc, manifestSizeLimit);
+            v1Regions =
+              SnapshotManifestV1.loadRegionManifests(conf, tpool, rootFs, workingDir, desc);
+            v2Regions = SnapshotManifestV2.loadRegionManifests(conf, tpool, rootFs, workingDir,
+              desc, manifestSizeLimit);
           } catch (InvalidProtocolBufferException e) {
-            throw new CorruptedSnapshotException("unable to parse region manifest " +
-                e.getMessage(), e);
+            throw new CorruptedSnapshotException(
+              "unable to parse region manifest " + e.getMessage(), e);
           } finally {
             tpool.shutdown();
           }
           if (v1Regions != null && v2Regions != null) {
-            regionManifests =
-              new ArrayList<SnapshotRegionManifest>(v1Regions.size() + v2Regions.size());
+            regionManifests = new ArrayList<>(v1Regions.size() + v2Regions.size());
             regionManifests.addAll(v1Regions);
             regionManifests.addAll(v2Regions);
           } else if (v1Regions != null) {
@@ -347,7 +425,8 @@ public final class SnapshotManifest {
         break;
       }
       default:
-        throw new CorruptedSnapshotException("Invalid Snapshot version: "+ desc.getVersion(), desc);
+        throw new CorruptedSnapshotException("Invalid Snapshot version: " + desc.getVersion(),
+          ProtobufUtil.createSnapshotDesc(desc));
     }
   }
 
@@ -368,7 +447,7 @@ public final class SnapshotManifest {
   /**
    * Get the table descriptor from the Snapshot
    */
-  public HTableDescriptor getTableDescriptor() {
+  public TableDescriptor getTableDescriptor() {
     return this.htd;
   }
 
@@ -386,15 +465,14 @@ public final class SnapshotManifest {
   }
 
   /**
-   * Get all the Region Manifest from the snapshot.
-   * This is an helper to get a map with the region encoded name
+   * Get all the Region Manifest from the snapshot. This is an helper to get a map with the region
+   * encoded name
    */
   public Map<String, SnapshotRegionManifest> getRegionManifestsMap() {
-    if (regionManifests == null || regionManifests.size() == 0) return null;
+    if (regionManifests == null || regionManifests.isEmpty()) return null;
 
-    HashMap<String, SnapshotRegionManifest> regionsMap =
-        new HashMap<String, SnapshotRegionManifest>(regionManifests.size());
-    for (SnapshotRegionManifest manifest: regionManifests) {
+    HashMap<String, SnapshotRegionManifest> regionsMap = new HashMap<>(regionManifests.size());
+    for (SnapshotRegionManifest manifest : regionManifests) {
       String regionName = getRegionNameFromManifest(manifest);
       regionsMap.put(regionName, manifest);
     }
@@ -403,20 +481,19 @@ public final class SnapshotManifest {
 
   public void consolidate() throws IOException {
     if (getSnapshotFormat(desc) == SnapshotManifestV1.DESCRIPTOR_VERSION) {
-      Path rootDir = FSUtils.getRootDir(conf);
       LOG.info("Using old Snapshot Format");
       // write a copy of descriptor to the snapshot directory
-      new FSTableDescriptors(conf, workingDirFs, rootDir)
-        .createTableDescriptorForTableDirectory(workingDir, htd, false);
+      FSTableDescriptors.createTableDescriptorForTableDirectory(workingDirFs, workingDir, htd,
+        false);
     } else {
-      LOG.debug("Convert to Single Snapshot Manifest for " + this.desc.getName());
+      LOG.debug("Convert to Single Snapshot Manifest for {}", this.desc.getName());
       convertToV2SingleManifest();
     }
   }
 
   /*
-   * In case of rolling-upgrade, we try to read all the formats and build
-   * the snapshot with the latest format.
+   * In case of rolling-upgrade, we try to read all the formats and build the snapshot with the
+   * latest format.
    */
   private void convertToV2SingleManifest() throws IOException {
     // Try to load v1 and v2 regions
@@ -424,13 +501,13 @@ public final class SnapshotManifest {
     ThreadPoolExecutor tpool = createExecutor("SnapshotManifestLoader");
     setStatusMsg("Loading Region manifests for " + this.desc.getName());
     try {
-      v1Regions = SnapshotManifestV1.loadRegionManifests(conf, tpool, workingDirFs,
-          workingDir, desc);
-      v2Regions = SnapshotManifestV2.loadRegionManifests(conf, tpool, workingDirFs,
-          workingDir, desc, manifestSizeLimit);
+      v1Regions =
+        SnapshotManifestV1.loadRegionManifests(conf, tpool, workingDirFs, workingDir, desc);
+      v2Regions = SnapshotManifestV2.loadRegionManifests(conf, tpool, workingDirFs, workingDir,
+        desc, manifestSizeLimit);
 
       SnapshotDataManifest.Builder dataManifestBuilder = SnapshotDataManifest.newBuilder();
-      dataManifestBuilder.setTableSchema(htd.convert());
+      dataManifestBuilder.setTableSchema(ProtobufUtil.toTableSchema(htd));
 
       if (v1Regions != null && v1Regions.size() > 0) {
         dataManifestBuilder.addAllRegionManifests(v1Regions);
@@ -456,26 +533,20 @@ public final class SnapshotManifest {
       int totalDeletes = 0;
       ExecutorCompletionService<Void> completionService = new ExecutorCompletionService<>(tpool);
       if (v1Regions != null) {
-        for (final SnapshotRegionManifest regionManifest: v1Regions) {
+        for (SnapshotRegionManifest regionManifest : v1Regions) {
           ++totalDeletes;
-          completionService.submit(new Callable<Void>() {
-            @Override
-            public Void call() throws Exception {
-              SnapshotManifestV1.deleteRegionManifest(workingDirFs, workingDir, regionManifest);
-              return null;
-            }
+          completionService.submit(() -> {
+            SnapshotManifestV1.deleteRegionManifest(workingDirFs, workingDir, regionManifest);
+            return null;
           });
         }
       }
       if (v2Regions != null) {
-        for (final SnapshotRegionManifest regionManifest: v2Regions) {
+        for (SnapshotRegionManifest regionManifest : v2Regions) {
           ++totalDeletes;
-          completionService.submit(new Callable<Void>() {
-            @Override
-            public Void call() throws Exception {
-              SnapshotManifestV2.deleteRegionManifest(workingDirFs, workingDir, regionManifest);
-              return null;
-            }
+          completionService.submit(() -> {
+            SnapshotManifestV2.deleteRegionManifest(workingDirFs, workingDir, regionManifest);
+            return null;
           });
         }
       }
@@ -497,13 +568,10 @@ public final class SnapshotManifest {
   /*
    * Write the SnapshotDataManifest file
    */
-  private void writeDataManifest(final SnapshotDataManifest manifest)
-      throws IOException {
-    FSDataOutputStream stream = workingDirFs.create(new Path(workingDir, DATA_MANIFEST_NAME));
-    try {
+  private void writeDataManifest(final SnapshotDataManifest manifest) throws IOException {
+    try (
+      FSDataOutputStream stream = workingDirFs.create(new Path(workingDir, DATA_MANIFEST_NAME))) {
       manifest.writeTo(stream);
-    } finally {
-      stream.close();
     }
   }
 
@@ -511,9 +579,7 @@ public final class SnapshotManifest {
    * Read the SnapshotDataManifest file
    */
   private SnapshotDataManifest readDataManifest() throws IOException {
-    FSDataInputStream in = null;
-    try {
-      in = workingDirFs.open(new Path(workingDir, DATA_MANIFEST_NAME));
+    try (FSDataInputStream in = workingDirFs.open(new Path(workingDir, DATA_MANIFEST_NAME))) {
       CodedInputStream cin = CodedInputStream.newInstance(in);
       cin.setSizeLimit(manifestSizeLimit);
       return SnapshotDataManifest.parseFrom(cin);
@@ -521,8 +587,6 @@ public final class SnapshotManifest {
       return null;
     } catch (InvalidProtocolBufferException e) {
       throw new CorruptedSnapshotException("unable to parse data manifest " + e.getMessage(), e);
-    } finally {
-      if (in != null) in.close();
     }
   }
 
@@ -533,18 +597,19 @@ public final class SnapshotManifest {
   public static ThreadPoolExecutor createExecutor(final Configuration conf, final String name) {
     int maxThreads = conf.getInt("hbase.snapshot.thread.pool.max", 8);
     return Threads.getBoundedCachedThreadPool(maxThreads, 30L, TimeUnit.SECONDS,
-              Threads.getNamedThreadFactory(name));
+      new ThreadFactoryBuilder().setNameFormat(name + "-pool-%d").setDaemon(true)
+        .setUncaughtExceptionHandler(Threads.LOGGING_EXCEPTION_HANDLER).build());
   }
 
   /**
    * Extract the region encoded name from the region manifest
    */
   static String getRegionNameFromManifest(final SnapshotRegionManifest manifest) {
-    byte[] regionName = HRegionInfo.createRegionName(
-            ProtobufUtil.toTableName(manifest.getRegionInfo().getTableName()),
-            manifest.getRegionInfo().getStartKey().toByteArray(),
-            manifest.getRegionInfo().getRegionId(), true);
-    return HRegionInfo.encodeRegionName(regionName);
+    byte[] regionName =
+      RegionInfo.createRegionName(ProtobufUtil.toTableName(manifest.getRegionInfo().getTableName()),
+        manifest.getRegionInfo().getStartKey().toByteArray(),
+        manifest.getRegionInfo().getRegionId(), true);
+    return RegionInfo.encodeRegionName(regionName);
   }
 
   /*
