@@ -21,9 +21,9 @@ import java.io.IOException;
 import java.math.BigInteger;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Comparator;
 import java.util.LinkedList;
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 import java.util.TreeMap;
 import org.apache.commons.lang3.ArrayUtils;
@@ -146,15 +146,14 @@ public class RegionSplitter {
    */
   public interface SplitAlgorithm {
     /**
-     * Split a pre-existing region into 2 regions. n * first row (inclusive) n * last row
-     * (exclusive)
+     * Split a pre-existing region into 2 regions. first row (inclusive) last row (exclusive)
      * @return the split row to use
      */
     byte[] split(byte[] start, byte[] end);
 
     /**
-     * Split an entire table. n * number of regions to split the table into n * user input is
-     * validated at this time. may throw a runtime exception in response to a parse failure
+     * Split an entire table. number of regions to split the table into user input is validated at
+     * this time. may throw a runtime exception in response to a parse failure
      * @return array of split keys for the initial regions of the table. The length of the returned
      *         array should be numRegions-1.
      */
@@ -188,7 +187,7 @@ public class RegionSplitter {
 
     /**
      * In HBase, the last row is represented by an empty byte array. Set this value to help the
-     * split code understand how to evenly divide the first region. n * raw user input (may throw
+     * split code understand how to evenly divide the first region. raw user input (may throw
      * RuntimeException on parse failure)
      */
     void setFirstRow(String userInput);
@@ -196,19 +195,19 @@ public class RegionSplitter {
     /**
      * In HBase, the last row is represented by an empty byte array. Set this value to help the
      * split code understand how to evenly divide the last region. Note that this last row is
-     * inclusive for all rows sharing the same prefix. n * raw user input (may throw
-     * RuntimeException on parse failure)
+     * inclusive for all rows sharing the same prefix. raw user input (may throw RuntimeException on
+     * parse failure)
      */
     void setLastRow(String userInput);
 
     /**
-     * n * user or file input for row
+     * user or file input for row
      * @return byte array representation of this row for HBase
      */
     byte[] strToRow(String input);
 
     /**
-     * n * byte array representing a row in HBase
+     * byte array representing a row in HBase
      * @return String to use for debug &amp; file printing
      */
     String rowToStr(byte[] row);
@@ -252,10 +251,9 @@ public class RegionSplitter {
    * </ul>
    * There are three SplitAlgorithms built into RegionSplitter, HexStringSplit, DecimalStringSplit,
    * and UniformSplit. These are different strategies for choosing region boundaries. See their
-   * source code for details. n * Usage: RegionSplitter &lt;TABLE&gt; &lt;SPLITALGORITHM&gt; &lt;-c
+   * source code for details. Usage: RegionSplitter &lt;TABLE&gt; &lt;SPLITALGORITHM&gt; &lt;-c
    * &lt;# regions&gt; -f &lt;family:family:...&gt; | -r [-o &lt;# outstanding splits&gt;]&gt; [-D
-   * &lt;conf.param=value&gt;] n * HBase IO problem n * user requested exit n * problem parsing user
-   * input
+   * &lt;conf.param=value&gt;] HBase IO problem user requested exit problem parsing user input
    */
   @SuppressWarnings("static-access")
   public static void main(String[] args) throws IOException, InterruptedException, ParseException {
@@ -376,8 +374,8 @@ public class RegionSplitter {
   }
 
   /**
-   * Alternative getCurrentNrHRS which is no longer available. n * @return Rough count of
-   * regionservers out on cluster.
+   * Alternative getCurrentNrHRS which is no longer available.
+   * @return Rough count of regionservers out on cluster.
    * @throws IOException if a remote or network exception occurs
    */
   private static int getRegionServerCount(final Connection connection) throws IOException {
@@ -461,13 +459,15 @@ public class RegionSplitter {
                 }
               }
 
+              // Sort the ServerNames by the number of regions they have
+              final List<ServerName> serversLeft = Lists.newArrayList(daughterRegions.keySet());
+              serversLeft.sort(Comparator.comparing(rsSizes::get));
+
               // Round-robin through the ServerName list. Choose the lightest-loaded servers
               // first to keep the master from load-balancing regions as we split.
-              for (Map.Entry<ServerName,
-                LinkedList<Pair<byte[], byte[]>>> daughterRegion : daughterRegions.entrySet()) {
+              for (final ServerName rsLoc : serversLeft) {
                 Pair<byte[], byte[]> dr = null;
-                ServerName rsLoc = daughterRegion.getKey();
-                LinkedList<Pair<byte[], byte[]>> regionList = daughterRegion.getValue();
+                final LinkedList<Pair<byte[], byte[]>> regionList = daughterRegions.get(rsLoc);
 
                 // Find a region in the ServerName list that hasn't been moved
                 LOG.debug("Finding a region on " + rsLoc);
@@ -714,7 +714,7 @@ public class RegionSplitter {
   }
 
   /**
-   * nn * @return A Pair where first item is table dir and second is the split file.
+   * @return A Pair where first item is table dir and second is the split file.
    * @throws IOException if a remote or network exception occurs
    */
   private static Pair<Path, Path> getTableDirAndSplitFile(final Configuration conf,
@@ -980,6 +980,9 @@ public class RegionSplitter {
      * @return the midpoint of the 2 numbers
      */
     public BigInteger split2(BigInteger a, BigInteger b) {
+      if (b.equals(lastRowInt)) {
+        b = b.add(BigInteger.ONE);
+      }
       return a.add(b).divide(BigInteger.valueOf(2)).abs();
     }
 
