@@ -175,6 +175,13 @@ public abstract class HBaseCluster implements Closeable, Configurable {
    */
   public abstract void suspendRegionServer(ServerName serverName) throws IOException;
 
+  /**
+   * Wait for the specified region server to suspend the thread / process.
+   * @throws IOException if something goes wrong or timeout occurs
+   */
+  public abstract void waitForRegionServerToSuspend(ServerName serverName, long timeout)
+    throws IOException;
+
   /**
    * Resume the region server
    * @param serverName the hostname to resume the regionserver on
@@ -182,6 +189,13 @@ public abstract class HBaseCluster implements Closeable, Configurable {
    */
   public abstract void resumeRegionServer(ServerName serverName) throws IOException;
 
+  /**
+   * Wait for the specified region server to resume the thread / process.
+   * @throws IOException if something goes wrong or timeout occurs
+   */
+  public abstract void waitForRegionServerToResume(ServerName serverName, long timeout)
+    throws IOException;
+
   /**
    * Starts a new zookeeper node on the given hostname or if this is a mini/local cluster, silently
    * logs warning message.
@@ -284,6 +298,41 @@ public abstract class HBaseCluster implements Closeable, Configurable {
   public abstract void waitForNameNodeToStop(ServerName serverName, long timeout)
     throws IOException;
 
+  /**
+   * Starts a new journalnode on the given hostname or if this is a mini/local cluster, silently
+   * logs warning message.
+   * @throws IOException if something goes wrong
+   */
+  public abstract void startJournalNode(ServerName serverName) throws IOException;
+
+  /**
+   * Kills the journalnode process if this is a distributed cluster, otherwise, this causes master
+   * to exit doing basic clean up only.
+   * @throws IOException if something goes wrong
+   */
+  public abstract void killJournalNode(ServerName serverName) throws IOException;
+
+  /**
+   * Stops the journalnode if this is a distributed cluster, otherwise silently logs warning
+   * message.
+   * @throws IOException if something goes wrong
+   */
+  public abstract void stopJournalNode(ServerName serverName) throws IOException;
+
+  /**
+   * Wait for the specified journalnode to join the cluster
+   * @throws IOException if something goes wrong or timeout occurs
+   */
+  public abstract void waitForJournalNodeToStart(ServerName serverName, long timeout)
+    throws IOException;
+
+  /**
+   * Wait for the specified journalnode to stop
+   * @throws IOException if something goes wrong or timeout occurs
+   */
+  public abstract void waitForJournalNodeToStop(ServerName serverName, long timeout)
+    throws IOException;
+
   /**
    * Starts a new master on the given hostname or if this is a mini/local cluster, starts a master
    * locally.
