@@ -19,6 +19,7 @@ package org.apache.hadoop.hbase;
 
 import java.io.IOException;
 import java.util.concurrent.CompletableFuture;
+import java.util.function.Supplier;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.client.AsyncConnection;
 import org.apache.hadoop.hbase.client.Connection;
@@ -75,6 +76,10 @@ public final class MiniClusterRule extends ExternalResource {
       return this;
     }
 
+    public Builder setConfiguration(Supplier<Configuration> supplier) {
+      return setConfiguration(supplier.get());
+    }
+
     public MiniClusterRule build() {
       return new MiniClusterRule(conf,
         miniClusterOption != null ? miniClusterOption : StartMiniClusterOption.builder().build());
