@@ -302,6 +302,16 @@ public class MiniHBaseCluster extends HBaseCluster {
     waitOnRegionServer(getRegionServerIndex(serverName));
   }
 
+  @Override
+  public void waitForRegionServerToSuspend(ServerName serverName, long timeout) throws IOException {
+    LOG.warn("Waiting for regionserver to suspend on mini cluster is not supported");
+  }
+
+  @Override
+  public void waitForRegionServerToResume(ServerName serverName, long timeout) throws IOException {
+    LOG.warn("Waiting for regionserver to resume on mini cluster is not supported");
+  }
+
   @Override
   public void startZkNode(String hostname, int port) throws IOException {
     LOG.warn("Starting zookeeper nodes on mini cluster is not supported");
@@ -377,6 +387,31 @@ public class MiniHBaseCluster extends HBaseCluster {
     LOG.warn("Waiting for namenodes to stop on mini cluster is not supported");
   }
 
+  @Override
+  public void startJournalNode(ServerName serverName) {
+    LOG.warn("Starting journalnodes on mini cluster is not supported");
+  }
+
+  @Override
+  public void killJournalNode(ServerName serverName) {
+    LOG.warn("Aborting journalnodes on mini cluster is not supported");
+  }
+
+  @Override
+  public void stopJournalNode(ServerName serverName) {
+    LOG.warn("Stopping journalnodes on mini cluster is not supported");
+  }
+
+  @Override
+  public void waitForJournalNodeToStart(ServerName serverName, long timeout) {
+    LOG.warn("Waiting for journalnodes to start on mini cluster is not supported");
+  }
+
+  @Override
+  public void waitForJournalNodeToStop(ServerName serverName, long timeout) {
+    LOG.warn("Waiting for journalnodes to stop on mini cluster is not supported");
+  }
+
   @Override
   public void startMaster(String hostname, int port) throws IOException {
     this.startMaster();
