@@ -21,14 +21,9 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertTrue;
+
 import java.io.File;
-import java.io.IOException;
-import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
-import java.util.Map.Entry;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.FileUtil;
@@ -39,26 +34,44 @@ import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.http.ssl.KeyStoreTestUtil;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
+import org.apache.hadoop.hbase.testclassification.MiscTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.zookeeper.MiniZooKeeperCluster;
 import org.apache.hadoop.hdfs.MiniDFSCluster;
+import org.apache.hadoop.security.ssl.SSLFactory;
+import org.junit.ClassRule;
+import org.junit.Rule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
+import org.junit.rules.TestName;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * Test our testing utility class
  */
-@Category(LargeTests.class)
+@Category({ MiscTests.class, LargeTests.class })
 public class TestHBaseTestingUtility {
-  private static final Log LOG = LogFactory.getLog(TestHBaseTestingUtility.class);
+  private static final int NUMTABLES = 1;
+  private static final int NUMROWS = 100;
+  private static final int NUMREGIONS = 10;
+
+  @ClassRule
+  public static final HBaseClassTestRule CLASS_RULE =
+    HBaseClassTestRule.forClass(TestHBaseTestingUtility.class);
+
+  private static final Logger LOG = LoggerFactory.getLogger(TestHBaseTestingUtility.class);
+
+  @Rule
+  public TestName name = new TestName();
 
   /**
-   * Basic sanity test that spins up multiple HDFS and HBase clusters that share
-   * the same ZK ensemble. We then create the same table in both and make sure
-   * that what we insert in one place doesn't end up in the other.
-   * @throws Exception
+   * Basic sanity test that spins up multiple HDFS and HBase clusters that share the same ZK
+   * ensemble. We then create the same table in both and make sure that what we insert in one place
+   * doesn't end up in the other.
+   * @throws Exception on error
    */
-  @Test (timeout=180000)
+  @Test
   public void testMultiClusters() throws Exception {
     // Create three clusters
 
@@ -89,17 +102,17 @@ public class TestHBaseTestingUtility {
       htu2.startMiniCluster();
       htu3.startMiniCluster();
 
-      final TableName TABLE_NAME = TableName.valueOf("test");
+      final TableName tableName = TableName.valueOf(name.getMethodName());
       final byte[] FAM_NAME = Bytes.toBytes("fam");
       final byte[] ROW = Bytes.toBytes("row");
       final byte[] QUAL_NAME = Bytes.toBytes("qual");
       final byte[] VALUE = Bytes.toBytes("value");
 
-      Table table1 = htu1.createTable(TABLE_NAME, FAM_NAME);
-      Table table2 = htu2.createTable(TABLE_NAME, FAM_NAME);
+      Table table1 = htu1.createTable(tableName, FAM_NAME);
+      Table table2 = htu2.createTable(tableName, FAM_NAME);
 
       Put put = new Put(ROW);
-      put.add(FAM_NAME, QUAL_NAME, VALUE);
+      put.addColumn(FAM_NAME, QUAL_NAME, VALUE);
       table1.put(put);
 
       Get get = new Get(ROW);
@@ -120,7 +133,8 @@ public class TestHBaseTestingUtility {
     }
   }
 
-  @Test public void testMiniCluster() throws Exception {
+  @Test
+  public void testMiniCluster() throws Exception {
     HBaseTestingUtility hbt = new HBaseTestingUtility();
 
     MiniHBaseCluster cluster = hbt.startMiniCluster();
@@ -145,8 +159,8 @@ public class TestHBaseTestingUtility {
 
   @Test
   public void testMiniClusterWithSSLOn() throws Exception {
-    final String BASEDIR = System.getProperty("test.build.dir",
-        "target/test-dir") + "/" + TestHBaseTestingUtility.class.getSimpleName();
+    final String BASEDIR = System.getProperty("test.build.dir", "target/test-dir") + "/"
+      + TestHBaseTestingUtility.class.getSimpleName();
     String sslConfDir = KeyStoreTestUtil.getClasspathDir(TestHBaseTestingUtility.class);
     String keystoresDir = new File(BASEDIR).getAbsolutePath();
 
@@ -158,8 +172,8 @@ public class TestHBaseTestingUtility {
     KeyStoreTestUtil.setupSSLConfig(keystoresDir, sslConfDir, hbt.getConfiguration(), false);
 
     hbt.getConfiguration().set("hbase.ssl.enabled", "true");
-    hbt.getConfiguration().addResource("ssl-server.xml");
-    hbt.getConfiguration().addResource("ssl-client.xml");
+    hbt.getConfiguration().addResource(hbt.getConfiguration().get(SSLFactory.SSL_CLIENT_CONF_KEY));
+    hbt.getConfiguration().addResource(hbt.getConfiguration().get(SSLFactory.SSL_SERVER_CONF_KEY));
 
     MiniHBaseCluster cluster = hbt.startMiniCluster();
     try {
@@ -170,22 +184,22 @@ public class TestHBaseTestingUtility {
   }
 
   /**
-   *  Test that we can start and stop multiple time a cluster
-   *   with the same HBaseTestingUtility.
+   * Test that we can start and stop multiple time a cluster with the same HBaseTestingUtility.
    */
-  @Test public void testMultipleStartStop() throws Exception{
+  @Test
+  public void testMultipleStartStop() throws Exception {
     HBaseTestingUtility htu1 = new HBaseTestingUtility();
     Path foo = new Path("foo");
 
     htu1.startMiniCluster();
     htu1.getDFSCluster().getFileSystem().create(foo);
-    assertTrue( htu1.getDFSCluster().getFileSystem().exists(foo));
+    assertTrue(htu1.getDFSCluster().getFileSystem().exists(foo));
     htu1.shutdownMiniCluster();
 
     htu1.startMiniCluster();
-    assertFalse( htu1.getDFSCluster().getFileSystem().exists(foo));
+    assertFalse(htu1.getDFSCluster().getFileSystem().exists(foo));
     htu1.getDFSCluster().getFileSystem().create(foo);
-    assertTrue( htu1.getDFSCluster().getFileSystem().exists(foo));
+    assertTrue(htu1.getDFSCluster().getFileSystem().exists(foo));
     htu1.shutdownMiniCluster();
   }
 
@@ -220,7 +234,7 @@ public class TestHBaseTestingUtility {
       // kill another active zk server
       currentActivePort = cluster2.killCurrentActiveZooKeeperServer();
       assertTrue(currentActivePort >= defaultClientPort);
-      assertTrue(cluster2.getClientPort() == currentActivePort);      
+      assertTrue(cluster2.getClientPort() == currentActivePort);
       assertEquals(2, cluster2.getBackupZooKeeperServerNum());
       assertEquals(3, cluster2.getZooKeeperServerNum());
 
@@ -250,13 +264,15 @@ public class TestHBaseTestingUtility {
     HBaseTestingUtility hbt = new HBaseTestingUtility();
 
     // Test 1 - set up zookeeper cluster with same number of ZK servers and specified client ports
-    int [] clientPortList1 = {1111, 1112, 1113};
+    int[] clientPortList1 = { 1111, 1112, 1113 };
     MiniZooKeeperCluster cluster1 = hbt.startMiniZKCluster(clientPortList1.length, clientPortList1);
     try {
       List<Integer> clientPortListInCluster = cluster1.getClientPortList();
 
       for (i = 0; i < clientPortListInCluster.size(); i++) {
-        assertEquals(clientPortListInCluster.get(i).intValue(), clientPortList1[i]);
+        // cannot assert the specific port due to the port conflict in which situation
+        // it always chooses a bigger port by +1. The below is the same.
+        assertTrue(clientPortListInCluster.get(i).intValue() >= clientPortList1[i]);
       }
     } finally {
       hbt.shutdownMiniZKCluster();
@@ -264,20 +280,20 @@ public class TestHBaseTestingUtility {
 
     // Test 2 - set up zookeeper cluster with more ZK servers than specified client ports
     hbt.getConfiguration().setInt("test.hbase.zookeeper.property.clientPort", defaultClientPort);
-    int [] clientPortList2 = {2222, 2223};
+    int[] clientPortList2 = { 2222, 2223 };
     MiniZooKeeperCluster cluster2 =
-        hbt.startMiniZKCluster(clientPortList2.length + 2, clientPortList2);
+      hbt.startMiniZKCluster(clientPortList2.length + 2, clientPortList2);
 
     try {
       List<Integer> clientPortListInCluster = cluster2.getClientPortList();
 
       for (i = 0, j = 0; i < clientPortListInCluster.size(); i++) {
         if (i < clientPortList2.length) {
-          assertEquals(clientPortListInCluster.get(i).intValue(), clientPortList2[i]);
+          assertTrue(clientPortListInCluster.get(i).intValue() >= clientPortList2[i]);
         } else {
           // servers with no specified client port will use defaultClientPort or some other ports
           // based on defaultClientPort
-          assertEquals(clientPortListInCluster.get(i).intValue(), defaultClientPort + j);
+          assertTrue(clientPortListInCluster.get(i).intValue() >= defaultClientPort + j);
           j++;
         }
       }
@@ -287,9 +303,9 @@ public class TestHBaseTestingUtility {
 
     // Test 3 - set up zookeeper cluster with invalid client ports
     hbt.getConfiguration().setInt("test.hbase.zookeeper.property.clientPort", defaultClientPort);
-    int [] clientPortList3 = {3333, -3334, 3335, 0};
+    int[] clientPortList3 = { 3333, -3334, 3335, 0 };
     MiniZooKeeperCluster cluster3 =
-        hbt.startMiniZKCluster(clientPortList3.length + 1, clientPortList3);
+      hbt.startMiniZKCluster(clientPortList3.length + 1, clientPortList3);
 
     try {
       List<Integer> clientPortListInCluster = cluster3.getClientPortList();
@@ -298,9 +314,9 @@ public class TestHBaseTestingUtility {
         // Servers will only use valid client ports; if ports are not specified or invalid,
         // the default port or a port based on default port will be used.
         if (i < clientPortList3.length && clientPortList3[i] > 0) {
-          assertEquals(clientPortListInCluster.get(i).intValue(), clientPortList3[i]);
+          assertTrue(clientPortListInCluster.get(i).intValue() >= clientPortList3[i]);
         } else {
-          assertEquals(clientPortListInCluster.get(i).intValue(), defaultClientPort + j);
+          assertTrue(clientPortListInCluster.get(i).intValue() >= defaultClientPort + j);
           j++;
         }
       }
@@ -313,9 +329,9 @@ public class TestHBaseTestingUtility {
     // the algorithm should choice defaultClientPort+1 and defaultClientPort+3 to fill
     // out the ports for servers without ports specified.
     hbt.getConfiguration().setInt("test.hbase.zookeeper.property.clientPort", defaultClientPort);
-    int [] clientPortList4 = {-4444, defaultClientPort+2, 4446, defaultClientPort};
+    int[] clientPortList4 = { -4444, defaultClientPort + 2, 4446, defaultClientPort };
     MiniZooKeeperCluster cluster4 =
-        hbt.startMiniZKCluster(clientPortList4.length + 1, clientPortList4);
+      hbt.startMiniZKCluster(clientPortList4.length + 1, clientPortList4);
 
     try {
       List<Integer> clientPortListInCluster = cluster4.getClientPortList();
@@ -324,10 +340,10 @@ public class TestHBaseTestingUtility {
         // Servers will only use valid client ports; if ports are not specified or invalid,
         // the default port or a port based on default port will be used.
         if (i < clientPortList4.length && clientPortList4[i] > 0) {
-          assertEquals(clientPortListInCluster.get(i).intValue(), clientPortList4[i]);
+          assertTrue(clientPortListInCluster.get(i).intValue() >= clientPortList4[i]);
         } else {
-          assertEquals(clientPortListInCluster.get(i).intValue(), defaultClientPort + j);
-          j +=2;
+          assertTrue(clientPortListInCluster.get(i).intValue() >= defaultClientPort + j);
+          j += 2;
         }
       }
     } finally {
@@ -335,11 +351,11 @@ public class TestHBaseTestingUtility {
     }
 
     // Test 5 - set up zookeeper cluster with same ports specified - fail is expected.
-    int [] clientPortList5 = {5555, 5556, 5556};
+    int[] clientPortList5 = { 5555, 5556, 5556 };
 
     try {
       MiniZooKeeperCluster cluster5 =
-          hbt.startMiniZKCluster(clientPortList5.length, clientPortList5);
+        hbt.startMiniZKCluster(clientPortList5.length, clientPortList5);
       assertTrue(cluster5.getClientPort() == -1); // expected failure
     } catch (Exception e) {
       // exception is acceptable
@@ -348,7 +364,8 @@ public class TestHBaseTestingUtility {
     }
   }
 
-  @Test public void testMiniDFSCluster() throws Exception {
+  @Test
+  public void testMiniDFSCluster() throws Exception {
     HBaseTestingUtility hbt = new HBaseTestingUtility();
     MiniDFSCluster cluster = hbt.startMiniDFSCluster(null);
     FileSystem dfs = cluster.getFileSystem();
@@ -361,7 +378,8 @@ public class TestHBaseTestingUtility {
     hbt.shutdownMiniCluster();
   }
 
-  @Test public void testSetupClusterTestBuildDir() throws Exception {
+  @Test
+  public void testSetupClusterTestBuildDir() throws Exception {
     HBaseTestingUtility hbt = new HBaseTestingUtility();
     Path testdir = hbt.getClusterTestDir();
     LOG.info("uuid-subdir=" + testdir);
@@ -376,7 +394,8 @@ public class TestHBaseTestingUtility {
     assertFalse(fs.exists(testdir));
   }
 
-  @Test public void testTestDir() throws Exception {
+  @Test
+  public void testTestDir() throws Exception {
     HBaseTestingUtility hbt = new HBaseTestingUtility();
     Path testdir = hbt.getDataTestDir();
     LOG.info("testdir=" + testdir);
@@ -386,56 +405,24 @@ public class TestHBaseTestingUtility {
     assertTrue(hbt.cleanupTestDir());
   }
 
-  @Test public void testMRYarnConfigsPopulation() throws IOException {
-    Map<String, String> dummyProps = new HashMap<>();
-    dummyProps.put("mapreduce.jobtracker.address", "dummyhost:11234");
-    dummyProps.put("yarn.resourcemanager.address", "dummyhost:11235");
-    dummyProps.put("mapreduce.jobhistory.address", "dummyhost:11236");
-    dummyProps.put("yarn.resourcemanager.scheduler.address", "dummyhost:11237");
-    dummyProps.put("mapreduce.jobhistory.webapp.address", "dummyhost:11238");
-    dummyProps.put("yarn.resourcemanager.webapp.address", "dummyhost:11239");
-  
-    HBaseTestingUtility hbt = new HBaseTestingUtility();
-    
-    // populate the mr props to the Configuration instance
-    for (Entry<String, String> entry : dummyProps.entrySet()) {
-      hbt.getConfiguration().set(entry.getKey(), entry.getValue());
-    }
-    
-    for (Entry<String,String> entry : dummyProps.entrySet()) {
-      assertTrue("The Configuration for key " + entry.getKey() +" and value: " + entry.getValue() +
-                 " is not populated correctly", hbt.getConfiguration().get(entry.getKey()).equals(entry.getValue()));
-    }
-
-    hbt.startMiniMapReduceCluster();
-    
-    // Confirm that MiniMapReduceCluster overwrites the mr properties and updates the Configuration 
-    for (Entry<String,String> entry : dummyProps.entrySet()) {
-      assertFalse("The MR prop: " + entry.getValue() + " is not overwritten when map reduce mini"+
-                  "cluster is started", hbt.getConfiguration().get(entry.getKey()).equals(entry.getValue()));
-    }
-    
-    hbt.shutdownMiniMapReduceCluster();
-  }
-
   @Test
   public void testOverridingOfDefaultPorts() throws Exception {
     // confirm that default port properties being overridden to random
     Configuration defaultConfig = HBaseConfiguration.create();
     defaultConfig.setInt(HConstants.MASTER_INFO_PORT, HConstants.DEFAULT_MASTER_INFOPORT);
     defaultConfig.setInt(HConstants.REGIONSERVER_INFO_PORT,
-            HConstants.DEFAULT_REGIONSERVER_INFOPORT);
+      HConstants.DEFAULT_REGIONSERVER_INFOPORT);
     HBaseTestingUtility htu = new HBaseTestingUtility(defaultConfig);
     try {
       MiniHBaseCluster defaultCluster = htu.startMiniCluster();
       final String masterHostPort =
-              defaultCluster.getMaster().getServerName().getAddress().toString();
+        defaultCluster.getMaster().getServerName().getAddress().toString();
       assertNotEquals(HConstants.DEFAULT_MASTER_INFOPORT,
-              defaultCluster.getConfiguration().getInt(HConstants.MASTER_INFO_PORT, 0));
+        defaultCluster.getConfiguration().getInt(HConstants.MASTER_INFO_PORT, 0));
       assertNotEquals(HConstants.DEFAULT_REGIONSERVER_INFOPORT,
-              defaultCluster.getConfiguration().getInt(HConstants.REGIONSERVER_INFO_PORT, 0));
+        defaultCluster.getConfiguration().getInt(HConstants.REGIONSERVER_INFO_PORT, 0));
       assertEquals(masterHostPort,
-              defaultCluster.getConfiguration().get(HConstants.MASTER_ADDRS_KEY));
+        defaultCluster.getConfiguration().get(HConstants.MASTER_ADDRS_KEY));
     } finally {
       htu.shutdownMiniCluster();
     }
@@ -446,21 +433,47 @@ public class TestHBaseTestingUtility {
     final int nonDefaultRegionServerPort = 4444;
     altConfig.setInt(HConstants.MASTER_INFO_PORT, nonDefaultMasterInfoPort);
     altConfig.setInt(HConstants.REGIONSERVER_INFO_PORT, nonDefaultRegionServerPort);
-    altConfig.setBoolean(LocalHBaseCluster.ASSIGN_RANDOM_PORTS, false);
     htu = new HBaseTestingUtility(altConfig);
     try {
       MiniHBaseCluster customCluster = htu.startMiniCluster();
       final String masterHostPort =
-              customCluster.getMaster().getServerName().getAddress().toString();
+        customCluster.getMaster().getServerName().getAddress().toString();
       assertEquals(nonDefaultMasterInfoPort,
-              customCluster.getConfiguration().getInt(HConstants.MASTER_INFO_PORT, 0));
+        customCluster.getConfiguration().getInt(HConstants.MASTER_INFO_PORT, 0));
       assertEquals(nonDefaultRegionServerPort,
-              customCluster.getConfiguration().getInt(HConstants.REGIONSERVER_INFO_PORT, 0));
+        customCluster.getConfiguration().getInt(HConstants.REGIONSERVER_INFO_PORT, 0));
       assertEquals(masterHostPort,
-              customCluster.getConfiguration().get(HConstants.MASTER_ADDRS_KEY));
+        customCluster.getConfiguration().get(HConstants.MASTER_ADDRS_KEY));
     } finally {
       htu.shutdownMiniCluster();
     }
   }
-}
 
+  // This test demonstrates how long killHBTU takes vs. shutdownHBTU takes
+  // for realistic results, adjust NUMROWS, NUMTABLES to much larger number.
+  @Test
+  public void testKillMiniHBaseCluster() throws Exception {
+
+    HBaseTestingUtility htu = new HBaseTestingUtility();
+    htu.startMiniZKCluster();
+
+    try {
+      htu.startMiniHBaseCluster();
+
+      TableName tableName;
+      byte[] FAM_NAME;
+
+      for (int i = 0; i < NUMTABLES; i++) {
+        tableName = TableName.valueOf(name.getMethodName() + i);
+        FAM_NAME = Bytes.toBytes("fam" + i);
+
+        try (Table table = htu.createMultiRegionTable(tableName, FAM_NAME, NUMREGIONS)) {
+          htu.loadRandomRows(table, FAM_NAME, 100, NUMROWS);
+        }
+      }
+    } finally {
+      htu.killMiniHBaseCluster();
+      htu.shutdownMiniZKCluster();
+    }
+  }
+}
