@@ -347,7 +347,7 @@ public class TestHFileArchiving {
 
   /**
    * Test that the region directory is removed when we archive a region without store files, but
-   * still has hidden files. n
+   * still has hidden files.
    */
   @Test
   public void testDeleteRegionWithNoStoreFiles() throws Exception {
@@ -566,7 +566,7 @@ public class TestHFileArchiving {
   }
 
   /**
-   * Test that the store files are archived when a column family is removed. n
+   * Test that the store files are archived when a column family is removed.
    */
   @Test
   public void testArchiveOnTableFamilyDelete() throws Exception {
@@ -651,7 +651,8 @@ public class TestHFileArchiving {
 
         try {
           // Try to archive the file
-          HFileArchiver.archiveRegion(fs, rootDir, sourceRegionDir.getParent(), sourceRegionDir);
+          HFileArchiver.archiveRegion(conf, fs, rootDir, sourceRegionDir.getParent(),
+            sourceRegionDir);
 
           // The archiver succeded, the file is no longer in the original location
           // but it's in the archive location.
@@ -682,12 +683,14 @@ public class TestHFileArchiving {
   public void testArchiveRegionTableAndRegionDirsNull() throws IOException {
     Path rootDir = UTIL.getDataTestDirOnTestFS("testCleaningRace");
     FileSystem fileSystem = UTIL.getTestFileSystem();
+    Configuration conf = UTIL.getMiniHBaseCluster().getMaster().getConfiguration();
     // Try to archive the file but with null regionDir, can't delete sourceFile
-    assertFalse(HFileArchiver.archiveRegion(fileSystem, rootDir, null, null));
+    assertFalse(HFileArchiver.archiveRegion(conf, fileSystem, rootDir, null, null));
   }
 
   @Test
   public void testArchiveRegionWithTableDirNull() throws IOException {
+    Configuration conf = UTIL.getMiniHBaseCluster().getMaster().getConfiguration();
     Path regionDir = new Path(
       CommonFSUtils.getTableDir(new Path("./"), TableName.valueOf(name.getMethodName())), "xyzabc");
     Path familyDir = new Path(regionDir, "rd");
@@ -699,12 +702,13 @@ public class TestHFileArchiving {
     Path sourceRegionDir = new Path(rootDir, regionDir);
     fileSystem.mkdirs(sourceRegionDir);
     // Try to archive the file
-    assertFalse(HFileArchiver.archiveRegion(fileSystem, rootDir, null, sourceRegionDir));
+    assertFalse(HFileArchiver.archiveRegion(conf, fileSystem, rootDir, null, sourceRegionDir));
     assertFalse(fileSystem.exists(sourceRegionDir));
   }
 
   @Test
   public void testArchiveRegionWithRegionDirNull() throws IOException {
+    Configuration conf = UTIL.getMiniHBaseCluster().getMaster().getConfiguration();
     Path regionDir =
       new Path(CommonFSUtils.getTableDir(new Path("./"), TableName.valueOf(name.getMethodName())),
         "elgn4nf");
@@ -718,7 +722,7 @@ public class TestHFileArchiving {
     fileSystem.mkdirs(sourceRegionDir);
     // Try to archive the file but with null regionDir, can't delete sourceFile
     assertFalse(
-      HFileArchiver.archiveRegion(fileSystem, rootDir, sourceRegionDir.getParent(), null));
+      HFileArchiver.archiveRegion(conf, fileSystem, rootDir, sourceRegionDir.getParent(), null));
     assertTrue(fileSystem.exists(sourceRegionDir));
     fileSystem.delete(sourceRegionDir, true);
   }
@@ -732,7 +736,7 @@ public class TestHFileArchiving {
    * Get the names of all the files below the given directory
    * @param fs         the file system to inspect
    * @param archiveDir the directory in which to look
-   * @return a list of all files in the directory and sub-directories n
+   * @return a list of all files in the directory and sub-directories
    */
   private List<String> getAllFileNames(final FileSystem fs, Path archiveDir) throws IOException {
     FileStatus[] files = CommonFSUtils.listStatus(fs, archiveDir, new PathFilter() {
