@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -40,6 +40,7 @@ import java.util.concurrent.ExecutionException;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
 import org.apache.hadoop.hbase.HConstants;
+import org.apache.hadoop.hbase.ReplicationPeerNotFoundException;
 import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.replication.ReplicationException;
@@ -310,8 +311,8 @@ public class TestAsyncReplicationAdminApi extends TestAsyncAdminBase {
       tableCFs.clear();
       tableCFs.put(tableName3, null);
       admin.removeReplicationPeerTableCFs(ID_ONE, tableCFs).join();
-      fail("Test case should fail as removing table-cfs from a peer whose" +
-        " table-cfs didn't contain t3");
+      fail("Test case should fail as removing table-cfs from a peer whose"
+        + " table-cfs didn't contain t3");
     } catch (CompletionException e) {
       assertTrue(e.getCause() instanceof ReplicationException);
     }
@@ -477,6 +478,14 @@ public class TestAsyncReplicationAdminApi extends TestAsyncAdminBase {
     }
   }
 
+  @Test
+  public void testClusterKeyWithTrailingSpace() throws Exception {
+    admin.addReplicationPeer(ID_ONE,
+      ReplicationPeerConfig.newBuilder().setClusterKey(KEY_ONE + " ").build()).get();
+    String clusterKey = admin.getReplicationPeerConfig(ID_ONE).get().getClusterKey();
+    assertEquals(KEY_ONE, clusterKey);
+  }
+
   @Test
   public void testInvalidReplicationEndpoint() throws InterruptedException {
     try {
@@ -509,4 +518,18 @@ public class TestAsyncReplicationAdminApi extends TestAsyncAdminBase {
       assertThat(e.getCause(), instanceOf(DoNotRetryIOException.class));
     }
   }
+
+  /*
+   * Tests that admin api throws ReplicationPeerNotFoundException if peer doesn't exist.
+   */
+  @Test
+  public void testReplicationPeerNotFoundException() throws InterruptedException {
+    String dummyPeer = "dummy_peer";
+    try {
+      admin.removeReplicationPeer(dummyPeer).get();
+      fail();
+    } catch (ExecutionException e) {
+      assertThat(e.getCause(), instanceOf(ReplicationPeerNotFoundException.class));
+    }
+  }
 }
