@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -143,15 +143,15 @@ public class TestAsyncTableNoncedRetry {
   }
 
   @Test
-  public void testAppendWhenReturnResultsEqualsFalse() throws InterruptedException,
-    ExecutionException {
+  public void testAppendWhenReturnResultsEqualsFalse()
+    throws InterruptedException, ExecutionException {
     assertEquals(0, CALLED.get());
     AsyncTable<?> table = ASYNC_CONN.getTableBuilder(TABLE_NAME)
       .setRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 1;
-    Result result = table.append(new Append(row).addColumn(FAMILY, QUALIFIER, VALUE)
-      .setReturnResults(false)).get();
+    Result result = table
+      .append(new Append(row).addColumn(FAMILY, QUALIFIER, VALUE).setReturnResults(false)).get();
 
     // make sure we called twice and the result is still correct
     assertEquals(2, CALLED.get());
@@ -173,15 +173,15 @@ public class TestAsyncTableNoncedRetry {
   }
 
   @Test
-  public void testIncrementWhenReturnResultsEqualsFalse() throws InterruptedException,
-    ExecutionException {
+  public void testIncrementWhenReturnResultsEqualsFalse()
+    throws InterruptedException, ExecutionException {
     assertEquals(0, CALLED.get());
     AsyncTable<?> table = ASYNC_CONN.getTableBuilder(TABLE_NAME)
       .setRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 1;
-    Result result = table.increment(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L)
-      .setReturnResults(false)).get();
+    Result result = table
+      .increment(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L).setReturnResults(false)).get();
 
     // make sure we called twice and the result is still correct
     assertEquals(2, CALLED.get());
@@ -196,9 +196,9 @@ public class TestAsyncTableNoncedRetry {
       .setWriteRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 1;
-    Result result = table.mutateRow(new RowMutations(row)
-      .add(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L))
-      .add((Mutation) new Delete(row).addColumn(FAMILY, QUALIFIER2))).get();
+    Result result =
+      table.mutateRow(new RowMutations(row).add(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L))
+        .add((Mutation) new Delete(row).addColumn(FAMILY, QUALIFIER2))).get();
 
     // make sure we called twice and the result is still correct
     assertEquals(2, CALLED.get());
@@ -213,9 +213,9 @@ public class TestAsyncTableNoncedRetry {
       .setWriteRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 1;
-    Result result = table.mutateRow(new RowMutations(row)
-      .add(new Append(row).addColumn(FAMILY, QUALIFIER, VALUE))
-      .add((Mutation) new Delete(row).addColumn(FAMILY, QUALIFIER2))).get();
+    Result result =
+      table.mutateRow(new RowMutations(row).add(new Append(row).addColumn(FAMILY, QUALIFIER, VALUE))
+        .add((Mutation) new Delete(row).addColumn(FAMILY, QUALIFIER2))).get();
 
     // make sure we called twice and the result is still correct
     assertEquals(2, CALLED.get());
@@ -230,9 +230,9 @@ public class TestAsyncTableNoncedRetry {
       .setWriteRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 1;
-    Result result = table.mutateRow(new RowMutations(row)
-      .add(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L))
-      .add(new Append(row).addColumn(FAMILY, QUALIFIER2, VALUE))).get();
+    Result result =
+      table.mutateRow(new RowMutations(row).add(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L))
+        .add(new Append(row).addColumn(FAMILY, QUALIFIER2, VALUE))).get();
 
     // make sure we called twice and the result is still correct
     assertEquals(2, CALLED.get());
@@ -247,9 +247,9 @@ public class TestAsyncTableNoncedRetry {
       .setRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 1;
-    CheckAndMutateResult result = table.checkAndMutate(CheckAndMutate.newBuilder(row)
-      .ifNotExists(FAMILY, QUALIFIER2)
-      .build(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L))).get();
+    CheckAndMutateResult result =
+      table.checkAndMutate(CheckAndMutate.newBuilder(row).ifNotExists(FAMILY, QUALIFIER2)
+        .build(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L))).get();
 
     // make sure we called twice and the result is still correct
     assertEquals(2, CALLED.get());
@@ -264,9 +264,9 @@ public class TestAsyncTableNoncedRetry {
       .setRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 1;
-    CheckAndMutateResult result = table.checkAndMutate(CheckAndMutate.newBuilder(row)
-      .ifNotExists(FAMILY, QUALIFIER2)
-      .build(new Append(row).addColumn(FAMILY, QUALIFIER, VALUE))).get();
+    CheckAndMutateResult result =
+      table.checkAndMutate(CheckAndMutate.newBuilder(row).ifNotExists(FAMILY, QUALIFIER2)
+        .build(new Append(row).addColumn(FAMILY, QUALIFIER, VALUE))).get();
 
     // make sure we called twice and the result is still correct
     assertEquals(2, CALLED.get());
@@ -275,17 +275,18 @@ public class TestAsyncTableNoncedRetry {
   }
 
   @Test
-  public void testIncrementInRowMutationsInCheckAndMutate() throws InterruptedException,
-    ExecutionException, IOException {
+  public void testIncrementInRowMutationsInCheckAndMutate()
+    throws InterruptedException, ExecutionException, IOException {
     assertEquals(0, CALLED.get());
     AsyncTable<?> table = ASYNC_CONN.getTableBuilder(TABLE_NAME)
       .setRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 1;
-    CheckAndMutateResult result = table.checkAndMutate(CheckAndMutate.newBuilder(row)
-      .ifNotExists(FAMILY, QUALIFIER3)
-      .build(new RowMutations(row).add(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L))
-        .add((Mutation) new Delete(row).addColumn(FAMILY, QUALIFIER2)))).get();
+    CheckAndMutateResult result =
+      table.checkAndMutate(CheckAndMutate.newBuilder(row).ifNotExists(FAMILY, QUALIFIER3)
+        .build(new RowMutations(row).add(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L))
+          .add((Mutation) new Delete(row).addColumn(FAMILY, QUALIFIER2))))
+        .get();
 
     // make sure we called twice and the result is still correct
     assertEquals(2, CALLED.get());
@@ -294,17 +295,18 @@ public class TestAsyncTableNoncedRetry {
   }
 
   @Test
-  public void testAppendInRowMutationsInCheckAndMutate() throws InterruptedException,
-    ExecutionException, IOException {
+  public void testAppendInRowMutationsInCheckAndMutate()
+    throws InterruptedException, ExecutionException, IOException {
     assertEquals(0, CALLED.get());
     AsyncTable<?> table = ASYNC_CONN.getTableBuilder(TABLE_NAME)
       .setRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 1;
-    CheckAndMutateResult result = table.checkAndMutate(CheckAndMutate.newBuilder(row)
-      .ifNotExists(FAMILY, QUALIFIER3)
-      .build(new RowMutations(row).add(new Append(row).addColumn(FAMILY, QUALIFIER, VALUE))
-        .add((Mutation) new Delete(row).addColumn(FAMILY, QUALIFIER2)))).get();
+    CheckAndMutateResult result =
+      table.checkAndMutate(CheckAndMutate.newBuilder(row).ifNotExists(FAMILY, QUALIFIER3)
+        .build(new RowMutations(row).add(new Append(row).addColumn(FAMILY, QUALIFIER, VALUE))
+          .add((Mutation) new Delete(row).addColumn(FAMILY, QUALIFIER2))))
+        .get();
 
     // make sure we called twice and the result is still correct
     assertEquals(2, CALLED.get());
@@ -313,17 +315,18 @@ public class TestAsyncTableNoncedRetry {
   }
 
   @Test
-  public void testIncrementAndAppendInRowMutationsInCheckAndMutate() throws InterruptedException,
-    ExecutionException, IOException {
+  public void testIncrementAndAppendInRowMutationsInCheckAndMutate()
+    throws InterruptedException, ExecutionException, IOException {
     assertEquals(0, CALLED.get());
     AsyncTable<?> table = ASYNC_CONN.getTableBuilder(TABLE_NAME)
       .setRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 1;
-    CheckAndMutateResult result = table.checkAndMutate(CheckAndMutate.newBuilder(row)
-      .ifNotExists(FAMILY, QUALIFIER3)
-      .build(new RowMutations(row).add(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L))
-        .add(new Append(row).addColumn(FAMILY, QUALIFIER2, VALUE)))).get();
+    CheckAndMutateResult result =
+      table.checkAndMutate(CheckAndMutate.newBuilder(row).ifNotExists(FAMILY, QUALIFIER3)
+        .build(new RowMutations(row).add(new Increment(row).addColumn(FAMILY, QUALIFIER, 1L))
+          .add(new Append(row).addColumn(FAMILY, QUALIFIER2, VALUE))))
+        .get();
 
     // make sure we called twice and the result is still correct
     assertEquals(2, CALLED.get());
@@ -333,8 +336,7 @@ public class TestAsyncTableNoncedRetry {
   }
 
   @Test
-  public void testBatch() throws InterruptedException,
-    ExecutionException, IOException {
+  public void testBatch() throws InterruptedException, ExecutionException, IOException {
     byte[] row2 = Bytes.toBytes(Bytes.toString(row) + "2");
     byte[] row3 = Bytes.toBytes(Bytes.toString(row) + "3");
     byte[] row4 = Bytes.toBytes(Bytes.toString(row) + "4");
@@ -347,22 +349,19 @@ public class TestAsyncTableNoncedRetry {
       .setRpcTimeout(RPC_TIMEOUT, TimeUnit.MILLISECONDS).build();
 
     miniBatchOperationCount = 6;
-    List<Object> results = table.batchAll(Arrays.asList(
-      new Append(row).addColumn(FAMILY, QUALIFIER, VALUE),
-      new Increment(row2).addColumn(FAMILY, QUALIFIER, 1L),
-      new RowMutations(row3)
-        .add(new Increment(row3).addColumn(FAMILY, QUALIFIER, 1L))
-        .add(new Append(row3).addColumn(FAMILY, QUALIFIER2, VALUE)),
-      CheckAndMutate.newBuilder(row4)
-        .ifNotExists(FAMILY, QUALIFIER2)
-        .build(new Increment(row4).addColumn(FAMILY, QUALIFIER, 1L)),
-      CheckAndMutate.newBuilder(row5)
-        .ifNotExists(FAMILY, QUALIFIER2)
-        .build(new Append(row5).addColumn(FAMILY, QUALIFIER, VALUE)),
-      CheckAndMutate.newBuilder(row6)
-        .ifNotExists(FAMILY, QUALIFIER3)
-        .build(new RowMutations(row6).add(new Increment(row6).addColumn(FAMILY, QUALIFIER, 1L))
-          .add(new Append(row6).addColumn(FAMILY, QUALIFIER2, VALUE))))).get();
+    List<Object> results =
+      table.batchAll(Arrays.asList(new Append(row).addColumn(FAMILY, QUALIFIER, VALUE),
+        new Increment(row2).addColumn(FAMILY, QUALIFIER, 1L),
+        new RowMutations(row3).add(new Increment(row3).addColumn(FAMILY, QUALIFIER, 1L))
+          .add(new Append(row3).addColumn(FAMILY, QUALIFIER2, VALUE)),
+        CheckAndMutate.newBuilder(row4).ifNotExists(FAMILY, QUALIFIER2)
+          .build(new Increment(row4).addColumn(FAMILY, QUALIFIER, 1L)),
+        CheckAndMutate.newBuilder(row5).ifNotExists(FAMILY, QUALIFIER2)
+          .build(new Append(row5).addColumn(FAMILY, QUALIFIER, VALUE)),
+        CheckAndMutate.newBuilder(row6).ifNotExists(FAMILY, QUALIFIER3)
+          .build(new RowMutations(row6).add(new Increment(row6).addColumn(FAMILY, QUALIFIER, 1L))
+            .add(new Append(row6).addColumn(FAMILY, QUALIFIER2, VALUE)))))
+        .get();
 
     // make sure we called twice and the result is still correct
 
