@@ -70,6 +70,7 @@ import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.JVMClusterUtil;
 import org.apache.hadoop.hbase.util.ManualEnvironmentEdge;
+import org.apache.hadoop.hbase.util.ReflectionUtils;
 import org.apache.hadoop.hbase.util.Threads;
 import org.junit.After;
 import org.junit.AfterClass;
@@ -436,7 +437,7 @@ public class TestConnectionImplementation {
 
   /**
    * Test that the connection to the dead server is cut immediately when we receive the
-   * notification. n
+   * notification.
    */
   @Test
   public void testConnectionCut() throws Exception {
@@ -532,7 +533,7 @@ public class TestConnectionImplementation {
   }
 
   /**
-   * Test that when we delete a location using the first row of a region that we really delete it. n
+   * Test that when we delete a location using the first row of a region that we really delete it.
    */
   @Test
   public void testRegionCaching() throws Exception {
@@ -719,7 +720,7 @@ public class TestConnectionImplementation {
   }
 
   /**
-   * Test that Connection or Pool are not closed when managed externally n
+   * Test that Connection or Pool are not closed when managed externally
    */
   @Test
   public void testConnectionManagement() throws Exception {
@@ -850,7 +851,7 @@ public class TestConnectionImplementation {
   private int setNumTries(ConnectionImplementation hci, int newVal) throws Exception {
     Field numTries = hci.getClass().getDeclaredField("numTries");
     numTries.setAccessible(true);
-    Field modifiersField = Field.class.getDeclaredField("modifiers");
+    Field modifiersField = ReflectionUtils.getModifiersField();
     modifiersField.setAccessible(true);
     modifiersField.setInt(numTries, numTries.getModifiers() & ~Modifier.FINAL);
     final int prevNumRetriesVal = (Integer) numTries.get(hci);
@@ -1137,8 +1138,8 @@ public class TestConnectionImplementation {
 
     private final Class<? extends HBaseServerException> exceptionClass;
 
-    public ThrowingCallerFactory(Configuration conf) {
-      super(conf);
+    public ThrowingCallerFactory(Configuration conf, ConnectionConfiguration connectionConfig) {
+      super(conf, connectionConfig);
       this.exceptionClass =
         conf.getClass("testSpecialPauseException", null, HBaseServerException.class);
     }
