@@ -17,10 +17,14 @@
  */
 package org.apache.hadoop.hbase.client;
 
+import static org.apache.hadoop.hbase.client.metrics.ScanMetrics.REGIONS_SCANNED_METRIC_NAME;
+import static org.apache.hadoop.hbase.client.metrics.ServerSideScanMetrics.COUNT_OF_ROWS_SCANNED_KEY_METRIC_NAME;
+
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.util.Arrays;
 import java.util.List;
+import java.util.Map;
 import java.util.stream.Collectors;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileStatus;
@@ -33,6 +37,8 @@ import org.apache.hadoop.hbase.HBaseTestingUtility;
 import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.StartMiniClusterOption;
 import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.metrics.ScanMetrics;
+import org.apache.hadoop.hbase.client.metrics.ScanMetricsRegionInfo;
 import org.apache.hadoop.hbase.master.cleaner.TimeToLiveHFileCleaner;
 import org.apache.hadoop.hbase.master.snapshot.SnapshotManager;
 import org.apache.hadoop.hbase.regionserver.HRegion;
@@ -44,11 +50,13 @@ import org.apache.hadoop.hbase.testclassification.ClientTests;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.FSUtils;
 import org.apache.hadoop.hbase.util.HFileArchiveUtil;
 import org.apache.hadoop.hbase.util.JVMClusterUtil.RegionServerThread;
 import org.junit.After;
 import org.junit.Assert;
+import org.junit.Before;
 import org.junit.ClassRule;
 import org.junit.Rule;
 import org.junit.Test;
@@ -73,6 +81,7 @@ public class TestTableSnapshotScanner {
 
   private FileSystem fs;
   private Path rootDir;
+  private boolean clusterUp;
 
   @Rule
   public TestName name = new TestName();
@@ -88,29 +97,30 @@ public class TestTableSnapshotScanner {
     }
   }
 
+  @Before
   public void setupCluster() throws Exception {
     setupConf(UTIL.getConfiguration());
     StartMiniClusterOption option =
       StartMiniClusterOption.builder().numRegionServers(NUM_REGION_SERVERS)
         .numDataNodes(NUM_REGION_SERVERS).createRootDir(true).build();
     UTIL.startMiniCluster(option);
+    clusterUp = true;
     rootDir = UTIL.getHBaseCluster().getMaster().getMasterFileSystem().getRootDir();
     fs = rootDir.getFileSystem(UTIL.getConfiguration());
   }
 
+  @After
   public void tearDownCluster() throws Exception {
-    UTIL.shutdownMiniCluster();
+    if (clusterUp) {
+      UTIL.shutdownMiniCluster();
+    }
   }
 
-  private static void setupConf(Configuration conf) {
+  protected void setupConf(Configuration conf) {
     // Enable snapshot
     conf.setBoolean(SnapshotManager.HBASE_SNAPSHOT_ENABLED, true);
   }
 
-  @After
-  public void tearDown() throws Exception {
-  }
-
   public static void createTableAndSnapshot(HBaseTestingUtility util, TableName tableName,
     String snapshotName, int numRegions) throws Exception {
     try {
@@ -147,7 +157,6 @@ public class TestTableSnapshotScanner {
 
   @Test
   public void testNoDuplicateResultsWhenSplitting() throws Exception {
-    setupCluster();
     TableName tableName = TableName.valueOf("testNoDuplicateResultsWhenSplitting");
     String snapshotName = "testSnapshotBug";
     try {
@@ -188,16 +197,16 @@ public class TestTableSnapshotScanner {
 
       verifyScanner(scanner, bbb, yyy);
       scanner.close();
+    } catch (Exception e) {
+      e.printStackTrace();
     } finally {
       UTIL.getAdmin().deleteSnapshot(snapshotName);
       UTIL.deleteTable(tableName);
-      tearDownCluster();
     }
   }
 
   @Test
   public void testScanLimit() throws Exception {
-    setupCluster();
     final TableName tableName = TableName.valueOf(name.getMethodName());
     final String snapshotName = tableName + "Snapshot";
     TableSnapshotScanner scanner = null;
@@ -222,7 +231,6 @@ public class TestTableSnapshotScanner {
       }
       UTIL.getAdmin().deleteSnapshot(snapshotName);
       UTIL.deleteTable(tableName);
-      tearDownCluster();
     }
   }
 
@@ -241,9 +249,86 @@ public class TestTableSnapshotScanner {
     testScanner(UTIL, "testWithMultiRegion", 20, true);
   }
 
+  private ScanMetrics createTableSnapshotScannerAndGetScanMetrics(boolean enableScanMetrics,
+    boolean enableScanMetricsByRegion, byte[] endKey) throws Exception {
+    TableName tableName = TableName.valueOf(name.getMethodName() + "_TABLE");
+    String snapshotName = name.getMethodName() + "_SNAPSHOT";
+    try {
+      createTableAndSnapshot(UTIL, tableName, snapshotName, 50);
+      Path restoreDir = UTIL.getDataTestDirOnTestFS(snapshotName);
+      Scan scan = new Scan().withStartRow(bbb).withStopRow(endKey);
+      scan.setScanMetricsEnabled(enableScanMetrics);
+      scan.setEnableScanMetricsByRegion(enableScanMetricsByRegion);
+      Configuration conf = UTIL.getConfiguration();
+
+      TableSnapshotScanner snapshotScanner =
+        new TableSnapshotScanner(conf, restoreDir, snapshotName, scan);
+      verifyScanner(snapshotScanner, bbb, endKey);
+      return snapshotScanner.getScanMetrics();
+    } finally {
+      UTIL.getAdmin().deleteSnapshot(snapshotName);
+      UTIL.deleteTable(tableName);
+    }
+  }
+
+  @Test
+  public void testScanMetricsDisabled() throws Exception {
+    ScanMetrics scanMetrics = createTableSnapshotScannerAndGetScanMetrics(false, false, yyy);
+    Assert.assertNull(scanMetrics);
+  }
+
+  @Test
+  public void testScanMetricsWithScanMetricsByRegionDisabled() throws Exception {
+    ScanMetrics scanMetrics = createTableSnapshotScannerAndGetScanMetrics(true, false, yyy);
+    Assert.assertNotNull(scanMetrics);
+    int rowsScanned = 0;
+    for (byte[] row : HBaseTestingUtility.ROWS) {
+      if (Bytes.compareTo(row, bbb) >= 0 && Bytes.compareTo(row, yyy) < 0) {
+        rowsScanned++;
+      }
+    }
+    Map<String, Long> metricsMap = scanMetrics.getMetricsMap();
+    Assert.assertEquals(rowsScanned, (long) metricsMap.get(COUNT_OF_ROWS_SCANNED_KEY_METRIC_NAME));
+  }
+
+  @Test
+  public void testScanMetricsByRegionForSingleRegion() throws Exception {
+    // Scan single row with row key bbb
+    byte[] bbc = Bytes.toBytes("bbc");
+    ScanMetrics scanMetrics = createTableSnapshotScannerAndGetScanMetrics(true, true, bbc);
+    Assert.assertNotNull(scanMetrics);
+    Map<ScanMetricsRegionInfo, Map<String, Long>> scanMetricsByRegion =
+      scanMetrics.collectMetricsByRegion();
+    Assert.assertEquals(1, scanMetricsByRegion.size());
+    for (Map.Entry<ScanMetricsRegionInfo, Map<String, Long>> entry : scanMetricsByRegion
+      .entrySet()) {
+      ScanMetricsRegionInfo scanMetricsRegionInfo = entry.getKey();
+      Map<String, Long> metricsMap = entry.getValue();
+      Assert.assertNull(scanMetricsRegionInfo.getServerName());
+      Assert.assertNotNull(scanMetricsRegionInfo.getEncodedRegionName());
+      Assert.assertEquals(1, (long) metricsMap.get(REGIONS_SCANNED_METRIC_NAME));
+      Assert.assertEquals(1, (long) metricsMap.get(COUNT_OF_ROWS_SCANNED_KEY_METRIC_NAME));
+    }
+  }
+
+  @Test
+  public void testScanMetricsByRegionForMultiRegion() throws Exception {
+    ScanMetrics scanMetrics = createTableSnapshotScannerAndGetScanMetrics(true, true, yyy);
+    Assert.assertNotNull(scanMetrics);
+    Map<ScanMetricsRegionInfo, Map<String, Long>> scanMetricsByRegion =
+      scanMetrics.collectMetricsByRegion();
+    for (Map.Entry<ScanMetricsRegionInfo, Map<String, Long>> entry : scanMetricsByRegion
+      .entrySet()) {
+      ScanMetricsRegionInfo scanMetricsRegionInfo = entry.getKey();
+      Map<String, Long> metricsMap = entry.getValue();
+      Assert.assertNull(scanMetricsRegionInfo.getServerName());
+      Assert.assertNotNull(scanMetricsRegionInfo.getEncodedRegionName());
+      Assert.assertEquals(1, (long) metricsMap.get(REGIONS_SCANNED_METRIC_NAME));
+    }
+  }
+
   @Test
   public void testScannerWithRestoreScanner() throws Exception {
-    setupCluster();
     TableName tableName = TableName.valueOf("testScanner");
     String snapshotName = "testScannerWithRestoreScanner";
     try {
@@ -283,19 +368,18 @@ public class TestTableSnapshotScanner {
     } finally {
       UTIL.getAdmin().deleteSnapshot(snapshotName);
       UTIL.deleteTable(tableName);
-      tearDownCluster();
     }
   }
 
   private void testScanner(HBaseTestingUtility util, String snapshotName, int numRegions,
     boolean shutdownCluster) throws Exception {
-    setupCluster();
     TableName tableName = TableName.valueOf("testScanner");
     try {
       createTableAndSnapshot(util, tableName, snapshotName, numRegions);
 
       if (shutdownCluster) {
         util.shutdownMiniHBaseCluster();
+        clusterUp = false;
       }
 
       Path restoreDir = util.getDataTestDirOnTestFS(snapshotName);
@@ -307,10 +391,9 @@ public class TestTableSnapshotScanner {
       verifyScanner(scanner, bbb, yyy);
       scanner.close();
     } finally {
-      if (!shutdownCluster) {
+      if (clusterUp) {
         util.getAdmin().deleteSnapshot(snapshotName);
         util.deleteTable(tableName);
-        tearDownCluster();
       }
     }
   }
@@ -354,7 +437,6 @@ public class TestTableSnapshotScanner {
 
   @Test
   public void testMergeRegion() throws Exception {
-    setupCluster();
     TableName tableName = TableName.valueOf("testMergeRegion");
     String snapshotName = tableName.getNameAsString() + "_snapshot";
     Configuration conf = UTIL.getConfiguration();
@@ -380,9 +462,12 @@ public class TestTableSnapshotScanner {
           for (RegionInfo region : regions) {
             Path regionDir = new Path(tableDir, region.getEncodedName());
             for (Path familyDir : FSUtils.getFamilyDirs(fs, regionDir)) {
-              if (fs.listStatus(familyDir).length != 1) {
-                return false;
+              for (FileStatus fs : fs.listStatus(familyDir)) {
+                if (!fs.getPath().getName().equals(".filelist")) {
+                  return true;
+                }
               }
+              return false;
             }
           }
           return true;
@@ -448,7 +533,7 @@ public class TestTableSnapshotScanner {
         }
       });
       // set file modify time and then run cleaner
-      long time = System.currentTimeMillis() - TimeToLiveHFileCleaner.DEFAULT_TTL * 1000;
+      long time = EnvironmentEdgeManager.currentTime() - TimeToLiveHFileCleaner.DEFAULT_TTL * 1000;
       traverseAndSetFileTime(HFileArchiveUtil.getArchivePath(conf), time);
       UTIL.getMiniHBaseCluster().getMaster().getHFileCleaner().runCleaner();
       // scan snapshot
@@ -458,17 +543,15 @@ public class TestTableSnapshotScanner {
       }
     } catch (Exception e) {
       LOG.error("scan snapshot error", e);
+      Assert.fail("Should not throw Exception: " + e.getMessage());
       Assert.fail("Should not throw FileNotFoundException");
       Assert.assertTrue(e.getCause() != null);
       Assert.assertTrue(e.getCause().getCause() instanceof FileNotFoundException);
-    } finally {
-      tearDownCluster();
     }
   }
 
   @Test
   public void testDeleteTableWithMergedRegions() throws Exception {
-    setupCluster();
     final TableName tableName = TableName.valueOf(this.name.getMethodName());
     String snapshotName = tableName.getNameAsString() + "_snapshot";
     Configuration conf = UTIL.getConfiguration();
