@@ -28,6 +28,7 @@ import org.apache.hadoop.hbase.CellScanner;
 import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.io.CellOutputStream;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -63,13 +64,13 @@ public class CodecPerformance {
   static byte[] runEncoderTest(final int index, final int initialBufferSize,
     final ByteArrayOutputStream baos, final CellOutputStream encoder, final Cell[] cells)
     throws IOException {
-    long startTime = System.currentTimeMillis();
+    long startTime = EnvironmentEdgeManager.currentTime();
     for (int i = 0; i < cells.length; i++) {
       encoder.write(cells[i]);
     }
     encoder.flush();
     LOG.info("" + index + " encoded count=" + cells.length + " in "
-      + (System.currentTimeMillis() - startTime) + "ms for encoder " + encoder);
+      + (EnvironmentEdgeManager.currentTime() - startTime) + "ms for encoder " + encoder);
     // Ensure we did not have to grow the backing buffer.
     assertTrue(baos.size() < initialBufferSize);
     return baos.toByteArray();
@@ -78,12 +79,12 @@ public class CodecPerformance {
   static Cell[] runDecoderTest(final int index, final int count, final CellScanner decoder)
     throws IOException {
     Cell[] cells = new Cell[count];
-    long startTime = System.currentTimeMillis();
+    long startTime = EnvironmentEdgeManager.currentTime();
     for (int i = 0; decoder.advance(); i++) {
       cells[i] = decoder.current();
     }
     LOG.info("" + index + " decoded count=" + cells.length + " in "
-      + (System.currentTimeMillis() - startTime) + "ms for decoder " + decoder);
+      + (EnvironmentEdgeManager.currentTime() - startTime) + "ms for decoder " + decoder);
     // Ensure we did not have to grow the backing buffer.
     assertTrue(cells.length == count);
     return cells;
