@@ -1,5 +1,4 @@
-/**
- *
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -16,7 +15,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.coprocessor;
 
 import static org.junit.Assert.assertArrayEquals;
@@ -31,7 +29,6 @@ import java.util.Map;
 import java.util.Optional;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
-
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hbase.Cell;
@@ -74,8 +71,8 @@ import org.apache.hadoop.hbase.wal.WALEdit;
 import org.apache.hadoop.hbase.wal.WALKey;
 
 /**
- * A sample region observer that tests the RegionObserver interface.
- * It works with TestRegionObserverInterface to provide the test case.
+ * A sample region observer that tests the RegionObserver interface. It works with
+ * TestRegionObserverInterface to provide the test case.
  */
 public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
@@ -142,10 +139,10 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
   final AtomicInteger ctPreWALAppend = new AtomicInteger(0);
 
   static final String TABLE_SKIPPED = "SKIPPED_BY_PREWALRESTORE";
-  Map<String, byte[]> extendedAttributes = new HashMap<String,byte[]>();
+  Map<String, byte[]> extendedAttributes = new HashMap<String, byte[]>();
   static final byte[] WAL_EXTENDED_ATTRIBUTE_BYTES = Bytes.toBytes("foo");
 
-  public void setThrowOnPostFlush(Boolean val){
+  public void setThrowOnPostFlush(Boolean val) {
     throwOnPostFlush.set(val);
   }
 
@@ -187,17 +184,17 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
   }
 
   @Override
-  public InternalScanner preFlush(ObserverContext<RegionCoprocessorEnvironment> c,
-      Store store, InternalScanner scanner, FlushLifeCycleTracker tracker) throws IOException {
+  public InternalScanner preFlush(ObserverContext<RegionCoprocessorEnvironment> c, Store store,
+    InternalScanner scanner, FlushLifeCycleTracker tracker) throws IOException {
     ctPreFlush.incrementAndGet();
     return scanner;
   }
 
   @Override
-  public void postFlush(ObserverContext<RegionCoprocessorEnvironment> c,
-      Store store, StoreFile resultFile, FlushLifeCycleTracker tracker) throws IOException {
+  public void postFlush(ObserverContext<RegionCoprocessorEnvironment> c, Store store,
+    StoreFile resultFile, FlushLifeCycleTracker tracker) throws IOException {
     ctPostFlush.incrementAndGet();
-    if (throwOnPostFlush.get()){
+    if (throwOnPostFlush.get()) {
       throw new IOException("throwOnPostFlush is true in postFlush");
     }
   }
@@ -208,29 +205,29 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public void preCompactSelection(ObserverContext<RegionCoprocessorEnvironment> c, Store store,
-      List<? extends StoreFile> candidates, CompactionLifeCycleTracker tracker) throws IOException {
+    List<? extends StoreFile> candidates, CompactionLifeCycleTracker tracker) throws IOException {
     ctPreCompactSelect.incrementAndGet();
   }
 
   @Override
   public void postCompactSelection(ObserverContext<RegionCoprocessorEnvironment> c, Store store,
-      List<? extends StoreFile> selected, CompactionLifeCycleTracker tracker,
-      CompactionRequest request) {
+    List<? extends StoreFile> selected, CompactionLifeCycleTracker tracker,
+    CompactionRequest request) {
     ctPostCompactSelect.incrementAndGet();
   }
 
   @Override
   public InternalScanner preCompact(ObserverContext<RegionCoprocessorEnvironment> c, Store store,
-      InternalScanner scanner, ScanType scanType, CompactionLifeCycleTracker tracker,
-      CompactionRequest request) throws IOException {
+    InternalScanner scanner, ScanType scanType, CompactionLifeCycleTracker tracker,
+    CompactionRequest request) throws IOException {
     ctPreCompact.incrementAndGet();
     return scanner;
   }
 
   @Override
   public void postCompact(ObserverContext<RegionCoprocessorEnvironment> c, Store store,
-      StoreFile resultFile, CompactionLifeCycleTracker tracker,
-      CompactionRequest request) throws IOException {
+    StoreFile resultFile, CompactionLifeCycleTracker tracker, CompactionRequest request)
+    throws IOException {
     ctPostCompact.incrementAndGet();
   }
 
@@ -240,56 +237,55 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public void preScannerOpen(final ObserverContext<RegionCoprocessorEnvironment> c, final Scan scan)
-      throws IOException {
+    throws IOException {
     ctPreScannerOpen.incrementAndGet();
   }
 
   @Override
   public RegionScanner postScannerOpen(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final Scan scan, final RegionScanner s)
-      throws IOException {
+    final Scan scan, final RegionScanner s) throws IOException {
     ctPostScannerOpen.incrementAndGet();
     return s;
   }
 
   @Override
   public boolean preScannerNext(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final InternalScanner s, final List<Result> results,
-      final int limit, final boolean hasMore) throws IOException {
+    final InternalScanner s, final List<Result> results, final int limit, final boolean hasMore)
+    throws IOException {
     ctPreScannerNext.incrementAndGet();
     return hasMore;
   }
 
   @Override
   public boolean postScannerNext(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final InternalScanner s, final List<Result> results, final int limit,
-      final boolean hasMore) throws IOException {
+    final InternalScanner s, final List<Result> results, final int limit, final boolean hasMore)
+    throws IOException {
     ctPostScannerNext.incrementAndGet();
     return hasMore;
   }
 
   @Override
   public boolean postScannerFilterRow(final ObserverContext<RegionCoprocessorEnvironment> e,
-      final InternalScanner s, final Cell currentRow, final boolean hasMore) throws IOException {
+    final InternalScanner s, final Cell currentRow, final boolean hasMore) throws IOException {
     ctPostScannerFilterRow.incrementAndGet();
     return hasMore;
   }
 
   @Override
   public void preScannerClose(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final InternalScanner s) throws IOException {
+    final InternalScanner s) throws IOException {
     ctPreScannerClose.incrementAndGet();
   }
 
   @Override
   public void postScannerClose(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final InternalScanner s) throws IOException {
+    final InternalScanner s) throws IOException {
     ctPostScannerClose.incrementAndGet();
   }
 
   @Override
   public void preGetOp(final ObserverContext<RegionCoprocessorEnvironment> c, final Get get,
-      final List<Cell> results) throws IOException {
+    final List<Cell> results) throws IOException {
     RegionCoprocessorEnvironment e = c.getEnvironment();
     assertNotNull(e);
     assertNotNull(e.getRegion());
@@ -300,18 +296,20 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public void postGetOp(final ObserverContext<RegionCoprocessorEnvironment> c, final Get get,
-      final List<Cell> results) {
+    final List<Cell> results) {
     RegionCoprocessorEnvironment e = c.getEnvironment();
     assertNotNull(e);
     assertNotNull(e.getRegion());
     assertNotNull(get);
     assertNotNull(results);
-    if (e.getRegion().getTableDescriptor().getTableName().equals(
-        TestRegionObserverInterface.TEST_TABLE)) {
+    if (
+      e.getRegion().getTableDescriptor().getTableName()
+        .equals(TestRegionObserverInterface.TEST_TABLE)
+    ) {
       boolean foundA = false;
       boolean foundB = false;
       boolean foundC = false;
-      for (Cell kv: results) {
+      for (Cell kv : results) {
         if (CellUtil.matchingFamily(kv, TestRegionObserverInterface.A)) {
           foundA = true;
         }
@@ -330,85 +328,86 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
   }
 
   @Override
-  public void prePut(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final Put put, final WALEdit edit,
-      final Durability durability) throws IOException {
-    Map<byte[], List<Cell>> familyMap  = put.getFamilyCellMap();
+  public void prePut(final ObserverContext<RegionCoprocessorEnvironment> c, final Put put,
+    final WALEdit edit, final Durability durability) throws IOException {
+    Map<byte[], List<Cell>> familyMap = put.getFamilyCellMap();
     RegionCoprocessorEnvironment e = c.getEnvironment();
     assertNotNull(e);
     assertNotNull(e.getRegion());
     assertNotNull(familyMap);
-    if (e.getRegion().getTableDescriptor().getTableName().equals(
-        TestRegionObserverInterface.TEST_TABLE)) {
+    if (
+      e.getRegion().getTableDescriptor().getTableName()
+        .equals(TestRegionObserverInterface.TEST_TABLE)
+    ) {
       List<Cell> cells = familyMap.get(TestRegionObserverInterface.A);
       assertNotNull(cells);
       assertNotNull(cells.get(0));
       Cell cell = cells.get(0);
-      assertTrue(Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(),
-        cell.getQualifierLength(), TestRegionObserverInterface.A, 0,
-        TestRegionObserverInterface.A.length));
+      assertTrue(
+        Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(), cell.getQualifierLength(),
+          TestRegionObserverInterface.A, 0, TestRegionObserverInterface.A.length));
       cells = familyMap.get(TestRegionObserverInterface.B);
       assertNotNull(cells);
       assertNotNull(cells.get(0));
       cell = cells.get(0);
-      assertTrue(Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(),
-        cell.getQualifierLength(), TestRegionObserverInterface.B, 0,
-        TestRegionObserverInterface.B.length));
+      assertTrue(
+        Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(), cell.getQualifierLength(),
+          TestRegionObserverInterface.B, 0, TestRegionObserverInterface.B.length));
       cells = familyMap.get(TestRegionObserverInterface.C);
       assertNotNull(cells);
       assertNotNull(cells.get(0));
       cell = cells.get(0);
-      assertTrue(Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(),
-        cell.getQualifierLength(), TestRegionObserverInterface.C, 0,
-        TestRegionObserverInterface.C.length));
+      assertTrue(
+        Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(), cell.getQualifierLength(),
+          TestRegionObserverInterface.C, 0, TestRegionObserverInterface.C.length));
     }
     ctPrePut.incrementAndGet();
   }
 
   @Override
-  public void postPut(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final Put put, final WALEdit edit,
-      final Durability durability) throws IOException {
-    Map<byte[], List<Cell>> familyMap  = put.getFamilyCellMap();
+  public void postPut(final ObserverContext<RegionCoprocessorEnvironment> c, final Put put,
+    final WALEdit edit, final Durability durability) throws IOException {
+    Map<byte[], List<Cell>> familyMap = put.getFamilyCellMap();
     RegionCoprocessorEnvironment e = c.getEnvironment();
     assertNotNull(e);
     assertNotNull(e.getRegion());
     assertNotNull(familyMap);
     List<Cell> cells = familyMap.get(TestRegionObserverInterface.A);
-    if (e.getRegion().getTableDescriptor().getTableName().equals(
-        TestRegionObserverInterface.TEST_TABLE)) {
+    if (
+      e.getRegion().getTableDescriptor().getTableName()
+        .equals(TestRegionObserverInterface.TEST_TABLE)
+    ) {
       assertNotNull(cells);
       assertNotNull(cells.get(0));
-      // KeyValue v1 expectation.  Cast for now until we go all Cell all the time. TODO
+      // KeyValue v1 expectation. Cast for now until we go all Cell all the time. TODO
       Cell cell = cells.get(0);
-      assertTrue(Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(),
-        cell.getQualifierLength(), TestRegionObserverInterface.A, 0,
-        TestRegionObserverInterface.A.length));
+      assertTrue(
+        Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(), cell.getQualifierLength(),
+          TestRegionObserverInterface.A, 0, TestRegionObserverInterface.A.length));
       cells = familyMap.get(TestRegionObserverInterface.B);
       assertNotNull(cells);
       assertNotNull(cells.get(0));
-      // KeyValue v1 expectation.  Cast for now until we go all Cell all the time. TODO
+      // KeyValue v1 expectation. Cast for now until we go all Cell all the time. TODO
       cell = cells.get(0);
-      assertTrue(Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(),
-        cell.getQualifierLength(), TestRegionObserverInterface.B, 0,
-        TestRegionObserverInterface.B.length));
+      assertTrue(
+        Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(), cell.getQualifierLength(),
+          TestRegionObserverInterface.B, 0, TestRegionObserverInterface.B.length));
       cells = familyMap.get(TestRegionObserverInterface.C);
       assertNotNull(cells);
       assertNotNull(cells.get(0));
-      // KeyValue v1 expectation.  Cast for now until we go all Cell all the time. TODO
+      // KeyValue v1 expectation. Cast for now until we go all Cell all the time. TODO
       cell = cells.get(0);
-      assertTrue(Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(),
-        cell.getQualifierLength(), TestRegionObserverInterface.C, 0,
-        TestRegionObserverInterface.C.length));
+      assertTrue(
+        Bytes.equals(cell.getQualifierArray(), cell.getQualifierOffset(), cell.getQualifierLength(),
+          TestRegionObserverInterface.C, 0, TestRegionObserverInterface.C.length));
     }
     ctPostPut.incrementAndGet();
   }
 
   @Override
-  public void preDelete(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final Delete delete, final WALEdit edit,
-      final Durability durability) throws IOException {
-    Map<byte[], List<Cell>> familyMap  = delete.getFamilyCellMap();
+  public void preDelete(final ObserverContext<RegionCoprocessorEnvironment> c, final Delete delete,
+    final WALEdit edit, final Durability durability) throws IOException {
+    Map<byte[], List<Cell>> familyMap = delete.getFamilyCellMap();
     RegionCoprocessorEnvironment e = c.getEnvironment();
     assertNotNull(e);
     assertNotNull(e.getRegion());
@@ -420,15 +419,14 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public void prePrepareTimeStampForDeleteVersion(ObserverContext<RegionCoprocessorEnvironment> e,
-      Mutation delete, Cell cell, byte[] byteNow, Get get) throws IOException {
+    Mutation delete, Cell cell, byte[] byteNow, Get get) throws IOException {
     ctPrePrepareDeleteTS.incrementAndGet();
   }
 
   @Override
-  public void postDelete(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final Delete delete, final WALEdit edit,
-      final Durability durability) throws IOException {
-    Map<byte[], List<Cell>> familyMap  = delete.getFamilyCellMap();
+  public void postDelete(final ObserverContext<RegionCoprocessorEnvironment> c, final Delete delete,
+    final WALEdit edit, final Durability durability) throws IOException {
+    Map<byte[], List<Cell>> familyMap = delete.getFamilyCellMap();
     RegionCoprocessorEnvironment e = c.getEnvironment();
     assertNotNull(e);
     assertNotNull(e.getRegion());
@@ -439,7 +437,7 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public void preBatchMutate(ObserverContext<RegionCoprocessorEnvironment> c,
-      MiniBatchOperationInProgress<Mutation> miniBatchOp) throws IOException {
+    MiniBatchOperationInProgress<Mutation> miniBatchOp) throws IOException {
     RegionCoprocessorEnvironment e = c.getEnvironment();
     assertNotNull(e);
     assertNotNull(e.getRegion());
@@ -449,7 +447,7 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public void postBatchMutate(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final MiniBatchOperationInProgress<Mutation> miniBatchOp) throws IOException {
+    final MiniBatchOperationInProgress<Mutation> miniBatchOp) throws IOException {
     RegionCoprocessorEnvironment e = c.getEnvironment();
     assertNotNull(e);
     assertNotNull(e.getRegion());
@@ -459,13 +457,13 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public void postStartRegionOperation(final ObserverContext<RegionCoprocessorEnvironment> ctx,
-      Operation op) throws IOException {
+    Operation op) throws IOException {
     ctPostStartRegionOperation.incrementAndGet();
   }
 
   @Override
   public void postCloseRegionOperation(final ObserverContext<RegionCoprocessorEnvironment> ctx,
-      Operation op) throws IOException {
+    Operation op) throws IOException {
     if (ctPostStartRegionOperation.get() > 0) {
       ctPostCloseRegionOperation.incrementAndGet();
     }
@@ -473,35 +471,35 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public void postBatchMutateIndispensably(final ObserverContext<RegionCoprocessorEnvironment> ctx,
-      MiniBatchOperationInProgress<Mutation> miniBatchOp, final boolean success) throws IOException {
+    MiniBatchOperationInProgress<Mutation> miniBatchOp, final boolean success) throws IOException {
     ctPostBatchMutateIndispensably.incrementAndGet();
   }
 
   @Override
   public Result preIncrement(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final Increment increment) throws IOException {
+    final Increment increment) throws IOException {
     ctPreIncrement.incrementAndGet();
     return null;
   }
 
   @Override
   public Result preIncrementAfterRowLock(ObserverContext<RegionCoprocessorEnvironment> e,
-      Increment increment) throws IOException {
+    Increment increment) throws IOException {
     ctPreIncrementAfterRowLock.incrementAndGet();
     return null;
   }
 
   @Override
   public Result postIncrement(final ObserverContext<RegionCoprocessorEnvironment> c,
-      final Increment increment, final Result result) throws IOException {
+    final Increment increment, final Result result) throws IOException {
     ctPostIncrement.incrementAndGet();
     return result;
   }
 
   @Override
   public boolean preCheckAndPut(ObserverContext<RegionCoprocessorEnvironment> e, byte[] row,
-                                byte[] family, byte[] qualifier, CompareOperator compareOp, ByteArrayComparable comparator,
-                                Put put, boolean result) throws IOException {
+    byte[] family, byte[] qualifier, CompareOperator compareOp, ByteArrayComparable comparator,
+    Put put, boolean result) throws IOException {
     ctPreCheckAndPut.incrementAndGet();
     return true;
   }
@@ -515,8 +513,8 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public boolean preCheckAndPutAfterRowLock(ObserverContext<RegionCoprocessorEnvironment> e,
-      byte[] row, byte[] family, byte[] qualifier, CompareOperator compareOp,
-      ByteArrayComparable comparator, Put put, boolean result) throws IOException {
+    byte[] row, byte[] family, byte[] qualifier, CompareOperator compareOp,
+    ByteArrayComparable comparator, Put put, boolean result) throws IOException {
     ctPreCheckAndPutAfterRowLock.incrementAndGet();
     return true;
   }
@@ -530,8 +528,8 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public boolean postCheckAndPut(ObserverContext<RegionCoprocessorEnvironment> e, byte[] row,
-                                 byte[] family, byte[] qualifier, CompareOperator compareOp, ByteArrayComparable comparator,
-                                 Put put, boolean result) throws IOException {
+    byte[] family, byte[] qualifier, CompareOperator compareOp, ByteArrayComparable comparator,
+    Put put, boolean result) throws IOException {
     ctPostCheckAndPut.incrementAndGet();
     return true;
   }
@@ -545,8 +543,8 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public boolean preCheckAndDelete(ObserverContext<RegionCoprocessorEnvironment> e, byte[] row,
-                                   byte[] family, byte[] qualifier, CompareOperator compareOp, ByteArrayComparable comparator,
-                                   Delete delete, boolean result) throws IOException {
+    byte[] family, byte[] qualifier, CompareOperator compareOp, ByteArrayComparable comparator,
+    Delete delete, boolean result) throws IOException {
     ctPreCheckAndDelete.incrementAndGet();
     return true;
   }
@@ -560,8 +558,8 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public boolean preCheckAndDeleteAfterRowLock(ObserverContext<RegionCoprocessorEnvironment> e,
-      byte[] row, byte[] family, byte[] qualifier, CompareOperator compareOp,
-      ByteArrayComparable comparator, Delete delete, boolean result) throws IOException {
+    byte[] row, byte[] family, byte[] qualifier, CompareOperator compareOp,
+    ByteArrayComparable comparator, Delete delete, boolean result) throws IOException {
     ctPreCheckAndDeleteAfterRowLock.incrementAndGet();
     return true;
   }
@@ -575,8 +573,8 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public boolean postCheckAndDelete(ObserverContext<RegionCoprocessorEnvironment> e, byte[] row,
-                                    byte[] family, byte[] qualifier, CompareOperator compareOp, ByteArrayComparable comparator,
-                                    Delete delete, boolean result) throws IOException {
+    byte[] family, byte[] qualifier, CompareOperator compareOp, ByteArrayComparable comparator,
+    Delete delete, boolean result) throws IOException {
     ctPostCheckAndDelete.incrementAndGet();
     return true;
   }
@@ -612,77 +610,82 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public Result preAppendAfterRowLock(ObserverContext<RegionCoprocessorEnvironment> e,
-      Append append) throws IOException {
+    Append append) throws IOException {
     ctPreAppendAfterRowLock.incrementAndGet();
     return null;
   }
 
   @Override
   public Result preAppend(ObserverContext<RegionCoprocessorEnvironment> e, Append append)
-      throws IOException {
+    throws IOException {
     ctPreAppend.incrementAndGet();
     return null;
   }
 
   @Override
   public Result postAppend(ObserverContext<RegionCoprocessorEnvironment> e, Append append,
-      Result result) throws IOException {
+    Result result) throws IOException {
     ctPostAppend.incrementAndGet();
     return null;
   }
 
   @Override
   public void preBulkLoadHFile(ObserverContext<RegionCoprocessorEnvironment> ctx,
-                               List<Pair<byte[], String>> familyPaths) throws IOException {
+    List<Pair<byte[], String>> familyPaths) throws IOException {
     RegionCoprocessorEnvironment e = ctx.getEnvironment();
     assertNotNull(e);
     assertNotNull(e.getRegion());
-    if (e.getRegion().getTableDescriptor().getTableName().equals(
-        TestRegionObserverInterface.TEST_TABLE)) {
+    if (
+      e.getRegion().getTableDescriptor().getTableName()
+        .equals(TestRegionObserverInterface.TEST_TABLE)
+    ) {
       assertNotNull(familyPaths);
-      assertEquals(1,familyPaths.size());
+      assertEquals(1, familyPaths.size());
       assertArrayEquals(TestRegionObserverInterface.A, familyPaths.get(0).getFirst());
       String familyPath = familyPaths.get(0).getSecond();
       String familyName = Bytes.toString(TestRegionObserverInterface.A);
-      assertEquals(familyPath.substring(familyPath.length()-familyName.length()-1),"/"+familyName);
+      assertEquals(familyPath.substring(familyPath.length() - familyName.length() - 1),
+        "/" + familyName);
     }
     ctPreBulkLoadHFile.incrementAndGet();
   }
 
   @Override
   public void postBulkLoadHFile(ObserverContext<RegionCoprocessorEnvironment> ctx,
-      List<Pair<byte[], String>> familyPaths, Map<byte[], List<Path>> map)
-          throws IOException {
+    List<Pair<byte[], String>> familyPaths, Map<byte[], List<Path>> map) throws IOException {
     RegionCoprocessorEnvironment e = ctx.getEnvironment();
     assertNotNull(e);
     assertNotNull(e.getRegion());
-    if (e.getRegion().getTableDescriptor().getTableName().equals(
-        TestRegionObserverInterface.TEST_TABLE)) {
+    if (
+      e.getRegion().getTableDescriptor().getTableName()
+        .equals(TestRegionObserverInterface.TEST_TABLE)
+    ) {
       assertNotNull(familyPaths);
-      assertEquals(1,familyPaths.size());
+      assertEquals(1, familyPaths.size());
       assertArrayEquals(TestRegionObserverInterface.A, familyPaths.get(0).getFirst());
       String familyPath = familyPaths.get(0).getSecond();
       String familyName = Bytes.toString(TestRegionObserverInterface.A);
-      assertEquals(familyPath.substring(familyPath.length()-familyName.length()-1),"/"+familyName);
+      assertEquals(familyPath.substring(familyPath.length() - familyName.length() - 1),
+        "/" + familyName);
     }
     ctPostBulkLoadHFile.incrementAndGet();
   }
 
   @Override
   public void preReplayWALs(ObserverContext<? extends RegionCoprocessorEnvironment> env,
-      RegionInfo info, Path edits) throws IOException {
+    RegionInfo info, Path edits) throws IOException {
     ctPreReplayWALs.incrementAndGet();
   }
 
   @Override
   public void postReplayWALs(ObserverContext<? extends RegionCoprocessorEnvironment> env,
-      RegionInfo info, Path edits) throws IOException {
+    RegionInfo info, Path edits) throws IOException {
     ctPostReplayWALs.incrementAndGet();
   }
 
   @Override
   public void preWALRestore(ObserverContext<? extends RegionCoprocessorEnvironment> env,
-      RegionInfo info, WALKey logKey, WALEdit logEdit) throws IOException {
+    RegionInfo info, WALKey logKey, WALEdit logEdit) throws IOException {
     String tableName = logKey.getTableName().getNameAsString();
     if (tableName.equals(TABLE_SKIPPED)) {
       // skip recovery of TABLE_SKIPPED for testing purpose
@@ -694,29 +697,29 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
 
   @Override
   public void postWALRestore(ObserverContext<? extends RegionCoprocessorEnvironment> env,
-                             RegionInfo info, WALKey logKey, WALEdit logEdit) throws IOException {
+    RegionInfo info, WALKey logKey, WALEdit logEdit) throws IOException {
     ctPostWALRestore.incrementAndGet();
   }
 
   @Override
   public StoreFileReader preStoreFileReaderOpen(ObserverContext<RegionCoprocessorEnvironment> ctx,
-      FileSystem fs, Path p, FSDataInputStreamWrapper in, long size, CacheConfig cacheConf,
-      Reference r, StoreFileReader reader) throws IOException {
+    FileSystem fs, Path p, FSDataInputStreamWrapper in, long size, CacheConfig cacheConf,
+    Reference r, StoreFileReader reader) throws IOException {
     ctPreStoreFileReaderOpen.incrementAndGet();
     return null;
   }
 
   @Override
   public StoreFileReader postStoreFileReaderOpen(ObserverContext<RegionCoprocessorEnvironment> ctx,
-      FileSystem fs, Path p, FSDataInputStreamWrapper in, long size, CacheConfig cacheConf,
-      Reference r, StoreFileReader reader) throws IOException {
+    FileSystem fs, Path p, FSDataInputStreamWrapper in, long size, CacheConfig cacheConf,
+    Reference r, StoreFileReader reader) throws IOException {
     ctPostStoreFileReaderOpen.incrementAndGet();
     return reader;
   }
 
   @Override
-  public void preStoreScannerOpen(ObserverContext<RegionCoprocessorEnvironment> ctx,
-    Store store, ScanOptions options) throws IOException {
+  public void preStoreScannerOpen(ObserverContext<RegionCoprocessorEnvironment> ctx, Store store,
+    ScanOptions options) throws IOException {
     if (options.getScan().getTimeRange().isAllTime()) {
       setScanOptions(options);
     }
@@ -730,7 +733,7 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
   }
 
   public void preFlushScannerOpen(ObserverContext<RegionCoprocessorEnvironment> c, Store store,
-    ScanOptions options,FlushLifeCycleTracker tracker) throws IOException {
+    ScanOptions options, FlushLifeCycleTracker tracker) throws IOException {
     setScanOptions(options);
   }
 
@@ -748,14 +751,12 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
     options.setTimeToPurgeDeletes(TestRegionCoprocessorHost.TIME_TO_PURGE_DELETES);
   }
 
-
   @Override
-  public void preWALAppend(ObserverContext<RegionCoprocessorEnvironment> ctx,
-                                 WALKey key, WALEdit edit) throws IOException {
+  public void preWALAppend(ObserverContext<RegionCoprocessorEnvironment> ctx, WALKey key,
+    WALEdit edit) throws IOException {
     ctPreWALAppend.incrementAndGet();
 
-    key.addExtendedAttribute(Integer.toString(ctPreWALAppend.get()),
-        Bytes.toBytes("foo"));
+    key.addExtendedAttribute(Integer.toString(ctPreWALAppend.get()), Bytes.toBytes("foo"));
   }
 
   public boolean hadPreGet() {
@@ -925,15 +926,19 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
   public boolean wasScannerNextCalled() {
     return ctPreScannerNext.get() > 0 && ctPostScannerNext.get() > 0;
   }
+
   public boolean wasScannerFilterRowCalled() {
     return ctPostScannerFilterRow.get() > 0;
   }
+
   public boolean wasScannerCloseCalled() {
     return ctPreScannerClose.get() > 0 && ctPostScannerClose.get() > 0;
   }
+
   public boolean wasScannerOpenCalled() {
     return ctPreScannerOpen.get() > 0 && ctPostScannerOpen.get() > 0;
   }
+
   public boolean hadDeleted() {
     return ctPreDeleted.get() > 0 && ctPostDeleted.get() > 0;
   }
@@ -946,7 +951,6 @@ public class SimpleRegionObserver implements RegionCoprocessor, RegionObserver {
     return ctPreBulkLoadHFile.get() > 0;
   }
 
-
   public int getCtBeforeDelete() {
     return ctBeforeDelete.get();
   }
