@@ -40,6 +40,8 @@ import org.apache.hadoop.hbase.NamespaceDescriptor;
 import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.BalanceRequest;
+import org.apache.hadoop.hbase.client.BalanceResponse;
 import org.apache.hadoop.hbase.client.Connection;
 import org.apache.hadoop.hbase.client.ConnectionFactory;
 import org.apache.hadoop.hbase.client.MasterSwitchType;
@@ -187,6 +189,8 @@ public class TestMasterObserver {
     private boolean postRequestLockCalled;
     private boolean preLockHeartbeatCalled;
     private boolean postLockHeartbeatCalled;
+    private boolean preMasterStoreFlushCalled;
+    private boolean postMasterStoreFlushCalled;
 
     public void resetStates() {
       preCreateTableRegionInfosCalled = false;
@@ -278,6 +282,8 @@ public class TestMasterObserver {
       postRequestLockCalled = false;
       preLockHeartbeatCalled = false;
       postLockHeartbeatCalled = false;
+      preMasterStoreFlushCalled = false;
+      postMasterStoreFlushCalled = false;
     }
 
     @Override
@@ -682,13 +688,14 @@ public class TestMasterObserver {
     }
 
     @Override
-    public void preBalance(ObserverContext<MasterCoprocessorEnvironment> env) throws IOException {
+    public void preBalance(ObserverContext<MasterCoprocessorEnvironment> env,
+      BalanceRequest request) throws IOException {
       preBalanceCalled = true;
     }
 
     @Override
     public void postBalance(ObserverContext<MasterCoprocessorEnvironment> env,
-      List<RegionPlan> plans) throws IOException {
+      BalanceRequest request, List<RegionPlan> plans) throws IOException {
       postBalanceCalled = true;
     }
 
@@ -1039,6 +1046,18 @@ public class TestMasterObserver {
       TableName tableName) throws IOException {
     }
 
+    @Override
+    public void preMasterStoreFlush(ObserverContext<MasterCoprocessorEnvironment> ctx)
+      throws IOException {
+      preMasterStoreFlushCalled = true;
+    }
+
+    @Override
+    public void postMasterStoreFlush(ObserverContext<MasterCoprocessorEnvironment> ctx)
+      throws IOException {
+      postMasterStoreFlushCalled = true;
+    }
+
     @Override
     public void preSetUserQuota(final ObserverContext<MasterCoprocessorEnvironment> ctx,
       final String userName, final GlobalQuotaSettings quotas) throws IOException {
@@ -1145,12 +1164,12 @@ public class TestMasterObserver {
 
     @Override
     public void preBalanceRSGroup(ObserverContext<MasterCoprocessorEnvironment> ctx,
-      String groupName) throws IOException {
+      String groupName, BalanceRequest request) throws IOException {
     }
 
     @Override
     public void postBalanceRSGroup(ObserverContext<MasterCoprocessorEnvironment> ctx,
-      String groupName, boolean balancerRan) throws IOException {
+      String groupName, BalanceRequest request, BalanceResponse response) throws IOException {
     }
 
     @Override
@@ -1568,7 +1587,7 @@ public class TestMasterObserver {
       UTIL.waitUntilNoRegionsInTransition();
       // now trigger a balance
       master.balanceSwitch(true);
-      boolean balanceRun = master.balance();
+      master.balance();
       assertTrue("Coprocessor should be called on region rebalancing", cp.wasBalanceCalled());
     } finally {
       Admin admin = UTIL.getAdmin();
@@ -1673,4 +1692,22 @@ public class TestMasterObserver {
     ProcedureTestingUtility.waitNoProcedureRunning(master.getMasterProcedureExecutor());
     ProcedureTestingUtility.assertProcNotFailed(master.getMasterProcedureExecutor(), procId);
   }
+
+  @Test
+  public void testMasterStoreOperations() throws Exception {
+    HMaster master = UTIL.getMiniHBaseCluster().getMaster();
+    MasterCoprocessorHost host = master.getMasterCoprocessorHost();
+    CPMasterObserver cp = host.findCoprocessor(CPMasterObserver.class);
+    cp.resetStates();
+    assertFalse("No master store flush call", cp.preMasterStoreFlushCalled);
+    assertFalse("No master store flush call", cp.postMasterStoreFlushCalled);
+
+    try (Connection connection = ConnectionFactory.createConnection(UTIL.getConfiguration());
+      Admin admin = connection.getAdmin()) {
+      admin.flushMasterStore();
+
+      assertTrue("Master store flush called", cp.preMasterStoreFlushCalled);
+      assertTrue("Master store flush called", cp.postMasterStoreFlushCalled);
+    }
+  }
 }
