@@ -70,9 +70,11 @@ import org.apache.hadoop.hbase.io.ByteBuffAllocator;
 import org.apache.hadoop.hbase.io.compress.Compression;
 import org.apache.hadoop.hbase.io.encoding.DataBlockEncoder;
 import org.apache.hadoop.hbase.io.encoding.DataBlockEncoding;
+import org.apache.hadoop.hbase.io.encoding.IndexBlockEncoding;
 import org.apache.hadoop.hbase.io.hfile.HFile.Reader;
 import org.apache.hadoop.hbase.io.hfile.HFile.Writer;
 import org.apache.hadoop.hbase.io.hfile.ReaderContext.ReaderType;
+import org.apache.hadoop.hbase.monitoring.ThreadLocalServerSideScanMetrics;
 import org.apache.hadoop.hbase.nio.ByteBuff;
 import org.apache.hadoop.hbase.regionserver.StoreFileWriter;
 import org.apache.hadoop.hbase.testclassification.IOTests;
@@ -162,12 +164,7 @@ public class TestHFile {
     fillByteBuffAllocator(alloc, bufCount);
     // start write to store file.
     Path path = writeStoreFile();
-    try {
-      readStoreFile(path, conf, alloc);
-    } catch (Exception e) {
-      // fail test
-      assertTrue(false);
-    }
+    readStoreFile(path, conf, alloc);
     Assert.assertEquals(bufCount, alloc.getFreeBufferCount());
     alloc.clean();
   }
@@ -205,6 +202,90 @@ public class TestHFile {
     lru.shutdown();
   }
 
+  private void assertBytesReadFromCache(boolean isScanMetricsEnabled) throws Exception {
+    assertBytesReadFromCache(isScanMetricsEnabled, DataBlockEncoding.NONE);
+  }
+
+  private void assertBytesReadFromCache(boolean isScanMetricsEnabled, DataBlockEncoding encoding)
+    throws Exception {
+    // Write a store file
+    Path storeFilePath = writeStoreFile();
+
+    // Initialize the block cache and HFile reader
+    BlockCache lru = BlockCacheFactory.createBlockCache(conf);
+    Assert.assertTrue(lru instanceof LruBlockCache);
+    CacheConfig cacheConfig = new CacheConfig(conf, null, lru, ByteBuffAllocator.HEAP);
+    HFileReaderImpl reader =
+      (HFileReaderImpl) HFile.createReader(fs, storeFilePath, cacheConfig, true, conf);
+
+    // Read the first block in HFile from the block cache.
+    final int offset = 0;
+    BlockCacheKey cacheKey = new BlockCacheKey(storeFilePath.getName(), offset);
+    HFileBlock block = (HFileBlock) lru.getBlock(cacheKey, false, false, true);
+    Assert.assertNull(block);
+
+    // Assert that first block has not been cached in the block cache and no disk I/O happened to
+    // check that.
+    ThreadLocalServerSideScanMetrics.getBytesReadFromBlockCacheAndReset();
+    ThreadLocalServerSideScanMetrics.getBytesReadFromFsAndReset();
+    block = reader.getCachedBlock(cacheKey, false, false, true, BlockType.DATA, null);
+    Assert.assertEquals(0, ThreadLocalServerSideScanMetrics.getBytesReadFromBlockCacheAndReset());
+    Assert.assertEquals(0, ThreadLocalServerSideScanMetrics.getBytesReadFromFsAndReset());
+
+    // Read the first block from the HFile.
+    block = reader.readBlock(offset, -1, true, true, false, true, BlockType.DATA, null);
+    Assert.assertNotNull(block);
+    int bytesReadFromFs = block.getOnDiskSizeWithHeader();
+    if (block.getNextBlockOnDiskSize() > 0) {
+      bytesReadFromFs += block.headerSize();
+    }
+    block.release();
+    // Assert that disk I/O happened to read the first block.
+    Assert.assertEquals(isScanMetricsEnabled ? bytesReadFromFs : 0,
+      ThreadLocalServerSideScanMetrics.getBytesReadFromFsAndReset());
+    Assert.assertEquals(0, ThreadLocalServerSideScanMetrics.getBytesReadFromBlockCacheAndReset());
+
+    // Read the first block again and assert that it has been cached in the block cache.
+    block = reader.getCachedBlock(cacheKey, false, false, true, BlockType.DATA, encoding);
+    long bytesReadFromCache = 0;
+    if (encoding == DataBlockEncoding.NONE) {
+      Assert.assertNotNull(block);
+      bytesReadFromCache = block.getOnDiskSizeWithHeader();
+      if (block.getNextBlockOnDiskSize() > 0) {
+        bytesReadFromCache += block.headerSize();
+      }
+      block.release();
+      // Assert that bytes read from block cache account for same number of bytes that would have
+      // been read from FS if block cache wasn't there.
+      Assert.assertEquals(bytesReadFromFs, bytesReadFromCache);
+    } else {
+      Assert.assertNull(block);
+    }
+    Assert.assertEquals(isScanMetricsEnabled ? bytesReadFromCache : 0,
+      ThreadLocalServerSideScanMetrics.getBytesReadFromBlockCacheAndReset());
+    Assert.assertEquals(0, ThreadLocalServerSideScanMetrics.getBytesReadFromFsAndReset());
+
+    reader.close();
+  }
+
+  @Test
+  public void testBytesReadFromCache() throws Exception {
+    ThreadLocalServerSideScanMetrics.setScanMetricsEnabled(true);
+    assertBytesReadFromCache(true);
+  }
+
+  @Test
+  public void testBytesReadFromCacheWithScanMetricsDisabled() throws Exception {
+    ThreadLocalServerSideScanMetrics.setScanMetricsEnabled(false);
+    assertBytesReadFromCache(false);
+  }
+
+  @Test
+  public void testBytesReadFromCacheWithInvalidDataEncoding() throws Exception {
+    ThreadLocalServerSideScanMetrics.setScanMetricsEnabled(true);
+    assertBytesReadFromCache(true, DataBlockEncoding.FAST_DIFF);
+  }
+
   private BlockCache initCombinedBlockCache(final String l1CachePolicy) {
     Configuration that = HBaseConfiguration.create(conf);
     that.setFloat(BUCKET_CACHE_SIZE_KEY, 32); // 32MB for bucket cache.
@@ -1070,4 +1151,11 @@ public class TestHFile {
     alloc.clean();
   }
 
+  @Test
+  public void testHFileContextBuilderWithIndexEncoding() throws IOException {
+    HFileContext context =
+      new HFileContextBuilder().withIndexBlockEncoding(IndexBlockEncoding.PREFIX_TREE).build();
+    HFileContext newContext = new HFileContextBuilder(context).build();
+    assertTrue(newContext.getIndexBlockEncoding() == IndexBlockEncoding.PREFIX_TREE);
+  }
 }
