@@ -23,6 +23,7 @@ import static org.hamcrest.Matchers.hasProperty;
 import static org.hamcrest.Matchers.instanceOf;
 import static org.hamcrest.Matchers.startsWith;
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -54,6 +55,7 @@ import org.apache.hadoop.hbase.nio.ByteBuff;
 import org.apache.hadoop.hbase.testclassification.IOTests;
 import org.apache.hadoop.hbase.testclassification.SmallTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.ChecksumType;
 import org.hamcrest.Description;
 import org.hamcrest.Matcher;
 import org.hamcrest.TypeSafeMatcher;
@@ -92,6 +94,141 @@ public class TestHFileBlockHeaderCorruption {
     ruleChain = RuleChain.outerRule(testName).around(hFileTestRule);
   }
 
+  @Test
+  public void testChecksumTypeCorruptionFirstBlock() throws Exception {
+    HFileBlockChannelPosition firstBlock = null;
+    try {
+      try (HFileBlockChannelPositionIterator it =
+        new HFileBlockChannelPositionIterator(hFileTestRule)) {
+        assertTrue(it.hasNext());
+        firstBlock = it.next();
+      }
+
+      Corrupter c = new Corrupter(firstBlock);
+
+      logHeader(firstBlock);
+
+      // test corrupted HFileBlock with unknown checksumType code -1
+      c.write(HFileBlock.Header.CHECKSUM_TYPE_INDEX, ByteBuffer.wrap(new byte[] { -1 }));
+      logHeader(firstBlock);
+      try (HFileBlockChannelPositionIterator it =
+        new HFileBlockChannelPositionIterator(hFileTestRule)) {
+        CountingConsumer consumer = new CountingConsumer(it);
+        try {
+          consumer.readFully();
+          fail();
+        } catch (Exception e) {
+          assertThat(e, new IsThrowableMatching().withInstanceOf(IOException.class)
+            .withMessage(startsWith("Unknown checksum type code")));
+        }
+        assertEquals(0, consumer.getItemsRead());
+      }
+
+      // valid checksumType code test
+      for (ChecksumType t : ChecksumType.values()) {
+        testValidChecksumTypeReadBlock(t.getCode(), c, firstBlock);
+      }
+
+      c.restore();
+      // test corrupted HFileBlock with unknown checksumType code 3
+      c.write(HFileBlock.Header.CHECKSUM_TYPE_INDEX, ByteBuffer.wrap(new byte[] { 3 }));
+      logHeader(firstBlock);
+      try (HFileBlockChannelPositionIterator it =
+        new HFileBlockChannelPositionIterator(hFileTestRule)) {
+        CountingConsumer consumer = new CountingConsumer(it);
+        try {
+          consumer.readFully();
+          fail();
+        } catch (Exception e) {
+          assertThat(e, new IsThrowableMatching().withInstanceOf(IOException.class)
+            .withMessage(startsWith("Unknown checksum type code")));
+        }
+        assertEquals(0, consumer.getItemsRead());
+      }
+    } finally {
+      if (firstBlock != null) {
+        firstBlock.close();
+      }
+    }
+  }
+
+  @Test
+  public void testChecksumTypeCorruptionSecondBlock() throws Exception {
+    HFileBlockChannelPosition secondBlock = null;
+    try {
+      try (HFileBlockChannelPositionIterator it =
+        new HFileBlockChannelPositionIterator(hFileTestRule)) {
+        assertTrue(it.hasNext());
+        it.next();
+        assertTrue(it.hasNext());
+        secondBlock = it.next();
+      }
+
+      Corrupter c = new Corrupter(secondBlock);
+
+      logHeader(secondBlock);
+      // test corrupted HFileBlock with unknown checksumType code -1
+      c.write(HFileBlock.Header.CHECKSUM_TYPE_INDEX, ByteBuffer.wrap(new byte[] { -1 }));
+      logHeader(secondBlock);
+      try (HFileBlockChannelPositionIterator it =
+        new HFileBlockChannelPositionIterator(hFileTestRule)) {
+        CountingConsumer consumer = new CountingConsumer(it);
+        try {
+          consumer.readFully();
+          fail();
+        } catch (Exception e) {
+          assertThat(e, new IsThrowableMatching().withInstanceOf(RuntimeException.class)
+            .withMessage(startsWith("Unknown checksum type code")));
+        }
+        assertEquals(1, consumer.getItemsRead());
+      }
+
+      // valid checksumType code test
+      for (ChecksumType t : ChecksumType.values()) {
+        testValidChecksumTypeReadBlock(t.getCode(), c, secondBlock);
+      }
+
+      c.restore();
+      // test corrupted HFileBlock with unknown checksumType code 3
+      c.write(HFileBlock.Header.CHECKSUM_TYPE_INDEX, ByteBuffer.wrap(new byte[] { 3 }));
+      logHeader(secondBlock);
+      try (HFileBlockChannelPositionIterator it =
+        new HFileBlockChannelPositionIterator(hFileTestRule)) {
+        CountingConsumer consumer = new CountingConsumer(it);
+        try {
+          consumer.readFully();
+          fail();
+        } catch (Exception e) {
+          assertThat(e, new IsThrowableMatching().withInstanceOf(RuntimeException.class)
+            .withMessage(startsWith("Unknown checksum type code")));
+        }
+        assertEquals(1, consumer.getItemsRead());
+      }
+    } finally {
+      if (secondBlock != null) {
+        secondBlock.close();
+      }
+    }
+  }
+
+  public void testValidChecksumTypeReadBlock(byte checksumTypeCode, Corrupter c,
+    HFileBlockChannelPosition testBlock) throws IOException {
+    c.restore();
+    c.write(HFileBlock.Header.CHECKSUM_TYPE_INDEX,
+      ByteBuffer.wrap(new byte[] { checksumTypeCode }));
+    logHeader(testBlock);
+    try (
+      HFileBlockChannelPositionIterator it = new HFileBlockChannelPositionIterator(hFileTestRule)) {
+      CountingConsumer consumer = new CountingConsumer(it);
+      try {
+        consumer.readFully();
+      } catch (Exception e) {
+        fail("test fail: valid checksumType are not executing properly");
+      }
+      assertNotEquals(0, consumer.getItemsRead());
+    }
+  }
+
   @Test
   public void testOnDiskSizeWithoutHeaderCorruptionFirstBlock() throws Exception {
     HFileBlockChannelPosition firstBlock = null;
@@ -330,7 +467,8 @@ public class TestHFileBlockHeaderCorruption {
       try {
         reader = HFile.createReader(hfs, hfsPath, CacheConfig.DISABLED, true, conf);
         HFileBlock.FSReader fsreader = reader.getUncachedBlockReader();
-        iter = fsreader.blockRange(0, hfs.getFileStatus(hfsPath).getLen());
+        // The read block offset cannot out of the range:0,loadOnOpenDataOffset
+        iter = fsreader.blockRange(0, reader.getTrailer().getLoadOnOpenDataOffset());
       } catch (IOException e) {
         if (reader != null) {
           closeQuietly(reader::close);
