@@ -22,6 +22,7 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
 import java.io.ByteArrayOutputStream;
+import java.io.DataOutput;
 import java.io.DataOutputStream;
 import java.io.IOException;
 import java.nio.ByteBuffer;
@@ -32,6 +33,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Random;
 import java.util.Set;
+import java.util.concurrent.atomic.AtomicInteger;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FSDataOutputStream;
@@ -42,18 +44,23 @@ import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
 import org.apache.hadoop.hbase.HBaseCommonTestingUtility;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
+import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.KeyValueUtil;
 import org.apache.hadoop.hbase.PrivateCellUtil;
 import org.apache.hadoop.hbase.fs.HFileSystem;
 import org.apache.hadoop.hbase.io.ByteBuffAllocator;
+import org.apache.hadoop.hbase.io.FSDataInputStreamWrapper;
 import org.apache.hadoop.hbase.io.compress.Compression;
 import org.apache.hadoop.hbase.io.compress.Compression.Algorithm;
 import org.apache.hadoop.hbase.io.encoding.DataBlockEncoding;
-import org.apache.hadoop.hbase.io.hfile.HFileBlockIndex.BlockIndexChunk;
+import org.apache.hadoop.hbase.io.encoding.IndexBlockEncoding;
+import org.apache.hadoop.hbase.io.hfile.HFile.Writer;
 import org.apache.hadoop.hbase.io.hfile.HFileBlockIndex.BlockIndexReader;
+import org.apache.hadoop.hbase.io.hfile.NoOpIndexBlockEncoder.NoOpEncodedSeeker;
 import org.apache.hadoop.hbase.nio.ByteBuff;
 import org.apache.hadoop.hbase.nio.MultiByteBuff;
+import org.apache.hadoop.hbase.nio.RefCnt;
 import org.apache.hadoop.hbase.testclassification.IOTests;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.util.Bytes;
@@ -69,6 +76,8 @@ import org.junit.runners.Parameterized.Parameters;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.hbase.thirdparty.io.netty.util.ResourceLeakDetector;
+
 @RunWith(Parameterized.class)
 @Category({ IOTests.class, MediumTests.class })
 public class TestHFileBlockIndex {
@@ -135,6 +144,76 @@ public class TestHFileBlockIndex {
     testBlockIndexInternals(true);
   }
 
+  private void writeDataBlocksAndCreateIndex(HFileBlock.Writer hbw, FSDataOutputStream outputStream,
+    HFileBlockIndex.BlockIndexWriter biw) throws IOException {
+    for (int i = 0; i < NUM_DATA_BLOCKS; ++i) {
+      hbw.startWriting(BlockType.DATA).write(Bytes.toBytes(String.valueOf(RNG.nextInt(1000))));
+      long blockOffset = outputStream.getPos();
+      hbw.writeHeaderAndData(outputStream);
+
+      byte[] firstKey = null;
+      byte[] family = Bytes.toBytes("f");
+      byte[] qualifier = Bytes.toBytes("q");
+      for (int j = 0; j < 16; ++j) {
+        byte[] k = new KeyValue(RandomKeyValueUtil.randomOrderedKey(RNG, i * 16 + j), family,
+          qualifier, EnvironmentEdgeManager.currentTime(), KeyValue.Type.Put).getKey();
+        keys.add(k);
+        if (j == 8) {
+          firstKey = k;
+        }
+      }
+      assertTrue(firstKey != null);
+      if (firstKeyInFile == null) {
+        firstKeyInFile = firstKey;
+      }
+      biw.addEntry(firstKey, blockOffset, hbw.getOnDiskSizeWithHeader());
+
+      writeInlineBlocks(hbw, outputStream, biw, false);
+    }
+    writeInlineBlocks(hbw, outputStream, biw, true);
+    rootIndexOffset = biw.writeIndexBlocks(outputStream);
+    outputStream.close();
+  }
+
+  @Test
+  public void testBlockIndexWithOffHeapBuffer() throws Exception {
+    ResourceLeakDetector.setLevel(ResourceLeakDetector.Level.PARANOID);
+    path = new Path(TEST_UTIL.getDataTestDir(), "block_index_testBlockIndexWithOffHeapBuffer");
+    assertEquals(0, keys.size());
+    HFileContext meta = new HFileContextBuilder().withHBaseCheckSum(true)
+      .withIncludesMvcc(includesMemstoreTS).withIncludesTags(true).withCompression(compr)
+      .withBytesPerCheckSum(HFile.DEFAULT_BYTES_PER_CHECKSUM).build();
+    ByteBuffAllocator allocator = ByteBuffAllocator.create(TEST_UTIL.getConfiguration(), true);
+    HFileBlock.Writer hbw =
+      new HFileBlock.Writer(TEST_UTIL.getConfiguration(), null, meta, allocator);
+    FSDataOutputStream outputStream = fs.create(path);
+
+    final AtomicInteger counter = new AtomicInteger();
+    RefCnt.detector.setLeakListener(new ResourceLeakDetector.LeakListener() {
+      @Override
+      public void onLeak(String s, String s1) {
+        counter.incrementAndGet();
+      }
+    });
+
+    long maxSize = NUM_DATA_BLOCKS * 1000;
+    long blockSize = 1000;
+    LruBlockCache cache = new LruBlockCache(maxSize, blockSize);
+    CacheConfig cacheConfig = new CacheConfig(TEST_UTIL.getConfiguration(), null, cache, allocator);
+
+    HFileBlockIndex.BlockIndexWriter biw =
+      new HFileBlockIndex.BlockIndexWriter(hbw, cacheConfig, path.getName(), null);
+
+    writeDataBlocksAndCreateIndex(hbw, outputStream, biw);
+
+    System.gc();
+    Thread.sleep(1000);
+
+    allocator.allocate(128 * 1024).release();
+
+    assertEquals(0, counter.get());
+  }
+
   private void clear() throws IOException {
     keys.clear();
     firstKeyInFile = null;
@@ -176,6 +255,14 @@ public class TestHFileBlockIndex {
     public HFileBlock readBlock(long offset, long onDiskSize, boolean cacheBlock, boolean pread,
       boolean isCompaction, boolean updateCacheMetrics, BlockType expectedBlockType,
       DataBlockEncoding expectedDataBlockEncoding) throws IOException {
+      return readBlock(offset, onDiskSize, cacheBlock, pread, isCompaction, updateCacheMetrics,
+        expectedBlockType, expectedDataBlockEncoding, false);
+    }
+
+    @Override
+    public HFileBlock readBlock(long offset, long onDiskSize, boolean cacheBlock, boolean pread,
+      boolean isCompaction, boolean updateCacheMetrics, BlockType expectedBlockType,
+      DataBlockEncoding expectedDataBlockEncoding, boolean cacheOnly) throws IOException {
       if (offset == prevOffset && onDiskSize == prevOnDiskSize && pread == prevPread) {
         hitCount += 1;
         return prevBlock;
@@ -254,34 +341,9 @@ public class TestHFileBlockIndex {
       .withBytesPerCheckSum(HFile.DEFAULT_BYTES_PER_CHECKSUM).build();
     HFileBlock.Writer hbw = new HFileBlock.Writer(TEST_UTIL.getConfiguration(), null, meta);
     FSDataOutputStream outputStream = fs.create(path);
-    HFileBlockIndex.BlockIndexWriter biw = new HFileBlockIndex.BlockIndexWriter(hbw, null, null);
-    for (int i = 0; i < NUM_DATA_BLOCKS; ++i) {
-      hbw.startWriting(BlockType.DATA).write(Bytes.toBytes(String.valueOf(RNG.nextInt(1000))));
-      long blockOffset = outputStream.getPos();
-      hbw.writeHeaderAndData(outputStream);
-
-      byte[] firstKey = null;
-      byte[] family = Bytes.toBytes("f");
-      byte[] qualifier = Bytes.toBytes("q");
-      for (int j = 0; j < 16; ++j) {
-        byte[] k = new KeyValue(RandomKeyValueUtil.randomOrderedKey(RNG, i * 16 + j), family,
-          qualifier, EnvironmentEdgeManager.currentTime(), KeyValue.Type.Put).getKey();
-        keys.add(k);
-        if (j == 8) {
-          firstKey = k;
-        }
-      }
-      assertTrue(firstKey != null);
-      if (firstKeyInFile == null) {
-        firstKeyInFile = firstKey;
-      }
-      biw.addEntry(firstKey, blockOffset, hbw.getOnDiskSizeWithHeader());
-
-      writeInlineBlocks(hbw, outputStream, biw, false);
-    }
-    writeInlineBlocks(hbw, outputStream, biw, true);
-    rootIndexOffset = biw.writeIndexBlocks(outputStream);
-    outputStream.close();
+    HFileBlockIndex.BlockIndexWriter biw =
+      new HFileBlockIndex.BlockIndexWriter(hbw, null, null, null);
+    writeDataBlocksAndCreateIndex(hbw, outputStream, biw);
 
     numLevels = biw.getNumLevels();
     numRootEntries = biw.getNumRootEntries();
@@ -432,7 +494,8 @@ public class TestHFileBlockIndex {
 
   @Test
   public void testBlockIndexChunk() throws IOException {
-    BlockIndexChunk c = new BlockIndexChunk();
+    BlockIndexChunk c = new HFileBlockIndex.BlockIndexChunkImpl();
+    HFileIndexBlockEncoder indexBlockEncoder = NoOpIndexBlockEncoder.INSTANCE;
     ByteArrayOutputStream baos = new ByteArrayOutputStream();
     int N = 1000;
     int[] numSubEntriesAt = new int[N];
@@ -440,12 +503,12 @@ public class TestHFileBlockIndex {
     for (int i = 0; i < N; ++i) {
       baos.reset();
       DataOutputStream dos = new DataOutputStream(baos);
-      c.writeNonRoot(dos);
+      indexBlockEncoder.encode(c, false, dos);
       assertEquals(c.getNonRootSize(), dos.size());
 
       baos.reset();
       dos = new DataOutputStream(baos);
-      c.writeRoot(dos);
+      indexBlockEncoder.encode(c, true, dos);
       assertEquals(c.getRootSize(), dos.size());
 
       byte[] k = RandomKeyValueUtil.randomOrderedKey(RNG, i);
@@ -486,7 +549,7 @@ public class TestHFileBlockIndex {
   }
 
   /**
-   * to check if looks good when midKey on a leaf index block boundary n
+   * to check if looks good when midKey on a leaf index block boundary
    */
   @Test
   public void testMidKeyOnLeafIndexBlockBoundary() throws IOException {
@@ -543,7 +606,6 @@ public class TestHFileBlockIndex {
   /**
    * Testing block index through the HFile writer/reader APIs. Allows to test setting index block
    * size through configuration, intermediate-level index blocks, and caching index blocks on write.
-   * n
    */
   @Test
   public void testHFileWriterAndReader() throws IOException {
@@ -723,4 +785,96 @@ public class TestHFileBlockIndex {
     }
     reader.close();
   }
+
+  /**
+   * This test is for HBASE-27940, which midkey metadata in root index block would always be ignored
+   * by {@link BlockIndexReader#readMultiLevelIndexRoot}.
+   */
+  @Test
+  public void testMidKeyReadSuccessfullyFromRootIndexBlock() throws IOException {
+    conf.setInt(HFileBlockIndex.MAX_CHUNK_SIZE_KEY, 128);
+    Path hfilePath =
+      new Path(TEST_UTIL.getDataTestDir(), "testMidKeyReadSuccessfullyFromRootIndexBlock");
+    Compression.Algorithm compressAlgo = Compression.Algorithm.NONE;
+    int entryCount = 50000;
+    HFileContext context = new HFileContextBuilder().withBlockSize(4096).withIncludesTags(false)
+      .withDataBlockEncoding(DataBlockEncoding.NONE).withCompression(compressAlgo).build();
+
+    try (HFile.Writer writer = new HFile.WriterFactory(conf, new CacheConfig(conf))
+      .withPath(fs, hfilePath).withFileContext(context).create()) {
+
+      List<KeyValue> keyValues = new ArrayList<>(entryCount);
+      for (int i = 0; i < entryCount; ++i) {
+        byte[] keyBytes = RandomKeyValueUtil.randomOrderedKey(RNG, i);
+        // A random-length random value.
+        byte[] valueBytes = RandomKeyValueUtil.randomValue(RNG);
+        KeyValue keyValue =
+          new KeyValue(keyBytes, null, null, HConstants.LATEST_TIMESTAMP, valueBytes);
+        writer.append(keyValue);
+        keyValues.add(keyValue);
+      }
+    }
+
+    try (FSDataInputStream fsdis = fs.open(hfilePath)) {
+      long fileSize = fs.getFileStatus(hfilePath).getLen();
+      FixedFileTrailer trailer = FixedFileTrailer.readFromStream(fsdis, fileSize);
+
+      assertEquals(3, trailer.getMajorVersion());
+      assertEquals(entryCount, trailer.getEntryCount());
+      HFileContext meta = new HFileContextBuilder().withCompression(compressAlgo)
+        .withIncludesMvcc(false).withIncludesTags(false)
+        .withDataBlockEncoding(DataBlockEncoding.NONE).withHBaseCheckSum(true).build();
+      ReaderContext readerContext =
+        new ReaderContextBuilder().withInputStreamWrapper(new FSDataInputStreamWrapper(fsdis))
+          .withFilePath(hfilePath).withFileSystem(fs).withFileSize(fileSize).build();
+      HFileBlock.FSReader blockReader =
+        new HFileBlock.FSReaderImpl(readerContext, meta, ByteBuffAllocator.HEAP, conf);
+
+      MyEncoder encoder = new MyEncoder();
+      HFileBlockIndex.CellBasedKeyBlockIndexReaderV2 dataBlockIndexReader =
+        new HFileBlockIndex.CellBasedKeyBlockIndexReaderV2(trailer.createComparator(),
+          trailer.getNumDataIndexLevels(), encoder);
+
+      HFileBlock.BlockIterator blockIter = blockReader.blockRange(trailer.getLoadOnOpenDataOffset(),
+        fileSize - trailer.getTrailerSize());
+      // Data index. We also read statistics about the block index written after
+      // the root level.
+      dataBlockIndexReader.readMultiLevelIndexRoot(
+        blockIter.nextBlockWithBlockType(BlockType.ROOT_INDEX), trailer.getDataIndexCount());
+      NoOpEncodedSeeker noOpEncodedSeeker = (NoOpEncodedSeeker) encoder.encoderSeeker;
+      // Assert we have read midkey metadata successfully.
+      assertTrue(noOpEncodedSeeker.midLeafBlockOffset >= 0);
+      assertTrue(noOpEncodedSeeker.midLeafBlockOnDiskSize > 0);
+      assertTrue(noOpEncodedSeeker.midKeyEntry >= 0);
+    }
+  }
+
+  static class MyEncoder implements HFileIndexBlockEncoder {
+
+    EncodedSeeker encoderSeeker;
+
+    @Override
+    public void saveMetadata(Writer writer) throws IOException {
+      NoOpIndexBlockEncoder.INSTANCE.saveMetadata(writer);
+
+    }
+
+    @Override
+    public void encode(BlockIndexChunk blockIndexChunk, boolean rootIndexBlock, DataOutput out)
+      throws IOException {
+      NoOpIndexBlockEncoder.INSTANCE.encode(blockIndexChunk, rootIndexBlock, out);
+    }
+
+    @Override
+    public IndexBlockEncoding getIndexBlockEncoding() {
+      return NoOpIndexBlockEncoder.INSTANCE.getIndexBlockEncoding();
+    }
+
+    @Override
+    public EncodedSeeker createSeeker() {
+      encoderSeeker = NoOpIndexBlockEncoder.INSTANCE.createSeeker();
+      return encoderSeeker;
+    }
+
+  }
 }
