@@ -104,7 +104,7 @@ public class TestBucketWriterThread {
   }
 
   /**
-   * Test non-error case just works. nnn
+   * Test non-error case just works.
    */
   @Test
   public void testNonErrorCase() throws IOException, InterruptedException {
@@ -114,7 +114,7 @@ public class TestBucketWriterThread {
 
   /**
    * Pass through a too big entry and ensure it is cleared from queues and ramCache. Manually run
-   * the WriterThread. n
+   * the WriterThread.
    */
   @Test
   public void testTooBigEntry() throws InterruptedException {
@@ -122,11 +122,12 @@ public class TestBucketWriterThread {
     Mockito.when(tooBigCacheable.getSerializedLength()).thenReturn(Integer.MAX_VALUE);
     this.bc.cacheBlock(this.plainKey, tooBigCacheable);
     doDrainOfOneEntry(this.bc, this.wt, this.q);
+    assertTrue(bc.blocksByHFile.isEmpty());
   }
 
   /**
    * Do IOE. Take the RAMQueueEntry that was on the queue, doctor it to throw exception, then put it
-   * back and process it. nn
+   * back and process it.
    */
   @SuppressWarnings("unchecked")
   @Test
@@ -138,12 +139,13 @@ public class TestBucketWriterThread {
       Mockito.any(), Mockito.any(), Mockito.any(), Mockito.any());
     this.q.add(spiedRqe);
     doDrainOfOneEntry(bc, wt, q);
+    assertTrue(bc.blocksByHFile.isEmpty());
     // Cache disabled when ioes w/o ever healing.
     assertTrue(!bc.isCacheEnabled());
   }
 
   /**
-   * Do Cache full exception nn
+   * Do Cache full exception
    */
   @Test
   public void testCacheFullException() throws IOException, InterruptedException {
