@@ -19,6 +19,7 @@ package org.apache.hadoop.hbase.ipc;
 
 import static org.junit.Assert.assertEquals;
 
+import org.apache.hadoop.hbase.CallDroppedException;
 import org.apache.hadoop.hbase.CompatibilityFactory;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
@@ -146,15 +147,17 @@ public class TestRpcMetrics {
     mrpc.exception(new RegionTooBusyException("Some region"));
     mrpc.exception(new OutOfOrderScannerNextException());
     mrpc.exception(new NotServingRegionException());
+    mrpc.exception(new CallDroppedException());
     mrpc.exception(new RequestTooBigException());
     mrpc.exception(new FakeException());
     HELPER.assertCounter("exceptions.RegionMovedException", 1, serverSource);
     HELPER.assertCounter("exceptions.RegionTooBusyException", 1, serverSource);
     HELPER.assertCounter("exceptions.OutOfOrderScannerNextException", 1, serverSource);
     HELPER.assertCounter("exceptions.NotServingRegionException", 1, serverSource);
+    HELPER.assertCounter("exceptions.callDropped", 1, serverSource);
     HELPER.assertCounter("exceptions.requestTooBig", 1, serverSource);
     HELPER.assertCounter("exceptions.otherExceptions", 1, serverSource);
-    HELPER.assertCounter("exceptions", 7, serverSource);
+    HELPER.assertCounter("exceptions", 8, serverSource);
   }
 
   private class FakeException extends DoNotRetryIOException {
