@@ -33,6 +33,7 @@ import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.master.assignment.AssignmentManager;
+import org.apache.hadoop.hbase.master.balancer.LoadBalancerFactory;
 import org.apache.hadoop.hbase.master.balancer.StochasticLoadBalancer;
 import org.apache.hadoop.hbase.testclassification.MasterTests;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
@@ -65,11 +66,15 @@ public class TestMasterBalancerNPE {
      * Make {@link BalancerChore} not run,so does not disrupt the test.
      */
     HMaster.setDisableBalancerChoreForTest(true);
+    TEST_UTIL.getConfiguration().set(HConstants.HBASE_MASTER_LOADBALANCER_CLASS,
+      MyLoadBalancer.class.getName());
   }
 
   @After
   public void shutdown() throws Exception {
     HMaster.setDisableBalancerChoreForTest(false);
+    TEST_UTIL.getConfiguration().set(HConstants.HBASE_MASTER_LOADBALANCER_CLASS,
+      LoadBalancerFactory.getDefaultLoadBalancerClass().getName());
     TEST_UTIL.shutdownMiniCluster();
   }
 
@@ -92,8 +97,8 @@ public class TestMasterBalancerNPE {
 
     final RegionInfo regionInfo = regionInfos.get(0);
 
-    StochasticLoadBalancer loadBalancer = (StochasticLoadBalancer) master.getLoadBalancer();
-    StochasticLoadBalancer spiedLoadBalancer = Mockito.spy(loadBalancer);
+    MyLoadBalancer loadBalancer = (MyLoadBalancer) master.getLoadBalancer();
+    MyLoadBalancer spiedLoadBalancer = Mockito.spy(loadBalancer);
     final AtomicReference<RegionPlan> regionPlanRef = new AtomicReference<RegionPlan>();
 
     /**
@@ -191,7 +196,7 @@ public class TestMasterBalancerNPE {
        * Before HBASE-26712,here invokes {@link AssignmentManager#balance(RegionPlan)} which may
        * throw NPE.
        */
-      master.balance();
+      master.balanceOrUpdateMetrics();
 
       unassignThread.join();
       assertTrue(exceptionRef.get() == null);
@@ -206,4 +211,16 @@ public class TestMasterBalancerNPE {
     TEST_UTIL.createTable(tableName, FAMILYNAME);
     return tableName;
   }
+
+  /**
+   * Define this class because the test needs to override
+   * {@link StochasticLoadBalancer#balanceTable}, which is protected.
+   */
+  static class MyLoadBalancer extends StochasticLoadBalancer {
+    @Override
+    protected List<RegionPlan> balanceTable(TableName tableName,
+      Map<ServerName, List<RegionInfo>> loadOfOneTable) {
+      return super.balanceTable(tableName, loadOfOneTable);
+    }
+  }
 }
