@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -32,6 +32,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Random;
+import java.util.concurrent.ThreadLocalRandom;
 import java.util.concurrent.atomic.AtomicInteger;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
@@ -72,12 +73,12 @@ import org.junit.experimental.categories.Category;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-@Category({MasterTests.class, MediumTests.class})
+@Category({ MasterTests.class, MediumTests.class })
 public class TestRegionPlacement {
 
   @ClassRule
   public static final HBaseClassTestRule CLASS_RULE =
-      HBaseClassTestRule.forClass(TestRegionPlacement.class);
+    HBaseClassTestRule.forClass(TestRegionPlacement.class);
 
   private static final Logger LOG = LoggerFactory.getLogger(TestRegionPlacement.class);
   private final static HBaseTestingUtility TEST_UTIL = new HBaseTestingUtility();
@@ -94,8 +95,8 @@ public class TestRegionPlacement {
   public static void setupBeforeClass() throws Exception {
     Configuration conf = TEST_UTIL.getConfiguration();
     // Enable the favored nodes based load balancer
-    conf.setClass(HConstants.HBASE_MASTER_LOADBALANCER_CLASS,
-        FavoredNodeLoadBalancer.class, LoadBalancer.class);
+    conf.setClass(HConstants.HBASE_MASTER_LOADBALANCER_CLASS, FavoredNodeLoadBalancer.class,
+      LoadBalancer.class);
     conf.setBoolean("hbase.tests.use.shortcircuit.reads", false);
     TEST_UTIL.startMiniCluster(SLAVES);
     CONNECTION = TEST_UTIL.getConnection();
@@ -108,7 +109,8 @@ public class TestRegionPlacement {
     TEST_UTIL.shutdownMiniCluster();
   }
 
-  @Ignore ("Test for unfinished feature") @Test
+  @Ignore("Test for unfinished feature")
+  @Test
   public void testRegionPlacement() throws Exception {
     String tableStr = "testRegionAssignment";
     TableName table = TableName.valueOf(tableStr);
@@ -133,18 +135,18 @@ public class TestRegionPlacement {
 
     // Shuffle the secondary with tertiary favored nodes
     FavoredNodesPlan shuffledPlan = this.shuffleAssignmentPlan(currentPlan,
-        FavoredNodesPlan.Position.SECONDARY, FavoredNodesPlan.Position.TERTIARY);
+      FavoredNodesPlan.Position.SECONDARY, FavoredNodesPlan.Position.TERTIARY);
     // Let the region placement update the hbase:meta and Region Servers
     rp.updateAssignmentPlan(shuffledPlan);
 
     // Verify the region assignment. There are supposed to no region reassignment
     // All the regions are still on the primary region server
-    verifyRegionAssignment(shuffledPlan,0, REGION_NUM);
+    verifyRegionAssignment(shuffledPlan, 0, REGION_NUM);
 
     // Shuffle the plan by switching the primary with secondary and
     // verify the region reassignment is consistent with the plan.
-    shuffledPlan = this.shuffleAssignmentPlan(currentPlan,
-        FavoredNodesPlan.Position.PRIMARY, FavoredNodesPlan.Position.SECONDARY);
+    shuffledPlan = this.shuffleAssignmentPlan(currentPlan, FavoredNodesPlan.Position.PRIMARY,
+      FavoredNodesPlan.Position.SECONDARY);
 
     // Let the region placement update the hbase:meta and Region Servers
     rp.updateAssignmentPlan(shuffledPlan);
@@ -154,15 +156,17 @@ public class TestRegionPlacement {
     // also verify that the AssignmentVerificationReport has the correct information
     RegionPlacementMaintainer rp = new RegionPlacementMaintainer(TEST_UTIL.getConfiguration());
     // we are interested in only one table (and hence one report)
-    rp.setTargetTableName(new String[]{tableStr});
+    rp.setTargetTableName(new String[] { tableStr });
     List<AssignmentVerificationReport> reports = rp.verifyRegionPlacement(false);
     AssignmentVerificationReport report = reports.get(0);
     assertTrue(report.getRegionsWithoutValidFavoredNodes().isEmpty());
     assertTrue(report.getNonFavoredAssignedRegions().isEmpty());
     assertTrue(report.getTotalFavoredAssignments() >= REGION_NUM);
     assertTrue(report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.PRIMARY) != 0);
-    assertTrue(report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.SECONDARY) == 0);
-    assertTrue(report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.TERTIARY) == 0);
+    assertTrue(
+      report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.SECONDARY) == 0);
+    assertTrue(
+      report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.TERTIARY) == 0);
     assertTrue(report.getUnassignedRegions().isEmpty());
 
     // Check when a RS stops, the regions get assigned to their secondary/tertiary
@@ -175,41 +179,48 @@ public class TestRegionPlacement {
     assertTrue(report.getNonFavoredAssignedRegions().isEmpty());
     assertTrue(report.getTotalFavoredAssignments() >= REGION_NUM);
     assertTrue(report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.PRIMARY) > 0);
-    assertTrue("secondary " +
-    report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.SECONDARY) + " tertiary "
+    assertTrue(
+      "secondary "
+        + report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.SECONDARY)
+        + " tertiary "
         + report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.TERTIARY),
-        (report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.SECONDARY) > 0
+      (report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.SECONDARY) > 0
         || report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.TERTIARY) > 0));
-    assertTrue((report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.PRIMARY) +
-        report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.SECONDARY) +
-        report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.TERTIARY)) == REGION_NUM);
+    assertTrue((report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.PRIMARY)
+      + report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.SECONDARY)
+      + report.getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position.TERTIARY))
+        == REGION_NUM);
     RegionPlacementMaintainer.printAssignmentPlan(currentPlan);
   }
 
   private void killRandomServerAndVerifyAssignment()
-      throws IOException, InterruptedException, KeeperException {
+    throws IOException, InterruptedException, KeeperException {
     ServerName serverToKill = null;
     int killIndex = 0;
-    Random random = new Random(System.currentTimeMillis());
+    Random rand = ThreadLocalRandom.current();
     ServerName metaServer = TEST_UTIL.getHBaseCluster().getServerHoldingMeta();
     LOG.debug("Server holding meta " + metaServer);
     boolean isNamespaceServer = false;
     do {
       // kill a random non-meta server carrying at least one region
-      killIndex = random.nextInt(SLAVES);
+      killIndex = rand.nextInt(SLAVES);
       serverToKill = TEST_UTIL.getHBaseCluster().getRegionServer(killIndex).getServerName();
       Collection<HRegion> regs =
-          TEST_UTIL.getHBaseCluster().getRegionServer(killIndex).getOnlineRegionsLocalContext();
+        TEST_UTIL.getHBaseCluster().getRegionServer(killIndex).getOnlineRegionsLocalContext();
       isNamespaceServer = false;
       for (HRegion r : regs) {
-        if (r.getRegionInfo().getTable().getNamespaceAsString()
-            .equals(NamespaceDescriptor.SYSTEM_NAMESPACE_NAME_STR)) {
+        if (
+          r.getRegionInfo().getTable().getNamespaceAsString()
+            .equals(NamespaceDescriptor.SYSTEM_NAMESPACE_NAME_STR)
+        ) {
           isNamespaceServer = true;
           break;
         }
       }
-    } while (ServerName.isSameAddress(metaServer, serverToKill) || isNamespaceServer ||
-        TEST_UTIL.getHBaseCluster().getRegionServer(killIndex).getNumberOfOnlineRegions() == 0);
+    } while (
+      ServerName.isSameAddress(metaServer, serverToKill) || isNamespaceServer
+        || TEST_UTIL.getHBaseCluster().getRegionServer(killIndex).getNumberOfOnlineRegions() == 0
+    );
     LOG.debug("Stopping RS " + serverToKill);
     Map<RegionInfo, Pair<ServerName, ServerName>> regionsToVerify = new HashMap<>();
     // mark the regions to track
@@ -217,8 +228,8 @@ public class TestRegionPlacement {
       ServerName s = entry.getValue()[0];
       if (ServerName.isSameAddress(s, serverToKill)) {
         regionsToVerify.put(entry.getKey(), new Pair<>(entry.getValue()[1], entry.getValue()[2]));
-        LOG.debug("Adding " + entry.getKey() + " with sedcondary/tertiary " +
-            entry.getValue()[1] + " " + entry.getValue()[2]);
+        LOG.debug("Adding " + entry.getKey() + " with sedcondary/tertiary " + entry.getValue()[1]
+          + " " + entry.getValue()[2]);
       }
     }
     int orig = TEST_UTIL.getHBaseCluster().getMaster().getAssignmentManager().getNumRegionsOpened();
@@ -226,21 +237,23 @@ public class TestRegionPlacement {
     TEST_UTIL.getHBaseCluster().waitForRegionServerToStop(serverToKill, 60000);
     int curr = TEST_UTIL.getHBaseCluster().getMaster().getAssignmentManager().getNumRegionsOpened();
     while (curr - orig < regionsToVerify.size()) {
-      LOG.debug("Waiting for " + regionsToVerify.size() + " to come online " +
-          " Current #regions " + curr + " Original #regions " + orig);
+      LOG.debug("Waiting for " + regionsToVerify.size() + " to come online " + " Current #regions "
+        + curr + " Original #regions " + orig);
       Thread.sleep(200);
       curr = TEST_UTIL.getHBaseCluster().getMaster().getAssignmentManager().getNumRegionsOpened();
     }
     // now verify
     for (Map.Entry<RegionInfo, Pair<ServerName, ServerName>> entry : regionsToVerify.entrySet()) {
-      ServerName newDestination = TEST_UTIL.getHBaseCluster().getMaster()
-          .getAssignmentManager().getRegionStates().getRegionServerOfRegion(entry.getKey());
+      ServerName newDestination = TEST_UTIL.getHBaseCluster().getMaster().getAssignmentManager()
+        .getRegionStates().getRegionServerOfRegion(entry.getKey());
       Pair<ServerName, ServerName> secondaryTertiaryServers = entry.getValue();
-      LOG.debug("New destination for region " + entry.getKey().getEncodedName() +
-          " " + newDestination +". Secondary/Tertiary are " + secondaryTertiaryServers.getFirst()
-          + "/" + secondaryTertiaryServers.getSecond());
-      if (!(ServerName.isSameAddress(newDestination, secondaryTertiaryServers.getFirst())||
-          ServerName.isSameAddress(newDestination, secondaryTertiaryServers.getSecond()))){
+      LOG.debug("New destination for region " + entry.getKey().getEncodedName() + " "
+        + newDestination + ". Secondary/Tertiary are " + secondaryTertiaryServers.getFirst() + "/"
+        + secondaryTertiaryServers.getSecond());
+      if (
+        !(ServerName.isSameAddress(newDestination, secondaryTertiaryServers.getFirst())
+          || ServerName.isSameAddress(newDestination, secondaryTertiaryServers.getSecond()))
+      ) {
         fail("Region " + entry.getKey() + " not present on any of the expected servers");
       }
     }
@@ -251,15 +264,16 @@ public class TestRegionPlacement {
   /**
    * Used to test the correctness of this class.
    */
-  @Ignore ("Test for unfinished feature") @Test
+  @Ignore("Test for unfinished feature")
+  @Test
   public void testRandomizedMatrix() {
     int rows = 100;
     int cols = 100;
     float[][] matrix = new float[rows][cols];
-    Random random = new Random();
+    Random rand = ThreadLocalRandom.current();
     for (int i = 0; i < rows; i++) {
       for (int j = 0; j < cols; j++) {
-        matrix[i][j] = random.nextFloat();
+        matrix[i][j] = rand.nextFloat();
       }
     }
 
@@ -280,7 +294,7 @@ public class TestRegionPlacement {
     // the same values on the original matrix.
     int[] transformedIndices = new int[rows];
     for (int i = 0; i < rows; i++) {
-      transformedIndices[i] = random.nextInt(cols);
+      transformedIndices[i] = rand.nextInt(cols);
     }
     int[] invertedTransformedIndices = rm.invertIndices(transformedIndices);
     float[] transformedValues = new float[rows];
@@ -299,18 +313,17 @@ public class TestRegionPlacement {
   /**
    * Shuffle the assignment plan by switching two favored node positions.
    * @param plan The assignment plan
-   * @param p1 The first switch position
-   * @param p2 The second switch position
+   * @param p1   The first switch position
+   * @param p2   The second switch position
    * @return the shuffled assignment plan
    */
   private FavoredNodesPlan shuffleAssignmentPlan(FavoredNodesPlan plan,
-      FavoredNodesPlan.Position p1, FavoredNodesPlan.Position p2) throws IOException {
+    FavoredNodesPlan.Position p1, FavoredNodesPlan.Position p2) throws IOException {
     FavoredNodesPlan shuffledPlan = new FavoredNodesPlan();
 
     Map<String, RegionInfo> regionToHRegion =
-        rp.getRegionAssignmentSnapshot().getRegionNameToRegionInfoMap();
-    for (Map.Entry<String, List<ServerName>> entry :
-      plan.getAssignmentMap().entrySet()) {
+      rp.getRegionAssignmentSnapshot().getRegionNameToRegionInfoMap();
+    for (Map.Entry<String, List<ServerName>> entry : plan.getAssignmentMap().entrySet()) {
 
       // copy the server list from the original plan
       List<ServerName> shuffledServerList = new ArrayList<>();
@@ -327,21 +340,12 @@ public class TestRegionPlacement {
   }
 
   /**
-   * To verify the region assignment status.
-   * It will check the assignment plan consistency between hbase:meta and
-   * region servers.
-   * Also it will verify weather the number of region movement and
+   * To verify the region assignment status. It will check the assignment plan consistency between
+   * hbase:meta and region servers. Also it will verify weather the number of region movement and
    * the number regions on the primary region server are expected
-   *
-   * @param plan
-   * @param regionMovementNum
-   * @param numRegionsOnPrimaryRS
-   * @throws InterruptedException
-   * @throws IOException
    */
-  private void verifyRegionAssignment(FavoredNodesPlan plan,
-      int regionMovementNum, int numRegionsOnPrimaryRS)
-  throws InterruptedException, IOException {
+  private void verifyRegionAssignment(FavoredNodesPlan plan, int regionMovementNum,
+    int numRegionsOnPrimaryRS) throws InterruptedException, IOException {
     // Verify the assignment plan in hbase:meta is consistent with the expected plan.
     verifyMETAUpdated(plan);
 
@@ -361,18 +365,16 @@ public class TestRegionPlacement {
    * @param expectedPlan the region assignment plan
    * @throws IOException if an IO problem is encountered
    */
-  private void verifyMETAUpdated(FavoredNodesPlan expectedPlan)
-  throws IOException {
+  private void verifyMETAUpdated(FavoredNodesPlan expectedPlan) throws IOException {
     FavoredNodesPlan planFromMETA = rp.getRegionAssignmentSnapshot().getExistingAssignmentPlan();
     assertTrue("The assignment plan is NOT consistent with the expected plan ",
-        planFromMETA.equals(expectedPlan));
+      planFromMETA.equals(expectedPlan));
   }
 
   /**
    * Verify the number of region movement is expected
    */
-  private void verifyRegionMovementNum(int expected)
-      throws InterruptedException, IOException {
+  private void verifyRegionMovementNum(int expected) throws InterruptedException, IOException {
     MiniHBaseCluster cluster = TEST_UTIL.getHBaseCluster();
     HMaster m = cluster.getMaster();
     int lastRegionOpenedCount = m.getAssignmentManager().getNumRegionsOpened();
@@ -385,47 +387,42 @@ public class TestRegionPlacement {
     int currentRegionOpened, regionMovement;
     do {
       currentRegionOpened = m.getAssignmentManager().getNumRegionsOpened();
-      regionMovement= currentRegionOpened - lastRegionOpenedCount;
-      LOG.debug("There are " + regionMovement + "/" + expected +
-          " regions moved after " + attempt + " attempts");
+      regionMovement = currentRegionOpened - lastRegionOpenedCount;
+      LOG.debug("There are " + regionMovement + "/" + expected + " regions moved after " + attempt
+        + " attempts");
       Thread.sleep((++attempt) * sleep);
     } while (regionMovement != expected && attempt <= retry);
 
     // update the lastRegionOpenedCount
     lastRegionOpenedCount = currentRegionOpened;
 
-    assertEquals("There are only " + regionMovement + " instead of "
-          + expected + " region movement for " + attempt + " attempts", expected, regionMovement);
+    assertEquals("There are only " + regionMovement + " instead of " + expected
+      + " region movement for " + attempt + " attempts", expected, regionMovement);
   }
 
   /**
-   * Verify the number of user regions is assigned to the primary
-   * region server based on the plan is expected
+   * Verify the number of user regions is assigned to the primary region server based on the plan is
+   * expected
    * @param expectedNum the expected number of assigned regions
-   * @throws IOException
    */
-  private void verifyRegionOnPrimaryRS(int expectedNum)
-      throws IOException {
+  private void verifyRegionOnPrimaryRS(int expectedNum) throws IOException {
     lastRegionOnPrimaryRSCount = getNumRegionisOnPrimaryRS();
-    assertEquals("Only " +  expectedNum + " of user regions running " +
-        "on the primary region server", expectedNum ,
-        lastRegionOnPrimaryRSCount);
+    assertEquals(
+      "Only " + expectedNum + " of user regions running " + "on the primary region server",
+      expectedNum, lastRegionOnPrimaryRSCount);
   }
 
   /**
-   * Verify all the online region servers has been updated to the
-   * latest assignment plan
-   * @param plan
-   * @throws IOException
+   * Verify all the online region servers has been updated to the latest assignment plan
    */
   private void verifyRegionServerUpdated(FavoredNodesPlan plan) throws IOException {
     // Verify all region servers contain the correct favored nodes information
     MiniHBaseCluster cluster = TEST_UTIL.getHBaseCluster();
     for (int i = 0; i < SLAVES; i++) {
       HRegionServer rs = cluster.getRegionServer(i);
-      for (Region region: rs.getRegions(TableName.valueOf("testRegionAssignment"))) {
-        InetSocketAddress[] favoredSocketAddress = rs.getFavoredNodesForRegion(
-            region.getRegionInfo().getEncodedName());
+      for (Region region : rs.getRegions(TableName.valueOf("testRegionAssignment"))) {
+        InetSocketAddress[] favoredSocketAddress =
+          rs.getFavoredNodesForRegion(region.getRegionInfo().getEncodedName());
         String regionName = region.getRegionInfo().getRegionNameAsString();
         List<ServerName> favoredServerList = plan.getAssignmentMap().get(regionName);
 
@@ -435,9 +432,8 @@ public class TestRegionPlacement {
           TableDescriptor desc = region.getTableDescriptor();
           // Verify they are ROOT and hbase:meta regions since no favored nodes
           assertNull(favoredSocketAddress);
-          assertTrue("User region " +
-              region.getTableDescriptor().getTableName() +
-              " should have favored nodes", desc.isMetaRegion());
+          assertTrue("User region " + region.getTableDescriptor().getTableName()
+            + " should have favored nodes", desc.isMetaRegion());
         } else {
           // For user region, the favored nodes in the region server should be
           // identical to favored nodes in the assignmentPlan
@@ -446,15 +442,15 @@ public class TestRegionPlacement {
           for (int j = 0; j < favoredServerList.size(); j++) {
             InetSocketAddress addrFromRS = favoredSocketAddress[j];
             InetSocketAddress addrFromPlan = InetSocketAddress.createUnresolved(
-                favoredServerList.get(j).getHostname(), favoredServerList.get(j).getPort());
+              favoredServerList.get(j).getHostname(), favoredServerList.get(j).getPort());
 
             assertNotNull(addrFromRS);
             assertNotNull(addrFromPlan);
-            assertTrue("Region server " + rs.getServerName().getAddress()
-                + " has the " + positions[j] +
-                " for region " + region.getRegionInfo().getRegionNameAsString() + " is " +
-                addrFromRS + " which is inconsistent with the plan "
-                + addrFromPlan, addrFromRS.equals(addrFromPlan));
+            assertTrue(
+              "Region server " + rs.getServerName().getAddress() + " has the " + positions[j]
+                + " for region " + region.getRegionInfo().getRegionNameAsString() + " is "
+                + addrFromRS + " which is inconsistent with the plan " + addrFromPlan,
+              addrFromRS.equals(addrFromPlan));
           }
         }
       }
@@ -462,12 +458,10 @@ public class TestRegionPlacement {
   }
 
   /**
-   * Check whether regions are assigned to servers consistent with the explicit
-   * hints that are persisted in the hbase:meta table.
-   * Also keep track of the number of the regions are assigned to the
-   * primary region server.
+   * Check whether regions are assigned to servers consistent with the explicit hints that are
+   * persisted in the hbase:meta table. Also keep track of the number of the regions are assigned to
+   * the primary region server.
    * @return the number of regions are assigned to the primary region server
-   * @throws IOException
    */
   private int getNumRegionisOnPrimaryRS() throws IOException {
     final AtomicInteger regionOnPrimaryNum = new AtomicInteger(0);
@@ -479,25 +473,25 @@ public class TestRegionPlacement {
         try {
           @SuppressWarnings("deprecation")
           RegionInfo info = MetaTableAccessor.getRegionInfo(result);
-          if(info.getTable().getNamespaceAsString()
-              .equals(NamespaceDescriptor.SYSTEM_NAMESPACE_NAME_STR)) {
+          if (
+            info.getTable().getNamespaceAsString()
+              .equals(NamespaceDescriptor.SYSTEM_NAMESPACE_NAME_STR)
+          ) {
             return true;
           }
-          byte[] server = result.getValue(HConstants.CATALOG_FAMILY,
-              HConstants.SERVER_QUALIFIER);
+          byte[] server = result.getValue(HConstants.CATALOG_FAMILY, HConstants.SERVER_QUALIFIER);
           byte[] favoredNodes = result.getValue(HConstants.CATALOG_FAMILY,
-              FavoredNodeAssignmentHelper.FAVOREDNODES_QUALIFIER);
+            FavoredNodeAssignmentHelper.FAVOREDNODES_QUALIFIER);
           // Add the favored nodes into assignment plan
           ServerName[] favoredServerList =
-              FavoredNodeAssignmentHelper.getFavoredNodesList(favoredNodes);
+            FavoredNodeAssignmentHelper.getFavoredNodesList(favoredNodes);
           favoredNodesAssignmentPlan.put(info, favoredServerList);
 
           Position[] positions = Position.values();
           if (info != null) {
             totalRegionNum.incrementAndGet();
             if (server != null) {
-              ServerName serverName =
-                  ServerName.valueOf(Bytes.toString(server), -1);
+              ServerName serverName = ServerName.valueOf(Bytes.toString(server), -1);
               if (favoredNodes != null) {
                 String placement = "[NOT FAVORED NODE]";
                 for (int i = 0; i < favoredServerList.length; i++) {
@@ -509,15 +503,13 @@ public class TestRegionPlacement {
                     break;
                   }
                 }
-                LOG.info(info.getRegionNameAsString() + " on " +
-                    serverName + " " + placement);
+                LOG.info(info.getRegionNameAsString() + " on " + serverName + " " + placement);
               } else {
-                LOG.info(info.getRegionNameAsString() + " running on " +
-                    serverName + " but there is no favored region server");
+                LOG.info(info.getRegionNameAsString() + " running on " + serverName
+                  + " but there is no favored region server");
               }
             } else {
-              LOG.info(info.getRegionNameAsString() +
-                  " not assigned to any server");
+              LOG.info(info.getRegionNameAsString() + " not assigned to any server");
             }
           }
           return true;
@@ -528,20 +520,17 @@ public class TestRegionPlacement {
       }
     };
     MetaTableAccessor.fullScanRegions(CONNECTION, visitor);
-    LOG.info("There are " + regionOnPrimaryNum.intValue() + " out of " +
-        totalRegionNum.intValue() + " regions running on the primary" +
-        " region servers" );
-    return regionOnPrimaryNum.intValue() ;
+    LOG.info("There are " + regionOnPrimaryNum.intValue() + " out of " + totalRegionNum.intValue()
+      + " regions running on the primary" + " region servers");
+    return regionOnPrimaryNum.intValue();
   }
 
   /**
    * Create a table with specified table name and region number.
    * @param tableName the name of the table to be created
    * @param regionNum number of regions to create
-   * @throws IOException
    */
-  private static void createTable(TableName tableName, int regionNum)
-      throws IOException {
+  private static void createTable(TableName tableName, int regionNum) throws IOException {
     int expectedRegions = regionNum;
     byte[][] splitKeys = new byte[expectedRegions - 1][];
     for (int i = 1; i < expectedRegions; i++) {
@@ -555,8 +544,9 @@ public class TestRegionPlacement {
 
     try (RegionLocator r = CONNECTION.getRegionLocator(tableName)) {
       List<HRegionLocation> regions = r.getAllRegionLocations();
-      assertEquals("Tried to create " + expectedRegions + " regions "
-          + "but only found " + regions.size(), expectedRegions, regions.size());
+      assertEquals(
+        "Tried to create " + expectedRegions + " regions " + "but only found " + regions.size(),
+        expectedRegions, regions.size());
     }
   }
 }
