@@ -39,6 +39,7 @@ import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.master.procedure.MasterProcedureConstants;
 import org.apache.hadoop.hbase.master.procedure.MasterProcedureEnv;
 import org.apache.hadoop.hbase.master.procedure.MasterProcedureTestingUtility;
+import org.apache.hadoop.hbase.master.procedure.ModifyTableProcedure;
 import org.apache.hadoop.hbase.procedure2.ProcedureExecutor;
 import org.apache.hadoop.hbase.procedure2.ProcedureMetrics;
 import org.apache.hadoop.hbase.procedure2.ProcedureTestingUtility;
@@ -92,6 +93,8 @@ public class TestMergeTableRegionsProcedure {
     conf.setInt("hbase.master.maximum.ping.server.attempts", 3);
     conf.setInt("hbase.master.ping.server.retry.sleep.interval", 1);
     conf.setInt(MasterProcedureConstants.MASTER_PROCEDURE_THREADS, 1);
+    conf.set("hbase.coprocessor.region.classes",
+      RegionServerHostingReplicaSlowOpenCoprocessor.class.getName());
   }
 
   @BeforeClass
@@ -205,10 +208,10 @@ public class TestMergeTableRegionsProcedure {
     // the merged regions cleanup.
     UTIL.getHBaseCluster().getMaster().setCatalogJanitorEnabled(true);
     UTIL.getHBaseCluster().getMaster().getCatalogJanitor().triggerNow();
-    byte[] mergedRegion = proc.getMergedRegion().getRegionName();
+    RegionInfo mergedRegion = proc.getMergedRegion();
     while (ris != null && ris.get(0) != null && ris.get(1) != null) {
       ris = MetaTableAccessor.getMergeRegions(UTIL.getConnection(), mergedRegion);
-      LOG.info("{} {}", Bytes.toStringBinary(mergedRegion), ris);
+      LOG.info("{} {}", Bytes.toStringBinary(mergedRegion.getRegionName()), ris);
       Threads.sleep(1000);
     }
     assertEquals(countOfRowsLoaded, UTIL.countRows(tableName));
@@ -345,6 +348,32 @@ public class TestMergeTableRegionsProcedure {
     assertRegionCount(tableName, initialRegionCount - 1);
   }
 
+  @Test
+  public void testMergeDetectsModifyTableProcedure() throws Exception {
+    final TableName tableName = TableName.valueOf(name.getMethodName());
+    final ProcedureExecutor<MasterProcedureEnv> procExec = getMasterProcedureExecutor();
+
+    List<RegionInfo> regions = createTable(tableName);
+
+    RegionServerHostingReplicaSlowOpenCoprocessor.slowDownReplicaOpen = true;
+    TableDescriptor td = TableDescriptorBuilder.newBuilder(admin.getDescriptor(tableName))
+      .setRegionReplication(2).build();
+    long modifyProcId =
+      procExec.submitProcedure(new ModifyTableProcedure(procExec.getEnvironment(), td));
+
+    // Merge regions of the table, the MergeTableRegionsProcedure will fail because there is a
+    // ModifyTableProcedure in progress
+    MergeTableRegionsProcedure mergeProcedure = new MergeTableRegionsProcedure(
+      procExec.getEnvironment(), regions.toArray(new RegionInfo[0]), false);
+    long mergeProcId = procExec.submitProcedure(mergeProcedure);
+    ProcedureTestingUtility.waitProcedure(procExec, mergeProcId);
+    ProcedureTestingUtility.assertProcFailed(procExec, mergeProcId);
+
+    RegionServerHostingReplicaSlowOpenCoprocessor.slowDownReplicaOpen = false;
+    ProcedureTestingUtility.waitProcedure(procExec, modifyProcId);
+    ProcedureTestingUtility.assertProcNotFailed(procExec, modifyProcId);
+  }
+
   private List<RegionInfo> createTable(final TableName tableName) throws Exception {
     TableDescriptor desc = TableDescriptorBuilder.newBuilder(tableName)
       .setColumnFamily(ColumnFamilyDescriptorBuilder.of(FAMILY)).build();
