@@ -24,17 +24,16 @@ public class BalancerTestBase2 extends BalancerTestBase {
 
   @Before
   public void before() {
-    conf.setFloat("hbase.master.balancer.stochastic.maxMovePercent", 1.0f);
     conf.setLong(StochasticLoadBalancer.MAX_STEPS_KEY, 2000000L);
     conf.setFloat("hbase.master.balancer.stochastic.localityCost", 0);
-    conf.setLong("hbase.master.balancer.stochastic.maxRunningTime", 3 * 60 * 1000);
+    conf.setLong("hbase.master.balancer.stochastic.maxRunningTime", 3 * 60 * 1000L);
     conf.setFloat("hbase.master.balancer.stochastic.minCostNeedBalance", 0.05f);
-    loadBalancer.setConf(conf);
+    loadBalancer.onConfigurationChange(conf);
   }
 
   @After
   public void after() {
     // reset config to make sure balancer run
-    loadBalancer.setConf(conf);
+    loadBalancer.onConfigurationChange(conf);
   }
 }
