@@ -18,6 +18,7 @@
 package org.apache.hadoop.hbase.master.balancer;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
@@ -43,12 +44,12 @@ import org.apache.hadoop.hbase.Size;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.master.RegionPlan;
-import org.apache.hadoop.hbase.master.balancer.BaseLoadBalancer.Cluster;
-import org.apache.hadoop.hbase.master.balancer.StochasticLoadBalancer.ServerLocalityCostFunction;
 import org.apache.hadoop.hbase.testclassification.MasterTests;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
+import org.junit.Before;
+import org.junit.BeforeClass;
 import org.junit.ClassRule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
@@ -66,21 +67,31 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
 
   // Mapping of locality test -> expected locality
   private float[] expectedLocalities = { 1.0f, 0.0f, 0.50f, 0.25f, 1.0f };
+  private static Configuration storedConfiguration;
+
+  @BeforeClass
+  public static void saveInitialConfiguration() {
+    storedConfiguration = new Configuration(conf);
+  }
+
+  @Before
+  public void beforeEachTest() {
+    conf = new Configuration(storedConfiguration);
+    loadBalancer.onConfigurationChange(conf);
+  }
 
   /**
    * Data set for testLocalityCost: [test][0][0] = mapping of server to number of regions it hosts
    * [test][region + 1][0] = server that region is hosted on [test][region + 1][server + 1] =
    * locality for region on server
    */
-
   private int[][][] clusterRegionLocationMocks = new int[][][] {
-
     // Test 1: each region is entirely on server that hosts it
     new int[][] { new int[] { 2, 1, 1 }, new int[] { 2, 0, 0, 100 }, // region 0 is hosted and
                                                                      // entirely local on server 2
       new int[] { 0, 100, 0, 0 }, // region 1 is hosted and entirely on server 0
       new int[] { 0, 100, 0, 0 }, // region 2 is hosted and entirely on server 0
-      new int[] { 1, 0, 100, 0 }, // region 1 is hosted and entirely on server 1
+      new int[] { 1, 0, 100, 0 }, // region 3 is hosted and entirely on server 1
     },
 
     // Test 2: each region is 0% local on the server that hosts it
@@ -88,7 +99,7 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
                                                                      // entirely local on server 2
       new int[] { 1, 100, 0, 0 }, // region 1 is hosted and entirely on server 0
       new int[] { 1, 100, 0, 0 }, // region 2 is hosted and entirely on server 0
-      new int[] { 2, 0, 100, 0 }, // region 1 is hosted and entirely on server 1
+      new int[] { 2, 0, 100, 0 }, // region 3 is hosted and entirely on server 1
     },
 
     // Test 3: each region is 25% local on the server that hosts it (and 50% locality is possible)
@@ -96,7 +107,7 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
                                                                      // entirely local on server 2
       new int[] { 1, 50, 25, 0 }, // region 1 is hosted and entirely on server 0
       new int[] { 1, 50, 25, 0 }, // region 2 is hosted and entirely on server 0
-      new int[] { 2, 0, 50, 25 }, // region 1 is hosted and entirely on server 1
+      new int[] { 2, 0, 50, 25 }, // region 3 is hosted and entirely on server 1
     },
 
     // Test 4: each region is 25% local on the server that hosts it (and 100% locality is possible)
@@ -104,7 +115,7 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
                                                                       // entirely local on server 2
       new int[] { 1, 100, 25, 0 }, // region 1 is hosted and entirely on server 0
       new int[] { 1, 100, 25, 0 }, // region 2 is hosted and entirely on server 0
-      new int[] { 2, 0, 100, 25 }, // region 1 is hosted and entirely on server 1
+      new int[] { 2, 0, 100, 25 }, // region 3 is hosted and entirely on server 1
     },
 
     // Test 5: each region is 75% local on the server that hosts it (and 75% locality is possible
@@ -113,12 +124,11 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
                                                                       // entirely local on server 2
       new int[] { 1, 75, 75, 75 }, // region 1 is hosted and entirely on server 0
       new int[] { 1, 75, 75, 75 }, // region 2 is hosted and entirely on server 0
-      new int[] { 2, 75, 75, 75 }, // region 1 is hosted and entirely on server 1
+      new int[] { 2, 75, 75, 75 }, // region 3 is hosted and entirely on server 1
     }, };
 
   @Test
   public void testKeepRegionLoad() throws Exception {
-
     ServerName sn = ServerName.valueOf("test:8080", 100);
     int numClusterStatusToAdd = 20000;
     for (int i = 0; i < numClusterStatusToAdd; i++) {
@@ -140,7 +150,7 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
       when(clusterStatus.getLiveServerMetrics()).thenReturn(serverMetricsMap);
       // when(clusterStatus.getLoad(sn)).thenReturn(sl);
 
-      loadBalancer.setClusterMetrics(clusterStatus);
+      loadBalancer.updateClusterMetrics(clusterStatus);
     }
 
     String regionNameAsString = RegionInfo.getRegionNameAsString(Bytes.toBytes(REGION_KEY));
@@ -158,41 +168,157 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
   }
 
   @Test
-  public void testNeedBalance() {
-    float minCost = conf.getFloat("hbase.master.balancer.stochastic.minCostNeedBalance", 0.05f);
-    conf.setFloat("hbase.master.balancer.stochastic.minCostNeedBalance", 1.0f);
-    try {
-      // Test with/without per table balancer.
-      boolean[] perTableBalancerConfigs = { true, false };
-      for (boolean isByTable : perTableBalancerConfigs) {
-        conf.setBoolean(HConstants.HBASE_MASTER_LOADBALANCE_BYTABLE, isByTable);
-        loadBalancer.setConf(conf);
-        for (int[] mockCluster : clusterStateMocks) {
-          Map<ServerName, List<RegionInfo>> servers = mockClusterServers(mockCluster);
-          Map<TableName, Map<ServerName, List<RegionInfo>>> LoadOfAllTable =
-            (Map) mockClusterServersWithTables(servers);
-          List<RegionPlan> plans = loadBalancer.balanceCluster(LoadOfAllTable);
-          boolean emptyPlans = plans == null || plans.isEmpty();
-          assertTrue(emptyPlans || needsBalanceIdleRegion(mockCluster));
-        }
+  public void testUpdateBalancerLoadInfo() {
+    int[] cluster = new int[] { 10, 0 };
+    Map<ServerName, List<RegionInfo>> servers = mockClusterServers(cluster);
+    BalancerClusterState clusterState = mockCluster(cluster);
+    Map<TableName, Map<ServerName, List<RegionInfo>>> LoadOfAllTable =
+      (Map) mockClusterServersWithTables(servers);
+    boolean[] perTableBalancerConfigs = { true, false };
+    for (boolean isByTable : perTableBalancerConfigs) {
+      conf.setBoolean(HConstants.HBASE_MASTER_LOADBALANCE_BYTABLE, isByTable);
+      loadBalancer.onConfigurationChange(conf);
+      dummyMetricsStochasticBalancer.clearDummyMetrics();
+      loadBalancer.updateBalancerLoadInfo(LoadOfAllTable);
+      assertTrue("Metrics should be recorded!",
+        dummyMetricsStochasticBalancer.getDummyCostsMap() != null
+          && !dummyMetricsStochasticBalancer.getDummyCostsMap().isEmpty());
+
+      String metricRecordKey;
+      if (isByTable) {
+        metricRecordKey = "table1#" + StochasticLoadBalancer.OVERALL_COST_FUNCTION_NAME;
+      } else {
+        metricRecordKey =
+          HConstants.ENSEMBLE_TABLE_NAME + "#" + StochasticLoadBalancer.OVERALL_COST_FUNCTION_NAME;
       }
-    } finally {
-      // reset config
-      conf.unset(HConstants.HBASE_MASTER_LOADBALANCE_BYTABLE);
-      conf.setFloat("hbase.master.balancer.stochastic.minCostNeedBalance", minCost);
-      loadBalancer.setConf(conf);
+      double curOverallCost = loadBalancer.computeCost(clusterState, Double.MAX_VALUE);
+      double curOverallCostInMetrics =
+        dummyMetricsStochasticBalancer.getDummyCostsMap().get(metricRecordKey);
+      assertEquals(curOverallCost, curOverallCostInMetrics, 0.001);
     }
   }
 
+  @Test
+  public void testUpdateStochasticCosts() {
+    int[] cluster = new int[] { 10, 0 };
+    Map<ServerName, List<RegionInfo>> servers = mockClusterServers(cluster);
+    BalancerClusterState clusterState = mockCluster(cluster);
+    conf.setFloat("hbase.master.balancer.stochastic.minCostNeedBalance", 1.0f);
+    conf.setBoolean(HConstants.HBASE_MASTER_LOADBALANCE_BYTABLE, false);
+    loadBalancer.onConfigurationChange(conf);
+    dummyMetricsStochasticBalancer.clearDummyMetrics();
+    List<RegionPlan> plans =
+      loadBalancer.balanceCluster((Map) mockClusterServersWithTables(servers));
+
+    assertTrue("Balance plan should not be empty!", plans != null && !plans.isEmpty());
+    assertTrue("There should be metrics record in MetricsStochasticBalancer",
+      !dummyMetricsStochasticBalancer.getDummyCostsMap().isEmpty());
+
+    double overallCostOfCluster = loadBalancer.computeCost(clusterState, Double.MAX_VALUE);
+    double overallCostInMetrics = dummyMetricsStochasticBalancer.getDummyCostsMap().get(
+      HConstants.ENSEMBLE_TABLE_NAME + "#" + StochasticLoadBalancer.OVERALL_COST_FUNCTION_NAME);
+    assertEquals(overallCostOfCluster, overallCostInMetrics, 0.001);
+  }
+
+  @Test
+  public void testUpdateStochasticCostsIfBalanceNotRan() {
+    int[] cluster = new int[] { 10, 10 };
+    Map<ServerName, List<RegionInfo>> servers = mockClusterServers(cluster);
+    BalancerClusterState clusterState = mockCluster(cluster);
+    conf.setFloat("hbase.master.balancer.stochastic.minCostNeedBalance", Float.MAX_VALUE);
+    conf.setBoolean(HConstants.HBASE_MASTER_LOADBALANCE_BYTABLE, false);
+    loadBalancer.onConfigurationChange(conf);
+    dummyMetricsStochasticBalancer.clearDummyMetrics();
+    List<RegionPlan> plans =
+      loadBalancer.balanceCluster((Map) mockClusterServersWithTables(servers));
+
+    assertTrue("Balance plan should be empty!", plans == null || plans.isEmpty());
+    assertTrue("There should be metrics record in MetricsStochasticBalancer!",
+      !dummyMetricsStochasticBalancer.getDummyCostsMap().isEmpty());
+
+    double overallCostOfCluster = loadBalancer.computeCost(clusterState, Double.MAX_VALUE);
+    double overallCostInMetrics = dummyMetricsStochasticBalancer.getDummyCostsMap().get(
+      HConstants.ENSEMBLE_TABLE_NAME + "#" + StochasticLoadBalancer.OVERALL_COST_FUNCTION_NAME);
+    assertEquals(overallCostOfCluster, overallCostInMetrics, 0.001);
+  }
+
+  @Test
+  public void testNeedBalance() {
+    conf.setFloat("hbase.master.balancer.stochastic.minCostNeedBalance", 1.0f);
+    conf.setFloat(HConstants.LOAD_BALANCER_SLOP_KEY, -1f);
+    conf.setBoolean("hbase.master.balancer.stochastic.runMaxSteps", false);
+    conf.setLong("hbase.master.balancer.stochastic.maxSteps", 5000L);
+    // Test with/without per table balancer.
+    boolean[] perTableBalancerConfigs = { true, false };
+    for (boolean isByTable : perTableBalancerConfigs) {
+      conf.setBoolean(HConstants.HBASE_MASTER_LOADBALANCE_BYTABLE, isByTable);
+      loadBalancer.onConfigurationChange(conf);
+      for (int[] mockCluster : clusterStateMocks) {
+        assertTrue(hasEmptyBalancerPlans(mockCluster) || needsBalanceIdleRegion(mockCluster));
+      }
+    }
+  }
+
+  @Test
+  public void testBalanceOfSloppyServers() {
+    // We are testing slop checks, so don't "accidentally" balance due to a minCost calculation.
+    // During development, imbalance of a 100 server cluster, with one node having 10 regions
+    // and the rest having 5, is 0.0048. With minCostNeedBalance default of 0.025, test should
+    // validate slop checks without this override. We override just to ensure we will always
+    // validate slop check here, and for small clusters as well.
+    conf.setFloat("hbase.master.balancer.stochastic.minCostNeedBalance", 1.0f);
+    conf.setBoolean("hbase.master.balancer.stochastic.runMaxSteps", false);
+    conf.setLong("hbase.master.balancer.stochastic.maxSteps", 5000L);
+    loadBalancer.onConfigurationChange(conf);
+    for (int[] mockCluster : clusterStateMocksWithNoSlop) {
+      assertTrue(hasEmptyBalancerPlans(mockCluster));
+    }
+    for (int[] mockCluster : clusterStateMocksWithSlop) {
+      assertFalse(hasEmptyBalancerPlans(mockCluster));
+    }
+  }
+
+  @Test
+  public void testSloppyTablesLoadBalanceByTable() {
+    int[][] regionsPerServerPerTable = new int[][] {
+      new int[] { 8, 2, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
+        5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5 },
+      new int[] { 2, 8, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
+        5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5 }, };
+    conf.setFloat("hbase.master.balancer.stochastic.minCostNeedBalance", 1.0f);
+    conf.setBoolean("hbase.master.balancer.stochastic.runMaxSteps", false);
+    conf.setLong("hbase.master.balancer.stochastic.maxSteps", 5000L);
+    conf.setBoolean(HConstants.HBASE_MASTER_LOADBALANCE_BYTABLE, true);
+    loadBalancer.onConfigurationChange(conf);
+    assertFalse(hasEmptyBalancerPlans(regionsPerServerPerTable));
+  }
+
+  private boolean hasEmptyBalancerPlans(int[] mockCluster) {
+    Map<ServerName, List<RegionInfo>> servers = mockClusterServers(mockCluster);
+    return hasEmptyBalancerPlans(servers);
+  }
+
+  private boolean hasEmptyBalancerPlans(int[][] mockCluster) {
+    Map<ServerName, List<RegionInfo>> servers = mockClusterServers(mockCluster);
+    return hasEmptyBalancerPlans(servers);
+  }
+
+  private boolean hasEmptyBalancerPlans(Map<ServerName, List<RegionInfo>> servers) {
+    Map<TableName, Map<ServerName, List<RegionInfo>>> loadOfAllTable =
+      (Map) mockClusterServersWithTables(servers);
+    List<RegionPlan> plans = loadBalancer.balanceCluster(loadOfAllTable);
+    return plans == null || plans.isEmpty();
+  }
+
   @Test
   public void testLocalityCost() throws Exception {
     Configuration conf = HBaseConfiguration.create();
-    StochasticLoadBalancer.CostFunction costFunction = new ServerLocalityCostFunction(conf);
+    CostFunction costFunction = new ServerLocalityCostFunction(conf);
 
     for (int test = 0; test < clusterRegionLocationMocks.length; test++) {
       int[][] clusterRegionLocations = clusterRegionLocationMocks[test];
       MockCluster cluster = new MockCluster(clusterRegionLocations);
-      costFunction.init(cluster);
+      costFunction.prepare(cluster);
       double cost = costFunction.cost();
       double expected = 1 - expectedLocalities[test];
       assertEquals(expected, cost, 0.001);
@@ -203,13 +329,11 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
   @Test
   public void testMoveCostMultiplier() throws Exception {
     Configuration conf = HBaseConfiguration.create();
-    StochasticLoadBalancer.CostFunction costFunction =
-      new StochasticLoadBalancer.MoveCostFunction(conf);
-    BaseLoadBalancer.Cluster cluster = mockCluster(clusterStateMocks[0]);
-    costFunction.init(cluster);
+    CostFunction costFunction = new MoveCostFunction(conf);
+    BalancerClusterState cluster = mockCluster(clusterStateMocks[0]);
+    costFunction.prepare(cluster);
     costFunction.cost();
-    assertEquals(StochasticLoadBalancer.MoveCostFunction.DEFAULT_MOVE_COST,
-      costFunction.getMultiplier(), 0.01);
+    assertEquals(MoveCostFunction.DEFAULT_MOVE_COST, costFunction.getMultiplier(), 0.01);
 
     // In offpeak hours, the multiplier of move cost should be lower
     conf.setInt("hbase.offpeak.start.hour", 0);
@@ -219,21 +343,19 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
     long deltaFor15 = TimeZone.getDefault().getRawOffset() - 28800000;
     long timeFor15 = 1597907081000L - deltaFor15;
     EnvironmentEdgeManager.injectEdge(() -> timeFor15);
-    costFunction = new StochasticLoadBalancer.MoveCostFunction(conf);
-    costFunction.init(cluster);
+    costFunction = new MoveCostFunction(conf);
+    costFunction.prepare(cluster);
     costFunction.cost();
-    assertEquals(StochasticLoadBalancer.MoveCostFunction.DEFAULT_MOVE_COST_OFFPEAK,
-      costFunction.getMultiplier(), 0.01);
+    assertEquals(MoveCostFunction.DEFAULT_MOVE_COST_OFFPEAK, costFunction.getMultiplier(), 0.01);
   }
 
   @Test
   public void testMoveCost() throws Exception {
     Configuration conf = HBaseConfiguration.create();
-    StochasticLoadBalancer.CostFunction costFunction =
-      new StochasticLoadBalancer.MoveCostFunction(conf);
+    CostFunction costFunction = new MoveCostFunction(conf);
     for (int[] mockCluster : clusterStateMocks) {
-      BaseLoadBalancer.Cluster cluster = mockCluster(mockCluster);
-      costFunction.init(cluster);
+      BalancerClusterState cluster = mockCluster(mockCluster);
+      costFunction.prepare(cluster);
       double cost = costFunction.cost();
       assertEquals(0.0f, cost, 0.001);
 
@@ -266,42 +388,40 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
   @Test
   public void testSkewCost() {
     Configuration conf = HBaseConfiguration.create();
-    StochasticLoadBalancer.CostFunction costFunction =
-      new StochasticLoadBalancer.RegionCountSkewCostFunction(conf);
+    CostFunction costFunction = new RegionCountSkewCostFunction(conf);
     for (int[] mockCluster : clusterStateMocks) {
-      costFunction.init(mockCluster(mockCluster));
+      costFunction.prepare(mockCluster(mockCluster));
       double cost = costFunction.cost();
       assertTrue(cost >= 0);
       assertTrue(cost <= 1.01);
     }
 
-    costFunction.init(mockCluster(new int[] { 0, 0, 0, 0, 1 }));
+    costFunction.prepare(mockCluster(new int[] { 0, 0, 0, 0, 1 }));
     assertEquals(0, costFunction.cost(), 0.01);
-    costFunction.init(mockCluster(new int[] { 0, 0, 0, 1, 1 }));
+    costFunction.prepare(mockCluster(new int[] { 0, 0, 0, 1, 1 }));
     assertEquals(0, costFunction.cost(), 0.01);
-    costFunction.init(mockCluster(new int[] { 0, 0, 1, 1, 1 }));
+    costFunction.prepare(mockCluster(new int[] { 0, 0, 1, 1, 1 }));
     assertEquals(0, costFunction.cost(), 0.01);
-    costFunction.init(mockCluster(new int[] { 0, 1, 1, 1, 1 }));
+    costFunction.prepare(mockCluster(new int[] { 0, 1, 1, 1, 1 }));
     assertEquals(0, costFunction.cost(), 0.01);
-    costFunction.init(mockCluster(new int[] { 1, 1, 1, 1, 1 }));
+    costFunction.prepare(mockCluster(new int[] { 1, 1, 1, 1, 1 }));
     assertEquals(0, costFunction.cost(), 0.01);
-    costFunction.init(mockCluster(new int[] { 10000, 0, 0, 0, 0 }));
+    costFunction.prepare(mockCluster(new int[] { 10000, 0, 0, 0, 0 }));
     assertEquals(1, costFunction.cost(), 0.01);
   }
 
   @Test
   public void testCostAfterUndoAction() {
     final int runs = 10;
-    loadBalancer.setConf(conf);
     for (int[] mockCluster : clusterStateMocks) {
-      BaseLoadBalancer.Cluster cluster = mockCluster(mockCluster);
+      BalancerClusterState cluster = mockCluster(mockCluster);
       loadBalancer.initCosts(cluster);
       for (int i = 0; i != runs; ++i) {
         final double expectedCost = loadBalancer.computeCost(cluster, Double.MAX_VALUE);
-        Cluster.Action action = loadBalancer.nextAction(cluster);
+        BalanceAction action = loadBalancer.nextAction(cluster);
         cluster.doAction(action);
         loadBalancer.updateCostsAndWeightsWithAction(cluster, action);
-        Cluster.Action undoAction = action.undoAction();
+        BalanceAction undoAction = action.undoAction();
         cluster.doAction(undoAction);
         loadBalancer.updateCostsAndWeightsWithAction(cluster, undoAction);
         final double actualCost = loadBalancer.computeCost(cluster, Double.MAX_VALUE);
@@ -313,11 +433,10 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
   @Test
   public void testTableSkewCost() {
     Configuration conf = HBaseConfiguration.create();
-    StochasticLoadBalancer.CostFunction costFunction =
-      new StochasticLoadBalancer.TableSkewCostFunction(conf);
+    CostFunction costFunction = new TableSkewCostFunction(conf);
     for (int[] mockCluster : clusterStateMocks) {
-      BaseLoadBalancer.Cluster cluster = mockCluster(mockCluster);
-      costFunction.init(cluster);
+      BalancerClusterState cluster = mockCluster(mockCluster);
+      costFunction.prepare(cluster);
       double cost = costFunction.cost();
       assertTrue(cost >= 0);
       assertTrue(cost <= 1.01);
@@ -335,14 +454,12 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
     }
 
     Configuration conf = HBaseConfiguration.create();
-    StochasticLoadBalancer.ReadRequestCostFunction readCostFunction =
-      new StochasticLoadBalancer.ReadRequestCostFunction(conf);
+    ReadRequestCostFunction readCostFunction = new ReadRequestCostFunction(conf);
     double rateResult = readCostFunction.getRegionLoadCost(regionLoads);
     // read requests are treated as a rate so the average rate here is simply 1
     assertEquals(1, rateResult, 0.01);
 
-    StochasticLoadBalancer.StoreFileCostFunction storeFileCostFunction =
-      new StochasticLoadBalancer.StoreFileCostFunction(conf);
+    StoreFileCostFunction storeFileCostFunction = new StoreFileCostFunction(conf);
     double result = storeFileCostFunction.getRegionLoadCost(regionLoads);
     // storefile size cost is simply an average of it's value over time
     assertEquals(2.5, result, 0.01);
@@ -356,22 +473,14 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
       int load = i == 3 ? 1 : i;
       BalancerRegionLoad regionLoad = mock(BalancerRegionLoad.class);
       when(regionLoad.getReadRequestsCount()).thenReturn((long) load);
-      when(regionLoad.getStorefileSizeMB()).thenReturn(load);
       regionLoads.add(regionLoad);
     }
 
     Configuration conf = HBaseConfiguration.create();
-    StochasticLoadBalancer.ReadRequestCostFunction readCostFunction =
-      new StochasticLoadBalancer.ReadRequestCostFunction(conf);
+    ReadRequestCostFunction readCostFunction = new ReadRequestCostFunction(conf);
     double rateResult = readCostFunction.getRegionLoadCost(regionLoads);
-    // read requests are treated as a rate, so here is the average rate
+    // read requests are treated as a rate so the average rate here is simply 1
     assertEquals(1.67, rateResult, 0.01);
-
-    StochasticLoadBalancer.StoreFileCostFunction storeFileCostFunction =
-      new StochasticLoadBalancer.StoreFileCostFunction(conf);
-    rateResult = storeFileCostFunction.getRegionLoadCost(regionLoads);
-    // storefile size cost is simply an average of it's value over time
-    assertEquals(2.0, rateResult, 0.01);
   }
 
   @Test
@@ -406,33 +515,24 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
 
   @Test
   public void testAdditionalCostFunction() {
-    try {
-      conf.set(StochasticLoadBalancer.COST_FUNCTIONS_COST_FUNCTIONS_KEY,
-        DummyCostFunction.class.getName());
+    conf.set(StochasticLoadBalancer.COST_FUNCTIONS_COST_FUNCTIONS_KEY,
+      DummyCostFunction.class.getName());
 
-      loadBalancer.setConf(conf);
-      assertTrue(Arrays.asList(loadBalancer.getCostFunctionNames())
-        .contains(DummyCostFunction.class.getSimpleName()));
-    } finally {
-      conf.unset(StochasticLoadBalancer.COST_FUNCTIONS_COST_FUNCTIONS_KEY);
-      loadBalancer.setConf(conf);
-    }
+    loadBalancer.onConfigurationChange(conf);
+    assertTrue(Arrays.asList(loadBalancer.getCostFunctionNames())
+      .contains(DummyCostFunction.class.getSimpleName()));
   }
 
   @Test
   public void testDefaultCostFunctionList() {
-    List<String> expected =
-      Arrays.asList(StochasticLoadBalancer.RegionCountSkewCostFunction.class.getSimpleName(),
-        StochasticLoadBalancer.PrimaryRegionCountSkewCostFunction.class.getSimpleName(),
-        StochasticLoadBalancer.MoveCostFunction.class.getSimpleName(),
-        StochasticLoadBalancer.RackLocalityCostFunction.class.getSimpleName(),
-        StochasticLoadBalancer.TableSkewCostFunction.class.getSimpleName(),
-        StochasticLoadBalancer.RegionReplicaHostCostFunction.class.getSimpleName(),
-        StochasticLoadBalancer.RegionReplicaRackCostFunction.class.getSimpleName(),
-        StochasticLoadBalancer.ReadRequestCostFunction.class.getSimpleName(),
-        StochasticLoadBalancer.WriteRequestCostFunction.class.getSimpleName(),
-        StochasticLoadBalancer.MemStoreSizeCostFunction.class.getSimpleName(),
-        StochasticLoadBalancer.StoreFileCostFunction.class.getSimpleName());
+    List<String> expected = Arrays.asList(RegionCountSkewCostFunction.class.getSimpleName(),
+      PrimaryRegionCountSkewCostFunction.class.getSimpleName(),
+      MoveCostFunction.class.getSimpleName(), RackLocalityCostFunction.class.getSimpleName(),
+      TableSkewCostFunction.class.getSimpleName(),
+      RegionReplicaHostCostFunction.class.getSimpleName(),
+      RegionReplicaRackCostFunction.class.getSimpleName(),
+      ReadRequestCostFunction.class.getSimpleName(), WriteRequestCostFunction.class.getSimpleName(),
+      MemStoreSizeCostFunction.class.getSimpleName(), StoreFileCostFunction.class.getSimpleName());
 
     List<String> actual = Arrays.asList(loadBalancer.getCostFunctionNames());
     assertTrue("ExpectedCostFunctions: " + expected + " ActualCostFunctions: " + actual,
@@ -440,12 +540,12 @@ public class TestStochasticLoadBalancer extends BalancerTestBase {
   }
 
   private boolean needsBalanceIdleRegion(int[] cluster) {
-    return (Arrays.stream(cluster).anyMatch(x -> x > 1))
-      && (Arrays.stream(cluster).anyMatch(x -> x < 1));
+    return Arrays.stream(cluster).anyMatch(x -> x > 1)
+      && Arrays.stream(cluster).anyMatch(x -> x < 1);
   }
 
   // This mock allows us to test the LocalityCostFunction
-  private class MockCluster extends BaseLoadBalancer.Cluster {
+  private class MockCluster extends BalancerClusterState {
 
     private int[][] localities = null; // [region][server] = percent of blocks
 
