@@ -26,7 +26,6 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 import java.util.TreeMap;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
@@ -36,7 +35,6 @@ import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.RegionReplicaUtil;
 import org.apache.hadoop.hbase.master.RackManager;
-import org.apache.hadoop.hbase.master.balancer.BaseLoadBalancer.Cluster;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.testclassification.MasterTests;
 import org.junit.ClassRule;
@@ -53,11 +51,10 @@ public class TestStochasticLoadBalancerRegionReplica extends BalancerTestBase {
   @Test
   public void testReplicaCost() {
     Configuration conf = HBaseConfiguration.create();
-    StochasticLoadBalancer.CostFunction costFunction =
-      new StochasticLoadBalancer.RegionReplicaHostCostFunction(conf);
+    CostFunction costFunction = new RegionReplicaHostCostFunction(conf);
     for (int[] mockCluster : clusterStateMocks) {
-      BaseLoadBalancer.Cluster cluster = mockCluster(mockCluster);
-      costFunction.init(cluster);
+      BalancerClusterState cluster = mockCluster(mockCluster);
+      costFunction.prepare(cluster);
       double cost = costFunction.cost();
       assertTrue(cost >= 0);
       assertTrue(cost <= 1.01);
@@ -67,16 +64,15 @@ public class TestStochasticLoadBalancerRegionReplica extends BalancerTestBase {
   @Test
   public void testReplicaCostForReplicas() {
     Configuration conf = HBaseConfiguration.create();
-    StochasticLoadBalancer.CostFunction costFunction =
-      new StochasticLoadBalancer.RegionReplicaHostCostFunction(conf);
+    CostFunction costFunction = new RegionReplicaHostCostFunction(conf);
 
     int[] servers = new int[] { 3, 3, 3, 3, 3 };
     TreeMap<ServerName, List<RegionInfo>> clusterState = mockClusterServers(servers);
 
-    BaseLoadBalancer.Cluster cluster;
+    BalancerClusterState cluster;
 
-    cluster = new BaseLoadBalancer.Cluster(clusterState, null, null, null);
-    costFunction.init(cluster);
+    cluster = new BalancerClusterState(clusterState, null, null, null);
+    costFunction.prepare(cluster);
     double costWithoutReplicas = costFunction.cost();
     assertEquals(0, costWithoutReplicas, 0);
 
@@ -85,8 +81,8 @@ public class TestStochasticLoadBalancerRegionReplica extends BalancerTestBase {
       RegionReplicaUtil.getRegionInfoForReplica(clusterState.firstEntry().getValue().get(0), 1);
     clusterState.lastEntry().getValue().add(replica1);
 
-    cluster = new BaseLoadBalancer.Cluster(clusterState, null, null, null);
-    costFunction.init(cluster);
+    cluster = new BalancerClusterState(clusterState, null, null, null);
+    costFunction.prepare(cluster);
     double costWith1ReplicaDifferentServer = costFunction.cost();
 
     assertEquals(0, costWith1ReplicaDifferentServer, 0);
@@ -95,8 +91,8 @@ public class TestStochasticLoadBalancerRegionReplica extends BalancerTestBase {
     RegionInfo replica2 = RegionReplicaUtil.getRegionInfoForReplica(replica1, 2);
     clusterState.lastEntry().getValue().add(replica2);
 
-    cluster = new BaseLoadBalancer.Cluster(clusterState, null, null, null);
-    costFunction.init(cluster);
+    cluster = new BalancerClusterState(clusterState, null, null, null);
+    costFunction.prepare(cluster);
     double costWith1ReplicaSameServer = costFunction.cost();
 
     assertTrue(costWith1ReplicaDifferentServer < costWith1ReplicaSameServer);
@@ -104,8 +100,8 @@ public class TestStochasticLoadBalancerRegionReplica extends BalancerTestBase {
     // test with replication = 4 for following:
 
     RegionInfo replica3;
-    Iterator<Entry<ServerName, List<RegionInfo>>> it;
-    Entry<ServerName, List<RegionInfo>> entry;
+    Iterator<Map.Entry<ServerName, List<RegionInfo>>> it;
+    Map.Entry<ServerName, List<RegionInfo>> entry;
 
     clusterState = mockClusterServers(servers);
     it = clusterState.entrySet().iterator();
@@ -118,8 +114,8 @@ public class TestStochasticLoadBalancerRegionReplica extends BalancerTestBase {
     entry.getValue().add(replica2);
     it.next().getValue().add(replica3); // 2nd server
 
-    cluster = new BaseLoadBalancer.Cluster(clusterState, null, null, null);
-    costFunction.init(cluster);
+    cluster = new BalancerClusterState(clusterState, null, null, null);
+    costFunction.prepare(cluster);
     double costWith3ReplicasSameServer = costFunction.cost();
 
     clusterState = mockClusterServers(servers);
@@ -132,8 +128,8 @@ public class TestStochasticLoadBalancerRegionReplica extends BalancerTestBase {
     clusterState.lastEntry().getValue().add(replica2);
     clusterState.lastEntry().getValue().add(replica3);
 
-    cluster = new BaseLoadBalancer.Cluster(clusterState, null, null, null);
-    costFunction.init(cluster);
+    cluster = new BalancerClusterState(clusterState, null, null, null);
+    costFunction.prepare(cluster);
     double costWith2ReplicasOnTwoServers = costFunction.cost();
 
     assertTrue(costWith2ReplicasOnTwoServers < costWith3ReplicasSameServer);
@@ -153,7 +149,7 @@ public class TestStochasticLoadBalancerRegionReplica extends BalancerTestBase {
     regions = randomRegions(1);
     map.put(s2, regions);
     assertTrue(loadBalancer.needsBalance(HConstants.ENSEMBLE_TABLE_NAME,
-      new Cluster(map, null, null, null)));
+      new BalancerClusterState(map, null, null, null)));
     // check for the case where there are two hosts on the same rack and there are two racks
     // and both the replicas are on the same rack
     map.clear();
@@ -165,7 +161,7 @@ public class TestStochasticLoadBalancerRegionReplica extends BalancerTestBase {
     // add another server so that the cluster has some host on another rack
     map.put(ServerName.valueOf("host2", 1000, 11111), randomRegions(1));
     assertFalse(loadBalancer.needsBalance(HConstants.ENSEMBLE_TABLE_NAME,
-      new Cluster(map, null, null, new ForTestRackManagerOne())));
+      new BalancerClusterState(map, null, null, new ForTestRackManagerOne())));
   }
 
   @Test
@@ -175,7 +171,8 @@ public class TestStochasticLoadBalancerRegionReplica extends BalancerTestBase {
     int replication = 3; // 3 replicas per region
     int numRegionsPerServer = 80; // all regions are mostly balanced
     int numTables = 10;
-    testWithCluster(numNodes, numRegions, numRegionsPerServer, replication, numTables, true, true);
+    testWithClusterWithIteration(numNodes, numRegions, numRegionsPerServer, replication, numTables,
+      true, true);
   }
 
   private static class ForTestRackManagerOne extends RackManager {
