@@ -44,11 +44,15 @@ import org.junit.After;
 import org.junit.AfterClass;
 import org.junit.BeforeClass;
 import org.junit.ClassRule;
+import org.junit.Ignore;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+// This tests breaks monotonic WAL numbering after HBASE-20746 because of how it
+// manipulates the EnvironmentEdge.
+@Ignore("See HBASE-27243")
 @Category({ RegionServerTests.class, MediumTests.class })
 public class TestQuotaThrottle {
 
