@@ -33,6 +33,7 @@ import org.apache.hadoop.hbase.HBaseClassTestRule;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.ClientServiceCallable;
+import org.apache.hadoop.hbase.client.ClusterConnection;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.ResultScanner;
@@ -98,7 +99,9 @@ public class TestSpaceQuotaOnBulkLoad {
 
     // The table is now in violation. Try to do a bulk load
     ClientServiceCallable<Void> callable = helper.generateFileToLoad(tableName, 1, 50);
-    RpcRetryingCallerFactory factory = new RpcRetryingCallerFactory(TEST_UTIL.getConfiguration());
+    ClusterConnection conn = (ClusterConnection) TEST_UTIL.getConnection();
+    RpcRetryingCallerFactory factory =
+      new RpcRetryingCallerFactory(TEST_UTIL.getConfiguration(), conn.getConnectionConfiguration());
     RpcRetryingCaller<Void> caller = factory.<Void> newCaller();
     try {
       caller.callWithRetries(callable, Integer.MAX_VALUE);
@@ -157,7 +160,9 @@ public class TestSpaceQuotaOnBulkLoad {
       LOG.debug(file.getPath() + " -> " + file.getLen() + "B");
     }
 
-    RpcRetryingCallerFactory factory = new RpcRetryingCallerFactory(TEST_UTIL.getConfiguration());
+    ClusterConnection conn = (ClusterConnection) TEST_UTIL.getConnection();
+    RpcRetryingCallerFactory factory =
+      new RpcRetryingCallerFactory(TEST_UTIL.getConfiguration(), conn.getConnectionConfiguration());
     RpcRetryingCaller<Void> caller = factory.<Void> newCaller();
     try {
       caller.callWithRetries(callable, Integer.MAX_VALUE);
