@@ -712,8 +712,8 @@ public class TestAtomicOperation {
     }
 
     @Override
-    public RowLock getRowLockInternal(final byte[] row, boolean readLock, final RowLock prevRowlock)
-      throws IOException {
+    protected RowLock getRowLockInternal(final byte[] row, boolean readLock,
+      final RowLock prevRowlock) throws IOException {
       if (testStep == TestStep.CHECKANDPUT_STARTED) {
         latch.countDown();
       }
