@@ -54,6 +54,7 @@ import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.exceptions.UnexpectedStateException;
+import org.apache.hadoop.hbase.monitoring.ThreadLocalServerSideScanMetrics;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.testclassification.RegionServerTests;
 import org.apache.hadoop.hbase.util.Bytes;
@@ -62,6 +63,7 @@ import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.FSTableDescriptors;
 import org.apache.hadoop.hbase.wal.WALFactory;
 import org.junit.AfterClass;
+import org.junit.Assert;
 import org.junit.Before;
 import org.junit.ClassRule;
 import org.junit.Rule;
@@ -160,7 +162,7 @@ public class TestDefaultMemStore {
   }
 
   /**
-   * Test memstore snapshot happening while scanning. n
+   * Test memstore snapshot happening while scanning.
    */
   @Test
   public void testScanAcrossSnapshot() throws IOException {
@@ -236,7 +238,7 @@ public class TestDefaultMemStore {
   }
 
   /**
-   * A simple test which verifies the 3 possible states when scanning across snapshot. nn
+   * A simple test which verifies the 3 possible states when scanning across snapshot.
    */
   @Test
   public void testScanAcrossSnapshot2() throws IOException, CloneNotSupportedException {
@@ -354,6 +356,48 @@ public class TestDefaultMemStore {
     assertScannerResults(s, new KeyValue[] { kv1, kv2 });
   }
 
+  private long getBytesReadFromMemstore() throws IOException {
+    final byte[] f = Bytes.toBytes("family");
+    final byte[] q1 = Bytes.toBytes("q1");
+    final byte[] v = Bytes.toBytes("value");
+    int numKvs = 10;
+
+    MultiVersionConcurrencyControl.WriteEntry w = mvcc.begin();
+
+    KeyValue kv;
+    KeyValue[] kvs = new KeyValue[numKvs];
+    long totalCellSize = 0;
+    for (int i = 0; i < numKvs; i++) {
+      byte[] row = Bytes.toBytes(i);
+      kv = new KeyValue(row, f, q1, v);
+      kv.setSequenceId(w.getWriteNumber());
+      memstore.add(kv, null);
+      kvs[i] = kv;
+      totalCellSize += Segment.getCellLength(kv);
+    }
+    mvcc.completeAndWait(w);
+
+    ThreadLocalServerSideScanMetrics.getBytesReadFromMemstoreAndReset();
+    KeyValueScanner s = this.memstore.getScanners(mvcc.getReadPoint()).get(0);
+    assertScannerResults(s, kvs);
+    return totalCellSize;
+  }
+
+  @Test
+  public void testBytesReadFromMemstore() throws IOException {
+    ThreadLocalServerSideScanMetrics.setScanMetricsEnabled(true);
+    long totalCellSize = getBytesReadFromMemstore();
+    Assert.assertEquals(totalCellSize,
+      ThreadLocalServerSideScanMetrics.getBytesReadFromMemstoreAndReset());
+  }
+
+  @Test
+  public void testBytesReadFromMemstoreWithScanMetricsDisabled() throws IOException {
+    ThreadLocalServerSideScanMetrics.setScanMetricsEnabled(false);
+    getBytesReadFromMemstore();
+    Assert.assertEquals(0, ThreadLocalServerSideScanMetrics.getBytesReadFromMemstoreAndReset());
+  }
+
   /**
    * Regression test for HBASE-2616, HBASE-2670. When we insert a higher-memstoreTS version of a
    * cell but with the same timestamp, we still need to provide consistent reads for the same
@@ -528,7 +572,7 @@ public class TestDefaultMemStore {
   }
 
   /**
-   * Test memstore snapshots n
+   * Test memstore snapshots
    */
   @Test
   public void testSnapshotting() throws IOException {
@@ -566,7 +610,7 @@ public class TestDefaultMemStore {
   //////////////////////////////////////////////////////////////////////////////
 
   /**
-   * Test getNextRow from memstore n
+   * Test getNextRow from memstore
    */
   @Test
   public void testGetNextRow() throws Exception {
@@ -816,7 +860,7 @@ public class TestDefaultMemStore {
 
   /**
    * Add keyvalues with a fixed memstoreTs, and checks that memstore size is decreased as older
-   * keyvalues are deleted from the memstore. n
+   * keyvalues are deleted from the memstore.
    */
   @Test
   public void testUpsertMemstoreSize() throws Exception {
@@ -860,7 +904,7 @@ public class TestDefaultMemStore {
 
   /**
    * Tests that the timeOfOldestEdit is updated correctly for the various edit operations in
-   * memstore. n
+   * memstore.
    */
   @Test
   public void testUpdateToTimeOfOldestEdit() throws Exception {
@@ -901,7 +945,7 @@ public class TestDefaultMemStore {
   /**
    * Tests the HRegion.shouldFlush method - adds an edit in the memstore and checks that shouldFlush
    * returns true, and another where it disables the periodic flush functionality and tests whether
-   * shouldFlush returns false. n
+   * shouldFlush returns false.
    */
   @Test
   public void testShouldFlush() throws Exception {
@@ -1004,7 +1048,7 @@ public class TestDefaultMemStore {
   /**
    * Adds {@link #ROW_COUNT} rows and {@link #QUALIFIER_COUNT}
    * @param hmc Instance to add rows to.
-   * @return How many rows we added. n
+   * @return How many rows we added.
    */
   protected int addRows(final AbstractMemStore hmc) {
     return addRows(hmc, HConstants.LATEST_TIMESTAMP);
@@ -1013,7 +1057,7 @@ public class TestDefaultMemStore {
   /**
    * Adds {@link #ROW_COUNT} rows and {@link #QUALIFIER_COUNT}
    * @param hmc Instance to add rows to.
-   * @return How many rows we added. n
+   * @return How many rows we added.
    */
   protected int addRows(final MemStore hmc, final long ts) {
     for (int i = 0; i < ROW_COUNT; i++) {
