@@ -29,6 +29,7 @@ import java.util.Map;
 import java.util.Random;
 import java.util.Set;
 import java.util.TreeSet;
+import java.util.concurrent.ThreadLocalRandom;
 import java.util.stream.Collectors;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.ChoreService;
@@ -56,6 +57,7 @@ import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.hadoop.hbase.util.PairOfSameType;
 import org.apache.hadoop.hbase.util.StoppableImplementation;
@@ -132,8 +134,8 @@ public class TestEndToEndSplitTransaction {
             StoreFileReader reader = ((HStoreFile) sf).getReader();
             reader.getStoreFileScanner(true, false, false, 0, 0, false);
             scanner.put(r.getRegionInfo().getEncodedName(), reader);
-            LOG.info("Got reference to file = " + sf.getPath() + ",for region = " +
-              r.getRegionInfo().getEncodedName());
+            LOG.info("Got reference to file = " + sf.getPath() + ",for region = "
+              + r.getRegionInfo().getEncodedName());
           }));
       assertTrue("Regions did not split properly", regions.size() > 1);
       assertTrue("Could not get reference any of the store file", scanner.size() > 1);
@@ -221,7 +223,7 @@ public class TestEndToEndSplitTransaction {
     @Override
     public void run() {
       try {
-        Random random = new Random();
+        Random random = ThreadLocalRandom.current();
         for (int i = 0; i < 5; i++) {
           List<RegionInfo> regions = MetaTableAccessor.getTableRegions(connection, tableName, true);
           if (regions.isEmpty()) {
@@ -352,8 +354,8 @@ public class TestEndToEndSplitTransaction {
       // ensure that we do not have any gaps
       for (int i = 0; i < startKeys.length; i++) {
         assertArrayEquals(
-          "Hole in hbase:meta is detected. prevEndKey=" + Bytes.toStringBinary(prevEndKey) +
-            " ,regionStartKey=" + Bytes.toStringBinary(startKeys[i]),
+          "Hole in hbase:meta is detected. prevEndKey=" + Bytes.toStringBinary(prevEndKey)
+            + " ,regionStartKey=" + Bytes.toStringBinary(startKeys[i]),
           prevEndKey, startKeys[i]);
         prevEndKey = endKeys[i];
       }
@@ -379,7 +381,7 @@ public class TestEndToEndSplitTransaction {
   /* some utility methods for split tests */
 
   public static void flushAndBlockUntilDone(Admin admin, HRegionServer rs, byte[] regionName)
-      throws IOException, InterruptedException {
+    throws IOException, InterruptedException {
     log("flushing region: " + Bytes.toStringBinary(regionName));
     admin.flushRegion(regionName);
     log("blocking until flush is complete: " + Bytes.toStringBinary(regionName));
@@ -390,14 +392,15 @@ public class TestEndToEndSplitTransaction {
   }
 
   public static void compactAndBlockUntilDone(Admin admin, HRegionServer rs, byte[] regionName)
-      throws IOException, InterruptedException {
+    throws IOException, InterruptedException {
     log("Compacting region: " + Bytes.toStringBinary(regionName));
     // Wait till its online before we do compact else it comes back with NoServerForRegionException
     try {
       TEST_UTIL.waitFor(10000, new Waiter.Predicate<Exception>() {
-        @Override public boolean evaluate() throws Exception {
-          return rs.getServerName().equals(MetaTableAccessor.
-            getRegionLocation(admin.getConnection(), regionName).getServerName());
+        @Override
+        public boolean evaluate() throws Exception {
+          return rs.getServerName().equals(
+            MetaTableAccessor.getRegionLocation(admin.getConnection(), regionName).getServerName());
         }
       });
     } catch (Exception e) {
@@ -421,15 +424,15 @@ public class TestEndToEndSplitTransaction {
    * Blocks until the region split is complete in hbase:meta and region server opens the daughters
    */
   public static void blockUntilRegionSplit(Configuration conf, long timeout,
-      final byte[] regionName, boolean waitForDaughters) throws IOException, InterruptedException {
-    long start = System.currentTimeMillis();
+    final byte[] regionName, boolean waitForDaughters) throws IOException, InterruptedException {
+    long start = EnvironmentEdgeManager.currentTime();
     log("blocking until region is split:" + Bytes.toStringBinary(regionName));
     RegionInfo daughterA = null, daughterB = null;
     try (Connection conn = ConnectionFactory.createConnection(conf);
-        Table metaTable = conn.getTable(TableName.META_TABLE_NAME)) {
+      Table metaTable = conn.getTable(TableName.META_TABLE_NAME)) {
       Result result = null;
       RegionInfo region = null;
-      while ((System.currentTimeMillis() - start) < timeout) {
+      while ((EnvironmentEdgeManager.currentTime() - start) < timeout) {
         result = metaTable.get(new Get(regionName));
         if (result == null) {
           break;
@@ -446,23 +449,23 @@ public class TestEndToEndSplitTransaction {
         Threads.sleep(100);
       }
       if (daughterA == null || daughterB == null) {
-        throw new IOException("Failed to get daughters, daughterA=" + daughterA + ", daughterB=" +
-          daughterB + ", timeout=" + timeout + ", result=" + result + ", regionName=" +
-          Bytes.toString(regionName) + ", region=" + region);
+        throw new IOException("Failed to get daughters, daughterA=" + daughterA + ", daughterB="
+          + daughterB + ", timeout=" + timeout + ", result=" + result + ", regionName="
+          + Bytes.toString(regionName) + ", region=" + region);
       }
 
       // if we are here, this means the region split is complete or timed out
       if (waitForDaughters) {
-        long rem = timeout - (System.currentTimeMillis() - start);
+        long rem = timeout - (EnvironmentEdgeManager.currentTime() - start);
         blockUntilRegionIsInMeta(conn, rem, daughterA);
 
-        rem = timeout - (System.currentTimeMillis() - start);
+        rem = timeout - (EnvironmentEdgeManager.currentTime() - start);
         blockUntilRegionIsInMeta(conn, rem, daughterB);
 
-        rem = timeout - (System.currentTimeMillis() - start);
+        rem = timeout - (EnvironmentEdgeManager.currentTime() - start);
         blockUntilRegionIsOpened(conf, rem, daughterA);
 
-        rem = timeout - (System.currentTimeMillis() - start);
+        rem = timeout - (EnvironmentEdgeManager.currentTime() - start);
         blockUntilRegionIsOpened(conf, rem, daughterB);
 
         // Compacting the new region to make sure references can be cleaned up
@@ -478,7 +481,7 @@ public class TestEndToEndSplitTransaction {
   }
 
   public static void removeCompactedFiles(Connection conn, long timeout, RegionInfo hri)
-      throws IOException, InterruptedException {
+    throws IOException, InterruptedException {
     log("remove compacted files for : " + hri.getRegionNameAsString());
     List<HRegion> regions = TEST_UTIL.getHBaseCluster().getRegions(hri.getTable());
     regions.stream().forEach(r -> {
@@ -491,10 +494,10 @@ public class TestEndToEndSplitTransaction {
   }
 
   public static void blockUntilRegionIsInMeta(Connection conn, long timeout, RegionInfo hri)
-      throws IOException, InterruptedException {
+    throws IOException, InterruptedException {
     log("blocking until region is in META: " + hri.getRegionNameAsString());
-    long start = System.currentTimeMillis();
-    while (System.currentTimeMillis() - start < timeout) {
+    long start = EnvironmentEdgeManager.currentTime();
+    while (EnvironmentEdgeManager.currentTime() - start < timeout) {
       HRegionLocation loc = MetaTableAccessor.getRegionLocation(conn, hri);
       if (loc != null && !loc.getRegion().isOffline()) {
         log("found region in META: " + hri.getRegionNameAsString());
@@ -505,18 +508,18 @@ public class TestEndToEndSplitTransaction {
   }
 
   public static void blockUntilRegionIsOpened(Configuration conf, long timeout, RegionInfo hri)
-      throws IOException, InterruptedException {
+    throws IOException, InterruptedException {
     log("blocking until region is opened for reading:" + hri.getRegionNameAsString());
-    long start = System.currentTimeMillis();
+    long start = EnvironmentEdgeManager.currentTime();
     try (Connection conn = ConnectionFactory.createConnection(conf);
-        Table table = conn.getTable(hri.getTable())) {
+      Table table = conn.getTable(hri.getTable())) {
       byte[] row = hri.getStartKey();
       // Check for null/empty row. If we find one, use a key that is likely to be in first region.
       if (row == null || row.length <= 0) {
         row = new byte[] { '0' };
       }
       Get get = new Get(row);
-      while (System.currentTimeMillis() - start < timeout) {
+      while (EnvironmentEdgeManager.currentTime() - start < timeout) {
         try {
           table.get(get);
           break;
