@@ -312,7 +312,7 @@ public class TestMemStoreChunkPool {
       assertEquals(initialCount, newCreator.getPoolSize());
       assertEquals(0, newCreator.getPoolSize(ChunkType.INDEX_CHUNK));
 
-      Chunk dataChunk = newCreator.getChunk(CompactingMemStore.IndexType.CHUNK_MAP);
+      Chunk dataChunk = newCreator.getChunk();
       assertTrue(dataChunk.isDataChunk());
       assertTrue(dataChunk.isFromPool());
       assertEquals(initialCount - 1, newCreator.getPoolSize());
@@ -323,7 +323,7 @@ public class TestMemStoreChunkPool {
 
       // We set ChunkCreator.indexChunkSize to 0, but we want to get a IndexChunk
       try {
-        newCreator.getChunk(CompactingMemStore.IndexType.CHUNK_MAP, ChunkType.INDEX_CHUNK);
+        newCreator.getChunk(ChunkType.INDEX_CHUNK);
         fail();
       } catch (IllegalArgumentException e) {
       }
@@ -350,7 +350,7 @@ public class TestMemStoreChunkPool {
       assertEquals(0, newCreator.getPoolSize());
       assertEquals(0, newCreator.getPoolSize(ChunkType.INDEX_CHUNK));
 
-      dataChunk = newCreator.getChunk(CompactingMemStore.IndexType.CHUNK_MAP);
+      dataChunk = newCreator.getChunk();
       assertTrue(dataChunk.isDataChunk());
       assertTrue(!dataChunk.isFromPool());
       assertEquals(0, newCreator.getPoolSize());
@@ -358,7 +358,7 @@ public class TestMemStoreChunkPool {
 
       try {
         // We set ChunkCreator.indexChunkSize to 0, but we want to get a IndexChunk
-        newCreator.getChunk(CompactingMemStore.IndexType.CHUNK_MAP, ChunkType.INDEX_CHUNK);
+        newCreator.getChunk(ChunkType.INDEX_CHUNK);
         fail();
       } catch (IllegalArgumentException e) {
       }
@@ -387,14 +387,13 @@ public class TestMemStoreChunkPool {
       assertEquals(0, newCreator.getPoolSize());
       assertEquals(initialCount, newCreator.getPoolSize(ChunkType.INDEX_CHUNK));
 
-      dataChunk = newCreator.getChunk(CompactingMemStore.IndexType.CHUNK_MAP);
+      dataChunk = newCreator.getChunk();
       assertTrue(dataChunk.isDataChunk());
       assertTrue(!dataChunk.isFromPool());
       assertEquals(0, newCreator.getPoolSize());
       assertEquals(initialCount, newCreator.getPoolSize(ChunkType.INDEX_CHUNK));
 
-      Chunk indexChunk =
-        newCreator.getChunk(CompactingMemStore.IndexType.CHUNK_MAP, ChunkType.INDEX_CHUNK);
+      Chunk indexChunk = newCreator.getChunk(ChunkType.INDEX_CHUNK);
       assertEquals(0, newCreator.getPoolSize());
       assertEquals(initialCount - 1, newCreator.getPoolSize(ChunkType.INDEX_CHUNK));
       assertTrue(indexChunk.isIndexChunk());
@@ -415,11 +414,10 @@ public class TestMemStoreChunkPool {
     // Test both dataChunksPool and indexChunksPool are not null
     assertTrue(ChunkCreator.getInstance().getDataChunksPool() != null);
     assertTrue(ChunkCreator.getInstance().getIndexChunksPool() != null);
-    Chunk dataChunk = ChunkCreator.getInstance().getChunk(CompactingMemStore.IndexType.CHUNK_MAP);
+    Chunk dataChunk = ChunkCreator.getInstance().getChunk();
     assertTrue(dataChunk.isDataChunk());
     assertTrue(dataChunk.isFromPool());
-    Chunk indexChunk = ChunkCreator.getInstance().getChunk(CompactingMemStore.IndexType.CHUNK_MAP,
-      ChunkType.INDEX_CHUNK);
+    Chunk indexChunk = ChunkCreator.getInstance().getChunk(ChunkType.INDEX_CHUNK);
     assertTrue(indexChunk.isIndexChunk());
     assertTrue(indexChunk.isFromPool());
     Chunk jumboChunk =
