@@ -224,7 +224,7 @@ public class TestRegionMergeTransactionOnCluster {
       RegionInfo mergedRegionInfo = tableRegions.get(0).getFirst();
       TableDescriptor tableDescriptor = MASTER.getTableDescriptors().get(tableName);
       Result mergedRegionResult =
-        MetaTableAccessor.getRegionResult(MASTER.getConnection(), mergedRegionInfo.getRegionName());
+        MetaTableAccessor.getRegionResult(MASTER.getConnection(), mergedRegionInfo);
 
       // contains merge reference in META
       assertTrue(MetaTableAccessor.hasMergeRegions(mergedRegionResult.rawCells()));
@@ -299,8 +299,8 @@ public class TestRegionMergeTransactionOnCluster {
 
       // Wait around a bit to give stuff a chance to complete.
       while (true) {
-        mergedRegionResult = MetaTableAccessor.getRegionResult(TEST_UTIL.getConnection(),
-          mergedRegionInfo.getRegionName());
+        mergedRegionResult =
+          MetaTableAccessor.getRegionResult(TEST_UTIL.getConnection(), mergedRegionInfo);
         if (MetaTableAccessor.hasMergeRegions(mergedRegionResult.rawCells())) {
           LOG.info("Waiting on cleanup of merge columns {}",
             Arrays.asList(mergedRegionResult.rawCells()).stream().map(c -> c.toString())
