@@ -24,6 +24,7 @@ import static org.junit.Assert.assertTrue;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Optional;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.CompatibilityFactory;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
@@ -53,10 +54,15 @@ import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.master.LoadBalancer;
+import org.apache.hadoop.hbase.regionserver.compactions.CompactionContext;
+import org.apache.hadoop.hbase.regionserver.compactions.CompactionLifeCycleTracker;
+import org.apache.hadoop.hbase.regionserver.throttle.NoLimitThroughputController;
+import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.test.MetricsAssertHelper;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.testclassification.RegionServerTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.Threads;
 import org.junit.After;
 import org.junit.AfterClass;
@@ -156,13 +162,13 @@ public class TestRegionServerMetrics {
   }
 
   public void waitTableDeleted(TableName name, long timeoutInMillis) throws Exception {
-    long start = System.currentTimeMillis();
+    long start = EnvironmentEdgeManager.currentTime();
     while (true) {
       HTableDescriptor[] tables = admin.listTables();
       for (HTableDescriptor htd : tables) {
         if (htd.getNameAsString() == name.getNameAsString()) return;
       }
-      if (System.currentTimeMillis() - start > timeoutInMillis) return;
+      if (EnvironmentEdgeManager.currentTime() - start > timeoutInMillis) return;
       Thread.sleep(1000);
     }
   }
@@ -506,7 +512,19 @@ public class TestRegionServerMetrics {
       setMobThreshold(region, cf, 100);
       // metrics are reset by the region initialization
       region.initialize();
-      region.compact(true);
+      // This is how we MOB compact region
+      List<HStore> stores = region.getStores();
+      for (HStore store : stores) {
+        // Force major compaction
+        store.triggerMajorCompaction();
+        Optional<CompactionContext> context = store.requestCompaction(HStore.PRIORITY_USER,
+          CompactionLifeCycleTracker.DUMMY, User.getCurrent());
+        if (!context.isPresent()) {
+          continue;
+        }
+        region.compact(context.get(), store, NoLimitThroughputController.INSTANCE,
+          User.getCurrent());
+      }
       metricsRegionServer.getRegionServerWrapper().forceRecompute();
       assertCounter("cellsCountCompactedFromMob", numHfiles);
       assertCounter("cellsCountCompactedToMob", 0);
