@@ -21,8 +21,8 @@ import static org.apache.hadoop.hbase.regionserver.StripeStoreFileManager.OPEN_K
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -95,15 +95,15 @@ public class TestStripeStoreFileManager {
     MockHStoreFile sf = createFile();
     manager.insertNewFiles(al(sf));
     assertEquals(1, manager.getStorefileCount());
-    Collection<HStoreFile> filesForGet = manager.getFilesForScan(KEY_A, true, KEY_A, true);
+    Collection<HStoreFile> filesForGet = manager.getFilesForScan(KEY_A, true, KEY_A, true, false);
     assertEquals(1, filesForGet.size());
     assertTrue(filesForGet.contains(sf));
 
     // Add some stripes and make sure we get this file for every stripe.
     manager.addCompactionResults(al(),
       al(createFile(OPEN_KEY, KEY_B), createFile(KEY_B, OPEN_KEY)));
-    assertTrue(manager.getFilesForScan(KEY_A, true, KEY_A, true).contains(sf));
-    assertTrue(manager.getFilesForScan(KEY_C, true, KEY_C, true).contains(sf));
+    assertTrue(manager.getFilesForScan(KEY_A, true, KEY_A, true, false).contains(sf));
+    assertTrue(manager.getFilesForScan(KEY_C, true, KEY_C, true, false).contains(sf));
   }
 
   @Test
@@ -117,7 +117,7 @@ public class TestStripeStoreFileManager {
     Collection<HStoreFile> allFiles = manager.clearFiles();
     assertEquals(4, allFiles.size());
     assertEquals(0, manager.getStorefileCount());
-    assertEquals(0, manager.getStorefiles().size());
+    assertEquals(0, manager.getStoreFiles().size());
   }
 
   private static ArrayList<HStoreFile> dumpIterator(Iterator<HStoreFile> iter) {
@@ -541,13 +541,9 @@ public class TestStripeStoreFileManager {
 
   private void verifyInvalidCompactionScenario(StripeStoreFileManager manager,
     ArrayList<HStoreFile> filesToCompact, ArrayList<HStoreFile> filesToInsert) throws Exception {
-    Collection<HStoreFile> allFiles = manager.getStorefiles();
-    try {
-      manager.addCompactionResults(filesToCompact, filesToInsert);
-      fail("Should have thrown");
-    } catch (IOException ex) {
-      // Ignore it.
-    }
+    Collection<HStoreFile> allFiles = manager.getStoreFiles();
+    assertThrows(IllegalStateException.class,
+      () -> manager.addCompactionResults(filesToCompact, filesToInsert));
     verifyAllFiles(manager, allFiles); // must have the same files.
   }
 
@@ -560,7 +556,7 @@ public class TestStripeStoreFileManager {
     Collection<HStoreFile> results) throws Exception {
     start = start != null ? start : HConstants.EMPTY_START_ROW;
     end = end != null ? end : HConstants.EMPTY_END_ROW;
-    Collection<HStoreFile> sfs = manager.getFilesForScan(start, true, end, false);
+    Collection<HStoreFile> sfs = manager.getFilesForScan(start, true, end, false, false);
     assertEquals(results.size(), sfs.size());
     for (HStoreFile result : results) {
       assertTrue(sfs.contains(result));
