@@ -17,26 +17,35 @@
  */
 package org.apache.hadoop.hbase.regionserver;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
-import java.util.Random;
+import java.util.concurrent.ThreadLocalRandom;
+import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
-import org.apache.hadoop.hbase.HBaseTestCase;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Durability;
 import org.apache.hadoop.hbase.client.Put;
+import org.apache.hadoop.hbase.client.RegionInfo;
+import org.apache.hadoop.hbase.client.RegionInfoBuilder;
 import org.apache.hadoop.hbase.client.Scan;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.testclassification.RegionServerTests;
 import org.apache.hadoop.hbase.testclassification.SmallTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
+import org.junit.AfterClass;
+import org.junit.BeforeClass;
 import org.junit.ClassRule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
@@ -44,45 +53,66 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 @Category({ RegionServerTests.class, SmallTests.class })
-public class TestWideScanner extends HBaseTestCase {
+public class TestWideScanner {
 
   @ClassRule
   public static final HBaseClassTestRule CLASS_RULE =
     HBaseClassTestRule.forClass(TestWideScanner.class);
 
+  private static final HBaseTestingUtility UTIL = new HBaseTestingUtility();
+
   private static final Logger LOG = LoggerFactory.getLogger(TestWideScanner.class);
 
-  static final byte[] A = Bytes.toBytes("A");
-  static final byte[] B = Bytes.toBytes("B");
-  static final byte[] C = Bytes.toBytes("C");
-  static byte[][] COLUMNS = { A, B, C };
-  static final Random rng = new Random();
-  static final HTableDescriptor TESTTABLEDESC =
-    new HTableDescriptor(TableName.valueOf("testwidescan"));
+  private static final byte[] A = Bytes.toBytes("A");
+  private static final byte[] B = Bytes.toBytes("B");
+  private static final byte[] C = Bytes.toBytes("C");
+  private static byte[][] COLUMNS = { A, B, C };
+
+  private static final TableDescriptor TESTTABLEDESC;
   static {
+    TableDescriptorBuilder builder =
+      TableDescriptorBuilder.newBuilder(TableName.valueOf("testwidescan"));
     for (byte[] cfName : new byte[][] { A, B, C }) {
-      TESTTABLEDESC.addFamily(new HColumnDescriptor(cfName)
-        // Keep versions to help debugging.
-        .setMaxVersions(100).setBlocksize(8 * 1024));
+      // Keep versions to help debugging.
+      builder.setColumnFamily(ColumnFamilyDescriptorBuilder.newBuilder(cfName).setMaxVersions(100)
+        .setBlocksize(8 * 1024).build());
     }
+    TESTTABLEDESC = builder.build();
   }
 
   /** HRegionInfo for root region */
-  HRegion r;
+  private static HRegion REGION;
+
+  @BeforeClass
+  public static void setUp() throws IOException {
+    Path testDir = UTIL.getDataTestDir();
+    RegionInfo hri = RegionInfoBuilder.newBuilder(TESTTABLEDESC.getTableName()).build();
+    REGION =
+      HBaseTestingUtility.createRegionAndWAL(hri, testDir, UTIL.getConfiguration(), TESTTABLEDESC);
+  }
+
+  @AfterClass
+  public static void tearDown() throws IOException {
+    if (REGION != null) {
+      HBaseTestingUtility.closeRegionAndWAL(REGION);
+      REGION = null;
+    }
+    UTIL.cleanupTestDir();
+  }
 
   private int addWideContent(HRegion region) throws IOException {
     int count = 0;
     for (char c = 'a'; c <= 'c'; c++) {
       byte[] row = Bytes.toBytes("ab" + c);
       int i, j;
-      long ts = System.currentTimeMillis();
+      long ts = EnvironmentEdgeManager.currentTime();
       for (i = 0; i < 100; i++) {
         byte[] b = Bytes.toBytes(String.format("%10d", i));
         for (j = 0; j < 100; j++) {
           Put put = new Put(row);
           put.setDurability(Durability.SKIP_WAL);
           long ts1 = ++ts;
-          put.addColumn(COLUMNS[rng.nextInt(COLUMNS.length)], b, ts1, b);
+          put.addColumn(COLUMNS[ThreadLocalRandom.current().nextInt(COLUMNS.length)], b, ts1, b);
           region.put(put);
           count++;
         }
@@ -94,17 +124,15 @@ public class TestWideScanner extends HBaseTestCase {
   @Test
   public void testWideScanBatching() throws IOException {
     final int batch = 256;
-    try {
-      this.r = createNewHRegion(TESTTABLEDESC, null, null);
-      int inserted = addWideContent(this.r);
-      List<Cell> results = new ArrayList<>();
-      Scan scan = new Scan();
-      scan.addFamily(A);
-      scan.addFamily(B);
-      scan.addFamily(C);
-      scan.setMaxVersions(100);
-      scan.setBatch(batch);
-      InternalScanner s = r.getScanner(scan);
+    int inserted = addWideContent(REGION);
+    List<Cell> results = new ArrayList<>();
+    Scan scan = new Scan();
+    scan.addFamily(A);
+    scan.addFamily(B);
+    scan.addFamily(C);
+    scan.readVersions(100);
+    scan.setBatch(batch);
+    try (InternalScanner s = REGION.getScanner(scan)) {
       int total = 0;
       int i = 0;
       boolean more;
@@ -129,22 +157,16 @@ public class TestWideScanner extends HBaseTestCase {
         results.clear();
 
         // trigger ChangedReadersObservers
-        Iterator<KeyValueScanner> scanners =
-          ((HRegion.RegionScannerImpl) s).storeHeap.getHeap().iterator();
+        Iterator<KeyValueScanner> scanners = ((RegionScannerImpl) s).storeHeap.getHeap().iterator();
         while (scanners.hasNext()) {
           StoreScanner ss = (StoreScanner) scanners.next();
-          ss.updateReaders(Collections.EMPTY_LIST, Collections.EMPTY_LIST);
+          ss.updateReaders(Collections.emptyList(), Collections.emptyList());
         }
       } while (more);
 
       // assert that the scanner returned all values
       LOG.info("inserted " + inserted + ", scanned " + total);
       assertEquals(total, inserted);
-
-      s.close();
-    } finally {
-      HBaseTestingUtility.closeRegionAndWAL(this.r);
     }
   }
-
 }
