@@ -462,7 +462,7 @@ public abstract class TestReplicationSourceManager {
   /**
    * Test whether calling removePeer() on a ReplicationSourceManager that failed on initializing the
    * corresponding ReplicationSourceInterface correctly cleans up the corresponding replication
-   * queue and ReplicationPeer. See HBASE-16096. n
+   * queue and ReplicationPeer. See HBASE-16096.
    */
   @Test
   public void testPeerRemovalCleanup() throws Exception {
@@ -554,9 +554,44 @@ public abstract class TestReplicationSourceManager {
     }
   }
 
+  @Test
+  public void testDisablePeerMetricsCleanup() throws Exception {
+    final String peerId = "DummyPeer";
+    final ReplicationPeerConfig peerConfig = ReplicationPeerConfig.newBuilder()
+      .setClusterKey(utility.getZkCluster().getAddress().toString() + ":/hbase").build();
+    try {
+      MetricsReplicationSourceSource globalSource = getGlobalSource();
+      final int globalLogQueueSizeInitial = globalSource.getSizeOfLogQueue();
+      final long sizeOfLatestPath = getSizeOfLatestPath();
+      addPeerAndWait(peerId, peerConfig, true);
+      assertEquals(sizeOfLatestPath + globalLogQueueSizeInitial, globalSource.getSizeOfLogQueue());
+      ReplicationSourceInterface source = manager.getSource(peerId);
+      // Sanity check
+      assertNotNull(source);
+      final int sizeOfSingleLogQueue = source.getSourceMetrics().getSizeOfLogQueue();
+      // Enqueue log and check if metrics updated
+      source.enqueueLog(new Path("abc"));
+      assertEquals(1 + sizeOfSingleLogQueue, source.getSourceMetrics().getSizeOfLogQueue());
+      assertEquals(source.getSourceMetrics().getSizeOfLogQueue() + globalLogQueueSizeInitial,
+        globalSource.getSizeOfLogQueue());
+
+      // Refreshing the peer should decrement the global and single source metrics
+      manager.refreshSources(peerId);
+      assertEquals(globalLogQueueSizeInitial, globalSource.getSizeOfLogQueue());
+
+      source = manager.getSource(peerId);
+      assertNotNull(source);
+      assertEquals(sizeOfSingleLogQueue, source.getSourceMetrics().getSizeOfLogQueue());
+      assertEquals(source.getSourceMetrics().getSizeOfLogQueue() + globalLogQueueSizeInitial,
+        globalSource.getSizeOfLogQueue());
+    } finally {
+      removePeerAndWait(peerId);
+    }
+  }
+
   /**
-   * Add a peer and wait for it to initialize nn * @param waitForSource Whether to wait for
-   * replication source to initialize n
+   * Add a peer and wait for it to initialize
+   * @param waitForSource Whether to wait for replication source to initialize
    */
   private void addPeerAndWait(final String peerId, final ReplicationPeerConfig peerConfig,
     final boolean waitForSource) throws Exception {
@@ -594,7 +629,7 @@ public abstract class TestReplicationSourceManager {
   }
 
   /**
-   * Remove a peer and wait for it to get cleaned up nn
+   * Remove a peer and wait for it to get cleaned up
    */
   private void removePeerAndWait(final String peerId) throws Exception {
     final ReplicationPeers rp = manager.getReplicationPeers();
