@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -58,12 +58,12 @@ import org.apache.hbase.thirdparty.com.google.common.collect.ListMultimap;
 /**
  * Test the reading and writing of access permissions on {@code _acl_} table.
  */
-@Category({SecurityTests.class, MediumTests.class})
+@Category({ SecurityTests.class, MediumTests.class })
 public class TestTablePermissions {
 
   @ClassRule
   public static final HBaseClassTestRule CLASS_RULE =
-      HBaseClassTestRule.forClass(TestTablePermissions.class);
+    HBaseClassTestRule.forClass(TestTablePermissions.class);
 
   private static final Logger LOG = LoggerFactory.getLogger(TestTablePermissions.class);
   private static final HBaseTestingUtility UTIL = new HBaseTestingUtility();
@@ -85,10 +85,8 @@ public class TestTablePermissions {
 
   private static String TEST_NAMESPACE = "perms_test_ns";
   private static String TEST_NAMESPACE2 = "perms_test_ns2";
-  private static TableName TEST_TABLE =
-      TableName.valueOf("perms_test");
-  private static TableName TEST_TABLE2 =
-      TableName.valueOf("perms_test2");
+  private static TableName TEST_TABLE = TableName.valueOf("perms_test");
+  private static TableName TEST_TABLE2 = TableName.valueOf("perms_test2");
   private static byte[] TEST_FAMILY = Bytes.toBytes("f1");
   private static byte[] TEST_QUALIFIER = Bytes.toBytes("col1");
 
@@ -103,8 +101,7 @@ public class TestTablePermissions {
     // Wait for the ACL table to become available
     UTIL.waitTableEnabled(PermissionStorage.ACL_TABLE_NAME);
 
-    ZKW = new ZKWatcher(UTIL.getConfiguration(),
-      "TestTablePermissions", ABORTABLE);
+    ZKW = new ZKWatcher(UTIL.getConfiguration(), "TestTablePermissions", ABORTABLE);
 
     UTIL.createTable(TEST_TABLE, TEST_FAMILY);
     UTIL.createTable(TEST_TABLE2, TEST_FAMILY);
@@ -119,7 +116,7 @@ public class TestTablePermissions {
   public void tearDown() throws Exception {
     Configuration conf = UTIL.getConfiguration();
     try (Connection connection = ConnectionFactory.createConnection(conf);
-        Table table = connection.getTable(PermissionStorage.ACL_TABLE_NAME)) {
+      Table table = connection.getTable(PermissionStorage.ACL_TABLE_NAME)) {
       PermissionStorage.removeTablePermissions(conf, TEST_TABLE, table);
       PermissionStorage.removeTablePermissions(conf, TEST_TABLE2, table);
       PermissionStorage.removeTablePermissions(conf, PermissionStorage.ACL_TABLE_NAME, table);
@@ -129,7 +126,8 @@ public class TestTablePermissions {
   /**
    * The PermissionStorage.addUserPermission may throw exception before closing the table.
    */
-  private void addUserPermission(Configuration conf, UserPermission userPerm, Table t) throws IOException {
+  private void addUserPermission(Configuration conf, UserPermission userPerm, Table t)
+    throws IOException {
     try {
       PermissionStorage.addUserPermission(conf, userPerm, t);
     } finally {
@@ -144,29 +142,28 @@ public class TestTablePermissions {
       // add some permissions
       addUserPermission(conf,
         new UserPermission("george",
-            Permission.newBuilder(TEST_TABLE)
-                .withActions(Permission.Action.READ, Permission.Action.WRITE).build()),
+          Permission.newBuilder(TEST_TABLE)
+            .withActions(Permission.Action.READ, Permission.Action.WRITE).build()),
         connection.getTable(PermissionStorage.ACL_TABLE_NAME));
       addUserPermission(conf,
         new UserPermission("hubert",
-            Permission.newBuilder(TEST_TABLE).withActions(Permission.Action.READ).build()),
+          Permission.newBuilder(TEST_TABLE).withActions(Permission.Action.READ).build()),
         connection.getTable(PermissionStorage.ACL_TABLE_NAME));
       addUserPermission(conf,
         new UserPermission("humphrey",
-            Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY).withQualifier(TEST_QUALIFIER)
-                .withActions(Permission.Action.READ).build()),
+          Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY).withQualifier(TEST_QUALIFIER)
+            .withActions(Permission.Action.READ).build()),
         connection.getTable(PermissionStorage.ACL_TABLE_NAME));
     }
     // retrieve the same
     ListMultimap<String, UserPermission> perms =
-        PermissionStorage.getTablePermissions(conf, TEST_TABLE);
+      PermissionStorage.getTablePermissions(conf, TEST_TABLE);
     List<UserPermission> userPerms = perms.get("george");
     assertNotNull("Should have permissions for george", userPerms);
     assertEquals("Should have 1 permission for george", 1, userPerms.size());
     assertEquals(Permission.Scope.TABLE, userPerms.get(0).getAccessScope());
     TablePermission permission = (TablePermission) userPerms.get(0).getPermission();
-    assertEquals("Permission should be for " + TEST_TABLE,
-        TEST_TABLE, permission.getTableName());
+    assertEquals("Permission should be for " + TEST_TABLE, TEST_TABLE, permission.getTableName());
     assertNull("Column family should be empty", permission.getFamily());
 
     // check actions
@@ -181,8 +178,7 @@ public class TestTablePermissions {
     assertEquals("Should have 1 permission for hubert", 1, userPerms.size());
     assertEquals(Permission.Scope.TABLE, userPerms.get(0).getAccessScope());
     permission = (TablePermission) userPerms.get(0).getPermission();
-    assertEquals("Permission should be for " + TEST_TABLE,
-        TEST_TABLE, permission.getTableName());
+    assertEquals("Permission should be for " + TEST_TABLE, TEST_TABLE, permission.getTableName());
     assertNull("Column family should be empty", permission.getFamily());
 
     // check actions
@@ -197,12 +193,11 @@ public class TestTablePermissions {
     assertEquals("Should have 1 permission for humphrey", 1, userPerms.size());
     assertEquals(Permission.Scope.TABLE, userPerms.get(0).getAccessScope());
     permission = (TablePermission) userPerms.get(0).getPermission();
-    assertEquals("Permission should be for " + TEST_TABLE,
-        TEST_TABLE, permission.getTableName());
+    assertEquals("Permission should be for " + TEST_TABLE, TEST_TABLE, permission.getTableName());
     assertTrue("Permission should be for family " + Bytes.toString(TEST_FAMILY),
-        Bytes.equals(TEST_FAMILY, permission.getFamily()));
+      Bytes.equals(TEST_FAMILY, permission.getFamily()));
     assertTrue("Permission should be for qualifier " + Bytes.toString(TEST_QUALIFIER),
-        Bytes.equals(TEST_QUALIFIER, permission.getQualifier()));
+      Bytes.equals(TEST_QUALIFIER, permission.getQualifier()));
 
     // check actions
     assertNotNull(permission.getActions());
@@ -213,16 +208,16 @@ public class TestTablePermissions {
 
     // table 2 permissions
     try (Connection connection = ConnectionFactory.createConnection(conf);
-        Table table = connection.getTable(PermissionStorage.ACL_TABLE_NAME)) {
+      Table table = connection.getTable(PermissionStorage.ACL_TABLE_NAME)) {
       PermissionStorage.addUserPermission(conf,
         new UserPermission("hubert", Permission.newBuilder(TEST_TABLE2)
-            .withActions(Permission.Action.READ, Permission.Action.WRITE).build()),
+          .withActions(Permission.Action.READ, Permission.Action.WRITE).build()),
         table);
     }
     // check full load
     Map<byte[], ListMultimap<String, UserPermission>> allPerms = PermissionStorage.loadAll(conf);
-    assertEquals("Full permission map should have entries for both test tables",
-        2, allPerms.size());
+    assertEquals("Full permission map should have entries for both test tables", 2,
+      allPerms.size());
 
     userPerms = allPerms.get(TEST_TABLE.getName()).get("hubert");
     assertNotNull(userPerms);
@@ -251,27 +246,27 @@ public class TestTablePermissions {
     try (Connection connection = ConnectionFactory.createConnection(conf)) {
       addUserPermission(conf,
         new UserPermission("albert",
-            Permission.newBuilder(TEST_TABLE).withActions(Permission.Action.READ).build()),
+          Permission.newBuilder(TEST_TABLE).withActions(Permission.Action.READ).build()),
         connection.getTable(PermissionStorage.ACL_TABLE_NAME));
       addUserPermission(conf,
         new UserPermission("betty",
-            Permission.newBuilder(TEST_TABLE)
-                .withActions(Permission.Action.READ, Permission.Action.WRITE).build()),
+          Permission.newBuilder(TEST_TABLE)
+            .withActions(Permission.Action.READ, Permission.Action.WRITE).build()),
         connection.getTable(PermissionStorage.ACL_TABLE_NAME));
       addUserPermission(conf,
         new UserPermission("clark",
-            Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY)
-                .withActions(Permission.Action.READ).build()),
+          Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY)
+            .withActions(Permission.Action.READ).build()),
         connection.getTable(PermissionStorage.ACL_TABLE_NAME));
       addUserPermission(conf,
         new UserPermission("dwight",
-            Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY).withQualifier(TEST_QUALIFIER)
-                .withActions(Permission.Action.WRITE).build()),
+          Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY).withQualifier(TEST_QUALIFIER)
+            .withActions(Permission.Action.WRITE).build()),
         connection.getTable(PermissionStorage.ACL_TABLE_NAME));
     }
     // verify permissions survive changes in table metadata
     ListMultimap<String, UserPermission> preperms =
-        PermissionStorage.getTablePermissions(conf, TEST_TABLE);
+      PermissionStorage.getTablePermissions(conf, TEST_TABLE);
 
     Table table = UTIL.getConnection().getTable(TEST_TABLE);
     table.put(
@@ -281,12 +276,11 @@ public class TestTablePermissions {
     Admin admin = UTIL.getAdmin();
     try {
       admin.split(TEST_TABLE);
-    }
-    catch (IOException e) {
-      //although split fail, this may not affect following check
-      //In old Split API without AM2, if region's best split key is not found,
-      //there are not exception thrown. But in current API, exception
-      //will be thrown.
+    } catch (IOException e) {
+      // although split fail, this may not affect following check
+      // In old Split API without AM2, if region's best split key is not found,
+      // there are not exception thrown. But in current API, exception
+      // will be thrown.
       LOG.debug("region is not splittable, because " + e);
     }
 
@@ -294,7 +288,7 @@ public class TestTablePermissions {
     Thread.sleep(10000);
 
     ListMultimap<String, UserPermission> postperms =
-        PermissionStorage.getTablePermissions(conf, TEST_TABLE);
+      PermissionStorage.getTablePermissions(conf, TEST_TABLE);
 
     checkMultimapEqual(preperms, postperms);
   }
@@ -306,7 +300,7 @@ public class TestTablePermissions {
     byte[] permsData = PermissionStorage.writePermissionsAsBytes(permissions, conf);
 
     ListMultimap<String, UserPermission> copy =
-        PermissionStorage.readUserPermission(permsData, conf);
+      PermissionStorage.readUserPermission(permsData, conf);
 
     checkMultimapEqual(permissions, copy);
   }
@@ -314,30 +308,30 @@ public class TestTablePermissions {
   private ListMultimap<String, UserPermission> createPermissions() {
     ListMultimap<String, UserPermission> permissions = ArrayListMultimap.create();
     permissions.put("george", new UserPermission("george",
-        Permission.newBuilder(TEST_TABLE).withActions(Permission.Action.READ).build()));
+      Permission.newBuilder(TEST_TABLE).withActions(Permission.Action.READ).build()));
     permissions.put("george", new UserPermission("george", Permission.newBuilder(TEST_TABLE)
-        .withFamily(TEST_FAMILY).withActions(Permission.Action.WRITE).build()));
+      .withFamily(TEST_FAMILY).withActions(Permission.Action.WRITE).build()));
     permissions.put("george", new UserPermission("george",
-        Permission.newBuilder(TEST_TABLE2).withActions(Permission.Action.READ).build()));
+      Permission.newBuilder(TEST_TABLE2).withActions(Permission.Action.READ).build()));
     permissions.put("hubert", new UserPermission("hubert", Permission.newBuilder(TEST_TABLE2)
-        .withActions(Permission.Action.READ, Permission.Action.WRITE).build()));
+      .withActions(Permission.Action.READ, Permission.Action.WRITE).build()));
     permissions.put("bruce", new UserPermission("bruce",
-        Permission.newBuilder(TEST_NAMESPACE).withActions(Permission.Action.READ).build()));
+      Permission.newBuilder(TEST_NAMESPACE).withActions(Permission.Action.READ).build()));
     return permissions;
   }
 
   public void checkMultimapEqual(ListMultimap<String, UserPermission> first,
-      ListMultimap<String, UserPermission> second) {
+    ListMultimap<String, UserPermission> second) {
     assertEquals(first.size(), second.size());
     for (String key : first.keySet()) {
       List<UserPermission> firstPerms = first.get(key);
       List<UserPermission> secondPerms = second.get(key);
       assertNotNull(secondPerms);
       assertEquals(firstPerms.size(), secondPerms.size());
-      LOG.info("First permissions: "+firstPerms.toString());
-      LOG.info("Second permissions: "+secondPerms.toString());
+      LOG.info("First permissions: " + firstPerms.toString());
+      LOG.info("Second permissions: " + secondPerms.toString());
       for (UserPermission p : firstPerms) {
-        assertTrue("Permission "+p.toString()+" not found", secondPerms.contains(p));
+        assertTrue("Permission " + p.toString() + " not found", secondPerms.contains(p));
       }
     }
   }
@@ -350,29 +344,29 @@ public class TestTablePermissions {
     assertTrue(p2.equals(p1));
 
     p1 = Permission.newBuilder(TEST_TABLE)
-        .withActions(TablePermission.Action.READ, TablePermission.Action.WRITE).build();
+      .withActions(TablePermission.Action.READ, TablePermission.Action.WRITE).build();
     p2 = Permission.newBuilder(TEST_TABLE)
-        .withActions(TablePermission.Action.WRITE, TablePermission.Action.READ).build();
+      .withActions(TablePermission.Action.WRITE, TablePermission.Action.READ).build();
     assertTrue(p1.equals(p2));
     assertTrue(p2.equals(p1));
 
     p1 = Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY)
-        .withActions(TablePermission.Action.READ, TablePermission.Action.WRITE).build();
+      .withActions(TablePermission.Action.READ, TablePermission.Action.WRITE).build();
     p2 = Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY)
-        .withActions(TablePermission.Action.WRITE, TablePermission.Action.READ).build();
+      .withActions(TablePermission.Action.WRITE, TablePermission.Action.READ).build();
     assertTrue(p1.equals(p2));
     assertTrue(p2.equals(p1));
 
     p1 = Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY).withQualifier(TEST_QUALIFIER)
-        .withActions(TablePermission.Action.READ, TablePermission.Action.WRITE).build();
+      .withActions(TablePermission.Action.READ, TablePermission.Action.WRITE).build();
     p2 = Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY).withQualifier(TEST_QUALIFIER)
-        .withActions(TablePermission.Action.WRITE, TablePermission.Action.READ).build();
+      .withActions(TablePermission.Action.WRITE, TablePermission.Action.READ).build();
     assertTrue(p1.equals(p2));
     assertTrue(p2.equals(p1));
 
     p1 = Permission.newBuilder(TEST_TABLE).withActions(TablePermission.Action.READ).build();
     p2 = Permission.newBuilder(TEST_TABLE).withFamily(TEST_FAMILY)
-        .withActions(TablePermission.Action.READ).build();
+      .withActions(TablePermission.Action.READ).build();
     assertFalse(p1.equals(p2));
     assertFalse(p2.equals(p1));
 
@@ -381,7 +375,7 @@ public class TestTablePermissions {
     assertFalse(p1.equals(p2));
     assertFalse(p2.equals(p1));
     p2 = Permission.newBuilder(TEST_TABLE)
-        .withActions(TablePermission.Action.READ, TablePermission.Action.WRITE).build();
+      .withActions(TablePermission.Action.READ, TablePermission.Action.WRITE).build();
     assertFalse(p1.equals(p2));
     assertFalse(p2.equals(p1));
 
@@ -408,48 +402,46 @@ public class TestTablePermissions {
     try (Connection connection = ConnectionFactory.createConnection(conf)) {
       addUserPermission(conf,
         new UserPermission("user1", Permission.newBuilder()
-            .withActions(Permission.Action.READ, Permission.Action.WRITE).build()),
+          .withActions(Permission.Action.READ, Permission.Action.WRITE).build()),
         connection.getTable(PermissionStorage.ACL_TABLE_NAME));
       addUserPermission(conf,
         new UserPermission("user2",
-            Permission.newBuilder().withActions(Permission.Action.CREATE).build()),
+          Permission.newBuilder().withActions(Permission.Action.CREATE).build()),
         connection.getTable(PermissionStorage.ACL_TABLE_NAME));
       addUserPermission(conf,
         new UserPermission("user3",
-            Permission.newBuilder()
-                .withActions(Permission.Action.ADMIN, Permission.Action.READ,
-                  Permission.Action.CREATE)
-                .build()),
+          Permission.newBuilder()
+            .withActions(Permission.Action.ADMIN, Permission.Action.READ, Permission.Action.CREATE)
+            .build()),
         connection.getTable(PermissionStorage.ACL_TABLE_NAME));
     }
     ListMultimap<String, UserPermission> perms = PermissionStorage.getTablePermissions(conf, null);
     List<UserPermission> user1Perms = perms.get("user1");
     assertEquals("Should have 1 permission for user1", 1, user1Perms.size());
     assertEquals("user1 should have WRITE permission",
-                 new Permission.Action[] { Permission.Action.READ, Permission.Action.WRITE },
-                 user1Perms.get(0).getPermission().getActions());
+      new Permission.Action[] { Permission.Action.READ, Permission.Action.WRITE },
+      user1Perms.get(0).getPermission().getActions());
 
     List<UserPermission> user2Perms = perms.get("user2");
     assertEquals("Should have 1 permission for user2", 1, user2Perms.size());
     assertEquals("user2 should have CREATE permission",
-                 new Permission.Action[] { Permission.Action.CREATE },
-                 user2Perms.get(0).getPermission().getActions());
+      new Permission.Action[] { Permission.Action.CREATE },
+      user2Perms.get(0).getPermission().getActions());
 
     List<UserPermission> user3Perms = perms.get("user3");
     assertEquals("Should have 1 permission for user3", 1, user3Perms.size());
-    assertEquals("user3 should have ADMIN, READ, CREATE permission",
-                 new Permission.Action[] {
-                    Permission.Action.READ, Permission.Action.CREATE, Permission.Action.ADMIN
-                 },
-                 user3Perms.get(0).getPermission().getActions());
+    assertEquals(
+      "user3 should have ADMIN, READ, CREATE permission", new Permission.Action[] {
+        Permission.Action.READ, Permission.Action.CREATE, Permission.Action.ADMIN },
+      user3Perms.get(0).getPermission().getActions());
   }
 
   @Test
   public void testAuthManager() throws Exception {
     Configuration conf = UTIL.getConfiguration();
     /**
-     * test a race condition causing AuthManager to sometimes fail global permissions checks
-     * when the global cache is being updated
+     * test a race condition causing AuthManager to sometimes fail global permissions checks when
+     * the global cache is being updated
      */
     AuthManager authManager = new AuthManager(conf);
     // currently running user is the system user and should have global admin perms
@@ -459,13 +451,12 @@ public class TestTablePermissions {
       for (int i = 1; i <= 50; i++) {
         addUserPermission(conf,
           new UserPermission("testauth" + i,
-              Permission.newBuilder()
-                  .withActions(Permission.Action.ADMIN, Permission.Action.READ,
-                    Permission.Action.WRITE)
-                  .build()),
+            Permission.newBuilder()
+              .withActions(Permission.Action.ADMIN, Permission.Action.READ, Permission.Action.WRITE)
+              .build()),
           connection.getTable(PermissionStorage.ACL_TABLE_NAME));
         // make sure the system user still shows as authorized
-        assertTrue("Failed current user auth check on iter "+i,
+        assertTrue("Failed current user auth check on iter " + i,
           authManager.authorizeUserGlobal(currentUser, Permission.Action.ADMIN));
       }
     }
