@@ -94,7 +94,7 @@ public final class SnapshotTestingUtils {
   }
 
   /**
-   * Assert that we don't have any snapshots lists n * if the admin operation fails
+   * Assert that we don't have any snapshots lists if the admin operation fails
    */
   public static void assertNoSnapshots(Admin admin) throws IOException {
     assertEquals("Have some previous snapshots", 0, admin.listSnapshots().size());
@@ -297,11 +297,21 @@ public final class SnapshotTestingUtils {
    */
   public static void snapshot(Admin admin, final String snapshotName, final TableName tableName,
     final SnapshotType type, final int numTries) throws IOException {
+    snapshot(admin, snapshotName, tableName, type, numTries, null);
+  }
+
+  /*
+   * Take snapshot having snapshot properties with maximum of numTries attempts, ignoring
+   * CorruptedSnapshotException except for the last CorruptedSnapshotException
+   */
+  public static void snapshot(Admin admin, final String snapshotName, final TableName tableName,
+    final SnapshotType type, final int numTries, Map<String, Object> snapshotProps)
+    throws IOException {
     int tries = 0;
     CorruptedSnapshotException lastEx = null;
     while (tries++ < numTries) {
       try {
-        admin.snapshot(snapshotName, tableName, type);
+        admin.snapshot(snapshotName, tableName, type, snapshotProps);
         return;
       } catch (CorruptedSnapshotException cse) {
         LOG.warn("Got CorruptedSnapshotException", cse);
