@@ -133,7 +133,8 @@ public class TestWALSplitToHFile {
     this.rootDir = CommonFSUtils.getRootDir(this.conf);
     this.oldLogDir = new Path(this.rootDir, HConstants.HREGION_OLDLOGDIR_NAME);
     String serverName = ServerName
-      .valueOf(TEST_NAME.getMethodName() + "-manual", 16010, System.currentTimeMillis()).toString();
+      .valueOf(TEST_NAME.getMethodName() + "-manual", 16010, EnvironmentEdgeManager.currentTime())
+      .toString();
     this.logName = AbstractFSWALProvider.getWALDirectoryName(serverName);
     this.logDir = new Path(this.rootDir, logName);
     if (UTIL.getDFSCluster().getFileSystem().exists(this.rootDir)) {
@@ -209,7 +210,8 @@ public class TestWALSplitToHFile {
     FileSystem walFs = CommonFSUtils.getWALFileSystem(this.conf);
     this.oldLogDir = new Path(walRootDir, HConstants.HREGION_OLDLOGDIR_NAME);
     String serverName = ServerName
-      .valueOf(TEST_NAME.getMethodName() + "-manual", 16010, System.currentTimeMillis()).toString();
+      .valueOf(TEST_NAME.getMethodName() + "-manual", 16010, EnvironmentEdgeManager.currentTime())
+      .toString();
     this.logName = AbstractFSWALProvider.getWALDirectoryName(serverName);
     this.logDir = new Path(walRootDir, logName);
     this.wals = new WALFactory(conf, TEST_NAME.getMethodName());
