@@ -56,6 +56,7 @@ import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.io.crypto.KeyProviderForTesting;
 import org.apache.hadoop.hbase.regionserver.HRegion;
 import org.apache.hadoop.hbase.regionserver.LogRoller;
+import org.apache.hadoop.hbase.regionserver.MemStoreLAB;
 import org.apache.hadoop.hbase.regionserver.MultiVersionConcurrencyControl;
 import org.apache.hadoop.hbase.regionserver.wal.SecureProtobufLogReader;
 import org.apache.hadoop.hbase.regionserver.wal.SecureProtobufLogWriter;
@@ -273,6 +274,9 @@ public final class WALPerformanceEvaluation extends Configured implements Tool {
     // Internal config. goes off number of threads; if more threads than handlers, stuff breaks.
     // In regionserver, number of handlers == number of threads.
     getConf().setInt(HConstants.REGION_SERVER_HANDLER_COUNT, numThreads);
+    // We do not need memstore here, so disable memstore lab, otherwise we need to initialize
+    // ChunkCreator
+    getConf().setBoolean(MemStoreLAB.USEMSLAB_KEY, false);
 
     if (rootRegionDir == null) {
       TEST_UTIL = new HBaseTestingUtility(getConf());
@@ -372,7 +376,8 @@ public final class WALPerformanceEvaluation extends Configured implements Tool {
 
   /**
    * Verify the content of the WAL file. Verify that the file has expected number of edits.
-   * @param wals may not be null n * @return Count of edits. n
+   * @param wals may not be null
+   * @return Count of edits.
    */
   private long verify(final WALFactory wals, final Path wal, final boolean verbose)
     throws IOException {
@@ -536,7 +541,7 @@ public final class WALPerformanceEvaluation extends Configured implements Tool {
 
   /**
    * The guts of the {@link #main} method. Call this method to avoid the {@link #main(String[])}
-   * System.exit. nnn
+   * System.exit.
    */
   static int innerMain(final Configuration c, final String[] args) throws Exception {
     return ToolRunner.run(c, new WALPerformanceEvaluation(), args);
