@@ -38,8 +38,11 @@
 include Java
 
 # Some goodies for hirb. Should these be left up to the user's discretion?
-require 'irb/completion'
+if $stdin.tty?
+  require 'irb/completion'
+end
 require 'pathname'
+require 'getoptlong'
 
 # Add the directory names in hbase.jruby.sources commandline option
 # to the ruby load path so I can load up my HBase ruby modules
@@ -50,11 +53,6 @@ unless sources.nil?
   $LOAD_PATH.unshift Pathname.new(sources)
 end
 
-#
-# FIXME: Switch args processing to getopt
-#
-# See if there are args for this shell. If any, read and then strip from ARGV
-# so they don't go through to irb.  Output shell 'usage' if user types '--help'
 cmdline_help = <<HERE # HERE document output as shell usage
 Usage: shell [OPTIONS] [SCRIPTFILE [ARGUMENTS]]
 
@@ -82,60 +80,66 @@ def add_to_configuration(c, arg)
   c
 end
 
-found = []
+conf_from_cli = nil
+
+# strip out any config definitions that won't work with GetoptLong
+D_ARG = '-D'.freeze
+ARGV.delete_if do |arg|
+  if arg.start_with?(D_ARG) && arg.include?('=')
+    conf_from_cli = add_to_configuration(conf_from_cli, arg[2..-1])
+    true
+  else
+    false
+  end
+end
+
+opts = GetoptLong.new(
+  ['--help', '-h', GetoptLong::NO_ARGUMENT],
+  ['--debug', '-d', GetoptLong::NO_ARGUMENT],
+  ['--noninteractive', '-n', GetoptLong::NO_ARGUMENT],
+  ['--top-level-defs', GetoptLong::NO_ARGUMENT],
+  ['-D', GetoptLong::REQUIRED_ARGUMENT],
+  ['--return-values', '-r', GetoptLong::NO_ARGUMENT]
+)
+opts.ordering = GetoptLong::REQUIRE_ORDER
+
 script2run = nil
-log_level = org.apache.log4j.Level::ERROR
+log_level = 'ERROR'
 @shell_debug = false
 interactive = true
 full_backtrace = false
 top_level_definitions = false
-_configuration = nil
-D_ARG = '-D'.freeze
-while (arg = ARGV.shift)
-  if arg == '-h' || arg == '--help'
+
+opts.each do |opt, arg|
+  case opt
+  when '--help'
     puts cmdline_help
     exit
-  elsif arg == D_ARG
-    argValue = ARGV.shift || (raise "#{D_ARG} takes a 'key=value' parameter")
-    _configuration = add_to_configuration(_configuration, argValue)
-    found.push(arg)
-    found.push(argValue)
-  elsif arg.start_with? D_ARG
-    _configuration = add_to_configuration(_configuration, arg[2..-1])
-    found.push(arg)
-  elsif arg == '-d' || arg == '--debug'
-    log_level = org.apache.log4j.Level::DEBUG
+  when D_ARG
+    conf_from_cli = add_to_configuration(conf_from_cli, arg)
+  when '--debug'
+    log_level = 'DEBUG'
     full_backtrace = true
     @shell_debug = true
-    found.push(arg)
     puts 'Setting DEBUG log level...'
-  elsif arg == '-n' || arg == '--noninteractive'
+  when '--noninteractive'
     interactive = false
-    found.push(arg)
-  elsif arg == '-r' || arg == '--return-values'
+  when '--return-values'
     warn '[INFO] the -r | --return-values option is ignored. we always behave '\
-         'as though it was given.'
-    found.push(arg)
-  elsif arg == '--top-level-defs'
+           'as though it was given.'
+  when '--top-level-defs'
     top_level_definitions = true
-  else
-    # Presume it a script. Save it off for running later below
-    # after we've set up some environment.
-    script2run = arg
-    found.push(arg)
-    # Presume that any other args are meant for the script.
-    break
   end
 end
 
-# Delete all processed args
-found.each { |arg| ARGV.delete(arg) }
+script2run = ARGV.shift unless ARGV.empty?
+
 # Make sure debug flag gets back to IRB
 ARGV.unshift('-d') if @shell_debug
 
 # Set logging level to avoid verboseness
-org.apache.log4j.Logger.getLogger('org.apache.zookeeper').setLevel(log_level)
-org.apache.log4j.Logger.getLogger('org.apache.hadoop.hbase').setLevel(log_level)
+org.apache.hadoop.hbase.logging.Log4jUtils.setAllLevels('org.apache.zookeeper', log_level)
+org.apache.hadoop.hbase.logging.Log4jUtils.setAllLevels('org.apache.hadoop', log_level)
 
 # Require HBase now after setting log levels
 require 'hbase_constants'
@@ -147,7 +151,7 @@ require 'hbase_shell'
 require 'shell/formatter'
 
 # Setup the HBase module.  Create a configuration.
-@hbase = _configuration.nil? ? Hbase::Hbase.new : Hbase::Hbase.new(_configuration)
+@hbase = conf_from_cli.nil? ? Hbase::Hbase.new : Hbase::Hbase.new(conf_from_cli)
 
 # Setup console
 @shell = Shell::Shell.new(@hbase, interactive)
@@ -161,14 +165,14 @@ def debug
   if @shell_debug
     @shell_debug = false
     conf.back_trace_limit = 0
-    log_level = org.apache.log4j.Level::ERROR
+    log_level = 'ERROR'
   else
     @shell_debug = true
     conf.back_trace_limit = 100
-    log_level = org.apache.log4j.Level::DEBUG
+    log_level = 'DEBUG'
   end
-  org.apache.log4j.Logger.getLogger('org.apache.zookeeper').setLevel(log_level)
-  org.apache.log4j.Logger.getLogger('org.apache.hadoop.hbase').setLevel(log_level)
+  org.apache.hadoop.hbase.logging.Log4jUtils.setAllLevels('org.apache.zookeeper', log_level)
+  org.apache.hadoop.hbase.logging.Log4jUtils.setAllLevels('org.apache.hadoop', log_level)
   debug?
 end
 
@@ -209,7 +213,7 @@ workspace = @shell.get_workspace
 # script calls 'exit' or 'exit 0' or 'exit errcode'.
 if script2run
   ::Shell::Shell.exception_handler(!full_backtrace) do
-    IRB::HIRB.new(workspace, IRB::HBaseLoader.file_for_load(script2run)).run
+    IRB::HIRB.new(workspace, interactive, IRB::HBaseLoader.file_for_load(script2run)).run
   end
   exit @shell.exit_code unless @shell.exit_code.nil?
 end
@@ -218,9 +222,5 @@ if interactive
   # Output a banner message that tells users where to go for help
   @shell.print_banner
 end
-IRB::HIRB.new(workspace).run
-# Wrapping this check in the exception handler is only present in the 2.4.x line so that we can
-# maintain behavior that matches the earlier 2.x releases
-::Shell::Shell.exception_handler(!full_backtrace) do
-  exit @shell.exit_code unless interactive || @shell.exit_code.nil?
-end
+IRB::HIRB.new(workspace, interactive).run
+exit @shell.exit_code unless interactive || @shell.exit_code.nil?
