@@ -140,6 +140,14 @@ module Hbase
       command(:compaction_state, 'hbase:meta')
     end
 
+    #-------------------------------------------------------------------------------
+    define_test "compaction_switch should work" do
+      output = capture_stdout { command(:compaction_switch, false) }
+      assert(output.include?('PREV_STATE'))
+      output = capture_stdout { command(:compaction_switch, 'true') }
+      assert(output.include?('PREV_STATE'))
+    end
+
     #-------------------------------------------------------------------------------
 
     define_test "major_compact should work" do
