@@ -829,6 +829,11 @@ public class ThriftHBaseServiceHandler extends HBaseServiceHandler implements TH
     return TThriftServerType.TWO;
   }
 
+  @Override
+  public String getClusterId() throws TException {
+    return connectionCache.getClusterId();
+  }
+
   @Override
   public List<TOnlineLogRecord> getSlowLogResponses(Set<TServerName> tServerNames,
     TLogQueryFilter tLogQueryFilter) throws TIOError, TException {
