@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -59,12 +59,12 @@ import org.junit.ClassRule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 
-@Category({ClientTests.class, MediumTests.class})
+@Category({ ClientTests.class, MediumTests.class })
 public class TestThriftHBaseServiceHandlerWithReadOnly {
 
   @ClassRule
   public static final HBaseClassTestRule CLASS_RULE =
-      HBaseClassTestRule.forClass(TestThriftHBaseServiceHandlerWithReadOnly.class);
+    HBaseClassTestRule.forClass(TestThriftHBaseServiceHandlerWithReadOnly.class);
 
   private static final HBaseTestingUtility UTIL = new HBaseTestingUtility();
 
@@ -76,10 +76,9 @@ public class TestThriftHBaseServiceHandlerWithReadOnly {
   private static byte[] qualifierBname = Bytes.toBytes("qualifierB");
   private static byte[] valueAname = Bytes.toBytes("valueA");
   private static byte[] valueBname = Bytes.toBytes("valueB");
-  private static HColumnDescriptor[] families = new HColumnDescriptor[] {
-      new HColumnDescriptor(familyAname).setMaxVersions(3),
-      new HColumnDescriptor(familyBname).setMaxVersions(2)
-  };
+  private static HColumnDescriptor[] families =
+    new HColumnDescriptor[] { new HColumnDescriptor(familyAname).setMaxVersions(3),
+      new HColumnDescriptor(familyBname).setMaxVersions(2) };
 
   @BeforeClass
   public static void beforeClass() throws Exception {
@@ -222,23 +221,23 @@ public class TestThriftHBaseServiceHandlerWithReadOnly {
     ByteBuffer table = wrap(tableAname);
 
     List<TColumnValue> columnValuesA = new ArrayList<>(1);
-    TColumnValue columnValueA = new TColumnValue(wrap(familyAname), wrap(qualifierAname),
-        wrap(valueAname));
+    TColumnValue columnValueA =
+      new TColumnValue(wrap(familyAname), wrap(qualifierAname), wrap(valueAname));
     columnValuesA.add(columnValueA);
     TPut putA = new TPut(wrap(rowName), columnValuesA);
     putA.setColumnValues(columnValuesA);
 
     List<TColumnValue> columnValuesB = new ArrayList<>(1);
-    TColumnValue columnValueB = new TColumnValue(wrap(familyBname), wrap(qualifierBname),
-        wrap(valueBname));
+    TColumnValue columnValueB =
+      new TColumnValue(wrap(familyBname), wrap(qualifierBname), wrap(valueBname));
     columnValuesB.add(columnValueB);
     TPut putB = new TPut(wrap(rowName), columnValuesB);
     putB.setColumnValues(columnValuesB);
 
     boolean exceptionCaught = false;
     try {
-      handler.checkAndPut(table, wrap(rowName), wrap(familyAname),
-          wrap(qualifierAname), wrap(valueAname), putB);
+      handler.checkAndPut(table, wrap(rowName), wrap(familyAname), wrap(qualifierAname),
+        wrap(valueAname), putB);
     } catch (TIOError e) {
       exceptionCaught = true;
       assertTrue(e.getCause() instanceof DoNotRetryIOException);
@@ -332,13 +331,12 @@ public class TestThriftHBaseServiceHandlerWithReadOnly {
     TPut putB = new TPut(row, columnValuesB);
     putB.setColumnValues(columnValuesB);
 
-    TRowMutations tRowMutations = new TRowMutations(row,
-        Arrays.<TMutation> asList(TMutation.put(putB)));
+    TRowMutations tRowMutations =
+      new TRowMutations(row, Arrays.<TMutation> asList(TMutation.put(putB)));
 
     boolean exceptionCaught = false;
     try {
-      handler.checkAndMutate(table, row, family, qualifier, TCompareOp.EQUAL, value,
-          tRowMutations);
+      handler.checkAndMutate(table, row, family, qualifier, TCompareOp.EQUAL, value, tRowMutations);
     } catch (TIOError e) {
       exceptionCaught = true;
       assertTrue(e.getCause() instanceof DoNotRetryIOException);
@@ -358,8 +356,8 @@ public class TestThriftHBaseServiceHandlerWithReadOnly {
 
     boolean exceptionCaught = false;
     try {
-      handler.checkAndDelete(table, wrap(rowName), wrap(familyAname),
-          wrap(qualifierAname), wrap(valueAname), delete);
+      handler.checkAndDelete(table, wrap(rowName), wrap(familyAname), wrap(qualifierAname),
+        wrap(valueAname), delete);
     } catch (TIOError e) {
       exceptionCaught = true;
       assertTrue(e.getCause() instanceof DoNotRetryIOException);
@@ -421,8 +419,8 @@ public class TestThriftHBaseServiceHandlerWithReadOnly {
     ByteBuffer table = wrap(tableAname);
 
     List<TColumnValue> columnValuesA = new ArrayList<>(1);
-    TColumnValue columnValueA = new TColumnValue(wrap(familyAname), wrap(qualifierAname),
-        wrap(valueAname));
+    TColumnValue columnValueA =
+      new TColumnValue(wrap(familyAname), wrap(qualifierAname), wrap(valueAname));
     columnValuesA.add(columnValueA);
     TPut putA = new TPut(wrap(rowName), columnValuesA);
     putA.setColumnValues(columnValuesA);
@@ -434,11 +432,11 @@ public class TestThriftHBaseServiceHandlerWithReadOnly {
     mutations.add(mutationA);
     TMutation mutationB = TMutation.deleteSingle(delete);
     mutations.add(mutationB);
-    TRowMutations tRowMutations = new TRowMutations(wrap(rowName),mutations);
+    TRowMutations tRowMutations = new TRowMutations(wrap(rowName), mutations);
 
     boolean exceptionCaught = false;
     try {
-      handler.mutateRow(table,tRowMutations);
+      handler.mutateRow(table, tRowMutations);
     } catch (TIOError e) {
       exceptionCaught = true;
       assertTrue(e.getCause() instanceof DoNotRetryIOException);
