@@ -34,6 +34,7 @@ import org.apache.hadoop.hbase.AuthUtil;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.ZooKeeperConnectionException;
 import org.apache.hadoop.hbase.security.Superusers;
+import org.apache.hadoop.hbase.trace.TraceUtil;
 import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.Threads;
 import org.apache.hadoop.security.UserGroupInformation;
@@ -175,7 +176,8 @@ public class ZKWatcher implements Watcher, Abortable, Closeable {
     this.abortable = abortable;
     this.znodePaths = new ZNodePaths(conf);
     PendingWatcher pendingWatcher = new PendingWatcher();
-    this.recoverableZooKeeper = ZKUtil.connect(conf, quorum, pendingWatcher, identifier);
+    this.recoverableZooKeeper = RecoverableZooKeeper.connect(conf, quorum, pendingWatcher,
+      identifier, ZKConfig.getZKClientConfig(conf));
     pendingWatcher.prepare(this);
     if (canCreateBaseZNode) {
       try {
@@ -554,45 +556,47 @@ public class ZKWatcher implements Watcher, Abortable, Closeable {
   }
 
   private void processEvent(WatchedEvent event) {
-    switch (event.getType()) {
-      // If event type is NONE, this is a connection status change
-      case None: {
-        connectionEvent(event);
-        break;
-      }
-
-      // Otherwise pass along to the listeners
-      case NodeCreated: {
-        for (ZKListener listener : listeners) {
-          listener.nodeCreated(event.getPath());
+    TraceUtil.trace(() -> {
+      switch (event.getType()) {
+        // If event type is NONE, this is a connection status change
+        case None: {
+          connectionEvent(event);
+          break;
         }
-        break;
-      }
 
-      case NodeDeleted: {
-        for (ZKListener listener : listeners) {
-          listener.nodeDeleted(event.getPath());
+        // Otherwise pass along to the listeners
+        case NodeCreated: {
+          for (ZKListener listener : listeners) {
+            listener.nodeCreated(event.getPath());
+          }
+          break;
         }
-        break;
-      }
 
-      case NodeDataChanged: {
-        for (ZKListener listener : listeners) {
-          listener.nodeDataChanged(event.getPath());
+        case NodeDeleted: {
+          for (ZKListener listener : listeners) {
+            listener.nodeDeleted(event.getPath());
+          }
+          break;
         }
-        break;
-      }
 
-      case NodeChildrenChanged: {
-        for (ZKListener listener : listeners) {
-          listener.nodeChildrenChanged(event.getPath());
+        case NodeDataChanged: {
+          for (ZKListener listener : listeners) {
+            listener.nodeDataChanged(event.getPath());
+          }
+          break;
         }
-        break;
+
+        case NodeChildrenChanged: {
+          for (ZKListener listener : listeners) {
+            listener.nodeChildrenChanged(event.getPath());
+          }
+          break;
+        }
+        default:
+          LOG.error("Invalid event of type {} received for path {}. Ignoring.", event.getState(),
+            event.getPath());
       }
-      default:
-        LOG.error("Invalid event of type {} received for path {}. Ignoring.", event.getState(),
-          event.getPath());
-    }
+    }, "ZKWatcher.processEvent: " + event.getType() + " " + event.getPath());
   }
 
   /**
@@ -604,8 +608,9 @@ public class ZKWatcher implements Watcher, Abortable, Closeable {
   public void process(WatchedEvent event) {
     LOG.debug(prefix("Received ZooKeeper Event, " + "type=" + event.getType() + ", " + "state="
       + event.getState() + ", " + "path=" + event.getPath()));
+    final String spanName = ZKWatcher.class.getSimpleName() + "-" + identifier;
     if (!zkEventProcessor.isShutdown()) {
-      zkEventProcessor.submit(() -> processEvent(event));
+      zkEventProcessor.execute(TraceUtil.tracedRunnable(() -> processEvent(event), spanName));
     }
   }
 
